@@ -186,7 +186,7 @@
 <edge STYLE="bezier"/>
 </node>
 </node>
-<node CREATED="1202857342628" ID="Freemind_Link_1429727652" MODIFIED="1202857361258" TEXT="intial parameters">
+<node CREATED="1202857342628" ID="Freemind_Link_1429727652" MODIFIED="1202857361258" TEXT="initial parameters">
 <node CREATED="1150487450203" ID="Freemind_Link_789803054" MODIFIED="1202857507206" TEXT="initial time" VSHIFT="-5">
 <node CREATED="1150487477093" FOLDED="true" ID="Freemind_Link_398279288" MODIFIED="1202859413120" TEXT="start at preset sky time">
 <node CREATED="1202859416560" ID="Freemind_Link_1783872930" MODIFIED="1202859428220" TEXT="preset time list"/>
@@ -313,22 +313,22 @@
 </node>
 <node CREATED="1202853671886" ID="Freemind_Link_1987145465" MODIFIED="1202857115653" STYLE="fork" TEXT="amateur astronomer tools" VSHIFT="6">
 <cloud/>
-<node CREATED="1150481385281" FOLDED="true" ID="Freemind_Link_882075950" MODIFIED="1202855755737" TEXT="telescopes managment" VSHIFT="1">
+<node CREATED="1150481385281" FOLDED="true" ID="Freemind_Link_882075950" MODIFIED="1202855755737" TEXT="telescopes management" VSHIFT="1">
 <cloud/>
 <node CREATED="1150485648468" ID="Freemind_Link_1719502300" MODIFIED="1150485655828" TEXT="telescope goto"/>
 <node CREATED="1150485657671" ID="Freemind_Link_1224894730" MODIFIED="1150485659984" TEXT="status"/>
 <node CREATED="1202854369108" ID="Freemind_Link_411524457" MODIFIED="1202854379248" TEXT="telescope server control"/>
 </node>
 <node CREATED="1150487663937" ID="Freemind_Link_110718623" MODIFIED="1202856944119" TEXT="show image flip controls" VSHIFT="-7"/>
-<node CREATED="1202854506626" FOLDED="true" ID="Freemind_Link_1168478955" MODIFIED="1202854576741" TEXT="occulars managment">
+<node CREATED="1202854506626" FOLDED="true" ID="Freemind_Link_1168478955" MODIFIED="1202854576741" TEXT="occulars management">
 <node CREATED="1202855180109" ID="Freemind_Link_444624157" MODIFIED="1202855201099" TEXT="occular list"/>
 <node CREATED="1202855216844" ID="Freemind_Link_1171424144" MODIFIED="1202855227009" TEXT="add new occular"/>
 </node>
 <node CREATED="1150486017062" ID="Freemind_Link_1861025500" MODIFIED="1202854561581" TEXT="night view mode"/>
 <node CREATED="1150486020140" HGAP="23" ID="Freemind_Link_223731728" MODIFIED="1202854591548" TEXT="chart view mode" VSHIFT="-18"/>
-<node CREATED="1202854756910" HGAP="23" ID="Freemind_Link_1630778095" MODIFIED="1202855019339" TEXT="show sideral time" VSHIFT="-28"/>
+<node CREATED="1202854756910" HGAP="23" ID="Freemind_Link_1630778095" MODIFIED="1202855019339" TEXT="show sidereal time" VSHIFT="-28"/>
 </node>
-<node CREATED="1190407499812" HGAP="21" ID="Freemind_Link_1348197327" MODIFIED="1202859322907" TEXT="plugins managment" VSHIFT="8"/>
+<node CREATED="1190407499812" HGAP="21" ID="Freemind_Link_1348197327" MODIFIED="1202859322907" TEXT="plugins management" VSHIFT="8"/>
 </node>
 </node>
 <node CREATED="1202858347096" HGAP="74" ID="Freemind_Link_1690075164" MODIFIED="1202859648310" POSITION="left" TEXT="windows toggle bar" VSHIFT="-204">
