@@ -22,7 +22,6 @@
 #include <QString>
 #include <QObject>
 #include "StelUtils.hpp"
-#include "StelTranslator.hpp"
 #include "StelLocation.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
@@ -33,11 +32,11 @@
 //! @ingroup calendars
 //!
 //! Stellarium uses Julian Day numbers internally, and the conventional approach of using the Gregorian calendar for dates after 1582-10-15.
-//! For dates before that, the Julian calendar is used, in the form finalized by Augustus and running unchanged since 8AD.
-//! Astronomical year counting implies having a year 0, while some calendars adhere to historical counting like 1 B.C., 1 A.D.
+//! For dates before that, the Julian calendar is used, in the form finalized by Augustus and running unchanged since 8 A.D.
+//! Astronomical year counting implies having a year 0, while some calendars adhere to historical counting where 1 B.C. immediately precedes 1 A.D.
 //! Some European countries, especially the Protestant countries, delayed the calendar switch well into the 18th century.
 //! Other cultures have various other calendar schemes.
-//! All calendars have a numerical vector of time elements and may have individual string lists for names of elements like "week days" and "months".
+//! All calendars implemented here have a numerical vector of integer time elements and may have individual string lists for names of elements like "week days" and "months".
 //! If the pattern of weeks and months does not apply, the names may refer to other structural elements.
 //!
 //! The most important source used here is:
@@ -49,7 +48,7 @@
 //! Other functions with "moment" in their names use double arguments which are RD with fractions of day. Argument names with "_ut" added indicate the RD is given in UT, not local time.
 //!
 //! Most functions are static, with names derived from the functions given in Lisp in CC:UE. Most calendars have dates which can be described in lists of integers.
-//! Some functions require a StelLocation argument. For accessability as Stellarium scripting functions, argument order was changed to place the location argument as last
+//! Some functions require a StelLocation argument. For accessibility as Stellarium scripting functions, argument order was changed to place the location argument as last
 //! and declare it with a default value of the current location, so that it can be used in scripting. Currently, other, non-default StelLocation arguments cannot be used with scripting.
 //!
 //! @note The astronomical functions in parts make use of Stellarium's built-in astronomy instead of the algorithms given in CC. A notable difference consists already around DeltaT,
@@ -69,7 +68,7 @@ public:
 
 	Calendar(double jd):JD(jd) { setObjectName("Calendar"); }
 
-	virtual ~Calendar() Q_DECL_OVERRIDE {}
+	~Calendar() override {}
 
 public slots:
 	//! Translate e.g. stringlists of part names
