@@ -24,10 +24,10 @@
 #include "ui_calendarsDialog.h"
 
 #include "StelApp.hpp"
-#include "StelLocaleMgr.hpp"
+#include "StelGui.hpp"
 #include "StelModule.hpp"
 #include "StelModuleMgr.hpp"
-#include "StelMainView.hpp"
+#include "StelTranslator.hpp"
 
 // We only need to include calendars when we have to call special functions.
 #include "JulianCalendar.hpp"
@@ -41,14 +41,14 @@
 
 CalendarsDialog::CalendarsDialog()
 	: StelDialog("Calendars")
-	, cal(Q_NULLPTR)
+	, cal(nullptr)
 {
 	ui = new Ui_calendarsDialog();
 }
 
 CalendarsDialog::~CalendarsDialog()
 {
-	delete ui; ui=Q_NULLPTR;
+	delete ui; ui=nullptr;
 }
 
 void CalendarsDialog::retranslate()
@@ -72,8 +72,8 @@ void CalendarsDialog::createDialogContent()
 	connect(gui, SIGNAL(flagUseKineticScrollingChanged(bool)), this, SLOT(enableKineticScrolling(bool)));
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	connect(ui->restoreDefaultsButton, SIGNAL(clicked()), this, SLOT(resetCalendarsSettings()));
 	setAboutHtml();
@@ -81,8 +81,7 @@ void CalendarsDialog::createDialogContent()
 #ifdef STELLARIUM_RELEASE_BUILD
 	ui->labelRDvalue->hide();
 	ui->labelRD->hide();
-	// DISABLE Chinese etc for now, TBD!
-	ui->chineseCheckBox->hide();
+	// DISABLE handling Chinese etc for now, TBD!
 	ui->tabs->removeTab(2);
 #else
 	connect(cal->getCal("Julian"), &JulianCalendar::jdChanged, this, [=](double jd){ui->labelRDvalue->setText(QString::number(Calendar::fixedFromJD(jd, true)));});
@@ -113,6 +112,9 @@ void CalendarsDialog::createDialogContent()
 	connectBoolProperty(ui->ethiopicCheckBox,           "Calendars.flagShowEthiopic");
 	connectBoolProperty(ui->icelandicCheckBox,          "Calendars.flagShowIcelandic");
 	connectBoolProperty(ui->chineseCheckBox,            "Calendars.flagShowChinese");
+	connectBoolProperty(ui->japaneseCheckBox,           "Calendars.flagShowJapanese");
+	connectBoolProperty(ui->koreanCheckBox,             "Calendars.flagShowKorean");
+	connectBoolProperty(ui->vietnameseCheckBox,         "Calendars.flagShowVietnamese");
 	connectBoolProperty(ui->islamicCheckBox,            "Calendars.flagShowIslamic");
 	connectBoolProperty(ui->hebrewCheckBox,             "Calendars.flagShowHebrew");
 	connectBoolProperty(ui->oldHinduSolarCheckBox,      "Calendars.flagShowOldHinduSolar");
@@ -132,9 +134,11 @@ void CalendarsDialog::createDialogContent()
 	connectBoolProperty(ui->frenchArithmeticCheckBox,   "Calendars.flagShowFrenchArithmetic");
 	connectBoolProperty(ui->persianArithmeticCheckBox,  "Calendars.flagShowPersianArithmetic");
 	connectBoolProperty(ui->persianAstronomicalCheckBox,"Calendars.flagShowPersianAstronomical");
+	connectBoolProperty(ui->bahaiArithmeticCheckBox,    "Calendars.flagShowBahaiArithmetic");
+	connectBoolProperty(ui->bahaiAstronomicalCheckBox,  "Calendars.flagShowBahaiAstronomical");
 
 	connectBoolProperty(ui->overrideTextColorCheckBox,  "Calendars.flagTextColorOverride");
-	connectColorButton(ui->textcolorToolButton,         "Calendars.textColor",		"Calendars/text_color");
+	ui->textcolorToolButton->setup("Calendars.textColor", "Calendars/text_color");
 
 	// MAKE SURE to connect all part edit elements respective ...Changed() method here.
 	connect(ui->julianYearSpinBox,		SIGNAL(valueChanged(int)), this, SLOT(julianChanged()));
@@ -174,7 +178,7 @@ void CalendarsDialog::createDialogContent()
 void CalendarsDialog::setAboutHtml(void)
 {
 	// Regexp to replace {text} with an HTML link.
-	QRegularExpression a_rx("[{]([^{]*)[}]");
+	static const QRegularExpression a_rx("[{]([^{]*)[}]");
 
 	QString html = "<html><head></head><body>";
 	html += "<h2>" + q_("Calendars Plug-in") + "</h2><table width=\"90%\">";
@@ -204,17 +208,22 @@ void CalendarsDialog::setAboutHtml(void)
 	html += "<li>" + q_("French Revolution calendar (arithmetic version of 1795)") + "</li>";
 	html += "<li>" + q_("Persian calendar (arithmetic version)") + "</li>";
 	html += "<li>" + q_("Persian calendar (astronomical version)") + "</li>";
+	html += "<li>" + q_("Bahá’í calendar (arithmetic version)") + "</li>";
+	html += "<li>" + q_("Bahá’í calendar (astronomical version)") + "</li>";
 
-//	html += "<li>" + q_("Chinese calendars") + "</li>";
 	html += "<li>" + q_("Old Hindu Solar and Lunar calendars") + "</li>";
 	html += "<li>" + q_("New Hindu Solar and Lunar calendars") + "</li>";
 	html += "<li>" + q_("Astronomically 'accurate' Hindu Solar and Lunar calendars") + "</li>";
 	html += "<li>" + q_("Tibetan (Phuglugs, Phug-pa, K&#x101;lacakra) calendar") + "</li>";
+	html += "<li>" + q_("Chinese calendar") + "</li>";
+	html += "<li>" + q_("Japanese calendar") + "</li>";
+	html += "<li>" + q_("Korean calendar") + "</li>";
+	html += "<li>" + q_("Vietnamese calendar") + "</li>";
+	html += "<li>" + q_("Balinese Pawukon calendar") + "</li>";
 	html += "<li>" + q_("Maya calendars") + "</li>";
 	html += "<li>" + q_("Aztec calendars") + "</li>";
-	html += "<li>" + q_("Balinese Pawukon calendar") + "</li>";
 	html += "</ul>";
-	html += "<p>" + q_("The plugin is in an early stage of development. Please cross-check results and report errors.") + "</p>";
+	html += "<p>" + q_("The plugin is still under development. Please cross-check results and report errors.") + "</p>";
 	html += "<p>" + q_("For some calendars, we welcome proper formatting suggestions by actual users.") + "</p>";
 
 	html += "<h3>" + q_("Publications") + "</h3>";
@@ -235,7 +244,7 @@ void CalendarsDialog::setAboutHtml(void)
 	html += "</body></html>";
 
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
-	if(gui!=Q_NULLPTR)
+	if(gui)
 	{
 		QString htmlStyleSheet(gui->getStelStyle().htmlStyleSheet);
 		ui->aboutTextBrowser->document()->setDefaultStyleSheet(htmlStyleSheet);
