@@ -22,10 +22,9 @@
 #include "ui_equationOfTimeWindow.h"
 
 #include "StelApp.hpp"
-#include "StelCore.hpp"
-#include "StelLocaleMgr.hpp"
 #include "StelModule.hpp"
 #include "StelModuleMgr.hpp"
+#include "StelTranslator.hpp"
 
 EquationOfTimeWindow::EquationOfTimeWindow()
 	: StelDialog("EquationOfTime")
@@ -54,8 +53,8 @@ void EquationOfTimeWindow::createDialogContent()
 	ui->setupUi(dialog);
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	ui->checkBoxEnableAtStartup->setChecked(eq->getFlagEnableAtStartup());
 	connect(ui->checkBoxEnableAtStartup, SIGNAL(clicked(bool)), eq, SLOT(setFlagEnableAtStartup(bool)));
@@ -75,7 +74,7 @@ void EquationOfTimeWindow::createDialogContent()
 	connect(ui->pushButtonSave, SIGNAL(clicked()), this, SLOT(saveEquationOfTimeSettings()));	
 	connect(ui->pushButtonReset, SIGNAL(clicked()), this, SLOT(resetEquationOfTimeSettings()));
 
-	connectColorButton(ui->textColorButton, "EquationOfTime.textColor", "EquationOfTime/text_color");
+	ui->textColorButton->setup("EquationOfTime.textColor", "EquationOfTime/text_color");
 
 	setAboutHtml();
 }
@@ -89,7 +88,7 @@ void EquationOfTimeWindow::setAboutHtml()
 	html += "<tr><td><strong>" + q_("Author") + ":</strong></td><td>Alexander Wolf</td></tr>";
 	html += "</table>";
 
-	html += "<p>" + q_("This plugin shows the solution of the equation of time.") + "</p>";
+	html += "<p>" + q_("This plugin shows the value of the equation of time.") + "</p>";
 	html += StelApp::getInstance().getModuleMgr().getStandardSupportLinksInfo("Equation of Time plugin");
 	html += "</body></html>";
 
