@@ -31,7 +31,6 @@
 #include <QLogValueAxis>
 
 #include "StelApp.hpp"
-#include "StelCore.hpp"
 #include "ui_exoplanetsDialog.h"
 #include "ExoplanetsDialog.hpp"
 #include "Exoplanets.hpp"
@@ -40,18 +39,13 @@
 #include "StelMovementMgr.hpp"
 #include "StelStyle.hpp"
 #include "StelGui.hpp"
-#include "StelMainView.hpp"
-#include "StelFileMgr.hpp"
 #include "StelTranslator.hpp"
 #include "StelLocaleMgr.hpp"
 
-using namespace QtCharts;
-
 ExoplanetsDialog::ExoplanetsDialog()
 	: StelDialog("Exoplanets")
 	, ep(Q_NULLPTR)
 	, updateTimer(Q_NULLPTR)
-	, chart(Q_NULLPTR)
 {
         ui = new Ui_exoplanetsDialog;
 	exoplanetsHeader.clear();
@@ -66,8 +60,6 @@ ExoplanetsDialog::~ExoplanetsDialog()
 		updateTimer->stop();
 		delete updateTimer;
 		updateTimer = Q_NULLPTR;
-		if (chart)
-			delete chart;
 	}
 	delete ui;
 }
@@ -125,15 +117,15 @@ void ExoplanetsDialog::createDialogContent()
 	connectBoolProperty(ui->displayShowDesignationsCheckBox,   "Exoplanets.flagShowExoplanetsDesignations");
 	connectBoolProperty(ui->displayShowNumbersCheckBox,        "Exoplanets.flagShowExoplanetsNumbers");
 
-	connectColorButton(ui->exoplanetMarkerColor,		"Exoplanets.markerColor",    "Exoplanets/exoplanet_marker_color");
-	connectColorButton(ui->habitableExoplanetMarkerColor,	"Exoplanets.habitableColor", "Exoplanets/habitable_exoplanet_marker_color");
+	ui->exoplanetMarkerColor         ->setup("Exoplanets.markerColor",    "Exoplanets/exoplanet_marker_color");
+	ui->habitableExoplanetMarkerColor->setup("Exoplanets.habitableColor", "Exoplanets/habitable_exoplanet_marker_color");
 
 	updateTimer = new QTimer(this);
 	connect(updateTimer, SIGNAL(timeout()), this, SLOT(refreshUpdateValues()));
 	updateTimer->start(7000);
 
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	connect(ui->restoreDefaultsButton, SIGNAL(clicked()), this, SLOT(restoreDefaults()));
 	connect(ui->saveSettingsButton, SIGNAL(clicked()), this, SLOT(saveSettings()));	
@@ -580,7 +572,7 @@ void ExoplanetsDialog::setInfoHtml(void)
 	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Isagel"), "HD 102956 b", q_("Isagel is the name of the spaceship pilot in the epic science fiction poem Aniara written by Swedish author Harry Martinson."));
 	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Mönch"), "HD 130322", q_("Mönch is one of the prominent peaks of the Bernese Alps in Switzerland."));
 	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Eiger"), "HD 130322 b", q_("Eiger is one of the prominent peaks of the Bernese Alps, in the Jungfrau-Aletsch protected area."));
-	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Ebla"), "HD 218566", q_("Ebla was one of the earliest kingdoms in Syria, and served as a prominent region in the 2nd and 3rd millenia B.C."));
+	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Ebla"), "HD 218566", q_("Ebla was one of the earliest kingdoms in Syria, and served as a prominent region in the 2nd and 3rd millennia B.C."));
 	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Ugarit"), "HD 218566 b", q_("Ugarit was a city where its scribes devised the Ugaritic alphabet around 1400 B.C. The alphabet was made up of thirty letters and was inscribed on clay tablets."));
 	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Mpingo"), "WASP-71", q_("Mpingo is a famous tree that grows in southern Tanzania and produces ebony wood used for musical instruments and curios."));
 	html += QString("<li><strong>%1</strong> (%2) &mdash; %3</li>").arg(trans.qtranslate("Tanzanite"), "WASP-71 b", q_("Tanzanite is the name of a precious stone mined in Tanzania and is treasured worldwide."));
@@ -790,7 +782,7 @@ void ExoplanetsDialog::drawDiagram()
 
 	QList<double> aX = ep->getExoplanetsData(currentAxisX), aY = ep->getExoplanetsData(currentAxisY);
 
-	QtCharts::QChart *chart=new QtCharts::QChart();
+	QChart *chart=new QChart();
 	chart->setBackgroundBrush(QBrush(QColor(86, 87, 90)));
 	chart->setTitleBrush(QBrush(Qt::white));
 	chart->setMargins(QMargins(2, 1, 2, 1)); // set to 0/0/0/0 for max space usage. This is between the title/axis labels and the enclosing QChartView.
@@ -798,7 +790,7 @@ void ExoplanetsDialog::drawDiagram()
 	chart->setBackgroundRoundness(0); // remove rounded corners
 	chart->legend()->hide();
 
-	QtCharts::QScatterSeries *series=new QScatterSeries();
+	QScatterSeries *series=new QScatterSeries();
 	QAbstractAxis *chartXAxis, *chartYAxis;
 	for (int i=0; i<aX.length(); i++)
 	{
