@@ -22,12 +22,10 @@
 #include "LandscapeMgr.hpp"
 #include "StelLocaleMgr.hpp"
 #include "MeteorShower.hpp"
-#include "MeteorShowers.hpp"
-#include "SporadicMeteorMgr.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelModuleMgr.hpp"
-#include "StelObjectMgr.hpp"
+#include "StelPainter.hpp"
 #include "StelTexture.hpp"
 #include "StelUtils.hpp"
 #include "SolarSystem.hpp"
@@ -75,7 +73,6 @@ MeteorShower::MeteorShower(MeteorShowersMgr* mgr, const QVariantMap& map)
 	{
 		StelCore* core = StelApp::getInstance().getCore();
 		static SolarSystem *ssystem=GETSTELMODULE(SolarSystem);
-		double eclJ2000 = ssystem->getEarth()->getRotObliquity(2451545.0);
 		double ra_equ, dec_equ, currentLambda, beta;
 		
 		StelUtils::rectToSphe(&ra_equ,&dec_equ, ssystem->getSun()->getJ2000EquatorialPos(core));
@@ -92,6 +89,7 @@ MeteorShower::MeteorShower(MeteorShowersMgr* mgr, const QVariantMap& map)
 	m_rDeltaPeak = static_cast<float>(m_radiantDelta);
 
 	const int genericYear = 1000;
+	eclJ2000 = GETSTELMODULE(SolarSystem)->getEarth()->getRotObliquity(2451545.0);
 
 	// build the activity list
 	QList<QVariant> activities = map.value("activity").toList();
@@ -227,10 +225,7 @@ void MeteorShower::update(StelCore* core, double deltaTime)
 		return;
 	}
 
-	// gets the current UTC date
-	double currentJD = core->getJD();
 	static SolarSystem *ssystem=GETSTELMODULE(SolarSystem);
-	double eclJ2000 = ssystem->getEarth()->getRotObliquity(2451545.0);
 	double ra_equ, dec_equ, currentSolLong, beta;
 	StelUtils::rectToSphe(&ra_equ,&dec_equ, ssystem->getSun()->getJ2000EquatorialPos(core));
 	StelUtils::equToEcl(ra_equ, dec_equ, eclJ2000, &currentSolLong, &beta);
@@ -300,7 +295,7 @@ void MeteorShower::update(StelCore* core, double deltaTime)
 	}
 
 	// calculates a ZHR for the current date
-	int currentZHR = calculateZHR(currentJD);
+	int currentZHR = calculateZHR(core);
 	if (currentZHR < 1)
 	{
 		return;
@@ -316,11 +311,7 @@ void MeteorShower::update(StelCore* core, double deltaTime)
 	float rate = mpf / static_cast<float>(maxMpf);
 	for (int i = 0; i < maxMpf; ++i)
 	{
-		#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 		float prob = StelApp::getInstance().getRandF();
-		#else
-		float prob = static_cast<float>(qrand()) / static_cast<float>(RAND_MAX);
-		#endif
 		if (prob < rate)
 		{
 			MeteorObj *m = new MeteorObj(core, m_speed, static_cast<float>(m_radiantAlpha), static_cast<float>(m_radiantDelta),
@@ -358,11 +349,7 @@ void MeteorShower::drawRadiant(StelCore *core)
 	painter.setBlending(true, GL_SRC_ALPHA, GL_ONE);
 
 	Vec3f rgb;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 	float alpha = 0.85f + StelApp::getInstance().getRandF() / 10.f;
-#else
-	float alpha = 0.85f + (static_cast<float>(qrand()) / static_cast<float>(RAND_MAX)) / 10.f;
-#endif
 	switch(m_status)
 	{
 		case ACTIVE_CONFIRMED: //Active, confirmed data
@@ -413,7 +400,7 @@ void MeteorShower::drawMeteors(StelCore *core)
 
 	// step through and draw all active meteors
 	StelPainter painter(core->getProjection(StelCore::FrameAltAz));
-	for (auto* m : qAsConst(m_activeMeteors))
+	for (auto* m : std::as_const(m_activeMeteors))
 	{
 		m->draw(core, painter);
 	}
@@ -454,11 +441,9 @@ MeteorShower::Activity MeteorShower::hasConfirmedShower(double currentSolLong, b
 	return Activity();
 }
 
-int MeteorShower::calculateZHR(const double& currentJD)
+int MeteorShower::calculateZHR(StelCore *core)
 {
-	StelCore* core = StelApp::getInstance().getCore();
 	static SolarSystem *ssystem=GETSTELMODULE(SolarSystem);
-	const double eclJ2000 = ssystem->getEarth()->getRotObliquity(2451545.0);
 	double ra_equ, dec_equ, currentlambda, beta;
 	StelUtils::rectToSphe(&ra_equ,&dec_equ, ssystem->getSun()->getJ2000EquatorialPos(core));
 	StelUtils::equToEcl(ra_equ, dec_equ, eclJ2000, &currentlambda, &beta);
@@ -580,7 +565,6 @@ QString MeteorShower::getInfoString(const StelCore* core, const InfoStringGroup&
 
 		QString actStr = q_("Activity");
 		static SolarSystem *ssystem=GETSTELMODULE(SolarSystem);
-		double eclJ2000 = ssystem->getEarth()->getRotObliquity(2451545.0);
 		double ra_equ, dec_equ, currentLambda, beta, az, alt;
 		const double currentJD = core->getJD(); // save current JD
 		
@@ -596,7 +580,7 @@ QString MeteorShower::getInfoString(const StelCore* core, const InfoStringGroup&
 			StelUtils::getDateFromJulianDay(peakJD+utcShift, &Year, &startMonth, &startDay);
 
 			// Find approximate period of activity from ranges of solar longitude
-			// WB: IAU MDC have noticable differences when compared with IMO, but peak dates are around the same
+			// WB: IAU MDC have noticeable differences when compared with IMO, but peak dates are around the same
 			// We will use data from IMO calendars by converting date to solar longtitude
 			// This will allow them to be usable with more realistic activity period in the ancient and far future years
 			// Example : Activity duration of Perseids in recent years ~ July 17 - August 24
@@ -750,6 +734,7 @@ QString MeteorShower::getInfoString(const StelCore* core, const InfoStringGroup&
 		}
 	}
 
+	oss << getSolarLunarInfoString(core, flags);
 	postProcessInfoString(str, flags);
 	return str;
 }
