@@ -22,10 +22,7 @@
 
 #include "MeteorObj.hpp"
 #include "MeteorShowersMgr.hpp"
-#include "StelFader.hpp"
 #include "StelObject.hpp"
-#include "StelPainter.hpp"
-#include "StelTextureTypes.hpp"
 #include "StelTranslator.hpp"
 
 //! @class MeteorShower
@@ -57,7 +54,7 @@ public:
 		double start;              //! Initial solar longitude (J2000) of activity
 		double finish;             //! Last solar longitude (J2000) of activity
 		double peak;               //! Peak solar longitude (J2000) of activity
-		int disttype;              //! Distribution type (0 for Guass, 1 for Lorentz)
+		int disttype;              //! Distribution type (0 for Gauss, 1 for Lorentz)
 		float b1;                  //! B slope before peak
 		float b2;                  //! B slope after peak
 	};
@@ -156,6 +153,8 @@ private:
 
 	QList<MeteorObj*> m_activeMeteors; //! List with all the active meteors
 
+	double eclJ2000;                   //! Ecliptic on J2000.0 epoch
+
 	//! Draws the radiant
 	void drawRadiant(StelCore* core);
 
@@ -163,8 +162,7 @@ private:
 	void drawMeteors(StelCore* core);
 
 	//! Calculates the ZHR using two types of distribution function
-	//! @param current Julian day
-	int calculateZHR(const double& currentJD);
+	int calculateZHR(StelCore* core);
 };
 
 #endif /* METEORSHOWER_HPP */
