@@ -34,6 +34,7 @@
 #include "StelGui.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelProgressController.hpp"
+#include "StelTextureMgr.hpp"
 #include "StelUtils.hpp"
 #include "SporadicMeteorMgr.hpp"
 
@@ -50,11 +51,14 @@ MeteorShowersMgr::MeteorShowersMgr()
 	, m_enableMarker(true)
 	, m_showEnableButton(true)
 	, m_showSearchButton(true)
+	//, m_isUpdating(false)
 	, m_enableAutoUpdates(true)
 	, m_updateFrequencyHours(0)
 	, m_updateState(CompleteNoUpdates)
+	, m_networkManager(Q_NULLPTR)
 	, m_downloadReply(Q_NULLPTR)
 	, m_progressBar(Q_NULLPTR)
+	, m_updateTimer(Q_NULLPTR)
 {
 	setObjectName("MeteorShowers");
 }
@@ -89,7 +93,8 @@ void MeteorShowersMgr::init()
 	}
 
 	// Set up download manager and the update schedule
-	m_networkManager = StelApp::getInstance().getNetworkAccessManager();
+	//m_networkManager = StelApp::getInstance().getNetworkAccessManager();
+	m_networkManager = new QNetworkAccessManager(this);
 	m_updateState = CompleteNoUpdates;
 	m_updateTimer = new QTimer(this);
 	m_updateTimer->setSingleShot(false);   // recurring check for update
@@ -177,7 +182,7 @@ void MeteorShowersMgr::loadConfig()
 
 void MeteorShowersMgr::saveSettings()
 {
-	// Let's interpret hided radiants as "disabled at startup" when main settings are saving
+	// Let's interpret hidden radiants as "disabled at startup" when main settings are saving
 	m_conf->setValue(MS_CONFIG_PREFIX + "/enable_at_startup", getEnablePlugin());
 }
 
@@ -196,7 +201,7 @@ void MeteorShowersMgr::loadTextures()
 
 bool MeteorShowersMgr::loadCatalog(const QString& jsonPath)
 {
-	qDebug() << "[MeteorShowersMgr] Loading catalog file:"
+	qDebug().noquote() << "[MeteorShowersMgr] Loading catalog file:"
 		 << QDir::toNativeSeparators(jsonPath);
 
 	QFile jsonFile(jsonPath);
@@ -297,7 +302,11 @@ void MeteorShowersMgr::repaint()
 
 void MeteorShowersMgr::checkForUpdates()
 {
+#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+	if (m_enableAutoUpdates && m_lastUpdate.addSecs(static_cast<qint64>(m_updateFrequencyHours) * 3600) <= QDateTime::currentDateTime())
+#else
 	if (m_enableAutoUpdates && m_lastUpdate.addSecs(static_cast<qint64>(m_updateFrequencyHours) * 3600) <= QDateTime::currentDateTime() && m_networkManager->networkAccessible()==QNetworkAccessManager::Accessible)
+#endif
 	{
 		updateCatalog();
 	}
@@ -342,7 +351,9 @@ void MeteorShowersMgr::startDownload(QString urlString)
 	QNetworkRequest request;
 	request.setUrl(QUrl(m_url));
 	request.setRawHeader("User-Agent", StelUtils::getUserAgentString().toUtf8());
-	request.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+#if (QT_VERSION<QT_VERSION_CHECK(6,0,0))
+	request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
+#endif
 	m_downloadReply = m_networkManager->get(request);
 	connect(m_downloadReply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(updateDownloadProgress(qint64,qint64)));
 	m_updateState = MeteorShowersMgr::Updating;
@@ -385,7 +396,7 @@ void MeteorShowersMgr::downloadComplete(QNetworkReply *reply)
 	{
 		qWarning() << "[MeteorShowersMgr] Download error: While trying to access"
 			   << reply->url().toString()
-			   << "the following error occured:"
+			   << "the following error occurred:"
 			   << reply->errorString();
 
 		reply->deleteLater();
@@ -408,6 +419,7 @@ void MeteorShowersMgr::downloadComplete(QNetworkReply *reply)
 		}
 
 		m_updateState = MeteorShowersMgr::CompleteUpdates;
+		qDebug() << "[MeteorShowersMgr] Updating Meteor Showers catalog is complete...";
 		m_lastUpdate = QDateTime::currentDateTime();
 		m_conf->setValue("MeteorShowers/last_update", m_lastUpdate.toString(Qt::ISODate));
 	}
@@ -522,18 +534,21 @@ void MeteorShowersMgr::setColorARG(const Vec3f& rgb)
 {
 	m_colorARG = rgb;	
 	m_conf->setValue(MS_CONFIG_PREFIX + "/colorARG", rgb.toStr());
+	emit colorARGChanged(rgb);
 }
 
 void MeteorShowersMgr::setColorARC(const Vec3f& rgb)
 {
 	m_colorARC = rgb;	
 	m_conf->setValue(MS_CONFIG_PREFIX + "/colorARC", rgb.toStr());
+	emit colorARCChanged(rgb);
 }
 
 void MeteorShowersMgr::setColorIR(const Vec3f& rgb)
 {
 	m_colorIR = rgb;	
 	m_conf->setValue(MS_CONFIG_PREFIX + "/colorIR", rgb.toStr());
+	emit colorIRChanged(rgb);
 }
 
 void MeteorShowersMgr::setEnableAtStartup(const bool& b)
