@@ -20,13 +20,15 @@
 #ifndef METEORSHOWERSMGR_HPP
 #define METEORSHOWERSMGR_HPP
 
+#include <QDateTime>
 #include <QNetworkReply>
 #include <QNetworkAccessManager>
 
 #include "StelGuiItems.hpp"
-#include "StelTextureMgr.hpp"
-#include "StelObjectModule.hpp"
-#include "StelLocationMgr.hpp"
+#include "StelModule.hpp"
+#include "StelLocation.hpp"
+#include "StelTextureTypes.hpp"
+#include "VecMath.hpp"
 
 #define MS_CATALOG_VERSION 2
 #define MS_CONFIG_PREFIX QString("MeteorShowers")
@@ -57,6 +59,9 @@ class MeteorShowersMgr : public StelModule
 	Q_OBJECT
 	Q_PROPERTY(bool enablePlugin READ getEnablePlugin WRITE actionEnablePlugin NOTIFY enablePluginChanged)
 	Q_PROPERTY(bool enableLabels READ getEnableLabels WRITE setEnableLabels NOTIFY enableLabelsChanged)
+	Q_PROPERTY(Vec3f colorARG READ getColorARG WRITE setColorARG NOTIFY colorARGChanged)
+	Q_PROPERTY(Vec3f colorARC READ getColorARC WRITE setColorARC NOTIFY colorARCChanged)
+	Q_PROPERTY(Vec3f colorIR  READ getColorIR  WRITE setColorIR  NOTIFY colorIRChanged)
 
 public:
 	//! @enum UpdateState
@@ -136,6 +141,9 @@ signals:
 	void jsonUpdateComplete(void);
 	void enablePluginChanged(bool b);
 	void enableLabelsChanged(bool b);
+	void colorARGChanged(Vec3f c);
+	void colorARCChanged(Vec3f c);
+	void colorIRChanged(Vec3f c);
 
 public slots:
 	//! Enable the meteor showers plugin at Stellarium startup.
@@ -317,7 +325,7 @@ private:
 	StelTextureSP m_pointerTexture; //! Pointer texture
 	StelTextureSP m_radiantTexture; //! Radiant texture
 
-	bool m_isUpdating;
+	//bool m_isUpdating;
 	bool m_enableAutoUpdates;
 	int m_updateFrequencyHours;
 	QString m_url;
@@ -353,7 +361,7 @@ class MeteorShowersStelPluginInterface : public QObject, public StelPluginInterf
 public:
 	virtual StelModule* getStelModule() const Q_DECL_OVERRIDE;
 	virtual StelPluginInfo getPluginInfo() const Q_DECL_OVERRIDE;
-	virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
+	//virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
 };
 
 #endif /*METEORSHOWERSMGR_HPP*/
