@@ -23,8 +23,8 @@
 #include "StelApp.hpp"
 #include "StelGui.hpp"
 #include "StelModuleMgr.hpp"
+#include "StelTranslator.hpp"
 #include "ui_MSConfigDialog.h"
-#include "StelMainView.hpp"
 
 MSConfigDialog::MSConfigDialog(MeteorShowersMgr* mgr)
 	: StelDialog("MeteorShowers")
@@ -69,8 +69,8 @@ void MSConfigDialog::createDialogContent()
 	}
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(m_ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(m_ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(m_ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(m_ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 	connect(m_ui->bRestoreDefaults, SIGNAL(clicked()), this, SLOT(restoreDefaults()));
 
 	// General tab
@@ -84,9 +84,9 @@ void MSConfigDialog::createDialogContent()
 	connect(m_ui->enableLabels, SIGNAL(clicked(bool)), m_mgr, SLOT(setEnableLabels(bool)));
 	connect(m_ui->fontSize, SIGNAL(valueChanged(int)), m_mgr, SLOT(setFontSize(int)));
 
-	connect(m_ui->setColorARG, SIGNAL(clicked()), this, SLOT(setColorARG()));
-	connect(m_ui->setColorARC, SIGNAL(clicked()), this, SLOT(setColorARC()));
-	connect(m_ui->setColorIR, SIGNAL(clicked()), this, SLOT(setColorIR()));
+	m_ui->setColorARG->setup("MeteorShowers.colorARG", "MeteorShowers/colorARG");
+	m_ui->setColorARC->setup("MeteorShowers.colorARC", "MeteorShowers/colorARC");
+	m_ui->setColorIR ->setup("MeteorShowers.colorIR",  "MeteorShowers/colorIR");
 
 	// Update tab
 	connect(m_ui->enableUpdates, SIGNAL(clicked(bool)), m_mgr, SLOT(setEnableAutoUpdates(bool)));
@@ -135,7 +135,6 @@ void MSConfigDialog::init()
 	m_ui->activeRadiantsOnly->setChecked(m_mgr->getActiveRadiantOnly());
 	m_ui->enableLabels->setChecked(m_mgr->getEnableLabels());
 	m_ui->fontSize->setValue(m_mgr->getFontSize());
-	refreshMarkersColor();
 
 	// Update tab
 	refreshUpdateTab();
@@ -187,57 +186,6 @@ void MSConfigDialog::updateGuiFromSettings(void)
 	refreshUpdateTab();
 }
 
-void MSConfigDialog::refreshMarkersColor()
-{
-	Vec3d c = m_mgr->getColorARG().toVec3d();
-	QColor color(QColor::fromRgbF(c[0], c[1], c[2]));
-	m_ui->setColorARG->setStyleSheet("background-color:" + color.name() + ";");
-
-	c = m_mgr->getColorARC().toVec3d();
-	color = QColor(QColor::fromRgbF(c[0], c[1], c[2]));
-	m_ui->setColorARC->setStyleSheet("background-color:" + color.name() + ";");
-
-	c = m_mgr->getColorIR().toVec3d();
-	color = QColor(QColor::fromRgbF(c[0], c[1], c[2]));
-	m_ui->setColorIR->setStyleSheet("background-color:" + color.name() + ";");
-}
-
-void MSConfigDialog::setColorARG()
-{
-	Vec3d c = m_mgr->getColorARG().toVec3d();
-	QColor color(QColor::fromRgbF(c[0], c[1], c[2]));
-	color = QColorDialog::getColor(color,&StelMainView::getInstance());
-	if (color.isValid())
-	{
-		m_ui->setColorARG->setStyleSheet("background-color:" + color.name() + ";");
-		m_mgr->setColorARG(Vec3f(static_cast<float>(color.redF()), static_cast<float>(color.greenF()), static_cast<float>(color.blueF())));
-	}
-}
-
-void MSConfigDialog::setColorARC()
-{
-	Vec3d c = m_mgr->getColorARC().toVec3d();
-	QColor color(QColor::fromRgbF(c[0], c[1], c[2]));
-    color = QColorDialog::getColor(color,&StelMainView::getInstance());
-	if (color.isValid())
-	{
-		m_ui->setColorARC->setStyleSheet("background-color:" + color.name() + ";");
-		m_mgr->setColorARC(Vec3f(static_cast<float>(color.redF()), static_cast<float>(color.greenF()), static_cast<float>(color.blueF())));
-	}
-}
-
-void MSConfigDialog::setColorIR()
-{
-	Vec3d c = m_mgr->getColorIR().toVec3d();
-	QColor color(QColor::fromRgbF(c[0], c[1], c[2]));
-	color = QColorDialog::getColor(color,&StelMainView::getInstance());
-	if (color.isValid())
-	{
-		m_ui->setColorIR->setStyleSheet("background-color:" + color.name() + ";");
-		m_mgr->setColorIR(Vec3f(static_cast<float>(color.redF()), static_cast<float>(color.greenF()), static_cast<float>(color.blueF())));
-	}
-}
-
 void MSConfigDialog::setAboutHtml()
 {
 	QString html = "<html><head></head><body>"
@@ -284,7 +232,7 @@ void MSConfigDialog::setAboutHtml()
 	"</p>"
 	)
 	+ "<p>"
-	+ q_("This plugin uses two models to calculate ZHR, assumming that the activity profile of meteor "
+	+ q_("This plugin uses two models to calculate ZHR, assuming that the activity profile of meteor "
 		"shower follows the double exponential shape. To predict the local hourly rate, altitude of "
 		"radiant and limiting magnitude of the sky are taken into account. "
 		"Moonlight can also reduce the hourly rate, but it doesn't take into account.") +
@@ -326,7 +274,7 @@ void MSConfigDialog::setAboutHtml()
 		   "densest region of meteoroid stream.") +
 	"<br/></dd>" +
 	"<dt><strong>" + q_("Current ZHR") + "</strong></dt><dd>" +
-		q_("The ZHR at given time, assumming that the activity profile of meteor shower follows the double exponential shape.") +
+		q_("The ZHR at given time, assuming that the activity profile of meteor shower follows the double exponential shape.") +
 	"<br/></dd>" +
 	"<dt><strong>" + q_("Local Hourly Rate") + "</strong></dt><dd>" +
 		q_("The number of meteors in one hour for current location, it is the actual expected rate, calculated by "
