@@ -21,7 +21,6 @@
 
 #include "StelObjectModule.hpp"
 #include "StelObject.hpp"
-#include "StelFader.hpp"
 #include "Nova.hpp"
 #include "StelTextureTypes.hpp"
 #include <QFont>
@@ -183,7 +182,7 @@ signals:
 public slots:
 	// TODO: Add functions for scripting support
 
-	//! Download JSON from web recources described in the module section of the
+	//! Download JSON from web resources described in the module section of the
 	//! module.ini file and update the local JSON file.
 	void updateJSON(void);
 
@@ -265,6 +264,8 @@ private slots:
 
 	//! Call when button "Save settings" in main GUI are pressed
 	void saveSettings() { saveSettingsToConfig(); }
+
+	void setFlagSyncShowLabels(bool b) { Nova::syncShowLabels = b; }
 };
 
 #include <QObject>
@@ -279,7 +280,7 @@ class NovaeStelPluginInterface : public QObject, public StelPluginInterface
 public:
 	virtual StelModule* getStelModule() const Q_DECL_OVERRIDE;
 	virtual StelPluginInfo getPluginInfo() const Q_DECL_OVERRIDE;
-	virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
+	//virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
 };
 
 #endif /*NOVAE_HPP*/
