@@ -27,20 +27,28 @@ class Telescope;
 class Lens;
 
 //! @ingroup oculars
+//! @class CCD describes CCD properties for the Oculars plugin.
+//! pixel count, sensor size and pixel size are obviously related, and should all be given in data sheets or manuals.
+//! Sometimes one of them is lacking, or given only approximately like "APS-C" which can have some tolerance.
+//! As a consequence, it seems natural to assume one fixed and one updateable when setting one of those.
+//! The logic used here:
+//! * setResolutionX|Y: set pixel count in X|Y, and compute  pixelHeight|pixelWidth = chipWidth|chipHeight / resolutionX|Y
+//! * setChipWidth|setChipHeight: set chip width|height, and compute  pixelHeight|pixelWidth = chipWidth|chipHeight / resolutionX|Y
+//! * setPixelWidth|setPixelHeight: set pixel width|height, and compute chipWidth|chipHeight=pixelWidth|pixelHeight * resolutionX|Y
 class CCD : public QObject
 {
 	Q_OBJECT
-	Q_PROPERTY(QString name READ name WRITE setName)
-	Q_PROPERTY(int resolutionX READ resolutionX WRITE setResolutionX)
-	Q_PROPERTY(int resolutionY READ resolutionY WRITE setResolutionY)
-	Q_PROPERTY(double chipWidth READ chipWidth WRITE setChipWidth)
-	Q_PROPERTY(double chipHeight READ chipHeight WRITE setChipHeight)
-	Q_PROPERTY(double chipRotAngle READ chipRotAngle WRITE setChipRotAngle)
-	Q_PROPERTY(int binningX READ binningX WRITE setBinningX)
-	Q_PROPERTY(int binningY READ binningY WRITE setBinningY)
-	Q_PROPERTY(double hasOAG READ hasOAG WRITE setHasOAG)
-	Q_PROPERTY(double prismHeight READ prismHeight WRITE setPrismHeight)
-	Q_PROPERTY(double prismWidth READ prismWidth WRITE setPrismWidth)
+	Q_PROPERTY(QString name         READ name          WRITE setName)
+	Q_PROPERTY(int resolutionX      READ resolutionX   WRITE setResolutionX)
+	Q_PROPERTY(int resolutionY      READ resolutionY   WRITE setResolutionY)
+	Q_PROPERTY(double chipWidth     READ chipWidth     WRITE setChipWidth)
+	Q_PROPERTY(double chipHeight    READ chipHeight    WRITE setChipHeight)
+	Q_PROPERTY(double chipRotAngle  READ chipRotAngle  WRITE setChipRotAngle)
+	Q_PROPERTY(int binningX         READ binningX      WRITE setBinningX)
+	Q_PROPERTY(int binningY         READ binningY      WRITE setBinningY)
+	Q_PROPERTY(double hasOAG        READ hasOAG        WRITE setHasOAG)
+	Q_PROPERTY(double prismHeight   READ prismHeight   WRITE setPrismHeight)
+	Q_PROPERTY(double prismWidth    READ prismWidth    WRITE setPrismWidth)
 	Q_PROPERTY(double prismDistance READ prismDistance WRITE setPrismDistance)
 	Q_PROPERTY(double prismPosAngle READ prismPosAngle WRITE setPrismPosAngle)
 
@@ -84,13 +92,17 @@ public:
 	  * The formula for this calculation comes from the Yerkes observatory.
 	  * fov degrees = 2PI/360degrees * chipDimension mm / telescope FL mm
 	  */
-	double getActualFOVx(Telescope *telescope, Lens *lens) const;
-	double getActualFOVy(Telescope *telescope, Lens *lens) const;
+	double getActualFOVx(const Telescope *telescope, const Lens *lens) const;
+	double getActualFOVy(const Telescope *telescope, const Lens *lens) const;
+	//! Horizontal angular resolution in degrees per pixel in the middle of the field of view
+	double getCentralAngularResolutionX(const Telescope *telescope, const Lens *lens) const;
+	//! Vertical angular resolution in degrees per pixel in the middle of the field of view
+	double getCentralAngularResolutionY(const Telescope *telescope, const Lens *lens) const;
 	//! focuser size in inches
-	double getFocuserFOV(Telescope *telescope, Lens *lens, double focuserSize) const;
-	double getInnerOAGRadius(Telescope *telescope, Lens *lens) const;
-	double getOuterOAGRadius(Telescope *telescope, Lens *lens) const;
-	double getOAGActualFOVx(Telescope *telescope, Lens *lens) const;
+	double getFocuserFOV(const Telescope *telescope, const Lens *lens, double focuserSize) const;
+	double getInnerOAGRadius(const Telescope *telescope, const Lens *lens) const;
+	double getOuterOAGRadius(const Telescope *telescope, const Lens *lens) const;
+	double getOAGActualFOVx(const Telescope *telescope, const Lens *lens) const;
 	QMap<int, QString> propertyMap();
 private:
 	QString m_name;
@@ -110,14 +122,15 @@ private:
 	int m_binningY;
 	//! Show off axis guider view
 	bool m_has_oag;
-	//! OAG prism height (milimeters)
+	//! OAG prism height (millimeters)
 	double m_oag_prismHeight;
-	//! OAG prism width (milimeters)
+	//! OAG prism width (millimeters)
 	double m_oag_prismWidth;
-	//! OAG prisrm distance from the axis center (mimileters)
+	//! OAG prism distance from the axis center (millimeters)
 	double m_oag_prismDistance;
-	//! OAG prisrm position angle (degrees)
-	double m_oag_prismPosAngle;	
+	//! OAG prism position angle (degrees)
+	double m_oag_prismPosAngle;
+	static const QMap<int, QString> mapping;
 };
 
 
