@@ -25,8 +25,10 @@
 #include "Lens.hpp"
 #include "Ocular.hpp"
 #include "OcularDialog.hpp"
+#include "SolarSystem.hpp"
 #include "StelModule.hpp"
-#include "StelTexture.hpp"
+#include "StelTextureTypes.hpp"
+#include "StelProjectorType.hpp"
 #include "Telescope.hpp"
 #include "VecMath.hpp"
 
@@ -86,45 +88,47 @@ class Oculars : public StelModule
 	Q_PROPERTY(int selectedOcularIndex    READ getSelectedOcularIndex    WRITE selectOcularAtIndex    NOTIFY selectedOcularChanged)
 	Q_PROPERTY(int selectedTelescopeIndex READ getSelectedTelescopeIndex WRITE selectTelescopeAtIndex NOTIFY selectedTelescopeChanged)
 	Q_PROPERTY(int selectedLensIndex      READ getSelectedLensIndex      WRITE selectLensAtIndex      NOTIFY selectedLensChanged)
-	Q_PROPERTY(double selectedCCDRotationAngle READ getSelectedCCDRotationAngle WRITE setSelectedCCDRotationAngle NOTIFY selectedCCDRotationAngleChanged)
+	Q_PROPERTY(double selectedCCDRotationAngle      READ getSelectedCCDRotationAngle      WRITE setSelectedCCDRotationAngle      NOTIFY selectedCCDRotationAngleChanged)
 	Q_PROPERTY(double selectedCCDPrismPositionAngle READ getSelectedCCDPrismPositionAngle WRITE setSelectedCCDPrismPositionAngle NOTIFY selectedCCDPrismPositionAngleChanged)
 
-	Q_PROPERTY(bool flagGuiPanelEnabled          READ getFlagGuiPanelEnabled          WRITE enableGuiPanel NOTIFY flagGuiPanelEnabledChanged)
-	Q_PROPERTY(bool flagInitFOVUsage             READ getFlagInitFovUsage             WRITE setFlagInitFovUsage NOTIFY flagInitFOVUsageChanged) 
-	Q_PROPERTY(bool flagInitDirectionUsage       READ getFlagInitDirectionUsage       WRITE setFlagInitDirectionUsage NOTIFY flagInitDirectionUsageChanged) 
-	Q_PROPERTY(bool flagShowResolutionCriteria   READ getFlagShowResolutionCriteria   WRITE setFlagShowResolutionCriteria  NOTIFY flagShowResolutionCriteriaChanged)
-	Q_PROPERTY(bool flagRequireSelection   READ getFlagRequireSelection    WRITE setFlagRequireSelection    NOTIFY flagRequireSelectionChanged) 
-	Q_PROPERTY(bool flagAutoLimitMagnitude READ getFlagAutoLimitMagnitude  WRITE setFlagAutoLimitMagnitude  NOTIFY flagAutoLimitMagnitudeChanged)
-	Q_PROPERTY(bool flagHideGridsLines     READ getFlagHideGridsLines      WRITE setFlagHideGridsLines      NOTIFY flagHideGridsLinesChanged)
-	Q_PROPERTY(bool flagScaleImageCircle   READ getFlagScaleImageCircle    WRITE setFlagScaleImageCircle    NOTIFY flagScaleImageCircleChanged)// flag scale image circle scaleImageCirclCheckBox
-	Q_PROPERTY(bool flagSemiTransparency   READ getFlagUseSemiTransparency WRITE setFlagUseSemiTransparency NOTIFY flagUseSemiTransparencyChanged) 
-	Q_PROPERTY(int transparencyMask        READ getTransparencyMask        WRITE setTransparencyMask        NOTIFY transparencyMaskChanged)
-	Q_PROPERTY(bool flagDMSDegrees         READ getFlagDMSDegrees          WRITE setFlagDMSDegrees          NOTIFY flagDMSDegreesChanged)
-	Q_PROPERTY(bool flagAutosetMountForCCD READ getFlagAutosetMountForCCD  WRITE setFlagAutosetMountForCCD  NOTIFY flagAutosetMountForCCDChanged)
-	Q_PROPERTY(bool flagScalingFOVForTelrad	READ getFlagScalingFOVForTelrad  WRITE setFlagScalingFOVForTelrad  NOTIFY flagScalingFOVForTelradChanged) // TODO: Rename to flagTelradAutozoom etc. to be clearer.
-	Q_PROPERTY(Vec4f telradFOV              READ getTelradFOV             WRITE setTelradFOV             NOTIFY telradFOVChanged)
-	Q_PROPERTY(bool flagScalingFOVForCCD	READ getFlagScalingFOVForCCD  WRITE setFlagScalingFOVForCCD  NOTIFY flagScalingFOVForCCDChanged)
-	Q_PROPERTY(bool flagShowOcularsButton	READ getFlagShowOcularsButton  WRITE setFlagShowOcularsButton  NOTIFY flagShowOcularsButtonChanged)
-	Q_PROPERTY(bool flagShowContour		READ getFlagShowContour   WRITE setFlagShowContour   NOTIFY flagShowContourChanged)
-	Q_PROPERTY(bool flagShowCardinals	READ getFlagShowCardinals   WRITE setFlagShowCardinals   NOTIFY flagShowCardinalsChanged)
-	Q_PROPERTY(bool flagAlignCrosshair	READ getFlagAlignCrosshair   WRITE setFlagAlignCrosshair   NOTIFY flagAlignCrosshairChanged)
+	Q_PROPERTY(bool flagGuiPanelEnabled        READ getFlagGuiPanelEnabled        WRITE enableGuiPanel                NOTIFY flagGuiPanelEnabledChanged)
+	Q_PROPERTY(bool flagInitFOVUsage           READ getFlagInitFovUsage           WRITE setFlagInitFovUsage           NOTIFY flagInitFOVUsageChanged)
+	Q_PROPERTY(bool flagInitDirectionUsage     READ getFlagInitDirectionUsage     WRITE setFlagInitDirectionUsage     NOTIFY flagInitDirectionUsageChanged)
+	Q_PROPERTY(bool flagShowResolutionCriteria READ getFlagShowResolutionCriteria WRITE setFlagShowResolutionCriteria NOTIFY flagShowResolutionCriteriaChanged)
+	Q_PROPERTY(bool flagRequireSelection       READ getFlagRequireSelection       WRITE setFlagRequireSelection       NOTIFY flagRequireSelectionChanged)
+	Q_PROPERTY(bool flagAutoLimitMagnitude     READ getFlagAutoLimitMagnitude     WRITE setFlagAutoLimitMagnitude     NOTIFY flagAutoLimitMagnitudeChanged)
+	Q_PROPERTY(bool flagHideGridsLines         READ getFlagHideGridsLines         WRITE setFlagHideGridsLines         NOTIFY flagHideGridsLinesChanged)
+	Q_PROPERTY(bool flagScaleImageCircle       READ getFlagScaleImageCircle       WRITE setFlagScaleImageCircle       NOTIFY flagScaleImageCircleChanged)// flag scale image circle scaleImageCirclCheckBox
+	Q_PROPERTY(bool flagSemiTransparency       READ getFlagUseSemiTransparency    WRITE setFlagUseSemiTransparency    NOTIFY flagUseSemiTransparencyChanged)
+	Q_PROPERTY(int transparencyMask            READ getTransparencyMask           WRITE setTransparencyMask           NOTIFY transparencyMaskChanged)
+	Q_PROPERTY(bool flagDMSDegrees             READ getFlagDMSDegrees             WRITE setFlagDMSDegrees             NOTIFY flagDMSDegreesChanged)
+	Q_PROPERTY(bool flagHorizontalCoordinates  READ getFlagHorizontalCoordinates  WRITE setFlagHorizontalCoordinates  NOTIFY flagHorizontalCoordinatesChanged)
+	Q_PROPERTY(bool flagAutosetMountForCCD     READ getFlagAutosetMountForCCD     WRITE setFlagAutosetMountForCCD     NOTIFY flagAutosetMountForCCDChanged)
+	Q_PROPERTY(bool flagScalingFOVForTelrad	   READ getFlagScalingFOVForTelrad    WRITE setFlagScalingFOVForTelrad    NOTIFY flagScalingFOVForTelradChanged) // TODO: Rename to flagTelradAutozoom etc. to be clearer.
+	Q_PROPERTY(Vec4f telradFOV                 READ getTelradFOV                  WRITE setTelradFOV                  NOTIFY telradFOVChanged)
+	Q_PROPERTY(bool flagScalingFOVForCCD	   READ getFlagScalingFOVForCCD       WRITE setFlagScalingFOVForCCD       NOTIFY flagScalingFOVForCCDChanged)
+	Q_PROPERTY(bool flagMaxExposureTimeForCCD  READ getFlagMaxExposureTimeForCCD  WRITE setFlagMaxExposureTimeForCCD  NOTIFY flagMaxExposureTimeForCCDChanged)
+	Q_PROPERTY(bool flagShowOcularsButton	   READ getFlagShowOcularsButton      WRITE setFlagShowOcularsButton      NOTIFY flagShowOcularsButtonChanged)
+	Q_PROPERTY(bool flagShowContour		   READ getFlagShowContour            WRITE setFlagShowContour            NOTIFY flagShowContourChanged)
+	Q_PROPERTY(bool flagShowCardinals	   READ getFlagShowCardinals          WRITE setFlagShowCardinals          NOTIFY flagShowCardinalsChanged)
+	Q_PROPERTY(bool flagAlignCrosshair	   READ getFlagAlignCrosshair         WRITE setFlagAlignCrosshair         NOTIFY flagAlignCrosshairChanged)
 
-	Q_PROPERTY(int arrowButtonScale        READ getArrowButtonScale        WRITE setArrowButtonScale        NOTIFY arrowButtonScaleChanged)
-	Q_PROPERTY(int guiPanelFontSize        READ getGuiPanelFontSize        WRITE setGuiPanelFontSize        NOTIFY guiPanelFontSizeChanged)
-	Q_PROPERTY(Vec3f textColor             READ getTextColor               WRITE setTextColor               NOTIFY textColorChanged)
-	Q_PROPERTY(Vec3f lineColor             READ getLineColor               WRITE setLineColor               NOTIFY textColorChanged)
+	Q_PROPERTY(int arrowButtonScale READ getArrowButtonScale WRITE setArrowButtonScale NOTIFY arrowButtonScaleChanged)
+	Q_PROPERTY(int guiPanelFontSize READ getGuiPanelFontSize WRITE setGuiPanelFontSize NOTIFY guiPanelFontSizeChanged)
+	Q_PROPERTY(Vec3f textColor      READ getTextColor        WRITE setTextColor        NOTIFY textColorChanged)
+	Q_PROPERTY(Vec3f lineColor      READ getLineColor        WRITE setLineColor        NOTIFY textColorChanged)
 
-	Q_PROPERTY(bool flagShowCcdCropOverlay READ getFlagShowCcdCropOverlay  WRITE setFlagShowCcdCropOverlay  NOTIFY flagShowCcdCropOverlayChanged)
+	Q_PROPERTY(bool flagShowCcdCropOverlay READ getFlagShowCcdCropOverlay  WRITE setFlagShowCcdCropOverlay NOTIFY flagShowCcdCropOverlayChanged)
 	Q_PROPERTY(bool flagShowCcdCropOverlayPixelGrid READ getFlagShowCcdCropOverlayPixelGrid WRITE setFlagShowCcdCropOverlayPixelGrid NOTIFY flagShowCcdCropOverlayPixelGridChanged)
-	//Q_PROPERTY(int ccdCropOverlaySize      READ getCcdCropOverlaySize      WRITE setCcdCropOverlaySize      NOTIFY ccdCropOverlaySizeChanged)
-	Q_PROPERTY(int ccdCropOverlayHSize      READ getCcdCropOverlayHSize      WRITE setCcdCropOverlayHSize      NOTIFY ccdCropOverlayHSizeChanged)
-	Q_PROPERTY(int ccdCropOverlayVSize      READ getCcdCropOverlayVSize      WRITE setCcdCropOverlayVSize      NOTIFY ccdCropOverlayVSizeChanged)
+	//Q_PROPERTY(int ccdCropOverlaySize      READ getCcdCropOverlaySize      WRITE setCcdCropOverlaySize   NOTIFY ccdCropOverlaySizeChanged)
+	Q_PROPERTY(int ccdCropOverlayHSize     READ getCcdCropOverlayHSize      WRITE setCcdCropOverlayHSize   NOTIFY ccdCropOverlayHSizeChanged)
+	Q_PROPERTY(int ccdCropOverlayVSize     READ getCcdCropOverlayVSize      WRITE setCcdCropOverlayVSize   NOTIFY ccdCropOverlayVSizeChanged)
 
-	Q_PROPERTY(bool flagShowFocuserOverlay		READ getFlagShowFocuserOverlay		WRITE setFlagShowFocuserOverlay		NOTIFY flagShowFocuserOverlayChanged)
-	Q_PROPERTY(bool flagUseSmallFocuserOverlay	READ getFlagUseSmallFocuserOverlay	WRITE setFlagUseSmallFocuserOverlay	NOTIFY flagUseSmallFocuserOverlayChanged)
-	Q_PROPERTY(bool flagUseMediumFocuserOverlay	READ getFlagUseMediumFocuserOverlay	WRITE setFlagUseMediumFocuserOverlay	NOTIFY flagUseMediumFocuserOverlayChanged)
-	Q_PROPERTY(bool flagUseLargeFocuserOverlay	READ getFlagUseLargeFocuserOverlay	WRITE setFlagUseLargeFocuserOverlay	NOTIFY flagUseLargeFocuserOverlayChanged)
-	Q_PROPERTY(Vec3f focuserColor READ getFocuserColor WRITE setFocuserColor NOTIFY focuserColorChanged)
+	Q_PROPERTY(bool flagShowFocuserOverlay      READ getFlagShowFocuserOverlay	WRITE setFlagShowFocuserOverlay      NOTIFY flagShowFocuserOverlayChanged)
+	Q_PROPERTY(bool flagUseSmallFocuserOverlay  READ getFlagUseSmallFocuserOverlay	WRITE setFlagUseSmallFocuserOverlay  NOTIFY flagUseSmallFocuserOverlayChanged)
+	Q_PROPERTY(bool flagUseMediumFocuserOverlay READ getFlagUseMediumFocuserOverlay	WRITE setFlagUseMediumFocuserOverlay NOTIFY flagUseMediumFocuserOverlayChanged)
+	Q_PROPERTY(bool flagUseLargeFocuserOverlay  READ getFlagUseLargeFocuserOverlay	WRITE setFlagUseLargeFocuserOverlay  NOTIFY flagUseLargeFocuserOverlayChanged)
+	Q_PROPERTY(Vec3f focuserColor               READ getFocuserColor                WRITE setFocuserColor                NOTIFY focuserColorChanged)
 
 	//BM: Temporary, until the GUI is finalized and some other method of getting
 	//info from the main class is implemented.
@@ -213,21 +217,24 @@ public slots:
 	void setGuiPanelFontSize(int size);
 	int getGuiPanelFontSize()const {return guiPanelFontSize;}
 
-	void setTextColor(Vec3f color) {textColor=color; emit textColorChanged(color);}
+	void setTextColor(const Vec3f &color) {textColor=color; emit textColorChanged(color);}
 	Vec3f getTextColor() const {return textColor;}
 
-	void setLineColor(Vec3f color) {lineColor=color; emit lineColorChanged(color);}
+	void setLineColor(const Vec3f &color) {lineColor=color; emit lineColorChanged(color);}
 	Vec3f getLineColor() const {return lineColor;}
 
-	void setFocuserColor(Vec3f color) { focuserColor=color; emit focuserColorChanged(color);}
+	void setFocuserColor(const Vec3f &color) { focuserColor=color; emit focuserColorChanged(color);}
 	Vec3f getFocuserColor() const {return focuserColor;}
 
-	void setTelradFOV(Vec4f fov);
+	void setTelradFOV(const Vec4f &fov);
 	Vec4f getTelradFOV() const;
 
 	void setFlagDMSDegrees(const bool b);
 	bool getFlagDMSDegrees(void) const;
 
+	void setFlagHorizontalCoordinates(const bool b);
+	bool getFlagHorizontalCoordinates(void) const;
+
 	void setFlagRequireSelection(const bool b);
 	bool getFlagRequireSelection(void) const;
 	
@@ -252,6 +259,9 @@ public slots:
 	void setFlagScalingFOVForCCD(const bool b);
 	bool getFlagScalingFOVForCCD(void) const;
 
+	void setFlagMaxExposureTimeForCCD(const bool b);
+	bool getFlagMaxExposureTimeForCCD(void) const;
+
 	void setFlagUseSemiTransparency(const bool b);
 	bool getFlagUseSemiTransparency(void) const;
 
@@ -325,14 +335,15 @@ signals:
 
 	void flagGuiPanelEnabledChanged(bool value);
 	void guiPanelFontSizeChanged(int value);
-	void textColorChanged(Vec3f color);
-	void lineColorChanged(Vec3f color);
-	void focuserColorChanged(Vec3f color);
+	void textColorChanged(const Vec3f &color);
+	void lineColorChanged(const Vec3f &color);
+	void focuserColorChanged(const Vec3f &color);
 	void flagHideGridsLinesChanged(bool value);
 	void flagAutosetMountForCCDChanged(bool value);
 	void flagScalingFOVForTelradChanged(bool value);
 	void telradFOVChanged(Vec4f fov);
 	void flagScalingFOVForCCDChanged(bool value);
+	void flagMaxExposureTimeForCCDChanged(bool value);
 	void flagUseSemiTransparencyChanged(bool value);
 	void transparencyMaskChanged(int value);
 	void flagShowResolutionCriteriaChanged(bool value);
@@ -342,6 +353,7 @@ signals:
 	void flagRequireSelectionChanged(bool value);
 	void flagAutoLimitMagnitudeChanged(bool value);
 	void flagDMSDegreesChanged(bool value);
+	void flagHorizontalCoordinatesChanged(bool value);
 	void flagScaleImageCircleChanged(bool value);
 	void flagShowOcularsButtonChanged(bool value);
 	void flagShowCcdCropOverlayChanged(bool value);	
@@ -367,7 +379,8 @@ private slots:
 	void toggleCropOverlay();
 	void toggleFocuserOverlay();
 	void handleAutoLimitToggle(bool on);	//!< do a few activities in the background.
-	void handleStarMagLimitToggle(bool on); //!< Handle switching the main program's star limitation flag
+	void handleStarMagLimitToggle(bool on); //!< Handle switching the main program's star limitation flag	
+	void updateLatestSelectedSSO();
 
 private:
 	//! Compute the limiting magnitude for a telescope
@@ -379,6 +392,20 @@ private:
 	//! Returns TRUE if at least one bincular is defined.
 	bool isBinocularDefined();
 
+	/*! \brief Renders circles of constant angular radii
+	 *  \param angularRadii angular radii of the circles in radians
+	 */
+	void drawCirclesOfConstantAngularRadii(StelPainter& sPainter, const Mat4f& derotate, const std::vector<float>& angularRadii);
+	//! Renders off-axis guider frame and its inner and outer circles
+	void drawOAG(const StelProjectorP& projector, const Mat4f& derotate, const CCD& ccd, const Lens* lens);
+	//! Renders the actual rectangles corresponding to the CCD frame and the crop overlay with its grid.
+	//! \param frameUpDir window-space vector pointing in the "up" direction of the sensor frame
+	//! \param frameRightDir window-space vector pointing in the "right" direction of the sensor frame
+	//! \param frameCenter window-space position of the center of the sensor frame
+	//! \return bounding rect of the main sensor frame, relative to the center of the sensor, without rotation.
+	QRect drawSensorFrameAndOverlay(const StelProjectorP& projector, const Mat4f& derotate, const Vec2f& frameUpDir,
+	                                const Vec2f& frameRightDir, const Vec2f& frameCenter, const CCD& ccd,
+	                                const Lens* lens, const QSize& overlaySize);
 	//! Renders the CCD bounding box on-screen.  A telescope must be selected, or this call does nothing.
 	void paintCCDBounds();
 	//! Renders crosshairs into the viewport.
@@ -483,6 +510,7 @@ private:
 
 	bool flagGuiPanelEnabled;        //!< Display the GUI control panel
 	bool flagDMSDegrees;             //!< Use decimal degrees in CCD frame display
+	bool flagHorizontalCoordinates;  //!< Use horizontal coordinates instead equatorial coordinates for cross of center CCD
 	bool flagSemiTransparency;       //!< Draw the area outside the ocular circle not black but let some stars through.
 	int transparencyMask;		 //!< Value of transparency for semi-transparent mask
 	bool flagHideGridsLines;         //!< Switch off all grids and lines of GridMgr while in Ocular view
@@ -521,6 +549,8 @@ private:
 	Vec3f lineColor;
 	Vec3f focuserColor;
 
+	Planet* selectedSSO;
+
 	//Reticle
 	StelTextureSP reticleTexture;
 	StelTextureSP protractorTexture;
@@ -534,6 +564,7 @@ private:
 	bool flagAutosetMountForCCD;	//!< Flag used to track if we use automatic switch to type of mount for CCD frame
 	bool flagScalingFOVForTelrad;	//!< Flag used to track if we use automatic scaling FOV for Telrad
 	bool flagScalingFOVForCCD;	//!< Flag used to track if we use automatic scaling FOV for CCD
+	bool flagMaxExposureTimeForCCD;	//!< Flag used to track if we show max exposure time for CCD
 	bool flagShowResolutionCriteria;	//!< Show various criteria for angular resolution based on telescope/ocular
 	bool equatorialMountEnabledMain;	//!< Keep track of mount used in main program.
 	double reticleRotation;
@@ -565,7 +596,7 @@ class OcularsStelPluginInterface : public QObject, public StelPluginInterface
 public:
 	virtual StelModule* getStelModule() const Q_DECL_OVERRIDE;
 	virtual StelPluginInfo getPluginInfo() const Q_DECL_OVERRIDE;
-	virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
+	//virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
 };
 
 #endif /* OCULARS_HPP */
