@@ -23,11 +23,9 @@
 
 #include "StelApp.hpp"
 #include "StelGui.hpp"
-#include "StelFileMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelMainView.hpp"
 #include "StelTranslator.hpp"
-#include "StelActionMgr.hpp"
 
 #include <QAbstractItemModel>
 #include <QDataWidgetMapper>
@@ -102,6 +100,7 @@ void OcularDialog::retranslate()
 	{
 		ui->retranslateUi(dialog);
 		initAboutText();
+		updateSuffixes();
 	}
 }
 
@@ -304,8 +303,8 @@ void OcularDialog::createDialogContent()
 	}
 	
 	//Now the rest of the actions.
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	connectBoolProperty(ui->checkBoxControlPanel,		"Oculars.flagGuiPanelEnabled");
 	connectIntProperty(ui->guiFontSizeSpinBox,		"Oculars.guiPanelFontSize");
@@ -319,9 +318,11 @@ void OcularDialog::createDialogContent()
 	connectBoolProperty(ui->semiTransparencyCheckBox,	"Oculars.flagSemiTransparency");
 	connectIntProperty(ui->transparencySpinBox,	        "Oculars.transparencyMask");
 	connectBoolProperty(ui->checkBoxDMSDegrees,		"Oculars.flagDMSDegrees");
+	connectBoolProperty(ui->checkBoxHorizontalCoordinates,	"Oculars.flagHorizontalCoordinates");
 	connectBoolProperty(ui->checkBoxTypeOfMount,		"Oculars.flagAutosetMountForCCD");
 	connectBoolProperty(ui->checkBoxTelradFOVScaling,	"Oculars.flagScalingFOVForTelrad");
 	connectBoolProperty(ui->checkBoxCCDFOVScaling,		"Oculars.flagScalingFOVForCCD");
+	connectBoolProperty(ui->checkBoxCCDMaxExposureTime,     "Oculars.flagMaxExposureTimeForCCD");
 	connectBoolProperty(ui->checkBoxToolbarButton,		"Oculars.flagShowOcularsButton");
 	connectIntProperty(ui->arrowButtonScaleSpinBox,	        "Oculars.arrowButtonScale");
 	connectBoolProperty(ui->checkBoxShowCcdCropOverlay,	"Oculars.flagShowCcdCropOverlay");
@@ -331,13 +332,13 @@ void OcularDialog::createDialogContent()
 	connectBoolProperty(ui->contourCheckBox,		"Oculars.flagShowContour");
 	connectBoolProperty(ui->cardinalsCheckBox,		"Oculars.flagShowCardinals");
 	connectBoolProperty(ui->alignCrosshairCheckBox,		"Oculars.flagAlignCrosshair");
-	connectColorButton(ui->textColorToolButton,             "Oculars.textColor", "text_color", "Oculars");
-	connectColorButton(ui->lineColorToolButton,             "Oculars.lineColor", "line_color", "Oculars");
-	connectColorButton(ui->focuserColorToolButton,		"Oculars.focuserColor", "focuser_color", "Oculars");
 	connectBoolProperty(ui->checkBoxShowFocuserOverlay,	"Oculars.flagShowFocuserOverlay");
 	connectBoolProperty(ui->checkBoxUseSmallFocuser,	"Oculars.flagUseSmallFocuserOverlay");
 	connectBoolProperty(ui->checkBoxUseMediumFocuser,	"Oculars.flagUseMediumFocuserOverlay");
 	connectBoolProperty(ui->checkBoxUseLargeFocuser,	"Oculars.flagUseLargeFocuserOverlay");
+	ui->textColorToolButton->setup("Oculars.textColor", "text_color", "Oculars");
+	ui->lineColorToolButton->setup("Oculars.lineColor", "line_color", "Oculars");
+	ui->focuserColorToolButton->setup("Oculars.focuserColor", "focuser_color", "Oculars");
 
 	setupTelradFOVspins(plugin->getTelradFOV());
 	connect(plugin, SIGNAL(telradFOVChanged(Vec4f)), this, SLOT(setupTelradFOVspins(Vec4f)));
@@ -364,6 +365,7 @@ void OcularDialog::createDialogContent()
 	ui->lensName->setValidator(validatorName);
 
 	initAboutText();
+	updateSuffixes();
 
 	connect(ui->pushButtonMoveOcularUp,      SIGNAL(pressed()), this, SLOT(moveUpSelectedOcular()));
 	connect(ui->pushButtonMoveOcularDown,    SIGNAL(pressed()), this, SLOT(moveDownSelectedOcular()));
@@ -579,15 +581,41 @@ void OcularDialog::setLabelsDescriptionText(bool state)
 		// TRANSLATORS: Magnification factor for binoculars
 		ui->labelFL->setText(q_("Magnification factor:"));
 		ui->labelFS->setText(q_("Diameter:"));
+		ui->ocularFL->setSuffix("x");
 	}
 	else
 	{
 		ui->labelFOV->setText(q_("aFOV:"));
 		ui->labelFL->setText(q_("Focal length:"));
 		ui->labelFS->setText(q_("Field stop:"));
+		ui->ocularFL->setSuffix(QString(" %1").arg(qc_("mm","millimeters")));
 	}
 }
 
+void OcularDialog::updateSuffixes()
+{
+	const QString qMM = QString(" %1").arg(qc_("mm","millimeters"));
+	const QString qPX = QString(" %1").arg(qc_("px", "pixels"));
+	const QString qDG = QChar(0x00B0);
+	ui->telescopeFL->setSuffix(qMM);
+	ui->telescopeDiameter->setSuffix(qMM);
+	ui->ccdChipX->setSuffix(qMM);
+	ui->ccdChipY->setSuffix(qMM);
+	ui->OAGDist->setSuffix(qMM);
+	ui->OAGPrismH->setSuffix(qMM);
+	ui->OAGPrismW->setSuffix(qMM);
+	ui->ocularFieldStop->setSuffix(qMM);
+
+	ui->ccdResX->setSuffix(qPX);
+	ui->ccdResY->setSuffix(qPX);
+
+	ui->ccdRotAngle->setSuffix(qDG);
+	ui->OAGPrismPA->setSuffix(qDG);
+	ui->ocularAFov->setSuffix(qDG);
+
+	ui->lensMultiplier->setSuffix("x");
+}
+
 void OcularDialog::initAboutText()
 {
 	//BM: Most of the text for now is the original contents of the About widget.
@@ -629,6 +657,7 @@ void OcularDialog::initAboutText()
 	html += "<p>" +  q_("The sensor view has a feature to show a sensor crop overlay with information about the crop size. The size of this rectangle may be adjusted when binning is active (e.g. crop size of 100px will be adjusted to 99px by binning 3).") + " ";
 	html +=          q_("In this case, information about crop size overlay will be marked by %1.").arg("[*]") + " ";
 	html +=          q_("This mark is also displayed if the crop size is larger than the sensor size.") + "</p>";
+	html += "<p>" + q_("The sensor view has also a feature to show a max time of exposure for selected solar system objects (the mount has sidereal speed enabled) to avoid a movement of more than 1 pixel width.") + "</p>";
 
 	html += StelApp::getInstance().getModuleMgr().getStandardSupportLinksInfo("Oculars plugin");
 	html += "</body></html>";
