@@ -22,11 +22,10 @@
 #include "ui_pointerCoordinatesWindow.h"
 
 #include "StelApp.hpp"
-#include "StelCore.hpp"
-#include "StelLocaleMgr.hpp"
 #include "StelModule.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelGui.hpp"
+#include "StelTranslator.hpp"
 
 PointerCoordinatesWindow::PointerCoordinatesWindow()
 	: StelDialog("PointerCoordinates")
@@ -57,14 +56,16 @@ void PointerCoordinatesWindow::createDialogContent()
 	ui->setupUi(dialog);
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
-	populateValues();
-
-	connect(ui->checkBoxEnableAtStartup, SIGNAL(clicked(bool)), coord, SLOT(setFlagEnableAtStartup(bool)));
-	connect(ui->spinBoxFontSize, SIGNAL(valueChanged(int)), coord, SLOT(setFontSize(int)));
-	connect(ui->checkBoxShowButton, SIGNAL(clicked(bool)), coord, SLOT(setFlagShowCoordinatesButton(bool)));
+	connectBoolProperty(ui->checkBoxEnableAtStartup, "PointerCoordinates.enableAtStartup");
+	connectBoolProperty(ui->checkBoxShowButton,      "PointerCoordinates.showCoordinatesButton");
+	connectBoolProperty(ui->checkBoxConstellation,   "PointerCoordinates.showConstellation");
+	connectBoolProperty(ui->checkBoxCrossedLines,    "PointerCoordinates.showCrossedLines");
+	connectBoolProperty(ui->checkBoxElongation,      "PointerCoordinates.showElongation");
+	connectIntProperty(ui->spinBoxFontSize,          "PointerCoordinates.fontSize");
+	ui->textColorButton->setup("PointerCoordinates.fontColor", "PointerCoordinates/text_color");
 
 	// Place of the string with coordinates
 	populateCoordinatesPlacesList();
@@ -89,12 +90,7 @@ void PointerCoordinatesWindow::createDialogContent()
 	ui->coordinateSystemComboBox->setCurrentIndex(idx);
 	connect(ui->coordinateSystemComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(setCoordinateSystem(int)));
 
-	ui->checkBoxConstellation->setChecked(coord->getFlagShowConstellation());
-	connect(ui->checkBoxConstellation, SIGNAL(toggled(bool)), coord, SLOT(setFlagShowConstellation(bool)));
-
-	ui->checkBoxCrossedLines->setChecked(coord->getFlagShowCrossedLines());
-	connect(ui->checkBoxCrossedLines, SIGNAL(toggled(bool)), coord, SLOT(setFlagShowCrossedLines(bool)));
-
+	populateValues();
 	connect(ui->spinBoxX, SIGNAL(valueChanged(int)), this, SLOT(setCustomCoordinatesPlace()));
 	connect(ui->spinBoxY, SIGNAL(valueChanged(int)), this, SLOT(setCustomCoordinatesPlace()));
 
@@ -110,9 +106,6 @@ void PointerCoordinatesWindow::createDialogContent()
 
 void PointerCoordinatesWindow::populateValues()
 {
-	ui->checkBoxEnableAtStartup->setChecked(coord->getFlagEnableAtStartup());
-	ui->spinBoxFontSize->setValue(coord->getFontSize());
-	ui->checkBoxShowButton->setChecked(coord->getFlagShowCoordinatesButton());
 	QPair<int, int> cc = coord->getCustomCoordinatesPlace();
 	ui->spinBoxX->setValue(cc.first);
 	ui->spinBoxY->setValue(cc.second);
