@@ -17,7 +17,6 @@
  */
 
 #include "Pulsar.hpp"
-#include "Pulsars.hpp"
 #include "StelObject.hpp"
 #include "StelPainter.hpp"
 #include "StelApp.hpp"
@@ -25,7 +24,6 @@
 #include "StelTexture.hpp"
 #include "StelUtils.hpp"
 #include "StelTranslator.hpp"
-#include "StelModuleMgr.hpp"
 #include "StelSkyDrawer.hpp"
 #include "StelProjector.hpp"
 #include "StelLocaleMgr.hpp"
@@ -54,6 +52,7 @@ Vec3f Pulsar::glitchColor = Vec3f(0.2f,0.3f,1.0f);
 Pulsar::Pulsar(const QVariantMap& map)
 	: initialized(false)
 	, designation("")
+	, bdesignation("")
 	, pulsarName("")
 	, RA(0.)
 	, DE(0.)
@@ -81,6 +80,7 @@ Pulsar::Pulsar(const QVariantMap& map)
 	}
 
 	designation  = map.value("designation").toString();
+	bdesignation  = map.value("bdesignation").toString();
 	pulsarName = map.value("name").toString();
 	parallax = map.value("parallax").toFloat();
 	period = map.value("period").toDouble();
@@ -125,6 +125,7 @@ QVariantMap Pulsar::getMap(void) const
 {
 	QVariantMap map;
 	map["designation"] = designation;
+	map["bdesignation"] = bdesignation;
 	map["name"] = pulsarName;
 	map["parallax"] = parallax;
 	map["bperiod"] = bperiod;
@@ -159,7 +160,7 @@ QString Pulsar::getNameI18n(void) const
 	QString name = getEnglishName();
 	const StelTranslator& trans = StelApp::getInstance().getLocaleMgr().getSkyTranslator();
 	if (!pulsarName.isEmpty())
-		name = trans.qtranslate(pulsarName);
+		name = trans.qtranslate(pulsarName, "pulsar");
 
 	return name;
 }
@@ -179,15 +180,15 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 		oss << "<h2>";
 		if (!getNameI18n().isEmpty())
 			oss << getNameI18n() << "< br />";
-		oss << getDesignation() << "</h2>";
+		oss << (getBDesignation().isEmpty() ? getDesignation() : QString("%1 - %2").arg(getDesignation(), getBDesignation())) << "</h2>";
 	}
 
 	if (flags&ObjectType)
 	{
 		if (glitch==0)
-			oss << QString("%1: <b>%2</b>").arg(q_("Type"), getObjectTypeI18n()) << "<br />";
+			oss << QString("%1: <b>%2</b><br />").arg(q_("Type"), getObjectTypeI18n());
 		else
-			oss << QString("%1: <b>%2</b> (%3: %4)").arg(q_("Type"), getObjectTypeI18n(), q_("registered glitches"), QString::number(glitch)) << "<br />";
+			oss << QString("%1: <b>%2</b> (%3: %4)<br />").arg(q_("Type"), getObjectTypeI18n(), q_("registered glitches"), QString::number(glitch));
 	}
 
 	// Ra/Dec etc.
@@ -198,71 +199,66 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 		double pa = std::atan2(pmRA, pmDE)*M_180_PI;
 		if (pa<0)
 			pa += 360.;
-		oss << QString("%1: %2 %3 %4 %5&deg;").arg(q_("Proper motion"),
+		oss << QString("%1: %2 %3 %4 %5&deg;<br />").arg(q_("Proper motion"),
 			       QString::number(std::sqrt(pmRA*pmRA + pmDE*pmDE), 'f', 1), qc_("mas/yr", "milliarc second per year"),
-			       qc_("towards", "into the direction of"), QString::number(pa, 'f', 1)) << "<br />";
-		oss << QString("%1: %2 %3 (%4)").arg(q_("Proper motions by axes"), QString::number(pmRA, 'f', 1), QString::number(pmDE, 'f', 1), qc_("mas/yr", "milliarc second per year")) << "<br />";
+			       qc_("towards", "into the direction of"), QString::number(pa, 'f', 1));
+		oss << QString("%1: %2 %3 (%4)<br />").arg(q_("Proper motions by axes"), QString::number(pmRA, 'f', 1), QString::number(pmDE, 'f', 1), qc_("mas/yr", "milliarc second per year"));
 	}
 
 	if (flags&Extra)
 	{
 		if (period>0)
 		{
-			oss << QString("%1: %2 %3").arg(
+			oss << QString("%1: %2 %3<br />").arg(
 			       q_("Barycentric period"),
 			       QString::number(period, 'f', 16),
 			       //TRANSLATORS: Unit of measure for period - seconds
 			       qc_("s", "period"));
-			oss << "<br />";
 		}
 		if (pderivative>0)
-			oss << QString("%1: %2").arg(q_("Time derivative of barycentric period"), QString::number(pderivative, 'e', 5)) << "<br />";
+			oss << QString("%1: %2<br />").arg(q_("Time derivative of barycentric period"), QString::number(pderivative, 'e', 5));
 
 		if (dmeasure>0)
 		{
-			oss << QString("%1: %2 %3/%4<sup>3</sup>").arg(
+			oss << QString("%1: %2 %3/%4<sup>3</sup><br />").arg(
 				       q_("Dispersion measure"),
 				       QString::number(dmeasure, 'f', 3),
 				       //TRANSLATORS: Unit of measure for distance - parsecs
 				       qc_("pc", "distance"),
 				       //TRANSLATORS: Unit of measure for distance - centimeters
 				       qc_("cm", "distance"));
-			oss << "<br />";
 		}
 		double edot = getEdot(period, pderivative);
 		if (edot>0)
 		{
-			oss << QString("%1: %2 %3").arg(
+			oss << QString("%1: %2 %3<br />").arg(
 				       q_("Spin down energy loss rate"),
 				       QString::number(edot, 'e', 2),
 				       //TRANSLATORS: Unit of measure for power - erg per second
 				       qc_("ergs/s", "power"));
-			oss << "<br>";
 		}
 		if (bperiod>0)
 		{
-			oss << QString("%1: %2 %3").arg(
+			oss << QString("%1: %2 %3<br />").arg(
 				       q_("Binary period of pulsar"),
 				       QString::number(bperiod, 'f', 12),
 				       //TRANSLATORS: Unit of measure for period - days
 				       qc_("days", "period"));
-			oss << "<br>";
 		}
 		if (eccentricity>0)
-			oss << QString("%1: %2").arg(q_("Eccentricity"), QString::number(eccentricity, 'f', 10)) << "<br />";
+			oss << QString("%1: %2<br />").arg(q_("Eccentricity"), QString::number(eccentricity, 'f', 10));
 
 		if (parallax>0)
 		{
-			oss << QString("%1: %2 %3").arg(
+			oss << QString("%1: %2 %3<br />").arg(
 				       q_("Annual parallax"),
 				       QString::number(parallax),
 				       //TRANSLATORS: Unit of measure for annual parallax - milliarcseconds
 				       qc_("mas", "parallax"));
-			oss << "<br />";
 		}
 		if (distance>0)
 		{
-			oss << QString("%1: %2 %3 (%4 %5)")
+			oss << QString("%1: %2 %3 (%4 %5)<br />")
 			       .arg(q_("Distance based on electron density model"))
 			       .arg(distance)
 			       //TRANSLATORS: Unit of measure for distance - kiloparsecs
@@ -270,17 +266,15 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 			       .arg(distance*3261.563777)
 			       //TRANSLATORS: Unit of measure for distance - light years
 			       .arg(qc_("ly", "distance"));
-			oss << "<br />";
 		}
 		if (w50>0)
 		{
-			oss << QString("%1: %2 %3").arg(
+			oss << QString("%1: %2 %3<br />").arg(
 				       // xgettext:no-c-format
 				       q_("Profile width at 50% of peak"),
 				       QString::number(w50, 'f', 2),
 				       //TRANSLATORS: Unit of measure for time - milliseconds
 				       qc_("ms", "time"));
-			oss << "<br />";
 		}
 
 		// TRANSLATORS: Full phrase is "Time averaged flux density at XXXMHz"
@@ -291,18 +285,19 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 		QString sfd  = qc_("mJy", "spectral flux density");
 
 		if (s400>0)
-			oss << QString("%1 %2%3: %4 %5").arg(flux, QString::number(400), freq, QString::number(s400, 'f', 2), sfd) << "<br />";
+			oss << QString("%1 %2%3: %4 %5<br />").arg(flux, QString::number(400), freq, QString::number(s400, 'f', 2), sfd);
 
 		if (s600>0)
-			oss << QString("%1 %2%3: %4 %5").arg(flux, QString::number(600), freq, QString::number(s600, 'f', 2), sfd) << "<br />";
+			oss << QString("%1 %2%3: %4 %5<br />").arg(flux, QString::number(600), freq, QString::number(s600, 'f', 2), sfd);
 
 		if (s1400>0)
-			oss << QString("%1 %2%3: %4 %5").arg(flux, QString::number(1400), freq, QString::number(s1400, 'f', 2), sfd) << "<br />";
+			oss << QString("%1 %2%3: %4 %5<br />").arg(flux, QString::number(1400), freq, QString::number(s1400, 'f', 2), sfd);
 
-		if (notes.length()>0)
-			oss << "<br />" << QString("%1: %2").arg(q_("Notes"), getPulsarTypeInfoString(notes)) << "<br />";
+		if (!notes.isEmpty())
+			oss << StelUtils::wrapText(QString("%1: %2").arg(q_("Notes"), getPulsarTypeInfoString(notes))) << "<br />";
 	}
 
+	oss << getSolarLunarInfoString(core, flags);
 	postProcessInfoString(str, flags);
 	return str;
 }
@@ -421,12 +416,7 @@ QString Pulsar::getPulsarTypeInfoString(QString pcode) const
 		out.append(q_("isolated neutron star with pulsed thermal X-ray emission but no detectable radio emission"));
 	}
 
-	return out.join(",<br />");
-}
-
-void Pulsar::update(double deltaTime)
-{
-	labelsFader.update(static_cast<int>(deltaTime*1000));
+	return out.join(", ");
 }
 
 void Pulsar::draw(StelCore* core, StelPainter *painter)
@@ -454,7 +444,7 @@ void Pulsar::draw(StelCore* core, StelPainter *painter)
 		painter->setBlending(true, GL_ONE, GL_ONE);
 		painter->drawSprite2dMode(coord, distributionMode ? 4.f : 5.f);
 
-		if (labelsFader.getInterstate()<=0.f && !distributionMode && (mag+2.f)<mlimit)
+		if (!distributionMode && (mag+2.f)<mlimit)
 		{
 			QString name = getDesignation();
 			if (!getNameI18n().isEmpty())
