@@ -17,15 +17,12 @@
  */
 
 #include "Quasar.hpp"
-#include "Quasars.hpp"
 #include "StelObject.hpp"
 #include "StelPainter.hpp"
-#include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelTexture.hpp"
 #include "StelUtils.hpp"
 #include "StelTranslator.hpp"
-#include "StelModuleMgr.hpp"
 #include "StelSkyDrawer.hpp"
 #include "Planet.hpp"
 
@@ -153,6 +150,7 @@ QString Quasar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 			oss << QString("%1: %2 %3").arg(q_("Radio flux density around 1.4GHz (21cm)"), QString::number(f20, 'f', 3), sfd) << "<br />";
 	}
 
+	oss << getSolarLunarInfoString(core, flags);
 	postProcessInfoString(str, flags);
 	return str;
 }
@@ -194,11 +192,6 @@ float Quasar::getSelectPriority(const StelCore* core) const
 	return mag;
 }
 
-void Quasar::update(double deltaTime)
-{
-	labelsFader.update(static_cast<int>(deltaTime*1000));
-}
-
 void Quasar::draw(StelCore* core, StelPainter& painter)
 {
 	Vec3d win;
@@ -237,12 +230,12 @@ void Quasar::draw(StelCore* core, StelPainter& painter)
 			sd->preDrawPointSource(&painter);
 			sd->computeRCMag(mag, &rcMag);
 			// allow height-dependent twinkle and suppress twinkling in higher altitudes. Keep 0.1 twinkle amount in zenith.
-			sd->drawPointSource(&painter, vf, rcMag, sd->indexToColor(BvToColorIndex(bV)), true, qMin(1.0f, 1.0f-0.9f*altAz[2]));
+			sd->drawPointSource(&painter, vf.toVec3d(), rcMag, sd->indexToColor(BvToColorIndex(bV)), true, qMin(1.0f, 1.0f-0.9f*altAz[2]));
 			sd->postDrawPointSource(&painter);
-			painter.setColor(color[0], color[1], color[2], 1);
+			painter.setColor(color, 1);
 		}
 
-		if (labelsFader.getInterstate()<=0.f && !distributionMode && (mag+2.f)<mlimit)
+		if (!distributionMode && (mag+2.f)<mlimit)
 			painter.drawText(getJ2000EquatorialPos(core), designation, 0, shift, shift, false);
 	}
 }
