@@ -29,9 +29,7 @@
 #include "StelMovementMgr.hpp"
 #include "StelObjectMgr.hpp"
 #include "StelPropertyMgr.hpp"
-#include "StelScriptMgr.hpp"
 #include "StelSkyCultureMgr.hpp"
-#include "StelTranslator.hpp"
 #include "StelUtils.hpp"
 
 #include <QJsonDocument>
@@ -122,8 +120,8 @@ void MainService::get(const QByteArray& operation, const APIParameters &paramete
 			obj2.insert("name",loc.name);
 			obj2.insert("role",QString(loc.role));
 			obj2.insert("planet",loc.planetName);
-			obj2.insert("latitude",static_cast<double>(loc.latitude));
-			obj2.insert("longitude",static_cast<double>(loc.longitude));
+			obj2.insert("latitude",static_cast<double>(loc.getLatitude()));
+			obj2.insert("longitude",static_cast<double>(loc.getLongitude()));
 			obj2.insert("altitude",loc.altitude);
 			obj2.insert("region",loc.region);
 			obj2.insert("state",loc.state);
@@ -332,12 +330,12 @@ void MainService::post(const QByteArray& operation, const APIParameters &paramet
 	else if(operation == "focus")
 	{
 		QString target = QString::fromUtf8(parameters.value("target"));
-		SelectionMode selMode = Center;
+		MainService::SelectionMode selMode = MainService::Center;
 
 		if(parameters.value("mode") == "zoom")
-			selMode = Zoom;
+			selMode = MainService::Zoom;
 		else if(parameters.value("mode") == "mark")
-			selMode = Mark;
+			selMode = MainService::Mark;
 
 		//check target string first
 		if(target.isEmpty())
@@ -375,7 +373,7 @@ void MainService::post(const QByteArray& operation, const APIParameters &paramet
 		QMetaObject::invokeMethod(this,"focusObject",SERVICE_DEFAULT_INVOKETYPE,
 					  Q_RETURN_ARG(bool,result),
 					  Q_ARG(QString,target),
-					  Q_ARG(SelectionMode,selMode));
+					  Q_ARG(MainService::SelectionMode,selMode));
 
 		response.setData(result ? "true" : "false");
 	}
@@ -513,10 +511,28 @@ void MainService::post(const QByteArray& operation, const APIParameters &paramet
 
 		response.setData("ok");
 	}
+	else if(operation == "window")
+	{
+		bool wOk,hOk;
+
+		double w = parameters.value("w").toDouble(&wOk);
+		double h = parameters.value("h").toDouble(&hOk);
+
+		if(wOk && hOk)
+		{
+			QMetaObject::invokeMethod(this,"setWindowSize", SERVICE_DEFAULT_INVOKETYPE,
+						  Q_ARG(int,w),
+						  Q_ARG(int,h));
+
+			response.setData("ok");
+		}
+		else
+			response.writeRequestError("requires w and h parameters");
+	}
 	else
 	{
 		//TODO some sort of service description?
-		response.writeRequestError("unsupported operation. POST: time,focus,move,view,fov");
+		response.writeRequestError("unsupported operation. POST: time,focus,move,view,fov,window");
 	}
 }
 
@@ -536,7 +552,7 @@ QString MainService::getInfoString()
 	return selectedObject->getInfoString(core,StelObject::AllInfo | StelObject::NoFont);
 }
 
-bool MainService::focusObject(const QString &name, SelectionMode mode)
+bool MainService::focusObject(const QString &name, MainService::SelectionMode mode)
 {
 	//StelDialog::gotoObject
 
@@ -623,6 +639,11 @@ void MainService::setFov(double fov)
 	mvmgr->zoomTo(fov,0.25f);
 }
 
+void MainService::setWindowSize(const int width, const int height)
+{
+	StelMainView::getInstance().setWindowSize(width, height);
+}
+
 void MainService::actionToggled(const QString &id, bool val)
 {
 	actionMutex.lock();
