@@ -25,14 +25,14 @@
 #include "ui_remoteControlDialog.h"
 
 #include "StelApp.hpp"
-#include "StelCore.hpp"
-#include "StelLocaleMgr.hpp"
+#include "StelGui.hpp"
+#include "StelTranslator.hpp"
 #include "StelModule.hpp"
 #include "StelModuleMgr.hpp"
 
 RemoteControlDialog::RemoteControlDialog()
 	: StelDialog("RemoteControl")
-	, rc(Q_NULLPTR)
+	, rc(nullptr)
 {
 	ui = new Ui_remoteControlDialog();
 }
@@ -67,8 +67,8 @@ void RemoteControlDialog::createDialogContent()
 
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	// TODO Fill other buttons
 
@@ -144,7 +144,7 @@ void RemoteControlDialog::setAboutHtml(void)
 	// TODO Add longer instructions?
 
 	// Regexp to replace {text} with an HTML link.
-	QRegularExpression a_rx("[{]([^{]*)[}]");
+	static const QRegularExpression a_rx("[{]([^{]*)[}]");
 
 	html += "<p>" + q_("It is also possible to send commands via command line, e.g..");
 	html += "<pre>\n"
@@ -168,7 +168,7 @@ void RemoteControlDialog::setAboutHtml(void)
 	html += "</body></html>";
 
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
-	if(gui!=Q_NULLPTR)
+	if(gui!=nullptr)
 	{
 		QString htmlStyleSheet(gui->getStelStyle().htmlStyleSheet);
 		ui->aboutTextBrowser->document()->setDefaultStyleSheet(htmlStyleSheet);
