@@ -23,6 +23,7 @@
 #include <QLoggingCategory>
 #include <QObject>
 #include <QTcpSocket>
+#include "SyncProtocol.hpp"
 
 Q_DECLARE_LOGGING_CATEGORY(syncClient)
 
@@ -44,24 +45,26 @@ public:
 		SyncSelection	= 0x0004,
 		SyncStelProperty= 0x0008,
 		SyncView	= 0x0010,
-		SyncFov		= 0x0020,
+		//SyncFov	= 0x0020, // This used to be a special case. Keep the number for legacy connections.
 		SkipGUIProps	= 0x0040,
 		ALL		= 0xFFFF
 	};
 	Q_DECLARE_FLAGS(SyncOptions, SyncOption)
 	Q_FLAG(SyncOptions)
 
-	SyncClient(SyncOptions options, const QStringList& excludeProperties, QObject* parent = Q_NULLPTR);
-	virtual ~SyncClient() Q_DECL_OVERRIDE;
+	SyncClient(SyncOptions options, const QStringList& excludeProperties, QObject* parent = nullptr);
+	~SyncClient() override;
 
 	QString errorString() const { return errorStr; }
+	//! Check whether this property (format: "StelModule.property") is filtered away in the Client settings.
+	bool isPropertyFilteredAway(QString property) const;
 
 public slots:
 	void connectToServer(const QString& host, const int port);
 	void disconnectFromServer();
 
 protected:
-	void timerEvent(QTimerEvent* evt) Q_DECL_OVERRIDE;
+	void timerEvent(QTimerEvent* evt) override;
 signals:
 	void connected();
 	void disconnected(bool cleanExit);
@@ -79,7 +82,7 @@ private:
 	bool isConnecting;
 	SyncRemotePeer* server;
 	int timeoutTimerId;
-	QVector<SyncMessageHandler*> handlerList;
+	QHash<SyncProtocol::SyncMessageType, SyncMessageHandler*> handlerHash;
 
 	friend class ClientErrorHandler;
 };
