@@ -19,9 +19,9 @@
 
 #include "Satellite.hpp"
 #include "StelObject.hpp"
+#include "StelObjectMgr.hpp"
 #include "StelPainter.hpp"
 #include "StelApp.hpp"
-#include "StelLocation.hpp"
 #include "StelCore.hpp"
 #include "StelTexture.hpp"
 #include "VecMath.hpp"
@@ -40,7 +40,7 @@
 #include <QMatrix4x4>
 
 #include "gsatellite/gTime.hpp"
-#include "gsatellite/stdsat.h"
+//#include "gsatellite/stdsat.h"
 
 #include <cmath>
 
@@ -57,6 +57,7 @@ SphericalCap Satellite::viewportHalfspace = SphericalCap();
 int Satellite::orbitLineSegments = 90;
 int Satellite::orbitLineFadeSegments = 4;
 int Satellite::orbitLineSegmentDuration = 20;
+int Satellite::orbitLineThickness = 1;
 bool Satellite::orbitLinesFlag = true;
 bool Satellite::iconicModeFlag = false;
 bool Satellite::hideInvisibleSatellitesFlag = false;
@@ -64,7 +65,7 @@ bool Satellite::coloredInvisibleSatellitesFlag = true;
 Vec3f Satellite::invisibleSatelliteColor = Vec3f(0.2f,0.2f,0.2f);
 Vec3f Satellite::transitSatelliteColor = Vec3f(0.f,0.f,0.f);
 double Satellite::timeRateLimit = 1.0; // one JD per second by default
-int Satellite::tleEpochAge = 30; // default age of TLE's epoch to mark TLE as outdated (using for filters)
+int Satellite::tleEpochAge = 30; // default age of TLE's epoch to mark TLE as outdated (used for filters)
 
 bool Satellite::flagCFKnownStdMagnitude = false;
 bool Satellite::flagCFApogee = false;
@@ -114,7 +115,7 @@ Satellite::Satellite(const QString& identifier, const QVariantMap& map)
 	, hintColor(0.f,0.f,0.f)
 	, lastUpdated()	
 	, isISS(false)	
-	, pSatWrapper(Q_NULLPTR)
+	, pSatWrapper(nullptr)
 	, visibility(gSatWrapper::UNKNOWN)
 	, phaseAngle(0.)
 	, infoColor(0.f,0.f,0.f)
@@ -193,7 +194,7 @@ Satellite::Satellite(const QString& identifier, const QVariantMap& map)
 	QVariantList groupList =  map.value("groups", QVariantList()).toList();
 	if (!groupList.isEmpty())
 	{
-		for (const auto& group : qAsConst(groupList))
+		for (const auto& group : std::as_const(groupList))
 			groups.insert(group.toString());
 	}
 
@@ -218,7 +219,8 @@ Satellite::Satellite(const QString& identifier, const QVariantMap& map)
 		{ gSatWrapper::VISIBLE,		N_("The satellite is sunlit and the observer is in the dark") },
 		{ gSatWrapper::RADAR_NIGHT,	N_("The satellite isn't sunlit") },
 		{ gSatWrapper::PENUMBRAL,	N_("The satellite is in penumbra") },
-		{ gSatWrapper::ANNULAR,		N_("The satellite is eclipsed") }
+		{ gSatWrapper::ANNULAR,		N_("The satellite is eclipsed") },
+		{ gSatWrapper::BELOW_HORIZON,   N_("The satellite is below the horizon") }
 	};
 
 	update(0.);
@@ -226,10 +228,10 @@ Satellite::Satellite(const QString& identifier, const QVariantMap& map)
 
 Satellite::~Satellite()
 {
-	if (pSatWrapper != Q_NULLPTR)
+	if (pSatWrapper)
 	{
 		delete pSatWrapper;
-		pSatWrapper = Q_NULLPTR;
+		pSatWrapper = nullptr;
 	}
 }
 
@@ -251,8 +253,8 @@ QVariantMap Satellite::getMap(void)
 	map["stdMag"] = stdMag;
 	map["rcs"] = RCS;
 	map["status"] = status;
-	map["tle1"] = tleElements.first.data();
-	map["tle2"] = tleElements.second.data();
+	map["tle1"] = tleElements.first;
+	map["tle2"] = tleElements.second;
 
 	if (!description.isEmpty())
 		map["description"] = description;
@@ -269,7 +271,7 @@ QVariantMap Satellite::getMap(void)
 	map["orbitColor"] = orbitCol;
 	map["infoColor"] = infoCol;
 	QVariantList commList;
-	for (const auto& c : qAsConst(comms))
+	for (const auto& c : std::as_const(comms))
 	{
 		QVariantMap commMap;
 		commMap["frequency"] = c.frequency;
@@ -279,7 +281,7 @@ QVariantMap Satellite::getMap(void)
 	}
 	map["comms"] = commList;
 	QVariantList groupList;
-	for (const auto& g : qAsConst(groups))
+	for (const auto& g : std::as_const(groups))
 	{
 		groupList << g;
 	}
@@ -336,7 +338,7 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 	if (flags & ObjectType)
 		oss << QString("%1: <b>%2</b>").arg(q_("Type"), getObjectTypeI18n())  << "<br/>";
 	
-	if ((flags & Magnitude) && (stdMag<99. || RCS>0.) && (visibility==gSatWrapper::VISIBLE))
+	if ((flags & Magnitude) && ((stdMag<99.) || (RCS>0.)) && (visibility==gSatWrapper::VISIBLE))
 	{
 		const int decimals = 2;
 		const float airmass = getAirmass(core);
@@ -358,7 +360,7 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 		oss << QString("%1: %2 %3").arg(q_("Range rate")).arg(rangeRate, 5, 'f', 3).arg(qc_("km/s", "speed")) << "<br/>";
 		// TRANSLATORS: Satellite altitude
 		oss << QString("%1: %2 %3").arg(q_("Altitude")).arg(qRound(height)).arg(km) << "<br/>";
-		oss << QString("%1: %2 %3 / %4 %5").arg(q_("Perigee/apogee altitudes")).arg(qRound(perigee)).arg(km).arg(qRound(apogee)).arg(km) << "<br/>";
+		oss << QString("%1 (WGS-84): %2 %3 / %4 %5").arg(q_("Perigee/apogee altitudes")).arg(qRound(perigee)).arg(km).arg(qRound(apogee)).arg(km) << "<br/>";
 	}
 
 	if (flags&Size && RCS>0.)
@@ -446,7 +448,7 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 		//Visibility: Full text		
 		oss << q_(visibilityDescription.value(visibility, "")) << "<br />";
 
-		if (comms.size() > 0)
+		if (!comms.isEmpty() && (status!=Satellite::StatusNonoperational))
 		{
 			oss << q_("Radio communication") << ":<br/>";
 			for (const auto& c : comms)
@@ -454,8 +456,12 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 				oss << getCommLinkInfo(c);
 			}
 		}
+		// Umbra circle info. May not generally be interesting.
+		//oss << QString("%1: %2 km, %3: %4 km").arg(q_("Umbra distance"), QString::number(umbraDistance, 'f', 3), q_("Radius"), QString::number(umbraRadius, 'f', 3)) << "<br/>";
+		//oss << QString("%1: %2 km, %3: %4 km").arg(q_("Penumbra distance"), QString::number(penumbraDistance, 'f', 3), q_("Radius"), QString::number(penumbraRadius, 'f', 3)) << "<br/>";
 	}
 
+	oss << getSolarLunarInfoString(core, flags);
 	postProcessInfoString(str, flags);
 	return str;
 }
@@ -463,7 +469,6 @@ QString Satellite::getInfoString(const StelCore *core, const InfoStringGroup& fl
 QString Satellite::getCommLinkInfo(CommLink comm) const
 {
 	QString commLinkData;
-
 	if (!comm.modulation.isEmpty()) // OK, the signal modulation mode is exist
 		commLinkData = comm.modulation;
 
@@ -477,11 +482,10 @@ QString Satellite::getCommLinkInfo(CommLink comm) const
 
 	// Translate some specific communications terms
 	// See end of Satellites.cpp file to define translatable terms
-	QStringList commTerms;
-	commTerms << "uplink" << "downlink" << "beacon" << "telemetry" << "video" << "broadband" << "command";
+	static const QStringList commTerms={ "uplink", "downlink", "beacon", "telemetry", "video", "broadband", "command", "meteorological", "maritime", "mobile telephony", "mobile", "repeater", "digipeater", "-band", "crew voice", "imaging", "mode" };
 	for (auto& term: commTerms)
 	{
-		commLinkData.replace(term, q_(term));
+		commLinkData.replace(term, qc_(term, "comms"));
 	}
 	commLinkData.replace("&", q_("and"));
 
@@ -497,7 +501,6 @@ QString Satellite::getCommLinkInfo(CommLink comm) const
 		sign='+';
 
 	commLinkData.append(QString(": %1 %2 (%3%4 %5)<br />").arg(QString::number(comm.frequency, 'f', 3), qc_("MHz", "frequency"), sign, QString::number(ddop, 'f', 3), qc_("kHz", "frequency")));
-
 	return commLinkData;
 }
 
@@ -505,13 +508,12 @@ QString Satellite::getCommLinkInfo(CommLink comm) const
 void Satellite::calculateSatDataFromLine2(QString tle)
 {
 	// Details: http://www.satobs.org/seesat/Dec-2002/0197.html
-	const double meanEarthRadius = 6371.0088;
 	const double k = 8681663.653;
-	const double meanMotion = tle.left(63).rightRef(11).toDouble();
+	const double meanMotion = tle.left(63).right(11).toDouble();
 	const double semiMajorAxis = std::cbrt((k/meanMotion)*(k/meanMotion));
 	eccentricity = QString("0.%1").arg(tle.left(33).right(7)).toDouble();
-	perigee = semiMajorAxis*(1.0 - eccentricity) - meanEarthRadius;
-	apogee = semiMajorAxis*(1.0 + eccentricity) - meanEarthRadius;
+	perigee = semiMajorAxis*(1.0 - eccentricity) - EARTH_RADIUS;
+	apogee = semiMajorAxis*(1.0 + eccentricity) - EARTH_RADIUS;
 	inclination = QString(tle.left(16).right(8)).toDouble();
 }
 
@@ -519,13 +521,13 @@ void Satellite::calculateSatDataFromLine2(QString tle)
 void Satellite::calculateEpochFromLine1(QString tle)
 {
 	QString epochStr;
-	// Details: https://celestrak.com/columns/v04n03/ or https://en.wikipedia.org/wiki/Two-line_element_set
-	int year = tle.left(20).rightRef(2).toInt();
+	// Details: https://celestrak.org/columns/v04n03/ or https://en.wikipedia.org/wiki/Two-line_element_set
+	int year = tle.left(20).right(2).toInt();
 	if (year>=0 && year<57)
 		year += 2000;
 	else
 		year += 1900;
-	const double dayOfYear = tle.left(32).rightRef(12).toDouble();
+	const double dayOfYear = tle.left(32).right(12).toDouble();
 	QDate epoch = QDate(year, 1, 1).addDays(dayOfYear - 1);
 	if (!epoch.isValid())
 		epochStr = qc_("unknown", "unknown date");
@@ -544,8 +546,8 @@ QVariantMap Satellite::getInfoMap(const StelCore *core) const
 
 	map.insert("description", QString(description).replace("\n", " - "));
 	map.insert("catalog", id);
-	map.insert("tle1", tleElements.first.data());
-	map.insert("tle2", tleElements.second.data());
+	map.insert("tle1", tleElements.first);
+	map.insert("tle2", tleElements.second);
 	map.insert("tle-epoch", tleEpoch);
 
 	if (!internationalDesignator.isEmpty())
@@ -640,7 +642,7 @@ float Satellite::getVMagnitude(const StelCore* core) const
 			// fracil = fraction of satellite illuminated,
 			//	    [ 0 <= fracil <= 1 ]
 			//
-			// Original description: http://www.prismnet.com/~mmccants/tles/mccdesc.html
+			// Original description: http://mmccants.org/tles/mccdesc.html
 
 			double fracil = qMax(0.000001, static_cast<double>(calculateIlluminatedFraction()));
 
@@ -670,8 +672,8 @@ float Satellite::getVMagnitude(const StelCore* core) const
 				m[2].rotate(-120, Vz);
 
 				StelLocation loc   = StelApp::getInstance().getCore()->getCurrentLocation();
-				const double  radLatitude    = loc.latitude * KDEG2RAD;
-				const double  theta          = pSatWrapper->getEpoch().toThetaLMST(loc.longitude * KDEG2RAD);
+				const double  radLatitude    = loc.getLatitude() * KDEG2RAD;
+				const double  theta          = pSatWrapper->getEpoch().toThetaLMST(loc.getLongitude() * KDEG2RAD);
 				const double sinRadLatitude=sin(radLatitude);
 				const double cosRadLatitude=cos(radLatitude);
 				const double sinTheta=sin(theta);
@@ -784,12 +786,12 @@ void Satellite::setNewTleElements(const QString& tle1, const QString& tle2)
 	if (pSatWrapper)
 	{
 		gSatWrapper *old = pSatWrapper;
-		pSatWrapper = Q_NULLPTR;
+		pSatWrapper = nullptr;
 		delete old;
 	}
 
-	tleElements.first = tle1.toUtf8();
-	tleElements.second = tle2.toUtf8();
+	tleElements.first = tle1;
+	tleElements.second = tle2;
 
 	pSatWrapper = new gSatWrapper(id, tle1, tle2);
 	orbitPoints.clear();
@@ -802,8 +804,8 @@ void Satellite::setNewTleElements(const QString& tle1, const QString& tle2)
 
 void Satellite::recomputeSatData()
 {
-	calculateEpochFromLine1(tleElements.first.data());
-	calculateSatDataFromLine2(tleElements.second.data());
+	calculateEpochFromLine1(tleElements.first);
+	calculateSatDataFromLine2(tleElements.second);
 }
 
 void Satellite::update(double)
@@ -818,7 +820,12 @@ void Satellite::update(double)
 		velocity                 = pSatWrapper->getTEMEVel();
 		latLongSubPointPosition  = pSatWrapper->getSubPoint();
 		height                   = latLongSubPointPosition[2]; // km
-		if (height < 0.1)
+		/*
+		Vec2d pa                 = pSatWrapper->getPerigeeApogeeAltitudes();
+		perigee                  = pa[0];
+		apogee                   = pa[1];
+		*/
+		if (height < 80) // way below Kármán line: Satellite is certainly lost, at least TLE not applicable.
 		{
 			// The orbit is no longer valid.  Causes include very out of date
 			// TLE, system date and time out of a reasonable range, and orbital
@@ -844,6 +851,80 @@ void Satellite::update(double)
 	}
 }
 
+// Get radii and distances of shadow circles
+Vec4d Satellite::getUmbraData()
+{
+	const double rhoE=position.norm(); // geocentric Satellite distance, km
+	return Satellite::getUmbraData(rhoE);
+}
+
+//! Get radii and geocentric antisolar distances of shadow circles in km for a hypothetical object in geocentric distance rhoE [km].
+//! Vec4d(umbraDistance, umbraRadius, penumbraDistance, penumbraRadius);
+Vec4d Satellite::getUmbraData(const double rhoE)
+{
+	static PlanetP earth=GETSTELMODULE(SolarSystem)->getEarth();
+	static PlanetP sun = GETSTELMODULE(SolarSystem)->getSun();
+
+	// Compute locations of umbra and penumbra circles. These should show where the satellite enters/exits umbra/penumbra.
+	// The computation follows ideas from https://celestrak.org/columns/v03n01/
+	// These sources mention ECI coordinates (Earth Centered Inertial). Presumably TEME (True Equator Mean Equinox) are equivalent, at least for our purposes.
+	const double rS=earth->getHeliocentricEclipticPos().norm()*AU; // distance earth...sun
+	const double thetaE=asin((earth->getEquatorialRadius()*AU)/(rhoE));
+	Vec3d sunEquinoxEqPos = sun->getEquinoxEquatorialPos(StelApp::getInstance().getCore());
+	Vec3d sunTEME=sunEquinoxEqPos*AU;
+	const double thetaS=asin((sun->getEquatorialRadius()*AU)/(sunTEME.norm()));
+	Q_ASSERT(thetaE>thetaS);
+	const double theta=thetaE-thetaS; // angle so that satellite dives into umbra
+	// angle at Sun:
+	const double sigma=asin(sin(theta)*rhoE/rS);
+	// angle in geocenter
+	const double eta=M_PI-sigma-theta;
+	// complement
+	const double mu=M_PI-eta;
+	// geocentric distance of shadow circle towards antisun
+	double umbraDistance=rhoE*cos(mu);
+	// radius of shadow circle
+	double umbraRadius=rhoE*sin(mu);
+	// Repeat for penumbra
+	const double thetaP=thetaE+thetaS; // angle so that satellite touches penumbra
+	// angle at Sun:
+	const double sigmaP=asin(sin(thetaP)*rhoE/rS);
+	// angle in geocenter
+	const double etaP=M_PI-sigmaP-thetaP;
+	// complement
+	const double muP=M_PI-etaP;
+	// geocentric distance of shadow circle towards antisun
+	double penumbraDistance=rhoE*cos(muP);
+	// radius of shadow circle
+	double penumbraRadius=rhoE*sin(muP);
+	//// DBG OUT
+	//StelObjectMgr *om=GETSTELMODULE(StelObjectMgr);
+	//om->setExtraInfoString(StelObject::DebugAid, QString("&rho;<sub>E</sub> %1, r<sub>S</sub> %2, &theta;<sub>E</sub> %3°, &theta;<sub>S</sub> %4° <br/>")
+	//		       .arg(QString::number(rhoE, 'f', 3),
+	//			    QString::number(rS, 'f', 3),
+	//			    QString::number(thetaE*M_180_PI, 'f', 3),
+	//			    QString::number(thetaS*M_180_PI, 'f', 3)
+	//			    )
+	//		       );
+	//om->addToExtraInfoString(StelObject::DebugAid, QString("&theta; %1°, &sigma; %2°, &eta; %3°, &mu; %4° <br/>")
+	//		       .arg(
+	//			    QString::number(theta*M_180_PI, 'f', 3),
+	//			    QString::number(sigma*M_180_PI, 'f', 3),
+	//			    QString::number(eta*M_180_PI, 'f', 3),
+	//			    QString::number(mu*M_180_PI, 'f', 3)
+	//			    )
+	//		       );
+	//om->addToExtraInfoString(StelObject::DebugAid, QString("&theta;<sub>P</sub> %1°, &sigma; %2°, &eta; %3°, &mu; %4° <br/>")
+	//		       .arg(
+	//			    QString::number(thetaP*M_180_PI, 'f', 3),
+	//			    QString::number(sigmaP*M_180_PI, 'f', 3),
+	//			    QString::number(etaP*M_180_PI, 'f', 3),
+	//			    QString::number(muP*M_180_PI, 'f', 3)
+	//			    )
+	//		       );
+	return Vec4d(umbraDistance, umbraRadius, penumbraDistance, penumbraRadius);
+}
+
 double Satellite::getDoppler(double freq) const
 {
 	return  -freq*((rangeRate*1000.0)/SPEED_OF_LIGHT);
@@ -903,8 +984,37 @@ SatFlags Satellite::getFlags() const
 		flags |= SatCustomFilter;
 	if (!comms.isEmpty())
 		flags |= SatCommunication;
-	if (apogee<=100.0 || height<=100.0) // Karman line, atmosphere
+	if (apogee<=100.0 || height<=100.0) // Karman line, atmosphere: thermosphere
 		flags |= SatReentry;
+	if (status == StatusOperational)
+	{
+		flags |= SatOperationalOS;
+		flags |= SatActiveOS;
+	}
+	if (status == StatusNonoperational)
+		flags |= SatNonoperationalOS;
+	if (status == StatusPartiallyOperational)
+	{
+		flags |= SatPartiallyOperationalOS;
+		flags |= SatActiveOS;
+	}
+	if (status == StatusStandby)
+	{
+		flags |= SatStandbyOS;
+		flags |= SatActiveOS;
+	}
+	if (status == StatusSpare)
+	{
+		flags |= SatSpareOS;
+		flags |= SatActiveOS;
+	}
+	if (status == StatusExtendedMission)
+	{
+		flags |= SatExtendedMissionOS;
+		flags |= SatActiveOS;
+	}
+	if (status == StatusDecayed)
+		flags |= SatDecayedOS;
 
 	return flags;
 }
@@ -931,7 +1041,7 @@ bool Satellite::getCustomFiltersFlag() const
 	bool cfe = true;
 	if (flagCFEccentricity)
 		cfe = (eccentricity>=minCFEccentricity && eccentricity<=maxCFEccentricity);
-	// Known standrad magnitude
+	// Known standard magnitude
 	bool cfm = true;
 	if (flagCFKnownStdMagnitude)
 		cfm = (stdMag<99.0);
@@ -959,7 +1069,7 @@ void Satellite::parseInternationalDesignator(const QString& tle1)
 	QStringList tleData = tle1.split(" ");
 	QString rawString = tleData.at(2);
 	bool ok;
-	int year = rawString.leftRef(2).toInt(&ok);
+	int year = rawString.left(2).toInt(&ok);
 	if (!rawString.isEmpty() && ok)
 	{
 		// Y2K bug :) I wonder what NORAD will do in 2057. :)
@@ -1058,7 +1168,7 @@ void Satellite::draw(StelCore* core, StelPainter& painter)
 					sd->preDrawPointSource(&painter);
 					sd->computeRCMag(magSat, &rcMag);
 					// allow height-dependent twinkle and suppress twinkling in higher altitudes. Keep 0.1 twinkle amount in zenith.
-					sd->drawPointSource(&painter, vf, rcMag, color*hintBrightness, true, qMin(1.0f, 1.0f-0.9f*altAz[2]));
+					sd->drawPointSource(&painter, vf.toVec3d(), rcMag, color*hintBrightness, true, qMin(1.0f, 1.0f-0.9f*altAz[2]));
 					sd->postDrawPointSource(&painter);
 				}
 
@@ -1099,6 +1209,7 @@ void Satellite::draw(StelCore* core, StelPainter& painter)
 void Satellite::drawOrbit(StelCore *core, StelPainter& painter)
 {
 	int size = orbitPoints.size();
+	const float ppx = static_cast<float>(painter.getProjector()->getDevicePixelsPerPixel());
 
 	if (size>0)
 	{
@@ -1137,7 +1248,15 @@ void Satellite::drawOrbit(StelCore *core, StelPainter& painter)
 			}
 		}
 
+		painter.enableClientStates(true, false, false);
+		if (orbitLineThickness>1 || ppx>1.f)
+			painter.setLineWidth(orbitLineThickness*ppx);
+
 		painter.drawPath(vertexArray, colorArray); // (does client state switching as needed internally)
+
+		painter.enableClientStates(false);
+		if (orbitLineThickness>1 || ppx>1.f)
+			painter.setLineWidth(1);
 	}
 }
 
