@@ -73,29 +73,37 @@ typedef QSet<QString> GroupSet;
 //! @ingroup satellites
 enum SatFlag
 {
-	SatNoFlags		= 0x000000,
-	SatDisplayed		= 0x000001,
-	SatNotDisplayed		= 0x000002,
-	SatUser			= 0x000004,
-	SatOrbit		= 0x000008,
-	SatNew			= 0x000010,
-	SatError		= 0x000020,
-	SatSmallSize		= 0x000040,
-	SatMediumSize		= 0x000080,
-	SatLargeSize		= 0x000100,
-	SatLEO			= 0x000200,
-	SatMEO			= 0x000400,
-	SatGSO			= 0x000800,
-	SatHEO			= 0x001000,
-	SatHGSO			= 0x002000,
-	SatPolarOrbit		= 0x004000,
-	SatEquatOrbit		= 0x008000,
-	SatPSSO			= 0x010000,
-	SatHEarthO		= 0x020000,
-	SatOutdatedTLE		= 0x040000,
-	SatCustomFilter		= 0x080000,
-	SatCommunication	= 0x100000,
-	SatReentry		= 0x200000
+	SatNoFlags				= 0x00000000,
+	SatDisplayed				= 0x00000001,
+	SatNotDisplayed			= 0x00000002,
+	SatUser					= 0x00000004,
+	SatOrbit					= 0x00000008,
+	SatNew					= 0x00000010,
+	SatError					= 0x00000020,
+	SatSmallSize				= 0x00000040,
+	SatMediumSize			= 0x00000080,
+	SatLargeSize				= 0x00000100,
+	SatLEO					= 0x00000200,
+	SatMEO					= 0x00000400,
+	SatGSO					= 0x00000800,
+	SatHEO					= 0x00001000,
+	SatHGSO					= 0x00002000,
+	SatPolarOrbit				= 0x00004000,
+	SatEquatOrbit				= 0x00008000,
+	SatPSSO					= 0x00010000,
+	SatHEarthO				= 0x00020000,
+	SatOutdatedTLE			= 0x00040000,
+	SatCustomFilter			= 0x00080000,
+	SatCommunication			= 0x00100000,
+	SatReentry				= 0x00200000,
+	SatActiveOS				= 0x00400000,
+	SatOperationalOS			= 0x00800000,
+	SatNonoperationalOS		= 0x01000000,
+	SatPartiallyOperationalOS	= 0x02000000,
+	SatStandbyOS				= 0x04000000,
+	SatSpareOS				= 0x08000000,
+	SatExtendedMissionOS		= 0x10000000,
+	SatDecayedOS			= 0x20000000
 };
 typedef QFlags<SatFlag> SatFlags;
 Q_DECLARE_OPERATORS_FOR_FLAGS(SatFlags)
@@ -124,11 +132,11 @@ public:
 	//! @enum OptStatus operational statuses
 	enum OptStatus
 	{
-		StatusOperational		= 1,
+		StatusOperational			= 1,
 		StatusNonoperational		= 2,
 		StatusPartiallyOperational	= 3,
 		StatusStandby			= 4,
-		StatusSpare			= 5,
+		StatusSpare				= 5,
 		StatusExtendedMission		= 6,
 		StatusDecayed			= 7,
 		StatusUnknown			= 0
@@ -139,32 +147,32 @@ public:
 	//! \param data a QMap which contains the details of the satellite
 	//! (TLE set, description etc.)
 	Satellite(const QString& identifier, const QVariantMap& data);
-	~Satellite() Q_DECL_OVERRIDE;
+	~Satellite() override;
 
 	//! Get a QVariantMap which describes the satellite.  Could be used to
 	//! create a duplicate.
 	QVariantMap getMap(void);
 
-	virtual QString getType(void) const Q_DECL_OVERRIDE
+	QString getType(void) const override
 	{
 		return SATELLITE_TYPE;
 	}
 
-	virtual QString getObjectType(void) const Q_DECL_OVERRIDE
+	QString getObjectType(void) const override
 	{
 		return N_("artificial satellite");
 	}
-	virtual QString getObjectTypeI18n(void) const Q_DECL_OVERRIDE
+	QString getObjectTypeI18n(void) const override
 	{
 		return q_(getObjectType());
 	}
 
-	virtual QString getID(void) const Q_DECL_OVERRIDE
+	QString getID(void) const override
 	{
 		return id;
 	}
 
-	virtual float getSelectPriority(const StelCore* core) const Q_DECL_OVERRIDE;
+	float getSelectPriority(const StelCore* core) const override;
 
 	//! Get an HTML string to describe the object
 	//! @param core A pointer to the core
@@ -173,7 +181,7 @@ public:
 	//! - Name: designation in large type with the description underneath
 	//! - RaDecJ2000, RaDecOfDate, HourAngle, AltAzi
 	//! - Extra: range, range rate and altitude of satellite above the Earth, comms frequencies, modulation types and so on.
-	virtual QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const Q_DECL_OVERRIDE;
+	QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const override;
 	//! Return a map like StelObject::getInfoMap(), but with a few extra tags also available in getInfoString().
 	//! - description
 	//! - catalog
@@ -198,14 +206,14 @@ public:
 	//! - operational-status
 	//! - visibility (descriptive string)
 	//! - comm (Radio information, optional, if available. There may be several comm entries!)
-	virtual QVariantMap getInfoMap(const StelCore *core) const Q_DECL_OVERRIDE;
-	virtual Vec3f getInfoColor(void) const Q_DECL_OVERRIDE;
-	virtual Vec3d getJ2000EquatorialPos(const StelCore*) const Q_DECL_OVERRIDE;
-	virtual float getVMagnitude(const StelCore* core) const Q_DECL_OVERRIDE;
+	QVariantMap getInfoMap(const StelCore *core) const override;
+	Vec3f getInfoColor(void) const override;
+	Vec3d getJ2000EquatorialPos(const StelCore*) const override;
+	float getVMagnitude(const StelCore* core) const override;
 	//! Get angular half-size, degrees
-	virtual double getAngularRadius(const StelCore*) const Q_DECL_OVERRIDE;
-	virtual QString getNameI18n(void) const Q_DECL_OVERRIDE;
-	virtual QString getEnglishName(void) const Q_DECL_OVERRIDE
+	double getAngularRadius(const StelCore*) const override;
+	QString getNameI18n(void) const override;
+	QString getEnglishName(void) const override
 	{
 		return name;
 	}
@@ -245,6 +253,25 @@ public:
 	//! Calculation of illuminated fraction of the satellite.
 	float calculateIlluminatedFraction() const;
 
+	//! Get radii and geocentric antisolar distances of shadow circles in km from the geocenter.
+	//! @return Vec4d(umbraDistance, umbraRadius, penumbraDistance, penumbraRadius);
+	//! umbraDistance    : geocentric distance (km) of the umbra circle centre in the antisolar direction
+	//! umbraRadius      : radius (km) of the umbra circle
+	//! penumbraDistance : geocentric distance (km) of the penumbra circle in the antisolar direction
+	//! penumbraRadius   : radius (km) of the penumbra circle
+	Vec4d getUmbraData();
+
+	//! Get radii and geocentric antisolar distances of shadow circles in km for a hypothetical object in distance rhoE [km] from the geocenter.
+	//! @param rhoE distance [km] from the geocenter.
+	//! @return Vec4d(umbraDistance, umbraRadius, penumbraDistance, penumbraRadius);
+	//! umbraDistance    : geocentric distance (km) of the umbra circle centre in the antisolar direction
+	//! umbraRadius      : radius (km) of the umbra circle
+	//! penumbraDistance : geocentric distance (km) of the penumbra circle in the antisolar direction
+	//! penumbraRadius   : radius (km) of the penumbra circle
+	//! @note To gain data for an object in dist_km above (spherical) earth, use
+	//!    rhoE=earth->getEquatorialRadius()*AU+dist_km;
+	static Vec4d getUmbraData(const double rhoE);
+
 	//! Get operational status of satellite
 	QString getOperationalStatus() const;
 
@@ -313,7 +340,7 @@ private:
 	int status;
 	//! Contains the J2000 position.
 	Vec3d XYZ;
-	QPair< QByteArray, QByteArray > tleElements;
+	QPair< QString, QString> tleElements;
 	double height, range, rangeRate;
 	QList<CommLink> comms;
 	Vec3f hintColor;	
@@ -333,6 +360,7 @@ private:
 	static int   orbitLineSegments;
 	static int   orbitLineFadeSegments;
 	static int   orbitLineSegmentDuration; //measured in seconds
+	static int   orbitLineThickness;
 	static bool  orbitLinesFlag;
 	static bool  iconicModeFlag;
 	static bool  hideInvisibleSatellitesFlag;
@@ -375,9 +403,9 @@ private:
 
 	//Satellite Orbit Position calculation
 	gSatWrapper *pSatWrapper;
-	Vec3d	position;
-	Vec3d	velocity;
-	Vec3d	latLongSubPointPosition;
+	Vec3d	position; //< holds TEME coordinates [km]
+	Vec3d	velocity; //< holds TEME velocity [km/s]
+	Vec3d	latLongSubPointPosition; //< holds WGS84 satellite coordinates: long[degrees]/lat[degrees]/altitude[km]_over_wgs84
 	Vec3d	elAzPosition;
 
 	gSatWrapper::Visibility	visibility;
