@@ -23,8 +23,6 @@
 #include "StelObjectModule.hpp"
 #include "Satellite.hpp"
 #include "StelFader.hpp"
-#include "StelGui.hpp"
-#include "StelDialog.hpp"
 #include "StelLocation.hpp"
 
 #include <QDateTime>
@@ -162,12 +160,13 @@ class Satellites : public StelObjectModule
 	Q_PROPERTY(int  orbitLineSegments		READ getOrbitLineSegments		WRITE setOrbitLineSegments		NOTIFY orbitLineSegmentsChanged)
 	Q_PROPERTY(int  orbitLineFadeSegments		READ getOrbitLineFadeSegments		WRITE setOrbitLineFadeSegments		NOTIFY orbitLineFadeSegmentsChanged)
 	Q_PROPERTY(int  orbitLineSegmentDuration	READ getOrbitLineSegmentDuration	WRITE setOrbitLineSegmentDuration	NOTIFY orbitLineSegmentDurationChanged)
+	Q_PROPERTY(int  orbitLineThickness		READ getOrbitLineThickness		WRITE setOrbitLineThickness		NOTIFY orbitLineThicknessChanged)
 	Q_PROPERTY(int  tleEpochAgeDays			READ getTleEpochAgeDays			WRITE setTleEpochAgeDays		NOTIFY tleEpochAgeDaysChanged)
 	Q_PROPERTY(Vec3f invisibleSatelliteColor	READ getInvisibleSatelliteColor		WRITE setInvisibleSatelliteColor	NOTIFY invisibleSatelliteColorChanged)
 	Q_PROPERTY(Vec3f transitSatelliteColor		READ getTransitSatelliteColor		WRITE setTransitSatelliteColor		NOTIFY transitSatelliteColorChanged)
 	Q_PROPERTY(bool flagUmbraVisible		READ getFlagUmbraVisible		WRITE setFlagUmbraVisible		NOTIFY flagUmbraVisibleChanged)
-	Q_PROPERTY(bool flagUmbraAtFixedDistance	READ getFlagUmbraAtFixedDistance	WRITE setFlagUmbraAtFixedDistance	NOTIFY flagUmbraAtFixedDistanceChanged)
-	Q_PROPERTY(double umbraDistance			READ getUmbraDistance			WRITE setUmbraDistance			NOTIFY umbraDistanceChanged)
+	Q_PROPERTY(bool flagUmbraAtFixedAltitude	READ getFlagUmbraAtFixedAltitude	WRITE setFlagUmbraAtFixedAltitude	NOTIFY flagUmbraAtFixedAltitudeChanged)
+	Q_PROPERTY(double umbraAltitude			READ getUmbraAltitude			WRITE setUmbraAltitude			NOTIFY umbraAltitudeChanged)
 	Q_PROPERTY(Vec3f umbraColor			READ getUmbraColor			WRITE setUmbraColor			NOTIFY umbraColorChanged)
 	Q_PROPERTY(bool flagPenumbraVisible		READ getFlagPenumbraVisible		WRITE setFlagPenumbraVisible		NOTIFY flagPenumbraVisibleChanged)
 	Q_PROPERTY(Vec3f penumbraColor			READ getPenumbraColor			WRITE setPenumbraColor			NOTIFY penumbraColorChanged)
@@ -223,16 +222,16 @@ public:
 	};
 
 	Satellites();
-	virtual ~Satellites() Q_DECL_OVERRIDE;
+	~Satellites() override;
 
 	///////////////////////////////////////////////////////////////////////////
 	// Methods defined in the StelModule class
-	virtual void init() Q_DECL_OVERRIDE;
-	virtual void deinit() Q_DECL_OVERRIDE;
-	virtual void update(double deltaTime) Q_DECL_OVERRIDE;
-	virtual void draw(StelCore* core) Q_DECL_OVERRIDE;
-	virtual void drawPointer(StelCore* core, StelPainter& painter);
-	virtual double getCallOrder(StelModuleActionName actionName) const Q_DECL_OVERRIDE;
+	void init() override;
+	void deinit() override;
+	void update(double deltaTime) override;
+	void draw(StelCore* core) override;
+	void drawPointer(StelCore* core, StelPainter& painter);
+	double getCallOrder(StelModuleActionName actionName) const override;
 
 	///////////////////////////////////////////////////////////////////////////
 	// Methods defined in StelObjectModule class
@@ -241,19 +240,19 @@ public:
 	//! @param limitFov the field of view around the position v in which to search for satellites.
 	//! @param core the StelCore to use for computations.
 	//! @return a list containing the satellites located inside the limitFov circle around position v.
-	virtual QList<StelObjectP> searchAround(const Vec3d& v, double limitFov, const StelCore* core) const Q_DECL_OVERRIDE;
+	QList<StelObjectP> searchAround(const Vec3d& v, double limitFov, const StelCore* core) const override;
 
-	//! Return the matching satellite object's pointer if exists or Q_NULLPTR.
+	//! Return the matching satellite object's pointer if exists or nullptr.
 	//! @param nameI18n The case in-sensitive satellite name
-	virtual StelObjectP searchByNameI18n(const QString& nameI18n) const Q_DECL_OVERRIDE;
+	StelObjectP searchByNameI18n(const QString& nameI18n) const override;
 
-	//! Return the matching satellite if exists or Q_NULLPTR.
+	//! Return the matching satellite if exists or nullptr.
 	//! @param name The case in-sensitive standard program name
-	virtual StelObjectP searchByName(const QString& name) const Q_DECL_OVERRIDE;
+	StelObjectP searchByName(const QString& name) const override;
 
-	//! Return the matching satellite if exists or Q_NULLPTR.
+	//! Return the matching satellite if exists or nullptr.
 	//! @param id The satellite id (NORAD)
-	virtual StelObjectP searchByID(const QString &id) const Q_DECL_OVERRIDE;
+	StelObjectP searchByID(const QString &id) const override;
 	
 	//! Return the satellite with the given catalog number.
 	//! Used as a helper function by searchByName() and
@@ -274,16 +273,16 @@ public:
 	//! @param maxNbItem the maximum number of returned object names
 	//! @param useStartOfWords the autofill mode for returned objects names
 	//! @return a list of matching object name by order of relevance, or an empty list if nothing match
-	virtual QStringList listMatchingObjects(const QString& objPrefix, int maxNbItem=5, bool useStartOfWords=false) const Q_DECL_OVERRIDE;
+	QStringList listMatchingObjects(const QString& objPrefix, int maxNbItem=5, bool useStartOfWords=false) const override;
 
-	virtual QStringList listAllObjects(bool inEnglish) const Q_DECL_OVERRIDE;
+	QStringList listAllObjects(bool inEnglish) const override;
 
-	virtual QString getName() const Q_DECL_OVERRIDE { return "Satellites"; }
-	virtual QString getStelObjectType() const Q_DECL_OVERRIDE { return Satellite::SATELLITE_TYPE; }
+	QString getName() const override { return "Satellites"; }
+	QString getStelObjectType() const override { return Satellite::SATELLITE_TYPE; }
 
 	//! Implement this to tell the main Stellarium GUI that there is a GUI element to configure this
 	//! plugin. 
-	virtual bool configureGui(bool show=true) Q_DECL_OVERRIDE;
+	bool configureGui(bool show=true) override;
 
 	//! Set up the plugin with default values.  This means clearing out the Satellites section in the
 	//! main config.ini (if one already exists), and populating it with default values.  It also 
@@ -430,14 +429,15 @@ signals:
 	void autoRemoveEnabledChanged(bool b);
 	void orbitLineSegmentsChanged(int i);
 	void orbitLineFadeSegmentsChanged(int i);
+	void orbitLineThicknessChanged(int i);
 	void orbitLineSegmentDurationChanged(int i);
 	void tleEpochAgeDaysChanged(int i);
 	void invisibleSatelliteColorChanged(Vec3f);
 	void transitSatelliteColorChanged(Vec3f);
 	void flagUmbraVisibleChanged(bool b);
-	void flagUmbraAtFixedDistanceChanged(bool b);
+	void flagUmbraAtFixedAltitudeChanged(bool b);
 	void umbraColorChanged(Vec3f);
-	void umbraDistanceChanged(double d);
+	void umbraAltitudeChanged(double d);
 	void flagPenumbraVisibleChanged(bool b);
 	void penumbraColorChanged(Vec3f);
 	void flagCFKnownStdMagnitudeChanged(bool b);
@@ -589,6 +589,11 @@ public slots:
 	//! set number of fading segments at end of orbit
 	void setOrbitLineFadeSegments(int s);
 
+	//! return the thickness of orbit
+	int getOrbitLineThickness() {return Satellite::orbitLineThickness;}
+	//! set the thickness of orbit
+	void setOrbitLineThickness(int s);
+
 	//! return duration of a single segments
 	int getOrbitLineSegmentDuration() {return Satellite::orbitLineSegmentDuration;}
 	//! set duration of a single segments
@@ -606,10 +611,10 @@ public slots:
 	void setFlagUmbraVisible(bool b);
 	bool getFlagUmbraVisible() { return flagUmbraVisible; }
 
-	//! Set whether ring of Earth's umbra should be displayed at fixed distance.
+	//! Set whether ring of Earth's umbra should be displayed at given satellite altitude.
 	//! Emits settingsChanged() if the value changes.
-	void setFlagUmbraAtFixedDistance(bool b);
-	bool getFlagUmbraAtFixedDistance() { return flagUmbraAtFixedDistance; }
+	void setFlagUmbraAtFixedAltitude(bool b);
+	bool getFlagUmbraAtFixedAltitude() { return flagUmbraAtFixedAltitude; }
 
 	//! Get color for ring of Earth's umbra
 	//! @return color
@@ -619,9 +624,9 @@ public slots:
 
 	//! Get the fixed distance for center of visualized Earth's umbra
 	//! @return distance, km
-	double getUmbraDistance() { return umbraDistance; }
+	double getUmbraAltitude() { return fixedUmbraAltitude; }
 	//! Set the fixed distance for center of visualized Earth's umbra
-	void setUmbraDistance(double d);
+	void setUmbraAltitude(double d);
 
 	//! Set whether ring of Earth's penumbra should be displayed.
 	//! Emits settingsChanged() if the value changes.
@@ -772,11 +777,10 @@ private slots:
 	//! Call when button "Save settings" in main GUI are pressed
 	void saveSettings() { saveSettingsToConfig(); }	
 	void translateData();
-	void updateEarthShadowEnlargementFlag(bool state) { earthShadowEnlargementDanjon=state; }
 
 private:
 	//! Drawing the circles of Earth's umbra and penumbra
-	void drawCircles(StelCore* core);
+	void drawCircles(StelCore* core, StelPainter& painter);
 	//! Add to the current collection the satellite described by the data.
 	//! @warning Use only in other methods! Does not update satelliteListModel!
 	//! @todo This probably could be done easier if Satellite had a constructor
@@ -784,7 +788,7 @@ private:
 	//! @returns true if the addition was successful.
 	bool add(const TleData& tleData);
 	//! Guess the groups of satellites
-	QStringList guessGroups(const TleData& tleData);
+	QStringList guessGroups(const TleData& tleData);	
 	//! Get the standard magnitude and RCS data for satellite
 	//! @return standard magnitude, RCS
 	QPair<double, double> getStdMagRCS(const TleData& tleData);
@@ -844,7 +848,7 @@ private:
 	//! Path to the satellite catalog file.
 	QString catalogPath;
 	//! Plug-in data directory.
-	//! Intialized by init(). Contains the catalog file (satellites.json),
+	//! Initialized by init(). Contains the catalog file (satellites.json),
 	//! temporary TLE lists downloaded during an online update, or whatever
 	//! other modifiable files the plug-in needs.
 	QDir dataDir;
@@ -910,16 +914,14 @@ private:
 	//@{
 	//! Flag enabling visualization the Earth's umbra.
 	bool flagUmbraVisible;
-	//! Flag enabling visualization the Earth's umbra at fixed distance
-	bool flagUmbraAtFixedDistance;
+	//! Flag enabling visualization the Earth's umbra at a given altitude above a spherical Earth
+	bool flagUmbraAtFixedAltitude;
 	Vec3f umbraColor;
 	//! The distance for center of visualized Earth's umbra in kilometers
-	double umbraDistance;
+	double fixedUmbraAltitude;
 	//! Flag enabling visualization the Earth's penumbra.
 	bool flagPenumbraVisible;
 	Vec3f penumbraColor;
-	//! Used to track whether earth shadow enlargement shall be computed after Danjon (1951)
-	bool earthShadowEnlargementDanjon;
 	//@}
 
 	//! @name Screen message infrastructure
@@ -969,9 +971,9 @@ class SatellitesStelPluginInterface : public QObject, public StelPluginInterface
 	Q_PLUGIN_METADATA(IID StelPluginInterface_iid)
 	Q_INTERFACES(StelPluginInterface)
 public:
-	virtual StelModule* getStelModule() const Q_DECL_OVERRIDE;
-	virtual StelPluginInfo getPluginInfo() const Q_DECL_OVERRIDE;
-	virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
+	StelModule* getStelModule() const override;
+	StelPluginInfo getPluginInfo() const override;
+	//QObjectList getExtensionList() const override { return QObjectList(); }
 };
 
 #endif /* SATELLITES_HPP */
