@@ -59,14 +59,14 @@ gSatWrapper::gSatWrapper(QString designation, QString tle1,QString tle2)
 
 gSatWrapper::~gSatWrapper()
 {
-	if (pSatellite != Q_NULLPTR)
+	if (pSatellite)
 		delete pSatellite;
 }
 
 Vec3d gSatWrapper::getTEMEPos() const
 {
 	Vec3d returnedVector;
-	if (pSatellite != Q_NULLPTR)
+	if (pSatellite)
 		returnedVector = pSatellite->getPos();
 	else
 		qWarning() << "gSatWrapper::getTEMEPos Method called without pSatellite initialized";
@@ -77,7 +77,7 @@ Vec3d gSatWrapper::getTEMEPos() const
 Vec3d gSatWrapper::getTEMEVel() const
 {
 	Vec3d returnedVector;
-	if (pSatellite != Q_NULLPTR)
+	if (pSatellite)
 		returnedVector = pSatellite->getVel();
 	else
 		qWarning() << "gSatWrapper::getTEMEVel Method called without pSatellite initialized";
@@ -88,10 +88,10 @@ Vec3d gSatWrapper::getTEMEVel() const
 Vec3d gSatWrapper::getSubPoint() const
 {
 	Vec3d returnedVector;
-	if (pSatellite != Q_NULLPTR)
+	if (pSatellite)
 		returnedVector = pSatellite->getSubPoint();
 	else
-		qWarning() << "gSatWrapper::getTEMEVel Method called without pSatellite initialized";
+		qWarning() << "gSatWrapper::getSubPoint Method called without pSatellite initialized";
 
 	return returnedVector;
 }
@@ -109,19 +109,19 @@ void gSatWrapper::calcObserverECIPosition(Vec3d& ao_position, Vec3d& ao_velocity
 	{
 		StelLocation loc   = StelApp::getInstance().getCore()->getCurrentLocation();
 
-		double radLatitude	= loc.latitude * KDEG2RAD;
-		double theta		= epoch.toThetaLMST(loc.longitude * KDEG2RAD);
+		double radLatitude	= loc.getLatitude() * M_PI_180;
+		double theta		= epoch.toThetaLMST(loc.getLongitude() * M_PI_180);
 
 		/* Reference:  Explanatory supplement to the Astronomical Almanac 1992, page 209-210. */
-		/* Elipsoid earth model*/
-		/* c = Nlat/a */
-		double c = 1/std::sqrt(1 + __f*(__f - 2)*Sqr(sin(radLatitude)));
-		double sq = Sqr(1 - __f)*c;
+		/* Ellipsoid earth model*/
+		/* C = Nlat/a */
+		const double C = 1/std::sqrt(1 + __f*(__f - 2.)*Sqr(sin(radLatitude)));
+		const double S = Sqr(1 - __f)*C;
 
-		double r = (KEARTHRADIUS*c + (loc.altitude/1000))*cos(radLatitude);
+		double r = (EARTH_RADIUS*C + (loc.altitude/1000.))*cos(radLatitude);
 		ao_position[0] = r * cos(theta);/*kilometers*/
 		ao_position[1] = r * sin(theta);
-		ao_position[2] = (KEARTHRADIUS*sq + (loc.altitude/1000))*sin(radLatitude);
+		ao_position[2] = (EARTH_RADIUS*S + (loc.altitude/1000.))*sin(radLatitude);
 		ao_velocity[0] = -KMFACTOR*ao_position[1];/*kilometers/second*/
 		ao_velocity[1] =  KMFACTOR*ao_position[0];
 		ao_velocity[2] =  0;
@@ -135,12 +135,12 @@ Vec3d gSatWrapper::getAltAz() const
 	StelLocation loc   = StelApp::getInstance().getCore()->getCurrentLocation();
 	Vec3d topoSatPos;
 
-	const double  radLatitude	= loc.latitude * KDEG2RAD;
-	const double  theta		= epoch.toThetaLMST(loc.longitude * KDEG2RAD);
-	const double sinRadLatitude	= sin(radLatitude);
-	const double cosRadLatitude	= cos(radLatitude);
-	const double sinTheta	= sin(theta);
-	const double cosTheta	= cos(theta);
+	const double radLatitude    = loc.getLatitude() * M_PI_180;
+	const double sinRadLatitude = sin(radLatitude);
+	const double cosRadLatitude = cos(radLatitude);
+	const double theta          = epoch.toThetaLMST(loc.getLongitude() * M_PI_180);
+	const double sinTheta       = sin(theta);
+	const double cosTheta       = cos(theta);
 
 	// This now only updates if required.
 	calcObserverECIPosition(observerECIPos, observerECIVel);
@@ -173,7 +173,7 @@ void  gSatWrapper::getSlantRange(double &ao_slantRange, double &ao_slantRangeRat
 	Vec3d slantRange		= satECIPos - observerECIPos;
 	Vec3d slantRangeVelocity = satECIVel - observerECIVel;
 
-	ao_slantRange		= slantRange.length();
+	ao_slantRange		= slantRange.norm();
 	ao_slantRangeRate	= slantRange.dot(slantRangeVelocity)/ao_slantRange;
 }
 
@@ -187,8 +187,7 @@ void gSatWrapper::updateSunECIPos()
 	Vec3d sunEquinoxEqPos = solsystem->getSun()->getEquinoxEquatorialPos(StelApp::getInstance().getCore());
 
 	//sunEquinoxEqPos is measured in AU. we need measure it in Km
-	sunECIPos.set(sunEquinoxEqPos[0]*AU, sunEquinoxEqPos[1]*AU, sunEquinoxEqPos[2]*AU);
-	sunECIPos = sunECIPos + observerECIPos; //Change ref system centre
+	sunECIPos=sunEquinoxEqPos*AU + observerECIPos; //Change ref system centre
 }
 
 Vec3d gSatWrapper::getSunECIPos()
@@ -205,7 +204,7 @@ Vec3d gSatWrapper::getSunECIPos()
 // @brief This operation predicts the satellite visibility conditions.
 gSatWrapper::Visibility gSatWrapper::getVisibilityPredict() const
 {
-	gSatWrapper::Visibility rval = RADAR_NIGHT;
+	gSatWrapper::Visibility rval = BELOW_HORIZON;
 	Vec3d satAltAzPos = getAltAz();
 	if (satAltAzPos[2] > 0)
 	{
@@ -223,7 +222,7 @@ gSatWrapper::Visibility gSatWrapper::getVisibilityPredict() const
 			/*
 			Satellites in umbra/penumbra based on:-
 			Visually Observing Earth Satellites By Dr. T.S. Kelso
-			https://celestrak.com/columns/v03n01/
+			https://celestrak.org/columns/v03n01/
 			*/
 			double psun = std::sqrt(pow(satECIPos[0] - sunECIPos[0], 2) + pow(satECIPos[1] - sunECIPos[1], 2) + pow(satECIPos[2] - sunECIPos[2], 2) );
 			double pearth = std::sqrt(std::pow(satECIPos[0], 2) + std::pow(satECIPos[1], 2) + std::pow(satECIPos[2], 2));
