@@ -32,7 +32,6 @@
 #include <QMessageBox>
 
 #include "StelApp.hpp"
-#include "StelCore.hpp"
 #include "ui_satellitesDialog.h"
 #include "SatellitesDialog.hpp"
 #include "SatellitesImportDialog.hpp"
@@ -50,27 +49,24 @@
 #include "StelFileMgr.hpp"
 #include "StelTranslator.hpp"
 #include "StelActionMgr.hpp"
-#include "StelUtils.hpp"
 #include "StelMainView.hpp"
 
-#include "external/qxlsx/xlsxdocument.h"
-#include "external/qxlsx/xlsxchartsheet.h"
-#include "external/qxlsx/xlsxcellrange.h"
-#include "external/qxlsx/xlsxchart.h"
-#include "external/qxlsx/xlsxrichstring.h"
-#include "external/qxlsx/xlsxworkbook.h"
+#if defined(ENABLE_XLSX) && (SATELLITES_PLUGIN_IRIDIUM == 1)
+#include <xlsxdocument.h>
+#include <xlsxcellrange.h>
 using namespace QXlsx;
+#endif
 
 const QString SatellitesDialog::dash = QChar(0x2014);
 
 SatellitesDialog::SatellitesDialog()
 	: StelDialog("Satellites")
 	, satelliteModified(false)
-	, updateTimer(Q_NULLPTR)
-	, importWindow(Q_NULLPTR)
-	, filterWindow(Q_NULLPTR)
-	, commWindow(Q_NULLPTR)
-	, filterModel(Q_NULLPTR)
+	, updateTimer(nullptr)
+	, importWindow(nullptr)
+	, filterWindow(nullptr)
+	, commWindow(nullptr)
+	, filterModel(nullptr)
 	, checkStateRole(Qt::UserRole)
 	, delimiter(", ")	
 {
@@ -86,25 +82,25 @@ SatellitesDialog::~SatellitesDialog()
 	{
 		updateTimer->stop();
 		delete updateTimer;
-		updateTimer = Q_NULLPTR;
+		updateTimer = nullptr;
 	}
 
 	if (importWindow)
 	{
 		delete importWindow;
-		importWindow = Q_NULLPTR;
+		importWindow = nullptr;
 	}
 
 	if (filterWindow)
 	{
 		delete filterWindow;
-		filterWindow = Q_NULLPTR;
+		filterWindow = nullptr;
 	}
 
 	if (commWindow)
 	{
 		delete commWindow;
-		commWindow = Q_NULLPTR;
+		commWindow = nullptr;
 	}
 
 	delete ui;
@@ -134,8 +130,8 @@ void SatellitesDialog::createDialogContent()
 	ui->tabs->removeTab(ui->tabs->indexOf(ui->iridiumTab));
 #endif
 	ui->tabs->setCurrentIndex(0);	
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	Satellites* plugin = GETSTELMODULE(Satellites);
 
@@ -153,15 +149,6 @@ void SatellitesDialog::createDialogContent()
 	ui->satOrbitColorPickerButton->setText("");
 	ui->satInfoColorPickerButton->setText("");
 
-	// Set size of buttons
-	QSize bs = QSize(26, 26);
-	QList<QPushButton*> buttons;
-	buttons << ui->customFilterButton << ui->addSatellitesButton << ui->removeSatellitesButton << ui->selectAllButton
-		<< ui->satMarkerColorPickerButton << ui->satOrbitColorPickerButton << ui->satInfoColorPickerButton
-		<< ui->addSourceButton << ui->deleteSourceButton << ui->editSourceButton << ui->saveSourceButton
-		<< ui->resetSourcesButton << ui->commSatelliteButton;
-	for (auto btn: qAsConst(buttons)) { btn->setFixedSize(bs); }
-
 	// Settings tab / updates group
 	// These controls are refreshed by updateSettingsPage(), which in
 	// turn is triggered by setting any of these values. Because
@@ -191,12 +178,13 @@ void SatellitesDialog::createDialogContent()
 	connectIntProperty(ui->orbitSegmentsSpin,   "Satellites.orbitLineSegments");
 	connectIntProperty(ui->orbitFadeSpin,       "Satellites.orbitLineFadeSegments");
 	connectIntProperty(ui->orbitDurationSpin,   "Satellites.orbitLineSegmentDuration");
+	connectIntProperty(ui->orbitThicknessSpin,  "Satellites.orbitLineThickness");
 	connect(ui->orbitLinesCheckBox, SIGNAL(clicked(bool)), this, SLOT(handleOrbitLinesGroup(bool)));
 	handleOrbitLinesGroup(ui->orbitLinesCheckBox->isChecked());
 	// Logic sub-group: Umbra
 	connectBoolProperty(ui->umbraCheckBox,      "Satellites.flagUmbraVisible");
-	connectBoolProperty(ui->umbraAtDistance,    "Satellites.flagUmbraAtFixedDistance");
-	connectDoubleProperty(ui->umbraDistance,       "Satellites.umbraDistance");
+	connectBoolProperty(ui->umbraAtAltitude,    "Satellites.flagUmbraAtFixedAltitude");
+	connectDoubleProperty(ui->umbraAltitude,    "Satellites.umbraAltitude");
 	connect(ui->umbraCheckBox, SIGNAL(clicked(bool)), this, SLOT(handleUmbraGroup(bool)));
 	handleUmbraGroup(ui->umbraCheckBox->isChecked());
 	// Logic sub-group: Markers
@@ -206,10 +194,10 @@ void SatellitesDialog::createDialogContent()
 	connect(ui->iconicCheckBox, SIGNAL(clicked(bool)), ui->hideInvisibleSatellites, SLOT(setEnabled(bool)));
 	ui->hideInvisibleSatellites->setEnabled(ui->iconicCheckBox->isChecked());
 	// Logic sub-group: Colors
-	connectColorButton(ui->invisibleColorButton, "Satellites.invisibleSatelliteColor", "Satellites/invisible_satellite_color");
-	connectColorButton(ui->transitColorButton,   "Satellites.transitSatelliteColor",   "Satellites/transit_satellite_color");
-	connectColorButton(ui->umbraColor,           "Satellites.umbraColor",              "Satellites/umbra_color");
-	connectColorButton(ui->penumbraColor,        "Satellites.penumbraColor",           "Satellites/penumbra_color");
+	ui->invisibleColorButton->setup("Satellites.invisibleSatelliteColor", "Satellites/invisible_satellite_color");
+	ui->transitColorButton  ->setup("Satellites.transitSatelliteColor",   "Satellites/transit_satellite_color");
+	ui->umbraColor          ->setup("Satellites.umbraColor",              "Satellites/umbra_color");
+	ui->penumbraColor       ->setup("Satellites.penumbraColor",           "Satellites/penumbra_color");
 	// Logic sub-group: Penumbra
 	connectBoolProperty(ui->penumbraCheckBox,    "Satellites.flagPenumbraVisible");
 	// Logic sub-group: Visual filter / Altitude range
@@ -284,6 +272,9 @@ void SatellitesDialog::createDialogContent()
 	commWindow = new SatellitesCommDialog();
 	connect(ui->commSatelliteButton, SIGNAL(clicked()), commWindow, SLOT(setVisible()));
 
+	filterWindow = new SatellitesFilterDialog();
+	connect(ui->customFilterButton, SIGNAL(clicked()), filterWindow, SLOT(setVisible()));
+
 	// Sources tab
 	connect(ui->sourceList, SIGNAL(currentRowChanged(int)),			this, SLOT(updateButtonsProperties()));
 	connect(ui->sourceList, SIGNAL(itemChanged(QListWidgetItem*)),		this,	SLOT(saveSourceList()));
@@ -319,13 +310,6 @@ void SatellitesDialog::createDialogContent()
 	connect(ui->predictedIridiumFlaresSaveButton, SIGNAL(clicked()), this, SLOT(savePredictedIridiumFlares()));
 	connect(ui->iridiumFlaresTreeWidget, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(selectCurrentIridiumFlare(QModelIndex)));
 #endif
-
-	QString style = "QLabel { color: rgb(238, 238, 238); }";
-	ui->labelAutoAdd->setStyleSheet(style);
-	ui->labelTle->setStyleSheet(style);
-	ui->labelTleEpoch->setStyleSheet(style);
-	ui->labelTleEpochData->setStyleSheet(style);
-	ui->validAgeLabel->setStyleSheet(style);
 }
 
 void SatellitesDialog::enableMinMaxAltitude(bool state)
@@ -345,12 +329,13 @@ void SatellitesDialog::handleOrbitLinesGroup(bool state)
 	ui->orbitSegmentsSpin->setEnabled(state);
 	ui->orbitFadeSpin->setEnabled(state);
 	ui->orbitDurationSpin->setEnabled(state);
+	ui->orbitThicknessSpin->setEnabled(state);
 }
 
 void SatellitesDialog::handleUmbraGroup(bool state)
 {
-	ui->umbraAtDistance->setEnabled(state);
-	ui->umbraDistance->setEnabled(state);
+	ui->umbraAtAltitude->setEnabled(state);
+	ui->umbraAltitude->setEnabled(state);
 	ui->penumbraCheckBox->setEnabled(state);
 }
 
@@ -366,7 +351,7 @@ void SatellitesDialog::askSatMarkerColor()
 	QColor c = QColorDialog::getColor(buttonMarkerColor, &StelMainView::getInstance(), "");
 	if (c.isValid())
 	{
-		Vec3f vColor = Vec3d(c.redF(), c.greenF(), c.blueF()).toVec3f();
+		Vec3f vColor(c);
 		SatelliteP sat;
 		// colourize all selected satellites
 		for (int i = 0; i < selection.size(); i++)
@@ -377,7 +362,7 @@ void SatellitesDialog::askSatMarkerColor()
 		}
 		// colourize the button
 		buttonMarkerColor = c;
-		ui->satMarkerColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonMarkerColor.name() + "; }");
+		ui->satMarkerColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonMarkerColor.name() + "; }");
 		saveSatellites();
 	}
 }
@@ -394,7 +379,7 @@ void SatellitesDialog::askSatOrbitColor()
 	QColor c = QColorDialog::getColor(buttonOrbitColor, &StelMainView::getInstance(), "");
 	if (c.isValid())
 	{
-		Vec3f vColor = Vec3d(c.redF(), c.greenF(), c.blueF()).toVec3f();
+		Vec3f vColor(c);
 		SatelliteP sat;
 		// colourize all selected satellites
 		for (int i = 0; i < selection.size(); i++)
@@ -405,7 +390,7 @@ void SatellitesDialog::askSatOrbitColor()
 		}
 		// colourize the button
 		buttonOrbitColor = c;
-		ui->satOrbitColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonOrbitColor.name() + "; }");
+		ui->satOrbitColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonOrbitColor.name() + "; }");
 		saveSatellites();
 	}
 }
@@ -422,7 +407,7 @@ void SatellitesDialog::askSatInfoColor()
 	QColor c = QColorDialog::getColor(buttonInfoColor, &StelMainView::getInstance(), "");
 	if (c.isValid())
 	{
-		Vec3f vColor = Vec3d(c.redF(), c.greenF(), c.blueF()).toVec3f();
+		Vec3f vColor(c);
 		SatelliteP sat;
 		// colourize all selected satellites
 		for (int i = 0; i < selection.size(); i++)
@@ -433,7 +418,7 @@ void SatellitesDialog::askSatInfoColor()
 		}
 		// colourize the button
 		buttonInfoColor = c;
-		ui->satInfoColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonInfoColor.name() + "; }");
+		ui->satInfoColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonInfoColor.name() + "; }");
 		saveSatellites();
 	}
 }
@@ -471,28 +456,36 @@ void SatellitesDialog::filterListByGroup(int index)
 		return;
 
 	const QMap<QString, SatFlag> secondaryFilter = {
-		{ "all",		SatNoFlags },
-		{ "[displayed]",	SatDisplayed },
+		{ "all",			SatNoFlags },
+		{ "[displayed]",		SatDisplayed },
 		{ "[userdefined]",	SatUser },
 		{ "[undisplayed]",	SatNotDisplayed },
 		{ "[newlyadded]",	SatNew },
-		{ "[orbiterror]",	SatError },
+		{ "[orbiterror]",		SatError },
 		{ "[reentry]",		SatReentry },
-		{ "[smallsize]",	SatSmallSize },
+		{ "[smallsize]",		SatSmallSize },
 		{ "[mediumsize]",	SatMediumSize },
-		{ "[largesize]",	SatLargeSize },
-		{ "[LEO]",		SatLEO },
-		{ "[GSO]",		SatGSO },
-		{ "[MEO]",		SatMEO },
-		{ "[HEO]",		SatHEO },
+		{ "[largesize]",		SatLargeSize },
+		{ "[LEO]",			SatLEO },
+		{ "[GSO]",			SatGSO },
+		{ "[MEO]",			SatMEO },
+		{ "[HEO]",			SatHEO },
 		{ "[HGSO]",		SatHGSO },
-		{ "[polarorbit]",	SatPolarOrbit },
+		{ "[polarorbit]",		SatPolarOrbit },
 		{ "[equatorialorbit]",	SatEquatOrbit },
 		{ "[PSSO]",		SatPSSO },
 		{ "[HEarthO]",		SatHEarthO },
 		{ "[outdatedTLE]",	SatOutdatedTLE },
 		{ "[custom]",		SatCustomFilter },
-		{ "[communication]",	SatCommunication }
+		{ "[communication]",	SatCommunication },
+		{ "[activeOS]",		SatActiveOS },
+		{ "[operationalOS]",	SatOperationalOS },
+		{ "[nonopOS]",		SatNonoperationalOS },
+		{ "[partiallyopOS]",	SatPartiallyOperationalOS },
+		{ "[standbyOS]",	SatStandbyOS },
+		{ "[spareOS]",		SatSpareOS },
+		{ "[extmissionOS]",	SatExtendedMissionOS },
+		{ "[decayedOS]",	SatDecayedOS }
 	};
 
 	ui->customFilterButton->setEnabled(false);
@@ -673,11 +666,11 @@ void SatellitesDialog::updateSatelliteData()
 
 	// colourize the colorpicker button
 	buttonMarkerColor=mColor.toQColor(); // .setRgbF(mColor.v[0], mColor.v[1], mColor.v[2]);
-	ui->satMarkerColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonMarkerColor.name() + "; }");
+	ui->satMarkerColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonMarkerColor.name() + "; }");
 	buttonOrbitColor=oColor.toQColor(); // .setRgbF(oColor.v[0], oColor.v[1], oColor.v[2]);
-	ui->satOrbitColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonOrbitColor.name() + "; }");
+	ui->satOrbitColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonOrbitColor.name() + "; }");
 	buttonInfoColor=iColor.toQColor(); // .setRgbF(iColor.v[0], iColor.v[1], iColor.v[2]);
-	ui->satInfoColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonInfoColor.name() + "; }");
+	ui->satInfoColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonInfoColor.name() + "; }");
 
 	// bug #1350669 (https://bugs.launchpad.net/stellarium/+bug/1350669)
 	ui->satellitesList->repaint();
@@ -751,7 +744,7 @@ void SatellitesDialog::updateSatelliteData()
 	// Nice list of checkable, translated groups that allows adding new groups
 	ui->groupsListWidget->blockSignals(true);
 	ui->groupsListWidget->clear();
-	for (const auto& group : qAsConst(globalGroups))
+	for (const auto& group : std::as_const(globalGroups))
 	{
 		QListWidgetItem* item = new QListWidgetItem(q_(group),
 							    ui->groupsListWidget);
@@ -823,10 +816,37 @@ void SatellitesDialog::populateAboutPage()
 	html += "<li>" + q_("Polar sun-synchronous orbit (PSSO): A nearly polar orbit that passes the equator at the same local time on every pass. Useful for image-taking satellites because shadows will be the same on every pass. Typical Sun-synchronous orbits around Earth are about 600–800 km in altitude, with periods in the 96–100-minute range, and inclinations of around 98 degrees.") + "</li>";
 	html += "</ul></p>";
 
+	// TRANSLATORS: Title of a section in the About tab of the Satellites window
+	html += "<h3>" + q_("Communication links") + "</h3>";
+	html += "<p>" + q_("Many satellites having transmitters (transceivers and transponders) with many modes for telemetry and data packets. You should to know which demodulator you need to decode telemetry and packets:");
+	html += "<ul>";
+	html += "<li>APT &mdash; " + q_("Automatic Picture Transmission") + "</li>";
+	html += "<li>LRPT &mdash; " + q_("Low Resolution Picture Transmission") + "</li>";
+	html += "<li>HRPT &mdash; " + q_("High Resolution Picture Transmission") + "</li>";
+	html += "<li>AHRPT &mdash; " + q_("Advanced High Resolution Picture Transmission") + "</li>";
+	html += "<li>AX.25 &mdash; " + q_("Amateur Radio adaptation of X.25 packet protocol") + "</li>";
+	html += "<li>CW &mdash; " + q_("Continuous Wave, Morse Code") + "</li>";
+	html += "<li>AM &mdash; " + q_("Amplitude Modulation") + "</li>";
+	html += "<li>FM &mdash; " + q_("Frequency Modulation") + "</li>";
+	html += "<li>DUV &mdash; " + q_("Data Under Voice") + "</li>";
+	html += "<li>FSK &mdash; " + q_("Frequency Shift Keying") + "</li>";
+	html += "<li>GFSK &mdash; " + q_("Gaussian Frequency Shift Keying") + "</li>";
+	html += "<li>GMSK &mdash; " + q_("Gaussian Minimum Shift Keying") + "</li>";
+	html += "<li>AFSK &mdash; " + q_("Audio Frequency Shift Keying") + "</li>";
+	html += "<li>ASK &mdash; " + q_("Amplitude-shift Keying") + "</li>";
+	html += "<li>PSK &mdash; " + q_("Phase-shift Keying") + "</li>";
+	html += "<li>BPSK &mdash; " + q_("Binary Phase-shift Keying") + "</li>";
+	html += "<li>QPSK &mdash; " + q_("Quadrature Phase-shift Keying") + "</li>";
+	html += "<li>OQPSK &mdash; " + q_("Offset Quadrature Phase-shift Keying") + "</li>";
+	html += "<li>DPSK &mdash; " + q_("Differential Phase-shift Keying") + "</li>";
+	html += "<li>BOC &mdash; " + q_("Binary Offset Carrier") + "</li>";
+	html += "<li>MBOC &mdash; " + q_("Multiplexed Binary Offset Carrier") + "</li>";
+	html += "</ul></p>";
+
 	// TRANSLATORS: Title of a section in the About tab of the Satellites window
 	html += "<h3>" + q_("TLE data updates") + "</h3>";
 	html += "<p>" + q_("The Satellites plugin can automatically download TLE data from Internet sources, and by default the plugin will do this if the existing data is more than 72 hours old. ");
-	html += "</p><p>" + QString(q_("If you disable Internet updates, you may update from a file on your computer.  This file must be in the same format as the Celestrak updates (see %1 for an example).").arg("<a href=\"http://celestrak.com/NORAD/elements/visual.txt\">visual.txt</a>"));
+	html += "</p><p>" + QString(q_("If you disable Internet updates, you may update from a file on your computer.  This file must be in the same format as the Celestrak updates (see %1 for an example).").arg("<a href=\"https://celestrak.org/NORAD/elements/visual.txt\">visual.txt</a>"));
 	html += "</p><p>" + q_("<b>Note:</b> if the name of a satellite in update data has anything in square brackets at the end, it will be removed before the data is used.");
 	html += "</p>";
 
@@ -836,11 +856,11 @@ void SatellitesDialog::populateAboutPage()
 
 	html += "<h3>" + q_("Technical notes") + "</h3>";
 	html += "<p>" + q_("Positions are calculated using the SGP4 & SDP4 methods, using NORAD TLE data as the input.") + " ";
-	html +=               q_("The orbital calculation code is written by Jose Luis Canales according to the revised Spacetrack Report #3 (including Spacetrack Report #6)") + " <a href=\"http://www.celestrak.com/publications/AIAA/2006-6753\">[*]</a>. ";
-	html +=               q_("To calculate an approximate visual magnitude of satellites we use data from Mike McCants' database (with permissions) of the radar cross-section (RCS) and standard magnitudes.") + " ";
-	html +=               q_("Formula to calculate an approximate visual magnitude of satellites from the standard magnitude may be found at Mike McCants website") + " <a href=\"https://www.prismnet.com/~mmccants/tles/mccdesc.html\">[**]</a>. ";
-	html +=               q_("We use a spherical shape of satellite to calculate an approximate visual magnitude from RCS values.") + " ";
-	html +=               q_("For modelling Starlink magnitudes we use Anthony Mallama's formula") + " <a href=\"http://www.satobs.org/seesat/Aug-2020/0079.html\">[***]</a>.</p>";
+	html +=         q_("The orbital calculation code is written by Jose Luis Canales according to the revised Spacetrack Report #3 (including Spacetrack Report #6)") + " <a href=\"https://celestrak.org/publications/AIAA/2006-6753\">[*]</a>. ";
+	html +=         q_("To calculate an approximate visual magnitude of satellites we use data from Mike McCants' database (with permissions) of the radar cross-section (RCS) and standard magnitudes.") + " ";
+	html +=         q_("Formula to calculate an approximate visual magnitude of satellites from the standard magnitude may be found at Mike McCants website") + " <a href=\"https://mmccants.org/tles/mccdesc.html\">[**]</a>. ";
+	html +=         q_("We use a spherical shape of satellite to calculate an approximate visual magnitude from RCS values.") + " ";
+	html +=         q_("For modelling Starlink magnitudes we use Anthony Mallama's formula") + " <a href=\"http://www.satobs.org/seesat/Aug-2020/0079.html\">[***]</a>.</p>";
 
 	html += StelApp::getInstance().getModuleMgr().getStandardSupportLinksInfo("Satellites plugin");
 	html += "</body></html>";
@@ -933,7 +953,7 @@ void SatellitesDialog::saveEditedSource()
 
 	// Changes to item data (text or check state) are connected to
 	// saveSourceList(), so there's no need to call it explicitly.
-	if (ui->sourceList->currentItem()!=Q_NULLPTR)
+	if (ui->sourceList->currentItem()!=nullptr)
 		ui->sourceList->currentItem()->setText(u);
 	else if (ui->sourceList->findItems(u, Qt::MatchExactly).count() <= 0)
 	{
@@ -998,7 +1018,7 @@ void SatellitesDialog::addSourceRow(void)
 	ui->sourceEdit->selectAll();
 	ui->sourceEdit->setFocus();
 	ui->sourceList->blockSignals(true);
-	ui->sourceList->setCurrentItem(Q_NULLPTR);
+	ui->sourceList->setCurrentItem(nullptr);
 	ui->sourceList->blockSignals(false);
 }
 
@@ -1137,8 +1157,26 @@ void SatellitesDialog::populateFilterMenu()
 	ui->groupFilterCombo->insertItem(0, q_("[HEO/E satellites]"), QVariant("[HEarthO]"));
 	ui->groupFilterCombo->insertItem(0, q_("[outdated TLE]"), QVariant("[outdatedTLE]"));
 	ui->groupFilterCombo->insertItem(0, q_("[custom filter]"), QVariant("[custom]"));
-	ui->groupFilterCombo->insertItem(0, q_("[all user defined]"), QVariant("[userdefined]"));
-	ui->groupFilterCombo->insertItem(0, q_("[all]"), QVariant("all"));	
+	ui->groupFilterCombo->insertItem(0, q_("[all user defined]"), QVariant("[userdefined]"));	
+	// Add special groups - based on SATCAT Operational Status
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Active status does not require power or communications (e.g., geodetic satellites); Active is any satellite with an operational status of +, P, B, S, or X.
+	ui->groupFilterCombo->insertItem(0, q_("[active satellites]"), QVariant("[activeOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Satellites that are fully functioning
+	ui->groupFilterCombo->insertItem(0, q_("[operational satellites]"), QVariant("[operationalOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Satellites that are no longer functioning
+	ui->groupFilterCombo->insertItem(0, q_("[non-operational satellites]"), QVariant("[nonopOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Satellites that are partially fulfilling primary mission or secondary mission(s)
+	ui->groupFilterCombo->insertItem(0, q_("[partially operational satellites]"), QVariant("[partiallyopOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Previously operational satellite put into reserve status
+	ui->groupFilterCombo->insertItem(0, q_("[backup / standby satellites]"), QVariant("[standbyOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: New satellite awaiting full activation
+	ui->groupFilterCombo->insertItem(0, q_("[spare satellites]"), QVariant("[spareOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Satellites with extended mission(s)
+	ui->groupFilterCombo->insertItem(0, q_("[extended mission]"), QVariant("[extmissionOS]"));
+	// TRANSLATORS: Satellite group [SATCAT Operational Status]: Satellites that are decayed
+	ui->groupFilterCombo->insertItem(0, q_("[decayed satellites]"), QVariant("[decayedOS]"));
+	// Special group - All satellites (this item should be latest in the list)
+	ui->groupFilterCombo->insertItem(0, q_("[all]"), QVariant("all"));
 
 	// Restore current selection
 	index = (!selectedId.isEmpty()) ? qMax(0, ui->groupFilterCombo->findData(selectedId)) : 0;
@@ -1160,16 +1198,19 @@ void SatellitesDialog::populateInfo()
 	ui->updateFrequencySpinBox->setSuffix(QString(" %1").arg(qc_("h","time")));
 	// TRANSLATORS: Unit of measure for distance - kilometers
 	QString km = qc_("km", "distance");
+	QString px = qc_("px", "pixels");
 	ui->minAltitude->setSuffix(QString(" %1").arg(km));
 	ui->minAltitude->setToolTip(QString("%1: %2..%3 %4").arg(vr, QString::number(ui->minAltitude->minimum(), 'f', 0), QString::number(ui->minAltitude->maximum(), 'f', 0), km));
 	ui->maxAltitude->setSuffix(QString(" %1").arg(km));
 	ui->maxAltitude->setToolTip(QString("%1: %2..%3 %4").arg(vr, QString::number(ui->maxAltitude->minimum(), 'f', 0), QString::number(ui->maxAltitude->maximum(), 'f', 0), km));
 	ui->altitudeCheckBox->setToolTip(QString("<p>%1</p>").arg(q_("Display satellites and their orbits within selected range of altitudes only.")));
-	ui->umbraDistance->setSuffix(QString(" %1").arg(km));
-	ui->umbraDistance->setToolTip(QString("<p>%1. %2: %3..%4 %5</p>").arg(q_("Distance to the center of umbra from Earth's surface (height of imagined satellite)"), vr, QString::number(ui->umbraDistance->minimum(), 'f', 1), QString::number(ui->umbraDistance->maximum(), 'f', 1), km));
+	ui->umbraAltitude->setSuffix(QString(" %1").arg(km));
+	ui->umbraAltitude->setToolTip(QString("<p>%1. %2: %3..%4 %5</p>").arg(q_("Altitude of imagined satellite"), vr, QString::number(ui->umbraAltitude->minimum(), 'f', 1), QString::number(ui->umbraAltitude->maximum(), 'f', 1), km));
 	ui->orbitSegmentsSpin->setToolTip(QString("<p>%1. %2: %3..%4</p>").arg(q_("Number of segments: number of segments used to draw the line"), vr, QString::number(ui->orbitSegmentsSpin->minimum()), QString::number(ui->orbitSegmentsSpin->maximum())));
 	ui->orbitDurationSpin->setToolTip(QString("<p>%1. %2: %3..%4 %5</p>").arg(q_("Segment length: duration of a single segment in seconds"), vr, QString::number(ui->orbitDurationSpin->minimum()), QString::number(ui->orbitDurationSpin->maximum()), s));
 	ui->orbitFadeSpin->setToolTip(QString("<p>%1. %2: %3..%4</p>").arg(q_("Fade length: number of segments used to draw each end of the line"), vr, QString::number(ui->orbitFadeSpin->minimum()), QString::number(ui->orbitFadeSpin->maximum())));
+	ui->orbitThicknessSpin->setToolTip(QString("%1: %2..%3 %4").arg(q_("Orbit line thickness"), QString::number(ui->orbitThicknessSpin->minimum()), QString::number(ui->orbitThicknessSpin->maximum()), px));
+	ui->orbitThicknessSpin->setSuffix(QString(" %1").arg(px));
 	ui->minMagnitude->setToolTip(QString("%1: %2..%3").arg(vr, QString::number(ui->minMagnitude->minimum(), 'f', 2), QString::number(ui->minMagnitude->maximum(), 'f', 2)));
 	ui->maxMagnitude->setToolTip(QString("%1: %2..%3").arg(vr, QString::number(ui->maxMagnitude->minimum(), 'f', 2), QString::number(ui->maxMagnitude->maximum(), 'f', 2)));
 }
@@ -1379,9 +1420,9 @@ void SatellitesDialog::setRightSideToROMode()
 	buttonMarkerColor = QColor(QColor::fromRgbF(0.7f, 0.7f, 0.7f));
 	buttonOrbitColor = QColor(QColor::fromRgbF(0.7f, 0.7f, 0.7f));
 	buttonInfoColor = QColor(QColor::fromRgbF(0.7f, 0.7f, 0.7f));
-	ui->satMarkerColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonMarkerColor.name() + "; }");
-	ui->satOrbitColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonOrbitColor.name() + "; }");
-	ui->satInfoColorPickerButton->setStyleSheet("QPushButton { background-color:" + buttonInfoColor.name() + "; }");
+	ui->satMarkerColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonMarkerColor.name() + "; }");
+	ui->satOrbitColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonOrbitColor.name() + "; }");
+	ui->satInfoColorPickerButton->setStyleSheet("QToolButton { background-color:" + buttonInfoColor.name() + "; }");
 }
 
 // The status of elements on right side of GUI may be changed when satellite is selected
@@ -1414,7 +1455,7 @@ void SatellitesDialog::handleGroupChanges(QListWidgetItem* item)
 	{
 		// Harmonize the item with the rest...
 		flags ^= Qt::ItemIsEditable;
-		item->setFlags(flags | Qt::ItemIsUserCheckable | Qt::ItemIsTristate);
+		item->setFlags(flags | Qt::ItemIsUserCheckable | Qt::ItemIsAutoTristate);
 		item->setCheckState(Qt::Checked);
 		QString groupId = item->text().trimmed();
 		item->setData(Qt::UserRole, groupId);
@@ -1477,7 +1518,7 @@ void SatellitesDialog::updateTLEs(void)
 	}
 	else
 	{
-		QStringList updateFiles = QFileDialog::getOpenFileNames(Q_NULLPTR,
+		QStringList updateFiles = QFileDialog::getOpenFileNames(&StelMainView::getInstance(),
 									q_("Select TLE Update File"),
 									StelFileMgr::getDesktopDir(),
 									"*.*");
@@ -1577,16 +1618,21 @@ void SatellitesDialog::selectCurrentIridiumFlare(const QModelIndex &modelIndex)
 
 void SatellitesDialog::savePredictedIridiumFlares()
 {
-	QString filter = q_("Microsoft Excel Open XML Spreadsheet");
-	filter.append(" (*.xlsx);;");
-	filter.append(q_("CSV (Comma delimited)"));
-	filter.append(" (*.csv)");
-	QString defaultFilter("(*.xlsx)");
-	QString filePath = QFileDialog::getSaveFileName(Q_NULLPTR,
-							q_("Save predicted Iridium flares as..."),
-							QDir::homePath() + "/iridium_flares.xlsx",
-							filter,
-							&defaultFilter);
+	QString csv  = QString("%1 (*.csv)").arg(q_("CSV (Comma delimited)"));
+	QString xlsx = QString("%1 (*.xlsx)").arg(q_("Microsoft Excel Open XML Spreadsheet"));
+	QString filter, defaultExtension;
+
+	#ifdef ENABLE_XLSX
+	filter = QString("%1;;%2") .arg(xlsx, csv);
+	defaultExtension = "xlsx";
+	#else
+	filter = csv;
+	defaultExtension = "csv";
+	#endif
+
+	QString defaultFilter = QString("(*.%1)").arg(defaultExtension);
+	QString dir = QString("%1/iridium_flares.%2").arg(QDir::homePath(), defaultExtension);
+	QString filePath = QFileDialog::getSaveFileName(&StelMainView::getInstance(), q_("Save predicted Iridium flares as..."), dir, filter, &defaultFilter);
 
 	int count = ui->iridiumFlaresTreeWidget->topLevelItemCount();
 	int columns = iridiumFlaresHeader.size();
@@ -1602,8 +1648,11 @@ void SatellitesDialog::savePredictedIridiumFlares()
 		}
 
 		QTextStream predictedIridiumFlaresList(&predictedIridiumFlares);
+		#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		predictedIridiumFlaresList.setEncoding(QStringConverter::Utf8);
+		#else
 		predictedIridiumFlaresList.setCodec("UTF-8");
-
+		#endif
 		predictedIridiumFlaresList << iridiumFlaresHeader.join(delimiter) << StelUtils::getEndLineChar();
 
 		for (int i = 0; i < count; i++)
@@ -1622,6 +1671,7 @@ void SatellitesDialog::savePredictedIridiumFlares()
 	}
 	else
 	{
+		#ifdef ENABLE_XLSX
 		int *width;
 		width = new int[columns];
 		QString sData;
@@ -1670,6 +1720,7 @@ void SatellitesDialog::savePredictedIridiumFlares()
 
 		delete[] width;
 		xlsx.saveAs(filePath);
+		#endif
 	}
 }
 #endif
