@@ -24,7 +24,7 @@
 #include <QOpenGLContext>
 #include <QOpenGLFunctions_1_0>
 
-#ifndef QT_OPENGL_ES_2
+#if !QT_CONFIG(opengles2)
 //! Defines some OpenGL functions not resolved through StelOpenGL (which only contains base OpenGL ES2 functions)
 //! Using the QOpenGLFunctions_*_* directly would solve this better, but it conflicts with the
 //! current StelOpenGL header dramatically.
@@ -33,10 +33,15 @@ class GLExtFuncs : public QOpenGLFunctions_1_0
 public:
 	//! Since 3.2
 	PFNGLFRAMEBUFFERTEXTUREPROC glFramebufferTexture;
+	//! Since 1.0 but not found by QOpenGLFunctions_1_0 when in Core profile
+	void (APIENTRYP glDrawBuffer)(GLenum);
+	void (APIENTRYP glReadBuffer)(GLenum);
 
 	void init(QOpenGLContext* ctx)
 	{
 		glFramebufferTexture = reinterpret_cast<PFNGLFRAMEBUFFERTEXTUREPROC>(ctx->getProcAddress("glFramebufferTexture"));
+		glDrawBuffer = reinterpret_cast<decltype(glDrawBuffer)>(ctx->getProcAddress("glDrawBuffer"));
+		glReadBuffer = reinterpret_cast<decltype(glReadBuffer)>(ctx->getProcAddress("glReadBuffer"));
 
 		if(!ctx->isOpenGLES())
 			initializeOpenGLFunctions();
