@@ -21,22 +21,19 @@
 #ifndef S3DRENDERER_HPP
 #define S3DRENDERER_HPP
 
-#include "StelGui.hpp"
 #include "StelModule.hpp"
 #include "StelPainter.hpp"
 #include "Landscape.hpp"
 #include "SolarSystem.hpp"
 
 #include "StelOBJ.hpp"
-#include "StelOpenGLArray.hpp"
-#include "Heightmap.hpp"
 #include "Frustum.hpp"
 #include "Polyhedron.hpp"
 #include "S3DEnum.hpp"
-#include "SceneInfo.hpp"
 #include "ShaderManager.hpp"
 
 #include <QMatrix4x4>
+#include <QOpenGLVertexArrayObject>
 
 //predeclarations
 class LandscapeMgr;
@@ -49,9 +46,15 @@ class S3DRenderer : public QObject, protected QOpenGLFunctions
 {
 	Q_OBJECT
 public:
+	enum LocationInfoStyle {
+		LocationInfoTopRight,      // default for rectangular views
+		LocationInfoBottomCenter   // centered in the bottom. This will also obey gravity labels for a planetarium.
+	};
+	Q_ENUM(LocationInfoStyle)
+
 	//! Initializes an empty Scenery3d object.
-	S3DRenderer(QObject* parent = Q_NULLPTR);
-	virtual ~S3DRenderer() Q_DECL_OVERRIDE;
+	S3DRenderer(QObject* parent = nullptr);
+	~S3DRenderer() override;
 
 	//! Draw scenery, called by Scenery3dMgr.
 	void draw(StelCore* core, S3DScene &scene);
@@ -76,6 +79,8 @@ public:
 	void setPCSS(bool val) { shaderParameters.pcss = val; reinitShadowmapping = true; invalidateCubemap(); }
 	bool getLocationInfoEnabled(void) const { return textEnabled; }
 	void setLocationInfoEnabled(bool locationinfoenabled) { this->textEnabled = locationinfoenabled; }
+	S3DRenderer::LocationInfoStyle getLocationInfoStyle() const {return locationInfoStyle;}
+	void setLocationInfoStyle(S3DRenderer::LocationInfoStyle style) {locationInfoStyle=style;}
 
 	bool getLazyCubemapEnabled() const { return lazyDrawing; }
 	void setLazyCubemapEnabled(bool val) { lazyDrawing = val; }
@@ -120,6 +125,11 @@ public:
 	void setTorchBrightness(float brightness) { torchBrightness = brightness; invalidateCubemap(); }
 	float getTorchRange() const { return torchRange; }
 	void setTorchRange(float range) { torchRange = range; invalidateCubemap(); }
+	//! Sets the exaggeration strength for directional light (default: 1).
+	//! Going over 1 can be useful for very tiny holes casting important specks of light into dark interiors.
+	//! Example: meridiana "sundials" in Italian churches.
+	void setDirectionalLightPush(const float push) {directionalLightPush = push;}
+	float getDirectionalLightPush() const { return directionalLightPush;}
 
 	//Debugging method, save the Frustum to be able to move away from it and analyze it
 	void saveFrusts();
@@ -138,6 +148,7 @@ signals:
 	void message(const QString& msg) const; // ignore clazy warning here
 
 private:
+	QOpenGLVertexArrayObject vao;
 	ShaderMgr shaderManager;
 	PlanetP sun,moon,venus;
 	// a pointer to the scene currently being drawn. only valid during draw() calls
@@ -152,8 +163,11 @@ private:
 
 	float torchBrightness; // toggle light brightness
 	float torchRange; // used to calculate attenuation like in the second form at http://framebunker.com/blog/lighting-2-attenuation/
+	float directionalLightPush; // used to give extra power to the directional light, e.g. to enhance dim light patches shining through small holes. Default: 1.
 
 	bool textEnabled;           // switchable value: display coordinates on screen. THIS IS NOT FOR DEBUGGING, BUT A PROGRAM FEATURE!
+	LocationInfoStyle locationInfoStyle; // Finetuning.
+
 	bool debugEnabled;          // switchable value: display debug graphics and debug texts on screen
 	bool fixShadowData; //for debugging, fixes all shadow mapping related data (shadowmap contents, matrices, frustums, focus bodies...) at their current values
 	bool simpleShadows;
@@ -186,7 +200,7 @@ private:
 
 	/// ---- Cubemapping variables ----
 	bool requiresCubemap; //true if cubemapping is required (if projection is anything else than Perspective)
-	bool cubemappingUsedLastFrame; //true if cubemapping was used for the last frame. Used to determine if a projection switch occured.
+	bool cubemappingUsedLastFrame; //true if cubemapping was used for the last frame. Used to determine if a projection switch occurred.
 	bool lazyDrawing; //if lazy-drawing mode is enabled
 	bool updateOnlyDominantOnMoving; //if movement updates only dominant face directly
 	bool updateSecondDominantOnMoving; //if movement also updates the second-most dominant face
@@ -264,7 +278,7 @@ private:
 	//Holds the xy-scaling of the orthographic light cam + pos of near/far planes in view coords
 	//Needed for consistent shadow filter sizes and PCSS effect
 	QVector<QVector4D> shadowFrustumSize;
-	// Frustum of the view camera, constrainted to the shadowFarZ instead of the camFarZ
+	// Frustum of the view camera, constrained to the shadowFarZ instead of the camFarZ
 	Frustum camFrustShadow;
 	//near/far planes for the orthographic light that fits the whole scene
 	float lightOrthoNear;
@@ -343,7 +357,7 @@ private:
 	//Computes the crop matrix to focus the light
 	void computeCropMatrix(QMatrix4x4& cropMatrix, QVector4D &orthoScale, Polyhedron &focusBody, const QMatrix4x4 &lightProj, const QMatrix4x4 &lightMVP);
 	//Computes the light projection values
-	void computeOrthoProjVals(const Vec3f shadowDir, float &orthoExtent, float &orthoNear, float &orthoFar);
+	void computeOrthoProjVals(const Vec3f &shadowDir, float &orthoExtent, float &orthoNear, float &orthoFar);
 
 	void rendererMessage(const QString& msg) const;
 };
