@@ -119,10 +119,12 @@ void ShaderMgr::clearCache()
 
 	//iterate over the shaderContentCache - this contains the same amount of shaders as actually exist!
 	//the shaderCache could contain duplicate entries
-	for (auto* shader : m_shaderContentCache)
+	QHashIterator<QByteArray, QOpenGLShaderProgram*>it(m_shaderContentCache);
+	while (it.hasNext())
 	{
-		if (shader)
-			delete shader;
+		it.next();
+		if (it.value())
+			delete it.value();
 	}
 
 	m_shaderCache.clear();
@@ -134,8 +136,8 @@ QOpenGLShaderProgram* ShaderMgr::findOrLoadShader(uint flags)
 {
 	auto it = m_shaderCache.find(flags);
 
-	// This may also return Q_NULLPTR if the load failed.
-	//We wait until user explictly forces shader reload until we try again to avoid spamming errors.
+	// This may also return nullptr if the load failed.
+	//We wait until user explicitly forces shader reload until we try again to avoid spamming errors.
 	if(it!=m_shaderCache.end())
 		return *it;
 
@@ -148,7 +150,7 @@ QOpenGLShaderProgram* ShaderMgr::findOrLoadShader(uint flags)
 	//load shader files & preprocess
 	QByteArray vShader,gShader,fShader;
 
-	QOpenGLShaderProgram *prog = Q_NULLPTR;
+	QOpenGLShaderProgram *prog = nullptr;
 
 	if(preprocessShader(vShaderFile,flags,vShader) &&
 			preprocessShader(gShaderFile,flags,gShader) &&
@@ -178,7 +180,7 @@ QOpenGLShaderProgram* ShaderMgr::findOrLoadShader(uint flags)
 			if(!loadShader(*prog,vShader,gShader,fShader))
 			{
 				delete prog;
-				prog = Q_NULLPTR;
+				prog = nullptr;
 				qCCritical(shaderMgr)<<"ERROR: Shader '"<<flags<<"' could not be compiled. Fix errors and reload shaders or restart program.";
 			}
 #ifndef NDEBUG
@@ -353,7 +355,8 @@ bool ShaderMgr::loadShader(QOpenGLShaderProgram& program, const QByteArray& vSha
 
 	if(!vShader.isEmpty())
 	{
-		if(!program.addShaderFromSourceCode(QOpenGLShader::Vertex,vShader))
+		const auto prefix = StelOpenGL::globalShaderPrefix(StelOpenGL::VERTEX_SHADER);
+		if(!program.addShaderFromSourceCode(QOpenGLShader::Vertex, prefix + vShader))
 		{
 			qCCritical(shaderMgr) << "Unable to compile vertex shader";
 			qCCritical(shaderMgr) << program.log();
@@ -395,7 +398,57 @@ bool ShaderMgr::loadShader(QOpenGLShaderProgram& program, const QByteArray& vSha
 
 	if(!fShader.isEmpty())
 	{
-		if(!program.addShaderFromSourceCode(QOpenGLShader::Fragment,fShader))
+		const auto globalPrefix = StelOpenGL::globalShaderPrefix(StelOpenGL::FRAGMENT_SHADER);
+		const bool prefixHasVersion = globalPrefix.contains("#version");
+		const bool shaderHasVersion = fShader.contains("#version");
+		QByteArray prefix;
+		QByteArray finalShader = fShader;
+		if(shaderHasVersion)
+		{
+			static const QRegularExpression versionRE("^#version ([0-9]+)\\b.*");
+			static const QRegularExpression versionRE2("(^|\n)(#version[ \t]+)([0-9]+)\\b");
+			const QString shaderVersionString = QString(fShader.simplified()).replace(versionRE, "\\1");
+			bool svOK = false;
+			const int shaderVersion = shaderVersionString.toInt(&svOK);
+
+			const QString prefixVersionString = QString(globalPrefix.simplified()).replace(versionRE, "\\1");
+			bool pvOK = false;
+			const int prefixVersion = prefixVersionString.toInt(&pvOK);
+
+			bool failed = false;
+			if(!svOK)
+			{
+				qCCritical(shaderMgr) << "Failed to get shader version, string:" << shaderVersionString;
+				failed = true;
+			}
+
+			if(prefixHasVersion && !pvOK)
+			{
+				qCCritical(shaderMgr) << "Failed to get prefix version, string:" << prefixVersionString;
+				failed = true;
+			}
+
+			if(failed) return false;
+
+			if(!prefixHasVersion)
+			{
+				prefix = QString("#version %1\n").arg(shaderVersion).toUtf8() + globalPrefix;
+			}
+			else if(shaderVersion > prefixVersion)
+			{
+				prefix = QString(globalPrefix).replace(versionRE2, QString("\\1\\2%1").arg(shaderVersion)).toUtf8();
+			}
+			else
+			{
+				prefix = globalPrefix;
+			}
+			finalShader = QString(fShader).replace(versionRE2, "//\\1\\2\\3").toUtf8();
+		}
+		else
+		{
+			prefix = globalPrefix;
+		}
+		if(!program.addShaderFromSourceCode(QOpenGLShader::Fragment, prefix + finalShader))
 		{
 			qCCritical(shaderMgr) << "Unable to compile fragment shader";
 			qCCritical(shaderMgr) << program.log();
@@ -457,14 +510,14 @@ void ShaderMgr::buildUniformCache(QOpenGLShaderProgram &program)
 	{
 		GL(gl->glGetActiveUniform(prog,i,bufSize,&length,&size,&type,buf.data()));
 		QString str(buf);
-		str = str.trimmed(); // no idea if this is required
+		str = str.left(str.indexOf(QChar(0x00)));
 
 		GLint loc = program.uniformLocation(str);
 
 		auto it = uniformStrings.find(str);
 
-		// This may also return Q_NULLPTR if the load failed.
-		//We wait until user explictly forces shader reload until we try again to avoid spamming errors.
+		// This may also return nullptr if the load failed.
+		//We wait until user explicitly forces shader reload until we try again to avoid spamming errors.
 		if(it!=uniformStrings.end())
 		{
 			//this is uniform we recognize
