@@ -53,8 +53,8 @@ void ManualImportWindow::createDialogContent()
 	//Signals
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()),
 	        this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->LocationBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	connect(ui->lineEditColor, SIGNAL(textChanged(QString)), this, SLOT(parseColorString(QString)));
 	connect(ui->pushButtonSelectColor, SIGNAL(clicked()), this, SLOT(selectColor()));
@@ -80,7 +80,7 @@ void ManualImportWindow::retranslate()
 
 void ManualImportWindow::selectColor()
 {
-    QColor color = QColorDialog::getColor(objectColor,&StelMainView::getInstance());
+	QColor color = QColorDialog::getColor(objectColor,&StelMainView::getInstance());
 	objectColor =  color;
 	ui->lineEditColor->setText(QString("%1, %2, %3").arg(color.redF()).arg(color.greenF()).arg(color.blueF()));
 	setColorButtonColor(color);
@@ -90,18 +90,18 @@ void ManualImportWindow::parseColorString(QString colorCode)
 {
 	QStringList colorComponents = colorCode.split(QChar(','));
 	int count = colorComponents.count();
-	if (count < 3 || count > 4)
+	if ((count < 3) || (count > 4))
 		return;
 
 	bool ok;
 	double red = colorComponents.at(0).toDouble(&ok);
-	if (!ok || red < 0.0 || red > 1.0)
+	if (!ok || (red < 0.0) || (red > 1.0))
 		return;
 	double green = colorComponents.at(1).toDouble(&ok);
-	if (!ok || green < 0.0 || green > 1.0)
+	if (!ok || (green < 0.0) || (green > 1.0))
 		return;
 	double blue = colorComponents.at(2).toDouble(&ok);
-	if (!ok || blue < 0.0 || blue > 1.0)
+	if (!ok || (blue < 0.0) || (blue > 1.0))
 		return;
 
 	QColor color;
@@ -112,7 +112,7 @@ void ManualImportWindow::parseColorString(QString colorCode)
 	if (count == 4)
 	{
 		double alpha = colorComponents.at(3).toDouble(&ok);
-		if (!ok || alpha < 0.0 || alpha > 1.0)
+		if (!ok || (alpha < 0.0) || (alpha > 1.0))
 			return;
 		color.setAlphaF(alpha);
 	}
@@ -185,12 +185,12 @@ void ManualImportWindow::selectTextureFile(QLineEdit * filePathLineEdit)
 
 	//Select an existing file
 	QStringList supportedFormats;
-	for (auto format : QImageReader::supportedImageFormats())
+	for (const auto &format : QImageReader::supportedImageFormats())
 	{
 		supportedFormats.append(QString("*.%1").arg(QString(format)));//It's a wee bit long...
 	}
 	QString fileFilter = QString("Texture files (%1)").arg(supportedFormats.join(" "));
-	QString newFilePath = QFileDialog::getOpenFileName(Q_NULLPTR, QString(), texturesDirectoryPath, fileFilter);
+	QString newFilePath = QFileDialog::getOpenFileName(&StelMainView::getInstance(), QString(), texturesDirectoryPath, fileFilter);
 
 	//Is the file in one of the two "textures" directories?
 	if (newFilePath.isEmpty())
@@ -216,14 +216,14 @@ bool ManualImportWindow::verifyTextureFile(QString filePath)
 
 	if (texture.isNull())
 	{
-		qDebug() << "File doesn't exist or is not an accepted texure format:"
+		qDebug() << "File doesn't exist or is not an accepted texture format:"
 				<< filePath;
 		return false;
 	}
 
 	if (!verifyPowerOfTwo(texture.height()))
 	{
-		qDebug() << "Invalid texure height:" << texture.height()
+		qDebug() << "Invalid texture height:" << texture.height()
 				<< "for file" << filePath;
 		return false;
 	}
