@@ -27,7 +27,9 @@
 #include "ManualImportWindow.hpp"
 
 #include "StelApp.hpp"
+#include "StelGui.hpp"
 #include "StelFileMgr.hpp"
+#include "StelMainView.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelTranslator.hpp"
 #include "Planet.hpp"
@@ -37,7 +39,7 @@
 
 SolarSystemManagerWindow::SolarSystemManagerWindow()
 	: StelDialog("SolarSystemEditor")
-	, manualImportWindow(Q_NULLPTR)
+	, manualImportWindow(nullptr)
 {
 	ui = new Ui_solarSystemManagerWindow();
 	mpcImportWindow = new MpcImportWindow();
@@ -71,8 +73,8 @@ void SolarSystemManagerWindow::createDialogContent()
 	//Signals
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()),
 	        this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 	connect(ui->pushButtonCopyFile, SIGNAL(clicked()), this, SLOT(copyConfiguration()));
 	connect(ui->pushButtonReplaceFile, SIGNAL(clicked()), this, SLOT(replaceConfiguration()));
 	connect(ui->pushButtonAddFile, SIGNAL(clicked()), this, SLOT(addConfiguration()));
@@ -129,7 +131,7 @@ void SolarSystemManagerWindow::newImportMPC()
 
 void SolarSystemManagerWindow::newImportManual()
 {
-	if (manualImportWindow == Q_NULLPTR)
+	if (manualImportWindow == nullptr)
 	{
 		manualImportWindow = new ManualImportWindow();
 		connect(manualImportWindow, SIGNAL(visibleChanged(bool)), this, SLOT(resetImportManual(bool)));
@@ -151,7 +153,7 @@ void SolarSystemManagerWindow::resetImportManual(bool show)
 		populateSolarSystemList();
 
 		delete manualImportWindow;
-		manualImportWindow = Q_NULLPTR;
+		manualImportWindow = nullptr;
 
 		//This window is in the background, bring it to the foreground
 		dialog->setVisible(true);
@@ -185,7 +187,7 @@ void SolarSystemManagerWindow::populateSolarSystemList()
 
 void SolarSystemManagerWindow::removeObjects()
 {
-	if (ui->listWidgetObjects->selectedItems().length()>0)
+	if (!ui->listWidgetObjects->selectedItems().isEmpty())
 	{
 		// we must disconnect the signal or else the list will be rebuilt after the first deletion.
 		disconnect(ssEditor, SIGNAL(solarSystemChanged()), this, SLOT(populateSolarSystemList()));
@@ -206,7 +208,7 @@ void SolarSystemManagerWindow::removeObjects()
 
 void SolarSystemManagerWindow::copyConfiguration()
 {
-	QString filePath = QFileDialog::getSaveFileName(Q_NULLPTR,
+	QString filePath = QFileDialog::getSaveFileName(&StelMainView::getInstance(),
 							q_("Save the minor Solar System bodies as..."),
 							QDir::homePath() + "/ssystem_minor.ini");
 	ssEditor->copySolarSystemConfigurationFileTo(filePath);
@@ -216,7 +218,7 @@ void SolarSystemManagerWindow::replaceConfiguration()
 {
 	QString filter = q_("Configuration files");
 	filter.append(" (*.ini)");
-	QString filePath = QFileDialog::getOpenFileName(Q_NULLPTR, q_("Select a file to replace the Solar System minor bodies"), QDir::homePath(), filter);
+	QString filePath = QFileDialog::getOpenFileName(&StelMainView::getInstance(), q_("Select a file to replace the Solar System minor bodies"), QDir::homePath(), filter);
 	ssEditor->replaceSolarSystemConfigurationFileWith(filePath);
 }
 
@@ -224,7 +226,7 @@ void SolarSystemManagerWindow::addConfiguration()
 {
 	QString filter = q_("Configuration files");
 	filter.append(" (*.ini)");
-	QString filePath = QFileDialog::getOpenFileName(Q_NULLPTR, q_("Select a file to add the Solar System minor bodies"), QDir::toNativeSeparators(StelFileMgr::getInstallationDir()+"/data/ssystem_1000comets.ini"), filter);
+	QString filePath = QFileDialog::getOpenFileName(&StelMainView::getInstance(), q_("Select a file to add the Solar System minor bodies"), QDir::toNativeSeparators(StelFileMgr::getInstallationDir()+"/data/ssystem_1000comets.ini"), filter);
 	ssEditor->addFromSolarSystemConfigurationFile(filePath);
 }
 
@@ -245,7 +247,7 @@ void SolarSystemManagerWindow::setAboutHtml(void)
 	html += "</body></html>";
 
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
-	if(gui!=Q_NULLPTR)
+	if(gui!=nullptr)
 	{
 		QString htmlStyleSheet(gui->getStelStyle().htmlStyleSheet);
 		ui->aboutTextBrowser->document()->setDefaultStyleSheet(htmlStyleSheet);
