@@ -2,7 +2,7 @@
 The stellarium telescope library helps building
 telescope server programs, that can communicate with stellarium
 by means of the stellarium TCP telescope protocol.
-It also contains smaple server classes (dummy, Meade LX200).
+It also contains sample server classes (dummy, Meade LX200).
 
 Author and Copyright of this file and of the stellarium telescope library:
 Johannes Gajdosik, 2006
@@ -31,8 +31,6 @@ Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 
 #include <QByteArray>
 
-using namespace std;
-
 Lx200Command::Lx200Command(Server &server)
              : server(*static_cast<TelescopeClientDirectLx200*>(&server)),
                has_been_written_to_buffer(false)
