@@ -2,7 +2,7 @@
 The stellarium telescope library helps building
 telescope server programs, that can communicate with stellarium
 by means of the stellarium TCP telescope protocol.
-It also contains smaple server classes (dummy, Meade LX200).
+It also contains sample server classes (dummy, Meade LX200).
 
 Author and Copyright of this file and of the stellarium telescope library:
 Johannes Gajdosik, 2006
@@ -28,7 +28,6 @@ Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 #include "common/SerialPort.hpp"
 
 #include <list>
-using namespace std;
 
 class Lx200Command;
 
@@ -47,11 +46,11 @@ public:
 	
 private:
 	//! Parses read buffer data received from the telescope.
-	virtual void dataReceived(const char *&p, const char *read_buff_end) Q_DECL_OVERRIDE;
+	void dataReceived(const char *&p, const char *read_buff_end) override;
 	//! Not implemented, as this is not a connection to a client.
-	virtual void sendPosition(unsigned int ra_int, int dec_int, int status) Q_DECL_OVERRIDE {Q_UNUSED(ra_int) Q_UNUSED(dec_int) Q_UNUSED(status)}
+	void sendPosition(unsigned int ra_int, int dec_int, int status) override {Q_UNUSED(ra_int) Q_UNUSED(dec_int) Q_UNUSED(status)}
 	void resetCommunication(void);
-	virtual void prepareSelectFds(fd_set &read_fds, fd_set &write_fds, int &fd_max) Q_DECL_OVERRIDE;
+	void prepareSelectFds(fd_set &read_fds, fd_set &write_fds, int &fd_max) override;
 	bool writeFrontCommandToBuffer(void);
 	//! Flushes the command queue, sending commands to the write buffer.
 	//! This method iterates over the queue, writing to the write buffer
@@ -60,7 +59,7 @@ private:
 	void flushCommandList(void);
 	
 private:
-	list<Lx200Command*> command_list;
+	std::list<Lx200Command*> command_list;
 	long long int time_between_commands;
 	long long int next_send_time;
 	long long int read_timeout_endtime;
