@@ -24,22 +24,25 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
  
+#include <QRegularExpression>
+#include <QStringList>
+
 #include "TelescopeClientDirectLx200.hpp"
 
 #include "Lx200Connection.hpp"
 #include "Lx200Command.hpp"
 #include "common/LogFile.hpp"
 #include "StelCore.hpp"
+#ifndef QT_NO_DEBUG
 #include "StelUtils.hpp"
+#endif
 
-#include <QRegularExpression>
-#include <QStringList>
 
-TelescopeClientDirectLx200::TelescopeClientDirectLx200 (const QString &name, const QString &parameters, Equinox eq)
+TelescopeClientDirectLx200::TelescopeClientDirectLx200 (const QString &name, const QString &parameters, TelescopeControl::Equinox eq)
 	: TelescopeClient(name)
 	, time_delay(0)
 	, equinox(eq)
-	, lx200(Q_NULLPTR)
+	, lx200(nullptr)
 	, long_format_used(false)
 	, answers_received(false)
 	, last_ra(0)
@@ -77,7 +80,7 @@ TelescopeClientDirectLx200::TelescopeClientDirectLx200 (const QString &name, con
 	//end_of_timeout = -0x8000000000000000LL;
 	
 	#ifdef Q_OS_WIN
-	if(serialDeviceName.rightRef(serialDeviceName.size() - 3).toInt() > 9)
+	if(serialDeviceName.right(serialDeviceName.size() - 3).toInt() > 9)
 		serialDeviceName = "\\\\.\\" + serialDeviceName;//"\\.\COMxx", not sure if it will work
 	#endif //Q_OS_WIN
 	
@@ -108,7 +111,7 @@ void TelescopeClientDirectLx200::telescopeGoto(const Vec3d &j2000Pos, StelObject
 		return;
 
 	Vec3d position = j2000Pos;
-	if (equinox == EquinoxJNow)
+	if (equinox == TelescopeControl::EquinoxJNow)
 	{
 		const StelCore* core = StelApp::getInstance().getCore();
 		position = core->j2000ToEquinoxEqu(j2000Pos, StelCore::RefractionOff);
@@ -132,7 +135,7 @@ void TelescopeClientDirectLx200::telescopeSync(const Vec3d &j2000Pos, StelObject
 		return;
 
 	Vec3d position = j2000Pos;
-	if (equinox == EquinoxJNow)
+	if (equinox == TelescopeControl::EquinoxJNow)
 	{
 		const StelCore* core = StelApp::getInstance().getCore();
 		position = core->j2000ToEquinoxEqu(j2000Pos, StelCore::RefractionOff);
@@ -262,7 +265,7 @@ void TelescopeClientDirectLx200::sendPosition(unsigned int ra_int, int dec_int,
 	const double cdec = cos(dec);
 	Vec3d position(cos(ra)*cdec, sin(ra)*cdec, sin(dec));
 	Vec3d j2000Position = position;
-	if (equinox == EquinoxJNow)
+	if (equinox == TelescopeControl::EquinoxJNow)
 	{
 		const StelCore* core = StelApp::getInstance().getCore();
 		j2000Position = core->equinoxEquToJ2000(position, StelCore::RefractionOff);
