@@ -23,12 +23,12 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
+#include "TelescopeControl.hpp"
 #include "TelescopeClient.hpp"
 #include "Rts2/TelescopeClientJsonRts2.hpp"
 #include "Lx200/TelescopeClientDirectLx200.hpp"
 #include "NexStar/TelescopeClientDirectNexStar.hpp"
 #include "INDI/TelescopeClientINDI.hpp"
-#include "StelUtils.hpp"
 #include "StelTranslator.hpp"
 #include "StelCore.hpp"
 
@@ -53,18 +53,8 @@ const QString TelescopeClient::TELESCOPECLIENT_TYPE = QStringLiteral("Telescope"
 
 TelescopeClient *TelescopeClient::create(const QString &url)
 {
-	// example url: My_first_telescope:TCP:J2000:localhost:10000:500000
-	// split to:
-	// name    = My_first_telescope
-	// type    = TCP
-	// equinox = J2000
-	// params  = localhost:10000:500000
-	//
-	// The params part is optional.  We will use QRegularExpression to validate
-	// the url and extact the components.
-
-	// note, in a reg exp, [^:] matches any chararacter except ':'
-	QRegularExpression urlSchema("^([^:]*):([^:]*):([^:]*)(?::(.*))?$");
+	// note: in a reg exp, [^:] matches any character except ':'
+	static const QRegularExpression urlSchema("^([^:]*):([^:]*):([^:]*)(?::(.*))?$");
 	QRegularExpressionMatch urlMatch=urlSchema.match(url);
 	QString name, type, equinox, params;
 	if (urlMatch.hasMatch())
@@ -78,18 +68,15 @@ TelescopeClient *TelescopeClient::create(const QString &url)
 	else
 	{
 		qWarning() << "WARNING - telescope definition" << url << "not recognised";
-		return Q_NULLPTR;
+		return nullptr;
 	}
 
-	Equinox eq = EquinoxJ2000;
-	if (equinox == "JNow")
-		eq = EquinoxJNow;
+	const TelescopeControl::Equinox eq = (equinox == "JNow" ? TelescopeControl::EquinoxJNow : TelescopeControl::EquinoxJ2000);
 
-	qDebug() << "Creating telescope" << url << "; name/type/equinox/params:" << name << type << ((eq == EquinoxJNow) ? "JNow" : "J2000") << params;
+	qDebug() << "Creating telescope" << url << "; name/type/equinox/params:" << name << type << ((eq == TelescopeControl::EquinoxJNow) ? "JNow" : "J2000") << params;
 
-	TelescopeClient * newTelescope = Q_NULLPTR;
+	TelescopeClient * newTelescope = nullptr;
 	
-	//if (type == "Dummy")
 	if (type == "TelescopeServerDummy")
 	{
 		newTelescope = new TelescopeClientDummy(name, params);
@@ -129,7 +116,7 @@ TelescopeClient *TelescopeClient::create(const QString &url)
 	{
 		qDebug() << "TelescopeClient::create(): Unable to create a telescope client.";
 		delete newTelescope;
-		newTelescope = Q_NULLPTR;
+		newTelescope = nullptr;
 	}
 	return newTelescope;
 }
@@ -162,11 +149,7 @@ void TelescopeClient::move(double angle, double speed)
 	qDebug() << "TelescopeClient::move not implemented";
 }
 
-//! returns the current system time in microseconds since the Epoch
-//! Prior to revision 6308, it was necessary to put this method in an
-//! #ifdef block, as duplicate function definition caused errors during static
-//! linking.
-qint64 getNow(void)
+qint64 TelescopeClient::getNow(void)
 {
 // At the moment this can't be done in a platform-independent way with Qt
 // (QDateTime and QTime don't support microsecond precision)
@@ -178,13 +161,13 @@ qint64 getNow(void)
 	t = (*(reinterpret_cast<qint64*>(&file_time))/10) - 86400000000LL*134774;
 #else
 	struct timeval tv;
-	gettimeofday(&tv, Q_NULLPTR);
+	gettimeofday(&tv, nullptr);
 	t = tv.tv_sec * 1000000LL + tv.tv_usec;
 #endif
 	return t;
 }
 
-TelescopeTCP::TelescopeTCP(const QString &name, const QString &params, Equinox eq)
+TelescopeTCP::TelescopeTCP(const QString &name, const QString &params, TelescopeControl::Equinox eq)
 	: TelescopeClient(name)
 	, port(0)
 	, tcpSocket(new QTcpSocket())
@@ -217,7 +200,7 @@ TelescopeTCP::TelescopeTCP(const QString &name, const QString &params, Equinox e
 		return;
 	}
 
-	qDebug() << "TelescopeTCP paramaters host, port, time_delay:" << host << port << time_delay;
+	qDebug() << "TelescopeTCP parameters host, port, time_delay:" << host << port << time_delay;
 	
 	if (time_delay <= 0 || time_delay > 10000000)
 	{
@@ -254,7 +237,11 @@ TelescopeTCP::TelescopeTCP(const QString &name, const QString &params, Equinox e
 	interpolatedPosition.reset();
 	
 	connect(tcpSocket, SIGNAL(connected()), this, SLOT(socketConnected()));
+#if (QT_VERSION>=QT_VERSION_CHECK(5,15,0))
+	connect(tcpSocket, SIGNAL(errorOccurred(QAbstractSocket::SocketError)), this, SLOT(socketFailed(QAbstractSocket::SocketError)));
+#else
 	connect(tcpSocket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(socketFailed(QAbstractSocket::SocketError)));
+#endif
 }
 
 void TelescopeTCP::hangup(void)
@@ -282,7 +269,7 @@ void TelescopeTCP::telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject
 		return;
 
 	Vec3d position = j2000Pos;
-	if (equinox == EquinoxJNow)
+	if (equinox == TelescopeControl::EquinoxJNow)
 	{
 		const StelCore* core = StelApp::getInstance().getCore();
 		position = core->j2000ToEquinoxEqu(j2000Pos, StelCore::RefractionOff);
@@ -456,7 +443,7 @@ void TelescopeTCP::performReading(void)
 					const double cdec = cos(dec);
 					Vec3d position(cos(ra)*cdec, sin(ra)*cdec, sin(dec));
 					Vec3d j2000Position = position;
-					if (equinox == EquinoxJNow)
+					if (equinox == TelescopeControl::EquinoxJNow)
 					{
 						const StelCore* core = StelApp::getInstance().getCore();
 						j2000Position = core->equinoxEquToJ2000(position, StelCore::RefractionOff);
