@@ -33,19 +33,13 @@
 #include <QTcpSocket>
 #include <QObject>
 
-#include "StelApp.hpp"
 #include "StelObject.hpp"
 #include "StelTranslator.hpp"
+#include "TelescopeControl.hpp"
 #include "common/InterpolatedPosition.hpp"
 
 class StelCore;
 
-qint64 getNow(void);
-
-enum Equinox {
-	EquinoxJ2000,
-	EquinoxJNow
-};
 
 //! An abstract base class that should never be used directly, only inherited.
 //! This class used to be called Telescope, but it has been renamed
@@ -56,16 +50,24 @@ class TelescopeClient : public QObject, public StelObject
 	Q_OBJECT
 public:
 	static const QString TELESCOPECLIENT_TYPE;
+	//! example url: My_first_telescope:TCP:J2000:localhost:10000:500000
+	//! split to:
+	//! name    = My_first_telescope
+	//! type    = TCP
+	//! equinox = J2000
+	//! params  = localhost:10000:500000
+	//!
+	//! The params part is optional.  We use QRegularExpression to validate the url and extract the components.
 	static TelescopeClient *create(const QString &url);
-	virtual ~TelescopeClient(void) Q_DECL_OVERRIDE {}
+	~TelescopeClient(void) override {}
 	
-	// Method inherited from StelObject
-	QString getEnglishName(void) const Q_DECL_OVERRIDE {return name;}
-	QString getNameI18n(void) const Q_DECL_OVERRIDE {return nameI18n;}
-	Vec3f getInfoColor(void) const Q_DECL_OVERRIDE
-	{
-		return Vec3f(1.f, 1.f, 1.f);
-	}
+	// Methods inherited from StelObject
+	QString getEnglishName(void) const override {return name;}
+	QString getNameI18n(void) const override {return nameI18n;}
+	//Vec3f getInfoColor(void) const override
+	//{
+	//	return Vec3f(1.f, 1.f, 1.f);
+	//}
 	//! TelescopeClient supports the following InfoStringGroup flags:
 	//! - Name
 	//! - RaDecJ2000
@@ -74,32 +76,34 @@ public:
 	//! @param core the StelCore object
 	//! @param flags a set of InfoStringGroup items to include in the return value.
 	//! @return a QString containing an HMTL encoded description of the Telescope.
-	QString getInfoString(const StelCore* core, const InfoStringGroup& flags) const Q_DECL_OVERRIDE;
-	QString getType(void) const Q_DECL_OVERRIDE {return TELESCOPECLIENT_TYPE;}
-	QString getObjectType(void) const Q_DECL_OVERRIDE {return N_("telescope");}
-	QString getObjectTypeI18n(void) const Q_DECL_OVERRIDE {return q_(getObjectType());}
-	QString getID() const Q_DECL_OVERRIDE {return name;}
+	QString getInfoString(const StelCore* core, const InfoStringGroup& flags) const override;
+	QString getType(void) const override {return TELESCOPECLIENT_TYPE;}
+	QString getObjectType(void) const override {return N_("telescope");}
+	QString getObjectTypeI18n(void) const override {return q_(getObjectType());}
+	QString getID() const override {return name;}
 		
 	// Methods specific to telescope
 	virtual void telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject) = 0;
 	virtual void telescopeSync(const Vec3d &j2000Pos, StelObjectP selectObject) = 0;
-	virtual void telescopeAbortSlew() {}
+	virtual void telescopeAbortSlew() { qWarning() << "Telescope" << getID() << "does not support AbortSlew()!"; }
 
 	//!
 	//! \brief move
-	//! \param angle [0,360)
+	//! \param angle [0,360). 0=South, 90=West, 180=North, 270=East
 	//! \param speed [0,1]
 	//!
 	virtual void move(double angle, double speed);
 	virtual bool isConnected(void) const = 0;
 	virtual bool hasKnownPosition(void) const = 0;
-	void addOcular(double fov) {if (fov>=0.0) oculars.push_back(fov);}
-	const QList<double> &getOculars(void) const {return oculars;}
+	//! Store field of view for an ocular circle (unrelated to Oculars plugin)
+	void addOcular(double fov) {if (fov>=0.0) ocularFovs.push_back(fov);}
+	//! Retrieve list of fields of view for this telescope
+	const QList<double> &getOculars(void) const {return ocularFovs;}
 	
 	virtual bool prepareCommunication() {return false;}
 	virtual void performCommunication() {}
 
-	virtual QWidget* createControlWidget(QSharedPointer<TelescopeClient> telescope, QWidget* parent = Q_NULLPTR) const { Q_UNUSED(telescope) Q_UNUSED(parent) return Q_NULLPTR; }
+	virtual QWidget* createControlWidget(QSharedPointer<TelescopeClient> telescope, QWidget* parent = nullptr) const { Q_UNUSED(telescope) Q_UNUSED(parent) return nullptr; }
 
 protected:
 	TelescopeClient(const QString &name);
@@ -112,11 +116,14 @@ protected:
 		Q_UNUSED(flags)
 		return QString();
 	}
+
+	//! returns the current system time in microseconds since the Epoch
+	static qint64 getNow(void);
 private:
 	virtual bool isInitialized(void) const {return true;}
-	float getSelectPriority(const StelCore* core) const Q_DECL_OVERRIDE {Q_UNUSED(core) return -10.f;}
+	float getSelectPriority(const StelCore* core) const override {Q_UNUSED(core) return -10.f;}
 private:
-	QList<double> oculars; // fov of the oculars
+	QList<double> ocularFovs; // fov of the oculars
 };
 
 //! Example Telescope class. A physical telescope does not exist.
@@ -134,37 +141,42 @@ public:
 		desired_pos[1] = XYZ[1] = 0.0;
 		desired_pos[2] = XYZ[2] = 0.0;
 	}
-	~TelescopeClientDummy(void) Q_DECL_OVERRIDE {}
-	bool isConnected(void) const Q_DECL_OVERRIDE
+	~TelescopeClientDummy(void) override {}
+	bool isConnected(void) const override
 	{
 		return true;
 	}
-	bool prepareCommunication(void) Q_DECL_OVERRIDE
+	bool prepareCommunication(void) override
 	{
 		XYZ = XYZ * 31.0 + desired_pos;
-		const double lq = XYZ.lengthSquared();
+		const double lq = XYZ.normSquared();
 		if (lq > 0.0)
 			XYZ *= (1.0/std::sqrt(lq));
 		else
 			XYZ = desired_pos;
 		return true;
 	}
-	void telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject) Q_DECL_OVERRIDE
+	void telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject) override
 	{
 		Q_UNUSED(selectObject)
 		desired_pos = j2000Pos;
 		desired_pos.normalize();
 	}
-	void telescopeSync(const Vec3d &j2000Pos, StelObjectP selectObject) Q_DECL_OVERRIDE
+	void telescopeSync(const Vec3d &j2000Pos, StelObjectP selectObject) override
 	{
 		Q_UNUSED(selectObject)
 		Q_UNUSED(j2000Pos)
 	}
-	bool hasKnownPosition(void) const Q_DECL_OVERRIDE
+	void telescopeAbortSlew() override
+	{
+		desired_pos=XYZ;
+		qDebug() << "Telescope" << getID() << "Slew aborted";
+	}
+	bool hasKnownPosition(void) const override
 	{
 		return true;
 	}
-	Vec3d getJ2000EquatorialPos(const StelCore*) const Q_DECL_OVERRIDE
+	Vec3d getJ2000EquatorialPos(const StelCore*) const override
 	{
 		return XYZ;
 	}
@@ -183,24 +195,24 @@ class TelescopeTCP : public TelescopeClient
 {
 	Q_OBJECT
 public:
-	TelescopeTCP(const QString &name, const QString &params, Equinox eq = EquinoxJ2000);
-	~TelescopeTCP(void) Q_DECL_OVERRIDE
+	TelescopeTCP(const QString &name, const QString &params, TelescopeControl::Equinox eq = TelescopeControl::EquinoxJ2000);
+	~TelescopeTCP(void) override
 	{
 		hangup();
 	}
-	bool isConnected(void) const Q_DECL_OVERRIDE
+	bool isConnected(void) const override
 	{
 		//return (tcpSocket->isValid() && !wait_for_connection_establishment);
 		return (tcpSocket->state() == QAbstractSocket::ConnectedState);
 	}
 	
 private:
-	Vec3d getJ2000EquatorialPos(const StelCore* core=Q_NULLPTR) const Q_DECL_OVERRIDE;
-	bool prepareCommunication() Q_DECL_OVERRIDE;
-	void performCommunication() Q_DECL_OVERRIDE;
-	void telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject) Q_DECL_OVERRIDE;
-	void telescopeSync(const Vec3d &j2000Pos, StelObjectP selectObject) Q_DECL_OVERRIDE;
-	bool isInitialized(void) const Q_DECL_OVERRIDE
+	Vec3d getJ2000EquatorialPos(const StelCore* core=nullptr) const override;
+	bool prepareCommunication() override;
+	void performCommunication() override;
+	void telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject) override;
+	void telescopeSync(const Vec3d &j2000Pos, StelObjectP selectObject) override;
+	bool isInitialized(void) const override
 	{
 		return (!address.isNull());
 	}
@@ -221,12 +233,12 @@ private:
 	int time_delay;
 
 	InterpolatedPosition interpolatedPosition;
-	virtual bool hasKnownPosition(void) const Q_DECL_OVERRIDE
+	bool hasKnownPosition(void) const override
 	{
 		return interpolatedPosition.isKnown();
 	}
 
-	Equinox equinox;
+	TelescopeControl::Equinox equinox;
 	
 private slots:
 	void socketConnected(void);
