@@ -37,17 +37,16 @@
 #include "StelFileMgr.hpp"
 #include "StelGui.hpp"
 #include "StelGuiItems.hpp"
-#include "StelIniParser.hpp"
-#include "StelLocaleMgr.hpp"
+#include "StelMainView.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelMovementMgr.hpp"
 #include "StelObject.hpp"
 #include "StelObjectMgr.hpp"
 #include "StelPainter.hpp"
 #include "StelProjector.hpp"
-#include "StelStyle.hpp"
 #include "StelTextureMgr.hpp"
 #include "StelActionMgr.hpp"
+#include "StelJsonParser.hpp"
 
 #include <QDateTime>
 #include <QDir>
@@ -89,11 +88,11 @@ StelPluginInfo TelescopeControlStelPluginInterface::getPluginInfo() const
 ////////////////////////////////////////////////////////////////////////////////
 // Constructor and destructor
 TelescopeControl::TelescopeControl()
-	: toolbarButton(Q_NULLPTR)
+	: toolbarButton(nullptr)
 	, useTelescopeServerLogs(false)
 	, useServerExecutables(false)
-	, telescopeDialog(Q_NULLPTR)
-	, slewDialog(Q_NULLPTR)
+	, telescopeDialog(nullptr)
+	, slewDialog(nullptr)
 	, actionGroupId("PluginTelescopeControl")
 	, moveToSelectedActionId("actionMove_Telescope_To_Selection_%1")
 	, syncActionId("actionSync_Telescope_To_Selection_%1")
@@ -114,8 +113,8 @@ TelescopeControl::TelescopeControl()
 
 TelescopeControl::~TelescopeControl()
 {
-	delete slewDialog; slewDialog = Q_NULLPTR;
-	delete telescopeDialog; telescopeDialog = Q_NULLPTR;
+	delete slewDialog; slewDialog = nullptr;
+	delete telescopeDialog; telescopeDialog = nullptr;
 }
 
 
@@ -208,9 +207,9 @@ void TelescopeControl::init()
 
 		//Create toolbar button
 		StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
-		if (gui!=Q_NULLPTR)
+		if (gui!=nullptr)
 		{
-			toolbarButton =	new StelButton(Q_NULLPTR,
+			toolbarButton =	new StelButton(nullptr,
 						       QPixmap(":/telescopeControl/button_Slew_Dialog_on.png"),
 						       QPixmap(":/telescopeControl/button_Slew_Dialog_off.png"),
 						       QPixmap(":/graphicGui/miscGlow32x32.png"),
@@ -266,8 +265,7 @@ void TelescopeControl::deinit()
 	//Destroy all clients first in order to avoid displaying a TCP error
 	deleteAllTelescopes();
 
-	for (auto iterator = telescopeServerProcess.constBegin(); iterator != telescopeServerProcess.constEnd();
-		 ++iterator)
+	for (auto iterator = telescopeServerProcess.constBegin(); iterator != telescopeServerProcess.constEnd(); ++iterator)
 	{
 		int slotNumber = iterator.key();
 #ifdef Q_OS_WIN
@@ -280,7 +278,6 @@ void TelescopeControl::deinit()
 		qDebug() << "[TelescopeControl] deinit(): Server process at slot" << slotNumber << "terminated successfully.";
 	}
 
-	//TODO: Decide if it should be saved on change
 	//Save the configuration on exit
 	saveConfiguration();
 }
@@ -300,7 +297,7 @@ void TelescopeControl::draw(StelCore* core)
 	StelPainter sPainter(prj);
 	sPainter.setFont(labelFont);
 	reticleTexture->bind();
-	for (const auto& telescope : telescopeClients)
+	for (const auto& telescope : std::as_const(telescopeClients))
 	{
 		if (telescope->isConnected() && telescope->hasKnownPosition())
 		{
@@ -330,7 +327,7 @@ void TelescopeControl::draw(StelCore* core)
 					sPainter.drawText(XY[0], XY[1], telescope->getNameI18n(), 0, 6 + 10, -4, false);
 					//Same position as the other objects: doesn't work, telescope label overlaps object label
 					//sPainter.drawText(XY[0], XY[1], scope->getNameI18n(), 0, 10, 10, false);
-					reticleTexture->bind();
+					//reticleTexture->bind(); // 2022: WHY???
 				}
 			}
 		}
@@ -377,7 +374,7 @@ StelObjectP TelescopeControl::searchByNameI18n(const QString &nameI18n) const
 		if (telescope->getNameI18n() == nameI18n)
 			return qSharedPointerCast<StelObject>(telescope);
 	}
-	return Q_NULLPTR;
+	return nullptr;
 }
 
 StelObjectP TelescopeControl::searchByName(const QString &name) const
@@ -387,7 +384,7 @@ StelObjectP TelescopeControl::searchByName(const QString &name) const
 		if (telescope->getEnglishName() == name)
 			return qSharedPointerCast<StelObject>(telescope);
 	}
-	return Q_NULLPTR;
+	return nullptr;
 }
 
 QString TelescopeControl::getStelObjectType() const
@@ -572,7 +569,8 @@ void TelescopeControl::loadTelescopeServerExecutables(void)
 {
 	telescopeServers = QStringList();
 
-	//TODO: I don't like how this turned out
+	//TODO: I don't like how this turned out (FC, 2010)
+	//FIXME: elaborate on this? (GZ, 2022)
 	if(serverExecutablesDirectoryPath.isEmpty())
 		return;
 
@@ -587,7 +585,7 @@ void TelescopeControl::loadTelescopeServerExecutables(void)
 	QList<QFileInfo> telescopeServerExecutables = serverDirectory.entryInfoList(QStringList("TelescopeServer*"), (QDir::Files|QDir::Executable|QDir::CaseSensitive), QDir::Name);
 	if(!telescopeServerExecutables.isEmpty())
 	{
-		for (auto telescopeServerExecutable : telescopeServerExecutables)
+		for (auto &telescopeServerExecutable : std::as_const(telescopeServerExecutables))
 			telescopeServers.append(telescopeServerExecutable.baseName());//This strips the ".exe" suffix on Windows
 	}
 	else
@@ -664,9 +662,9 @@ void TelescopeControl::saveConfiguration()
 	settings->setValue("flag_telescope_circles", getFlagTelescopeCircles());
 
 	//Save colours
-	settings->setValue("color_telescope_reticles", getReticleColor().toHtmlColor());
-	settings->setValue("color_telescope_labels", getLabelColor().toHtmlColor());
-	settings->setValue("color_telescope_circles", getCircleColor().toHtmlColor());
+	settings->setValue("color_telescope_reticles", getReticleColor().toStr());
+	settings->setValue("color_telescope_labels",   getLabelColor().toStr());
+	settings->setValue("color_telescope_circles",  getCircleColor().toStr());
 
 	//Save telescope server executables flag and directory
 	settings->setValue("flag_use_server_executables", useServerExecutables);
@@ -730,7 +728,7 @@ void TelescopeControl::loadTelescopes()
 		qWarning() << "[TelescopeControl] Error loading telescopes";
 		return;
 	}
-	if(!QFileInfo(telescopesJsonPath).exists())
+	if(!QFileInfo::exists(telescopesJsonPath))
 	{
 		qWarning() << "[TelescopeControl] loadTelescopes(): No telescopes loaded. File is missing:" << QDir::toNativeSeparators(telescopesJsonPath);
 		telescopeDescriptions = result;
@@ -773,7 +771,7 @@ void TelescopeControl::loadTelescopes()
 			qWarning() << "[TelescopeControl] The existing version of telescopes.json is obsolete. Unable to rename.";
 
 		telescopeDescriptions = result;
-		QMessageBox::warning(Q_NULLPTR, q_("Attention!"), q_("The existing version of the configuration data for telescopes in the Telescope Control plugin is obsolete."), QMessageBox::Ok);
+		QMessageBox::warning(&StelMainView::getInstance(), q_("Attention!"), q_("The existing version of the configuration data for telescopes in the Telescope Control plugin is obsolete."), QMessageBox::Ok);
 		return;
 	}
 
@@ -789,6 +787,9 @@ void TelescopeControl::loadTelescopes()
 		node.next();
 		QString key = node.key();
 
+		if (key=="version") // skip "version" data
+			continue;
+
 		//If this is not a valid slot number, remove the node
 		int slot = key.toInt(&ok);
 		if(!ok || !isValidSlotNumber(slot))
@@ -968,7 +969,7 @@ void TelescopeControl::loadTelescopes()
 		{
 			if (connectionType == ConnectionInternal)
 			{
-				//Use a sever if necessary
+				//Use a server if necessary
 				if(deviceModels[deviceModelName].useExecutable)
 				{
 					if(startClientAtSlot(slot, connectionType, name, equinox, hostName, portTCP, delay, internalCircles))
@@ -1029,7 +1030,7 @@ void TelescopeControl::loadTelescopes()
 bool TelescopeControl::addTelescopeAtSlot(int slot, ConnectionType connectionType, QString name, QString equinox, QString host, int portTCP, int delay, bool connectAtStartup, QList<double> circles, QString deviceModelName, QString portSerial, QString rts2Url, QString rts2Username, QString rts2Password, int rts2Refresh, QString ascomDeviceId, bool ascomUseDeviceEqCoordType)
 {
 	//Validation
-	if(!isValidSlotNumber(slot) || name.isEmpty() || equinox.isEmpty() || connectionType <= ConnectionNA || connectionType >= ConnectionCount)
+	if(!isValidSlotNumber(slot) || name.isEmpty() || equinox.isEmpty() || connectionType <= ConnectionNA || connectionType >= ConnectionTypeCount)
 		return false;
 
 	//Create a new map node and fill it with parameters
@@ -1199,9 +1200,9 @@ bool TelescopeControl::startTelescopeAtSlot(int slot)
 	QString rts2Url;
 	QString rts2Username;
 	QString rts2Password;
-	int rts2Refresh;
+	int rts2Refresh=0;
 	QString ascomDeviceId;
-	bool ascomUseDeviceEqCoordType;
+	bool ascomUseDeviceEqCoordType=false;
 
 	if(!getTelescopeAtSlot(slot, connectionType, name, equinox, host, portTCP, delay, connectAtStartup, circles, deviceModelName, portSerial, rts2Url, rts2Username, rts2Password, rts2Refresh, ascomDeviceId, ascomUseDeviceEqCoordType))
 	{
@@ -1474,7 +1475,7 @@ void TelescopeControl::loadDeviceModels()
 	//Make sure that the device models file exists
 	bool useDefaultList = false;
 	QString deviceModelsJsonPath = StelFileMgr::findFile("modules/TelescopeControl", static_cast<StelFileMgr::Flags>(StelFileMgr::Directory|StelFileMgr::Writable)) + "/device_models.json";
-	if(!QFileInfo(deviceModelsJsonPath).exists())
+	if(!QFileInfo::exists(deviceModelsJsonPath))
 	{
 		if(!restoreDeviceModelsListTo(deviceModelsJsonPath))
 		{
@@ -1623,7 +1624,7 @@ void TelescopeControl::loadDeviceModels()
 	}
 }
 
-const QHash<QString, DeviceModel>& TelescopeControl::getDeviceModels()
+const QHash<QString, TelescopeControl::DeviceModel>& TelescopeControl::getDeviceModels()
 {
 	return deviceModels;
 }
@@ -1634,10 +1635,12 @@ QHash<int, QString> TelescopeControl::getConnectedClientsNames()
 	if (telescopeClients.isEmpty())
 		return connectedClientsNames;
 
-	for (const auto slotNumber : telescopeClients.keys())
+	QMapIterator<int, TelescopeClientP> it(telescopeClients);
+	while (it.hasNext())
 	{
-		if (telescopeClients.value(slotNumber)->isConnected())
-			connectedClientsNames.insert(slotNumber, telescopeClients.value(slotNumber)->getNameI18n());
+		it.next();
+		if (telescopeClients.value(it.key())->isConnected())
+			connectedClientsNames.insert(it.key(), it.value()->getNameI18n());
 	}
 
 	return connectedClientsNames;
@@ -1682,9 +1685,12 @@ bool TelescopeControl::setServerExecutablesDirectoryPath(const QString& newPath)
 
 	//If everything is fine...
 	serverExecutablesDirectoryPath = newPath;
+	QSettings *settings=StelApp::getInstance().getSettings();
+	settings->setValue("TelescopeControl/server_executables_path", serverExecutablesDirectoryPath);
 
 	stopAllTelescopes();
 	loadDeviceModels();
+	emit serverExecutablesDirectoryPathChanged(newPath);
 	return true;
 }
 
@@ -1697,6 +1703,7 @@ void TelescopeControl::setFlagUseServerExecutables(bool useExecutables)
 	useServerExecutables = useExecutables;
 	stopAllTelescopes();
 	loadDeviceModels();
+	emit getFlagUseServerExecutablesChanged(useExecutables);
 }
 
 void TelescopeControl::addLogAtSlot(int slot)
@@ -1743,7 +1750,7 @@ void TelescopeControl::logAtSlot(int slot)
 		log_file = telescopeServerLogStreams.value(slot);
 }
 
-QStringList TelescopeControl::listMatchingObjects(const QString& objPrefix, int maxNbItem, bool useStartOfWords) const
+QStringList TelescopeControl::listMatchingObjects(const QString& objPrefix, const int maxNbItem, bool useStartOfWords) const
 {
 	QStringList result;
 	if (maxNbItem<=0)
@@ -1785,11 +1792,25 @@ QStringList TelescopeControl::listMatchingObjects(const QString& objPrefix, int
 	}
 	result.sort();
 	if (result.size()>maxNbItem)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 		result.erase(result.begin()+maxNbItem, result.end());
-
+#else
+		result.erase(result.constBegin()+maxNbItem, result.constEnd());
+#endif
 	return result;
 }
 
+#ifdef Q_OS_WIN
+const QString TelescopeControl::TELESCOPE_SERVER_PATH = QString("/%1.exe");
+#else
+const QString TelescopeControl::TELESCOPE_SERVER_PATH = QString("/%1");
+#endif
+
+const QStringList TelescopeControl::EMBEDDED_TELESCOPE_SERVERS = {
+	"TelescopeServerDummy",
+	"TelescopeServerLx200",
+	"TelescopeServerNexStar"};
+
 void TelescopeControl::translations()
 {
 #if 0
