@@ -21,34 +21,36 @@
 #include <QDebug>
 
 #include "Dialog.hpp"
+#include "StelFileMgr.hpp"
 #include "AngleSpinBox.hpp"
 #include "StelApp.hpp"
-#include "StelLocaleMgr.hpp"
-#include "StelStyle.hpp"
 #include "VecMath.hpp"
+#include "StelJsonParser.hpp"
+#include "StelUtils.hpp"
+#include "StelCore.hpp"
+#include "StelObjectMgr.hpp"
+#include "StelModuleMgr.hpp"
+
 #include "TelescopeControl.hpp"
 #include "SlewDialog.hpp"
 #include "ui_slewDialog.h"
 #include "TelescopeClient.hpp"
-#include "INDI/TelescopeClientINDI.hpp"
 
-using namespace TelescopeControlGlobals;
-
-
-SlewDialog::SlewDialog()
-	: StelDialog("TelescopeControlSlew")
-	, storedPointsDialog(Q_NULLPTR)
+SlewDialog::SlewDialog(const QString &dialogName, QObject *parent)
+	: StelDialog(dialogName, parent)
+	, storedPointsDialog(nullptr)
 {
 	ui = new Ui_slewDialog();
 	
-    //TODO: Fix this - it's in the same plugin
-    telescopeManager = GETSTELMODULE(TelescopeControl);
+	//TODO: Fix this - it's in the same plugin
+	telescopeManager = GETSTELMODULE(TelescopeControl);
 }
 
 SlewDialog::~SlewDialog()
 {	
 	delete ui;
-	storedPointsDialog = Q_NULLPTR;
+	delete storedPointsDialog;
+	storedPointsDialog = nullptr;
 }
 
 void SlewDialog::retranslate()
@@ -63,8 +65,8 @@ void SlewDialog::createDialogContent()
 	
 	//Inherited connect
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	connect(ui->radioButtonHMS, SIGNAL(toggled(bool)), this, SLOT(setFormatHMS(bool)));
 	connect(ui->radioButtonDMS, SIGNAL(toggled(bool)), this, SLOT(setFormatDMS(bool)));
@@ -72,6 +74,7 @@ void SlewDialog::createDialogContent()
 
 	connect(ui->pushButtonSlew, SIGNAL(clicked()), this, SLOT(slew()));
 	connect(ui->pushButtonSync, SIGNAL(clicked()), this, SLOT(sync()));
+	connect(ui->pushButtonAbort, SIGNAL(clicked()), this, SLOT(abort()));
 	connect(ui->pushButtonConfigure, SIGNAL(clicked()), this, SLOT(showConfiguration()));
 
 	connect(telescopeManager, SIGNAL(clientConnected(int, QString)), this, SLOT(addTelescope(int, QString)));
@@ -88,7 +91,7 @@ void SlewDialog::createDialogContent()
 	//Coordinates are in HMS by default:
 	ui->radioButtonHMS->setChecked(true);
 
-	storedPointsDialog = new StoredPointsDialog;
+	storedPointsDialog = new StoredPointsDialog();
 	// add point and remove
 	connect(storedPointsDialog, SIGNAL(addStoredPoint(int, QString, double, double)), this, SLOT(addStoredPointToComboBox(int, QString, double, double)));
 	// remove point
@@ -146,11 +149,13 @@ void SlewDialog::updateTelescopeList()
 	ui->comboBoxTelescope->clear();
 
 	QHash<int, QString> connectedSlotsByNumber = telescopeManager->getConnectedClientsNames();
-	for (const auto slot : connectedSlotsByNumber.keys())
+	QHash<int, QString> ::const_iterator it=connectedSlotsByNumber.constBegin();
+	while (it!=connectedSlotsByNumber.constEnd())
 	{
-		QString telescopeName = connectedSlotsByNumber.value(slot);
-		connectedSlotsByName.insert(telescopeName, slot);
+		QString telescopeName = connectedSlotsByNumber.value(it.key());
+		connectedSlotsByName.insert(telescopeName, it.key());
 		ui->comboBoxTelescope->addItem(telescopeName);
+		++it;
 	}
 	
 	updateTelescopeControls();
@@ -220,7 +225,7 @@ void SlewDialog::slew()
 	if (!telescope)
 		return;
 
-	StelObjectP selectObject = Q_NULLPTR;
+	StelObjectP selectObject = nullptr;
 	telescope->telescopeGoto(targetPosition, selectObject);
 }
 
@@ -236,10 +241,19 @@ void SlewDialog::sync()
 	if (!telescope)
 		return;
 
-	StelObjectP selectObject = Q_NULLPTR;
+	StelObjectP selectObject = nullptr;
 	telescope->telescopeSync(targetPosition, selectObject);
 }
 
+void SlewDialog::abort()
+{
+	auto telescope = currentTelescope();
+	if (!telescope)
+		return;
+
+	telescope->telescopeAbortSlew();
+}
+
 void SlewDialog::getCurrentObjectInfo()
 {
 	const QList<StelObjectP>& selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
@@ -342,21 +356,21 @@ void SlewDialog::onCurrentTelescopeChanged()
 {
 	// remove previous controlWidget
 	QLayoutItem* child;
-	while ((child = ui->controlWidgetLayout->takeAt(0)) != Q_NULLPTR)
+	while ((child = ui->controlWidgetLayout->takeAt(0)) != nullptr)
 	{
 		delete child->widget();
 		delete child;
 	}
 
-    auto telescope = currentTelescope();
-    if (!telescope)
-        return;
+	auto telescope = currentTelescope();
+	if (!telescope)
+		return;
 
-    auto controlWidget = telescope->createControlWidget(telescope);
-    if (!controlWidget)
-        return;
+	auto controlWidget = telescope->createControlWidget(telescope);
+	if (!controlWidget)
+		return;
 
-    ui->controlWidgetLayout->addWidget(controlWidget);
+	ui->controlWidgetLayout->addWidget(controlWidget);
 }
 
 void SlewDialog::savePointsToFile()
@@ -382,11 +396,11 @@ void SlewDialog::savePointsToFile()
 	{
 		QVariant var = ui->comboBoxStoredPoints->itemData(i);
 		storedPoint sp = var.value<storedPoint>();
-		QVariantMap point;
-		point.insert("number",        sp.number);
-		point.insert("name",          sp.name);
-		point.insert("radiansRA",     sp.radiansRA);
-		point.insert("radiansDec",    sp.radiansDec);
+		QVariantMap point = {
+			{"number",        sp.number},
+			{"name",          sp.name},
+			{"radiansRA",     sp.radiansRA},
+			{"radiansDec",    sp.radiansDec}};
 
 		storedPointsDescriptions.insert(QString::number(sp.number),point);
 	}
@@ -408,7 +422,7 @@ void SlewDialog::loadPointsFromFile()
 		qWarning() << "SlewDialog: Error loading points";
 		return;
 	}
-	if(!QFileInfo(pointsJsonPath).exists())
+	if(!QFileInfo::exists(pointsJsonPath))
 	{
 		qWarning() << "SlewDialog::loadPointsFromFile(): No points loaded. File is missing:"
 				   << QDir::toNativeSeparators(pointsJsonPath);
