@@ -21,11 +21,7 @@
 #include "TelescopeConfigurationDialog.hpp"
 #include "Dialog.hpp"
 #include "StelApp.hpp"
-#include "StelCore.hpp"
-#include "StelFileMgr.hpp"
-#include "StelLocaleMgr.hpp"
 #include "StelModuleMgr.hpp"
-#include "StelStyle.hpp"
 #include "StelTranslator.hpp"
 #include "TelescopeControl.hpp"
 #include "ui_telescopeConfigurationDialog.h"
@@ -148,8 +144,8 @@ void TelescopeConfigurationDialog::createDialogContent()
 
 	// Inherited connect
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(buttonDiscardPressed()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &TelescopeConfigurationDialog::buttonDiscardPressed);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 	connect(dialog, SIGNAL(rejected()), this, SLOT(buttonDiscardPressed()));
 
 	// Connect: sender, signal, receiver, member
@@ -167,8 +163,7 @@ void TelescopeConfigurationDialog::createDialogContent()
 	connect(ui->pushButtonSave, SIGNAL(clicked()), this, SLOT(buttonSavePressed()));
 	connect(ui->pushButtonDiscard, SIGNAL(clicked()), this, SLOT(buttonDiscardPressed()));
 
-	connect(ui->comboBoxDeviceModel, SIGNAL(currentIndexChanged(const QString&)), this,
-	  SLOT(deviceModelSelected(const QString&)));
+	connect(ui->comboBoxDeviceModel, SIGNAL(currentIndexChanged(int)), this, SLOT(deviceModelSelected(int)));
 
 	// Setting validators
 	ui->lineEditTelescopeName->setValidator(telescopeNameValidator);
@@ -218,7 +213,11 @@ void TelescopeConfigurationDialog::initConfigurationDialog()
 	QStringList* plist = listSerialPorts();
 	ui->comboSerialPort->clear();
 	ui->comboSerialPort->addItems(*plist);
+#if (QT_VERSION>=QT_VERSION_CHECK(5,14,0))
+	emit ui->comboSerialPort->textActivated(plist->value(0));
+#else
 	ui->comboSerialPort->activated(plist->value(0));
+#endif
 	ui->comboSerialPort->setEditText(plist->value(0));
 	delete (plist);
 
@@ -255,21 +254,21 @@ void TelescopeConfigurationDialog::initNewTelescopeConfiguration(int slot)
 {
 	configuredSlot = slot;
 	initConfigurationDialog();
-	ui->stelWindowTitle->setText(q_("Add New Telescope"));
+	ui->titleBar->setTitle(q_("Add New Telescope"));
 	ui->lineEditTelescopeName->setText(QString("New Telescope %1").arg(QString::number(configuredSlot)));
 
-	ui->doubleSpinBoxTelescopeDelay->setValue(SECONDS_FROM_MICROSECONDS(DEFAULT_DELAY));
+	ui->doubleSpinBoxTelescopeDelay->setValue(SECONDS_FROM_MICROSECONDS(TelescopeControl::DEFAULT_DELAY));
 }
 
 void TelescopeConfigurationDialog::initExistingTelescopeConfiguration(int slot)
 {
 	configuredSlot = slot;
 	initConfigurationDialog();
-	ui->stelWindowTitle->setText(q_("Configure Telescope"));
+	ui->titleBar->setTitle(q_("Configure Telescope"));
 
 	// Read the telescope properties
 	QString name;
-	ConnectionType connectionType;
+	TelescopeControl::ConnectionType connectionType;
 	QString equinox;
 	QString host;
 	int portTCP;
@@ -289,12 +288,13 @@ void TelescopeConfigurationDialog::initExistingTelescopeConfiguration(int slot)
 		  connectAtStartup, circles, deviceModelName, serialPortName, rts2Url, rts2Username, rts2Password,
 		  rts2Refresh, ascomDeviceId, ascomUseDeviceEqCoordType))
 	{
-		// TODO: Add debug
+		// TODO: Add better debug
+		qDebug() << "Cannot get telescope for slot" << slot;
 		return;
 	}
 	ui->lineEditTelescopeName->setText(name);
 
-	if (connectionType == ConnectionInternal && !deviceModelName.isEmpty())
+	if (connectionType == TelescopeControl::ConnectionInternal && !deviceModelName.isEmpty())
 	{
 		ui->radioButtonTelescopeLocal->setChecked(true);
 		ui->lineEditHostName->setText("localhost"); // TODO: Remove magic word!
@@ -311,24 +311,28 @@ void TelescopeConfigurationDialog::initExistingTelescopeConfiguration(int slot)
 			ui->comboBoxDeviceModel->setCurrentIndex(index);
 
 		// Initialize the serial port value
+#if (QT_VERSION>=QT_VERSION_CHECK(5,14,0))
+		emit ui->comboSerialPort->textActivated(serialPortName);
+#else
 		ui->comboSerialPort->activated(serialPortName);
+#endif
 		ui->comboSerialPort->setEditText(serialPortName);
 	}
-	else if (connectionType == ConnectionRemote)
+	else if (connectionType == TelescopeControl::ConnectionRemote)
 	{
 		ui->radioButtonTelescopeConnection->setChecked(true); // Calls toggleTypeConnection(true)
 		ui->lineEditHostName->setText(host);
 	}
-	else if (connectionType == ConnectionLocal)
+	else if (connectionType == TelescopeControl::ConnectionLocal)
 	{
 		ui->radioButtonTelescopeConnection->setChecked(true);
 		ui->lineEditHostName->setText("localhost");
 	}
-	else if (connectionType == ConnectionVirtual)
+	else if (connectionType == TelescopeControl::ConnectionVirtual)
 	{
 		ui->radioButtonTelescopeVirtual->setChecked(true);
 	}
-	else if (connectionType == ConnectionRTS2)
+	else if (connectionType == TelescopeControl::ConnectionRTS2)
 	{
 		ui->radioButtonTelescopeRTS2->setChecked(true);
 		ui->lineEditRTS2Url->setText(rts2Url);
@@ -336,7 +340,7 @@ void TelescopeConfigurationDialog::initExistingTelescopeConfiguration(int slot)
 		ui->lineEditRTS2Password->setText(rts2Password);
 		ui->doubleSpinBoxRTS2Refresh->setValue(SECONDS_FROM_MICROSECONDS(rts2Refresh));
 	}
-	else if (connectionType == ConnectionINDI)
+	else if (connectionType == TelescopeControl::ConnectionINDI)
 	{
 		ui->radioButtonTelescopeINDI->setChecked(true);
 		ui->INDIProperties->setHost(host);
@@ -344,7 +348,7 @@ void TelescopeConfigurationDialog::initExistingTelescopeConfiguration(int slot)
 		ui->INDIProperties->setSelectedDevice(deviceModelName);
 	}
 	#ifdef Q_OS_WIN
-	else if (connectionType == ConnectionASCOM)
+	else if (connectionType == TelescopeControl::ConnectionASCOM)
 	{
 		ui->radioButtonTelescopeASCOM->setChecked(true);
 		ascomWidget->setSelectedDevice(ascomDeviceId);
@@ -386,7 +390,11 @@ void TelescopeConfigurationDialog::toggleTypeLocal(bool isChecked)
 		// Re-initialize values that may have been changed
 		ui->comboBoxDeviceModel->setCurrentIndex(0);
 		QStringList* plist = listSerialPorts();
+#if (QT_VERSION>=QT_VERSION_CHECK(5,14,0))
+		emit ui->comboSerialPort->textActivated(plist->value(0));
+#else
 		ui->comboSerialPort->activated(plist->value(0));
+#endif
 		ui->comboSerialPort->setEditText(plist->value(0));
 		delete (plist);
 		ui->lineEditHostName->setText("localhost");
@@ -488,7 +496,7 @@ void TelescopeConfigurationDialog::buttonSavePressed()
 
 		for (int i = 0; i < circleStrings.size(); i++)
 		{
-			if (i >= MAX_CIRCLE_COUNT) break;
+			if (i >= TelescopeControl::MAX_CIRCLE_COUNT) break;
 			double circle = circleStrings.at(i).toDouble();
 			if (circle > 0.0) circles.append(circle);
 		}
@@ -499,33 +507,33 @@ void TelescopeConfigurationDialog::buttonSavePressed()
 
 	// Type and server properties
 	// TODO: When adding, check for success!
-	ConnectionType type = ConnectionNA;
+	TelescopeControl::ConnectionType type = TelescopeControl::ConnectionNA;
 	if (ui->radioButtonTelescopeLocal->isChecked())
 	{
 		// Read the serial port
 		QString serialPortName = ui->comboSerialPort->currentText();
-		type = ConnectionInternal;
+		type = TelescopeControl::ConnectionInternal;
 		telescopeManager->addTelescopeAtSlot(configuredSlot, type, name, equinox, host, portTCP, delay,
 		  connectAtStartup, circles, ui->comboBoxDeviceModel->currentText(), serialPortName);
 	}
 	else if (ui->radioButtonTelescopeConnection->isChecked())
 	{
 		if (host == "localhost")
-			type = ConnectionLocal;
+			type = TelescopeControl::ConnectionLocal;
 		else
-			type = ConnectionRemote;
+			type = TelescopeControl::ConnectionRemote;
 		telescopeManager->addTelescopeAtSlot(
 		  configuredSlot, type, name, equinox, host, portTCP, delay, connectAtStartup, circles);
 	}
 	else if (ui->radioButtonTelescopeVirtual->isChecked())
 	{
-		type = ConnectionVirtual;
+		type = TelescopeControl::ConnectionVirtual;
 		telescopeManager->addTelescopeAtSlot(
 		  configuredSlot, type, name, equinox, QString(), portTCP, delay, connectAtStartup, circles);
 	}
 	else if (ui->radioButtonTelescopeRTS2->isChecked())
 	{
-		type = ConnectionRTS2;
+		type = TelescopeControl::ConnectionRTS2;
 		telescopeManager->addTelescopeAtSlot(configuredSlot, type, name, equinox, host, portTCP, delay,
 		  connectAtStartup, circles, QString(), QString(), ui->lineEditRTS2Url->text(),
 		  ui->lineEditRTS2Username->text(), ui->lineEditRTS2Password->text(),
@@ -533,14 +541,14 @@ void TelescopeConfigurationDialog::buttonSavePressed()
 	}
 	else if (ui->radioButtonTelescopeINDI->isChecked())
 	{
-		type = ConnectionINDI;
+		type = TelescopeControl::ConnectionINDI;
 		telescopeManager->addTelescopeAtSlot(configuredSlot, type, name, equinox, ui->INDIProperties->host(),
 		  ui->INDIProperties->port(), delay, connectAtStartup, circles, ui->INDIProperties->selectedDevice());
 	}
 	#ifdef Q_OS_WIN
 	else if (ui->radioButtonTelescopeASCOM->isChecked())
 	{
-		type = ConnectionASCOM;
+		type = TelescopeControl::ConnectionASCOM;
 		telescopeManager->addTelescopeAtSlot(configuredSlot, type, name, equinox, host, portTCP, delay,
 		  connectAtStartup, circles, QString(), QString(), QString(), QString(), QString(), -1,
 		  ascomWidget->selectedDevice(), ascomWidget->useDeviceEqCoordType());
@@ -555,8 +563,9 @@ void TelescopeConfigurationDialog::buttonDiscardPressed()
 	emit changesDiscarded();
 }
 
-void TelescopeConfigurationDialog::deviceModelSelected(const QString& deviceModelName)
+void TelescopeConfigurationDialog::deviceModelSelected(int modelIndex)
 {
+	const QString& deviceModelName=ui->comboBoxDeviceModel->itemText(modelIndex);
 	ui->labelDeviceModelDescription->setText(
 	  q_(telescopeManager->getDeviceModels().value(deviceModelName).description));
 	ui->doubleSpinBoxTelescopeDelay->setValue(
