@@ -20,11 +20,9 @@
 
 #include "Dialog.hpp"
 #include "StelApp.hpp"
-#include "StelCore.hpp"
 #include "StelModuleMgr.hpp"
-#include "StelFileMgr.hpp"
-#include "StelLocaleMgr.hpp"
 #include "StelStyle.hpp"
+#include "StelMainView.hpp"
 #include "StelTranslator.hpp"
 #include "TelescopeControl.hpp"
 #include "TelescopeConfigurationDialog.hpp"
@@ -42,31 +40,31 @@
 #include <QStandardItem>
 #include <QRegularExpression>
 
-using namespace TelescopeControlGlobals;
 
-
-TelescopeDialog::TelescopeDialog()
-	: StelDialog("TelescopeControl")
+TelescopeDialog::TelescopeDialog(const QString &dialogName, QObject *parent)
+	: StelDialog(dialogName, parent)
 	, telescopeCount(0)
 	, configuredSlot(0)
 	, configuredTelescopeIsNew(false)
 {
-	telescopeStatus[0] = StatusNA;
-	telescopeType[0] = ConnectionNA;
+	telescopeStatus[0] = TelescopeControl::StatusNA;
+	connectionTypes[0] = TelescopeControl::ConnectionNA;
 
 	ui = new Ui_telescopeDialogForm;
 
 	//TODO: Fix this - it's in the same plugin
 	telescopeManager = GETSTELMODULE(TelescopeControl);
+
 	telescopeListModel = new QStandardItemModel(0, ColumnCount);
 
-	//TODO: This shouldn't be a hash...
-	statusString[StatusNA] = QString(N_("N/A"));
-	statusString[StatusStarting] = QString(N_("Starting"));
-	statusString[StatusConnecting] = QString(N_("Connecting"));
-	statusString[StatusConnected] = QString(N_("Connected"));
-	statusString[StatusDisconnected] = QString(N_("Disconnected"));
-	statusString[StatusStopped] = QString(N_("Stopped"));
+	//TODO: (FC 2010) This shouldn't be a hash...--> GZ (2022): OK, it's map now.
+	statusString = {
+		{TelescopeControl::StatusNA,           N_("N/A")},
+		{TelescopeControl::StatusStarting,     N_("Starting")},
+		{TelescopeControl::StatusConnecting,   N_("Connecting")},
+		{TelescopeControl::StatusConnected,    N_("Connected")},
+		{TelescopeControl::StatusDisconnected, N_("Disconnected")},
+		{TelescopeControl::StatusStopped,      N_("Stopped")}};
 }
 
 TelescopeDialog::~TelescopeDialog()
@@ -112,8 +110,8 @@ void TelescopeDialog::createDialogContent()
 
 	//Inherited connect
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	//Connect: sender, signal, receiver, method
 	//Page: Telescopes
@@ -126,25 +124,28 @@ void TelescopeDialog::createDialogContent()
 	//connect(ui->telescopeTreeView, SIGNAL(activated (const QModelIndex &)), this, SLOT(configureTelescope(const QModelIndex &)));
 	
 	//Page: Options:
-	connect(ui->checkBoxReticles, SIGNAL(clicked(bool)),
-	        telescopeManager, SLOT(setFlagTelescopeReticles(bool)));
-	connect(ui->checkBoxLabels, SIGNAL(clicked(bool)),
-	        telescopeManager, SLOT(setFlagTelescopeLabels(bool)));
-	connect(ui->checkBoxCircles, SIGNAL(clicked(bool)),
-	        telescopeManager, SLOT(setFlagTelescopeCircles(bool)));
-	
-	connect(ui->checkBoxEnableLogs, SIGNAL(toggled(bool)), telescopeManager, SLOT(setFlagUseTelescopeServerLogs(bool)));
-	
+	connectBoolProperty(ui->checkBoxReticles,   "TelescopeControl.flagTelescopeReticles");
+	connectBoolProperty(ui->checkBoxLabels,     "TelescopeControl.flagTelescopeLabels");
+	connectBoolProperty(ui->checkBoxCircles,    "TelescopeControl.flagTelescopeCircles");
+	ui->reticleColorButton->setup("TelescopeControl.reticleColor", "TelescopeControl/color_telescope_reticles");
+	ui->labelColorButton  ->setup("TelescopeControl.labelColor",   "TelescopeControl/color_telescope_labels");
+	ui->circleColorButton ->setup("TelescopeControl.circleColor",  "TelescopeControl/color_telescope_circles");
+	connectBoolProperty(ui->checkBoxEnableLogs, "TelescopeControl.useTelescopeServerLogs");
+
 	connect(ui->checkBoxUseExecutables, SIGNAL(toggled(bool)), ui->labelExecutablesDirectory, SLOT(setEnabled(bool)));
 	connect(ui->checkBoxUseExecutables, SIGNAL(toggled(bool)), ui->lineEditExecutablesDirectory, SLOT(setEnabled(bool)));
 	connect(ui->checkBoxUseExecutables, SIGNAL(toggled(bool)), ui->pushButtonPickExecutablesDirectory, SLOT(setEnabled(bool)));
-	connect(ui->checkBoxUseExecutables, SIGNAL(toggled(bool)), this, SLOT(checkBoxUseExecutablesToggled(bool)));
-	
+
 	connect(ui->pushButtonPickExecutablesDirectory, SIGNAL(clicked()), this, SLOT(buttonBrowseServerDirectoryPressed()));
-	
+	//Telescope server directory
+	connectBoolProperty(ui->checkBoxUseExecutables, "TelescopeControl.useTelescopeServerExecutables");
+	ui->lineEditExecutablesDirectory->setText(telescopeManager->getServerExecutablesDirectoryPath());
+
+	connectStringProperty(ui->lineEditExecutablesDirectory, "TelescopeControl.serverExecutablesDirectoryPath");
+
 	//In other dialogs:
 	connect(&configurationDialog, SIGNAL(changesDiscarded()), this, SLOT(discardChanges()));
-	connect(&configurationDialog, SIGNAL(changesSaved(QString, ConnectionType)), this, SLOT(saveChanges(QString, ConnectionType)));
+	connect(&configurationDialog, SIGNAL(changesSaved(QString, TelescopeControl::ConnectionType)), this, SLOT(saveChanges(QString, TelescopeControl::ConnectionType)));
 	
 	//Initialize the style
 	updateStyle();
@@ -160,17 +161,17 @@ void TelescopeDialog::createDialogContent()
 	
 	//Populating the list
 	//Cycle the slots
-	for (int slotNumber = MIN_SLOT_NUMBER; slotNumber < SLOT_NUMBER_LIMIT; slotNumber++)
+	for (int slotNumber = TelescopeControl::MIN_SLOT_NUMBER; slotNumber < TelescopeControl::SLOT_NUMBER_LIMIT; slotNumber++)
 	{
 		//Slot #
 		//int slotNumber = (i+1)%SLOT_COUNT;//Making sure slot 0 is last
 		
 		//Make sure that this is initialized for all slots
-		telescopeStatus[slotNumber] = StatusNA;
+		telescopeStatus[slotNumber] = TelescopeControl::StatusNA;
 		
 		//Read the telescope properties
 		QString name;
-		ConnectionType connectionType;
+		TelescopeControl::ConnectionType connectionType;
 		QString equinox;
 		QString host;
 		int portTCP;
@@ -190,18 +191,18 @@ void TelescopeDialog::createDialogContent()
 			continue;
 		
 		//Determine the server type
-		telescopeType[slotNumber] = connectionType;
+		connectionTypes[slotNumber] = connectionType;
 		
 		//Determine the telescope's status
 		if (telescopeManager->isConnectedClientAtSlot(slotNumber))
 		{
-			telescopeStatus[slotNumber] = StatusConnected;
+			telescopeStatus[slotNumber] = TelescopeControl::StatusConnected;
 		}
 		else
 		{
 			//TODO: Fix this!
 			//At startup everything exists and attempts to connect
-			telescopeStatus[slotNumber] = StatusConnecting;
+			telescopeStatus[slotNumber] = TelescopeControl::StatusConnecting;
 		}
 		
 		addModelRow(slotNumber, connectionType, telescopeStatus[slotNumber], name);
@@ -231,19 +232,10 @@ void TelescopeDialog::createDialogContent()
 	}
 	updateWarningTexts();
 	
-	if(telescopeCount >= SLOT_COUNT)
+	if(telescopeCount >= TelescopeControl::SLOT_COUNT)
 		ui->pushButtonAdd->setEnabled(false);
 	
-	//Checkboxes
-	ui->checkBoxReticles->setChecked(telescopeManager->getFlagTelescopeReticles());
-	ui->checkBoxLabels->setChecked(telescopeManager->getFlagTelescopeLabels());
-	ui->checkBoxCircles->setChecked(telescopeManager->getFlagTelescopeCircles());
-	ui->checkBoxEnableLogs->setChecked(telescopeManager->getFlagUseTelescopeServerLogs());
-	
-	//Telescope server directory
-	ui->checkBoxUseExecutables->setChecked(telescopeManager->getFlagUseServerExecutables());
-	ui->lineEditExecutablesDirectory->setText(telescopeManager->getServerExecutablesDirectoryPath());
-	
+
 	//About page
 	setAboutText();
 	
@@ -257,7 +249,7 @@ void TelescopeDialog::createDialogContent()
 void TelescopeDialog::setAboutText()
 {
 	// Regexp to replace {text} with an HTML link.
-	QRegularExpression a_rx("[{]([^{]*)[}]");
+	static const QRegularExpression a_rx("[{]([^{]*)[}]");
 
 	//TODO: Expand
 	QString aboutPage = "<html><head></head><body>";
@@ -516,13 +508,13 @@ void TelescopeDialog::setAboutText()
 
 void TelescopeDialog::setHeaderNames()
 {
-	QStringList headerStrings;
-	// TRANSLATORS: Symbol for "number"
-	headerStrings << qc_("#", "numero sign");
-	//headerStrings << "Start";
-	headerStrings << q_("Status");
-	headerStrings << q_("Type");
-	headerStrings << q_("Name");
+	const QStringList headerStrings = {
+		// TRANSLATORS: Symbol for "number"
+		qc_("#", "numero sign"),
+		//"Start";
+		q_("Status"),
+		q_("Type"),
+		q_("Name")};
 	telescopeListModel->setHorizontalHeaderLabels(headerStrings);
 }
 
@@ -531,7 +523,7 @@ void TelescopeDialog::updateWarningTexts()
 	QString text;
 	if (telescopeCount > 0)
 	{
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 		QString modifierName = "Command";
 #else
 		QString modifierName = "Ctrl";
@@ -556,53 +548,34 @@ void TelescopeDialog::updateWarningTexts()
 	ui->labelWarning->setText(text);
 }
 
-QString TelescopeDialog::getTypeLabel(ConnectionType type)
+QString TelescopeDialog::getTypeLabel(TelescopeControl::ConnectionType type)
 {
-	QString typeLabel;
-	switch (type)
-	{
-		case ConnectionInternal:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("local, Stellarium");
-			break;
-		case ConnectionLocal:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("local, external");
-			break;
-		case ConnectionRemote:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("remote, unknown");
-			break;
-		case ConnectionVirtual:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("virtual");
-			break;
-		case ConnectionRTS2:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("remote, RTS2");
-			break;
-		case ConnectionINDI:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("remote, INDI/INDIGO");
-			break;
-		case ConnectionASCOM:
-			// TRANSLATORS: Telescope connection type
-			typeLabel = N_("local, ASCOM");
-			break;
-		default:
-			;
-	}
-	return typeLabel;
+	static const QMap<TelescopeControl::ConnectionType, QString>map={
+		// TRANSLATORS: Telescope connection type
+		{ TelescopeControl::ConnectionInternal, N_("local, Stellarium")},
+		// TRANSLATORS: Telescope connection type
+		{ TelescopeControl::ConnectionLocal, N_("local, external")},
+		// TRANSLATORS: Telescope connection type
+		{ TelescopeControl::ConnectionRemote, N_("remote, unknown")},
+		// TRANSLATORS: Telescope connection type
+		{TelescopeControl::ConnectionVirtual, N_("virtual")},
+		// TRANSLATORS: Telescope connection type
+		{TelescopeControl::ConnectionRTS2, N_("remote, RTS2")},
+		// TRANSLATORS: Telescope connection type
+		{TelescopeControl::ConnectionINDI, N_("remote, INDI/INDIGO")},
+		// TRANSLATORS: Telescope connection type
+		{TelescopeControl::ConnectionASCOM, N_("local, ASCOM")}};
+	return map.value(type, "");
 }
 
 void TelescopeDialog::addModelRow(int number,
-                                  ConnectionType type,
-                                  TelescopeStatus status,
-                                  const QString& name)
+				  TelescopeControl::ConnectionType type,
+				  TelescopeControl::TelescopeStatus status,
+				  const QString& name)
 {
 	Q_ASSERT(telescopeListModel);
 	
-	QStandardItem* tempItem = Q_NULLPTR;
+	QStandardItem* tempItem = nullptr;
 	int lastRow = telescopeListModel->rowCount();
 	// Number
 	tempItem = new QStandardItem(QString::number(number));
@@ -619,7 +592,7 @@ void TelescopeDialog::addModelRow(int number,
 	//telescopeListModel->setItem(lastRow, ColumnStartup, tempItem);//Start-up checkbox
 	
 	//Status
-	tempItem = new QStandardItem(q_(statusString[status]));
+	tempItem = new QStandardItem(q_(statusString.value((status))));
 	tempItem->setEditable(false);
 	telescopeListModel->setItem(lastRow, ColumnStatus, tempItem);
 	
@@ -637,9 +610,9 @@ void TelescopeDialog::addModelRow(int number,
 }
 
 void TelescopeDialog::updateModelRow(int rowNumber,
-                                     ConnectionType type,
-                                     TelescopeStatus status,
-                                     const QString& name)
+				     TelescopeControl::ConnectionType type,
+				     TelescopeControl::TelescopeStatus status,
+				     const QString& name)
 {
 	Q_ASSERT(telescopeListModel);
 	if (rowNumber > telescopeListModel->rowCount())
@@ -679,22 +652,22 @@ void TelescopeDialog::configureTelescope(const QModelIndex & currentIndex)
 	configuredSlot = telescopeListModel->data( telescopeListModel->index(currentIndex.row(), ColumnSlot) ).toInt();
 	
 	//Stop the telescope first if necessary
-	if(telescopeType[configuredSlot] != ConnectionInternal && telescopeStatus[configuredSlot] != StatusDisconnected)
+	if(connectionTypes[configuredSlot] != TelescopeControl::ConnectionInternal && telescopeStatus[configuredSlot] != TelescopeControl::StatusDisconnected)
 	{
 		if(telescopeManager->stopTelescopeAtSlot(configuredSlot)) //Act as "Disconnect"
-				telescopeStatus[configuredSlot] = StatusDisconnected;
+			telescopeStatus[configuredSlot] = TelescopeControl::StatusDisconnected;
 		else
 			return;
 	}
-	else if(telescopeStatus[configuredSlot] != StatusStopped)
+	else if(telescopeStatus[configuredSlot] != TelescopeControl::StatusStopped)
 	{
 		if(telescopeManager->stopTelescopeAtSlot(configuredSlot)) //Act as "Stop"
-					telescopeStatus[configuredSlot] = StatusStopped;
+			telescopeStatus[configuredSlot] = TelescopeControl::StatusStopped;
 	}
 	//Update the status in the list
 	int curRow = ui->telescopeTreeView->currentIndex().row();
 	QModelIndex curIndex = telescopeListModel->index(curRow, ColumnStatus);
-	QString string = q_(statusString[telescopeStatus[configuredSlot]]);
+	QString string = q_(statusString.value(telescopeStatus[configuredSlot]));
 	telescopeListModel->setData(curIndex, string, Qt::DisplayRole);
 	
 	setVisible(false);
@@ -713,37 +686,37 @@ void TelescopeDialog::buttonChangeStatusPressed()
 	
 	//TODO: As most of these are asynchronous actions, it looks like that there should be a queue...
 	
-	if(telescopeType[selectedSlot] != ConnectionInternal) 
+	if(connectionTypes[selectedSlot] != TelescopeControl::ConnectionInternal)
 	{
 		//Can't be launched by Stellarium -> can't be stopped by Stellarium
 		//Can be only connected/disconnected
-		if(telescopeStatus[selectedSlot] == StatusDisconnected)
+		if(telescopeStatus[selectedSlot] == TelescopeControl::StatusDisconnected)
 		{
 			if(telescopeManager->startTelescopeAtSlot(selectedSlot)) //Act as "Connect"
-				telescopeStatus[selectedSlot] = StatusConnecting;
+				telescopeStatus[selectedSlot] = TelescopeControl::StatusConnecting;
 		}
 		else
 		{
 			if(telescopeManager->stopTelescopeAtSlot(selectedSlot)) //Act as "Disconnect"
-				telescopeStatus[selectedSlot] = StatusDisconnected;
+				telescopeStatus[selectedSlot] = TelescopeControl::StatusDisconnected;
 		}
 	}
 	else
 	{
 		switch(telescopeStatus[selectedSlot]) //Why the switch?
 		{
-			case StatusNA:
-			case StatusStopped:
+			case TelescopeControl::StatusNA:
+			case TelescopeControl::StatusStopped:
 			{
 				if(telescopeManager->startTelescopeAtSlot(selectedSlot)) //Act as "Start"
-					telescopeStatus[selectedSlot] = StatusConnecting;
+					telescopeStatus[selectedSlot] = TelescopeControl::StatusConnecting;
 			}
 			break;
-			case StatusConnecting:
-			case StatusConnected:
+			case TelescopeControl::StatusConnecting:
+			case TelescopeControl::StatusConnected:
 			{
 				if(telescopeManager->stopTelescopeAtSlot(selectedSlot)) //Act as "Stop"
-					telescopeStatus[selectedSlot] = StatusStopped;
+					telescopeStatus[selectedSlot] = TelescopeControl::StatusStopped;
 			}
 			break;
 			default:
@@ -754,7 +727,7 @@ void TelescopeDialog::buttonChangeStatusPressed()
 	//Update the status in the list
 	int curRow = ui->telescopeTreeView->currentIndex().row();
 	QModelIndex curIndex = telescopeListModel->index(curRow, ColumnStatus);
-	QString string = q_(statusString[telescopeStatus[selectedSlot]]);
+	QString string = q_(statusString.value(telescopeStatus[selectedSlot]));
 	telescopeListModel->setData(curIndex, string, Qt::DisplayRole);
 }
 
@@ -766,16 +739,16 @@ void TelescopeDialog::buttonConfigurePressed()
 
 void TelescopeDialog::buttonAddPressed()
 {
-	if(telescopeCount >= SLOT_COUNT)
+	if(telescopeCount >= TelescopeControl::SLOT_COUNT)
 		return;
 	
 	configuredTelescopeIsNew = true;
 	
 	//Find the first unoccupied slot (there is at least one)
-	for (configuredSlot = MIN_SLOT_NUMBER; configuredSlot < SLOT_NUMBER_LIMIT; configuredSlot++)
+	for (configuredSlot = TelescopeControl::MIN_SLOT_NUMBER; configuredSlot < TelescopeControl::SLOT_NUMBER_LIMIT; configuredSlot++)
 	{
 		//configuredSlot = (i+1)%SLOT_COUNT;
-		if(telescopeStatus[configuredSlot] == StatusNA)
+		if(telescopeStatus[configuredSlot] == TelescopeControl::StatusNA)
 			break;
 	}
 	
@@ -799,19 +772,21 @@ void TelescopeDialog::buttonRemovePressed()
 		if(!telescopeManager->removeTelescopeAtSlot(selectedSlot))
 		{
 			//TODO: Add debug
+			qDebug() << "Cannot remove telescope at slot" << selectedSlot;
 			return;
 		}
 	}
 	else
 	{
 		//TODO: Add debug
+		qDebug() << "Cannot stop telescope at slot" << selectedSlot << ". Rejecting removal.";
 		return;
 	}
 	
 	//Save the changes to file
 	telescopeManager->saveTelescopes();
 	
-	telescopeStatus[selectedSlot] = StatusNA;
+	telescopeStatus[selectedSlot] = TelescopeControl::StatusNA;
 	telescopeCount -= 1;
 	
 //Update the interface to reflect the changes:
@@ -824,7 +799,7 @@ void TelescopeDialog::buttonRemovePressed()
 	telescopeListModel->removeRow(ui->telescopeTreeView->currentIndex().row());
 	
 	//If there are less than the maximal number of telescopes now, new ones can be added
-	if(telescopeCount < SLOT_COUNT)
+	if(telescopeCount < TelescopeControl::SLOT_COUNT)
 		ui->pushButtonAdd->setEnabled(true);
 	
 	//If there are no telescopes left, disable some buttons
@@ -844,35 +819,35 @@ void TelescopeDialog::buttonRemovePressed()
 	updateWarningTexts();
 }
 
-void TelescopeDialog::saveChanges(QString name, ConnectionType type)
+void TelescopeDialog::saveChanges(QString name, TelescopeControl::ConnectionType type)
 {
 	//Save the changes to file
 	telescopeManager->saveTelescopes();
 	
 	//Type and server properties
-	telescopeType[configuredSlot] = type;
+	connectionTypes[configuredSlot] = type;
 	switch (type)
 	{
-		case ConnectionVirtual:
-			telescopeStatus[configuredSlot] = StatusStopped;
+		case TelescopeControl::ConnectionVirtual:
+			telescopeStatus[configuredSlot] = TelescopeControl::StatusStopped;
 			break;
 
-		case ConnectionInternal:
+		case TelescopeControl::ConnectionInternal:
 			if(configuredTelescopeIsNew)
-				telescopeStatus[configuredSlot] = StatusStopped;//TODO: Is there a point? Isn't it better to force the status update method?
+				telescopeStatus[configuredSlot] = TelescopeControl::StatusStopped;//TODO: Is there a point? Isn't it better to force the status update method?
 			break;
 
-		case ConnectionLocal:
-			telescopeStatus[configuredSlot] = StatusDisconnected;
+		case TelescopeControl::ConnectionLocal:
+			telescopeStatus[configuredSlot] = TelescopeControl::StatusDisconnected;
 			break;
 
-		case ConnectionRemote:
+		case TelescopeControl::ConnectionRemote:
 		default:
-			telescopeStatus[configuredSlot] = StatusDisconnected;
+			telescopeStatus[configuredSlot] = TelescopeControl::StatusDisconnected;
 	}
 	
 	//Update the model/list
-	TelescopeStatus status = telescopeStatus[configuredSlot];
+	TelescopeControl::TelescopeStatus status = telescopeStatus[configuredSlot];
 	if(configuredTelescopeIsNew)
 	{
 		addModelRow(configuredSlot, type, status, name);
@@ -887,7 +862,7 @@ void TelescopeDialog::saveChanges(QString name, ConnectionType type)
 	ui->telescopeTreeView->sortByColumn(ColumnSlot, Qt::AscendingOrder);
 	
 	//Can't add more telescopes if they have reached the maximum number
-	if (telescopeCount >= SLOT_COUNT)
+	if (telescopeCount >= TelescopeControl::SLOT_COUNT)
 		ui->pushButtonAdd->setEnabled(false);
 	
 	//
@@ -918,7 +893,7 @@ void TelescopeDialog::discardChanges()
 	configurationDialog.setVisible(false);
 	setVisible(true);//Brings the current window to the foreground
 	
-	if (telescopeCount >= SLOT_COUNT)
+	if (telescopeCount >= TelescopeControl::SLOT_COUNT)
 		ui->pushButtonAdd->setEnabled(false);
 	if (telescopeCount == 0)
 		ui->pushButtonRemove->setEnabled(false);
@@ -935,26 +910,26 @@ void TelescopeDialog::updateTelescopeStates()
 	for (int i=0; i<(telescopeListModel->rowCount()); i++)
 	{
 		slotNumber = telescopeListModel->data( telescopeListModel->index(i, ColumnSlot) ).toInt();
-		//TODO: Check if these cover all possibilites
+		//TODO: Check if these cover all possibilities
 		if (telescopeManager->isConnectedClientAtSlot(slotNumber))
 		{
-			telescopeStatus[slotNumber] = StatusConnected;
+			telescopeStatus[slotNumber] = TelescopeControl::StatusConnected;
 		}
 		else if(telescopeManager->isExistingClientAtSlot(slotNumber))
 		{
-			telescopeStatus[slotNumber] = StatusConnecting;
+			telescopeStatus[slotNumber] = TelescopeControl::StatusConnecting;
 		}
 		else
 		{
-			if(telescopeType[slotNumber] == ConnectionInternal)
-				telescopeStatus[slotNumber] = StatusStopped;
+			if(connectionTypes[slotNumber] == TelescopeControl::ConnectionInternal)
+				telescopeStatus[slotNumber] = TelescopeControl::StatusStopped;
 			else
-				telescopeStatus[slotNumber] = StatusDisconnected;
+				telescopeStatus[slotNumber] = TelescopeControl::StatusDisconnected;
 		}
 		
 		//Update the status in the list
 		QModelIndex index = telescopeListModel->index(i, ColumnStatus);
-		QString statusStr = q_(statusString[telescopeStatus[slotNumber]]);
+		QString statusStr = q_(statusString.value(telescopeStatus[slotNumber]));
 		telescopeListModel->setData(index, statusStr, Qt::DisplayRole);
 	}
 	
@@ -968,11 +943,11 @@ void TelescopeDialog::updateTelescopeStates()
 
 void TelescopeDialog::updateStatusButtonForSlot(int selectedSlot)
 {
-	if(telescopeType[selectedSlot] != ConnectionInternal)
+	if(connectionTypes[selectedSlot] != TelescopeControl::ConnectionInternal)
 	{
 		//Can't be launched by Stellarium => can't be stopped by Stellarium
 		//Can be only connected/disconnected
-		if(telescopeStatus[selectedSlot] == StatusDisconnected)
+		if(telescopeStatus[selectedSlot] == TelescopeControl::StatusDisconnected)
 		{
 			setStatusButtonToConnect();
 			ui->pushButtonChangeStatus->setEnabled(true);
@@ -987,13 +962,13 @@ void TelescopeDialog::updateStatusButtonForSlot(int selectedSlot)
 	{
 		switch(telescopeStatus[selectedSlot])
 		{
-			case StatusNA:
-			case StatusStopped:
+			case TelescopeControl::StatusNA:
+			case TelescopeControl::StatusStopped:
 				setStatusButtonToStart();
 				ui->pushButtonChangeStatus->setEnabled(true);
 				break;
-			case StatusConnected:
-			case StatusConnecting:
+			case TelescopeControl::StatusConnected:
+			case TelescopeControl::StatusConnecting:
 				setStatusButtonToStop();
 				ui->pushButtonChangeStatus->setEnabled(true);
 				break;
@@ -1045,14 +1020,9 @@ void TelescopeDialog::updateStyle()
 	}
 }
 
-void TelescopeDialog::checkBoxUseExecutablesToggled(bool useExecutables)
-{
-	telescopeManager->setFlagUseServerExecutables(useExecutables);
-}
-
 void TelescopeDialog::buttonBrowseServerDirectoryPressed()
 {
-	QString newPath = QFileDialog::getExistingDirectory (Q_NULLPTR, QString(q_("Select a directory")), telescopeManager->getServerExecutablesDirectoryPath());
+	QString newPath = QFileDialog::getExistingDirectory (&StelMainView::getInstance(), QString(q_("Select a directory")), telescopeManager->getServerExecutablesDirectoryPath());
 	//TODO: Validation? Directory exists and contains servers?
 	if(!newPath.isEmpty())
 	{
