@@ -40,8 +40,8 @@ public:
 	//! @param parent the node for the parent menu item
 	//! @param prev the previous node in the current menu (typically shares the same parent)
 	TuiNodeColor(const QString& text, QObject* receiver, const char* method, Vec3f defValue, TuiNode* parent=Q_NULLPTR, TuiNode* prev=Q_NULLPTR);
-	virtual TuiNodeResponse handleEditingKey(int key);
-	virtual QString getDisplayText() const;
+	virtual TuiNodeResponse handleEditingKey(int key) Q_DECL_OVERRIDE;
+	virtual QString getDisplayText() const Q_DECL_OVERRIDE;
 
 signals:
 	void setValue(Vec3f c);
