@@ -44,24 +44,8 @@ void StelLogger::init(const QString& logFilePath)
 	writeLog(QString("Operating System: %1").arg(StelUtils::getOperatingSystemInfo()));	
 
 	// write compiler version
-#if defined __GNUC__ && !defined __clang__ && !defined __INTEL_COMPILER
-	#ifdef __MINGW32__
-		#define COMPILER "MinGW GCC"
-	#else
-		#define COMPILER "GCC"
-	#endif
-	writeLog(QString("Compiled using %1 %2.%3.%4").arg(COMPILER).arg(__GNUC__).arg(__GNUC_MINOR__).arg(__GNUC_PATCHLEVEL__));
-#elif defined __clang__
-	writeLog(QString("Compiled using %1 %2.%3.%4").arg("Clang").arg(__clang_major__).arg(__clang_minor__).arg(__clang_patchlevel__));
-#elif defined __INTEL_COMPILER
-	QString iccVer = QString::number(__INTEL_COMPILER);
-	int iccVL = iccVer.length();
-	writeLog(QString("Compiled using %1 %2.%3.%4.%5").arg("Intel C/C++").arg(iccVer.mid(0, iccVL-2)).arg(iccVer.mid(iccVL-2,1)).arg(iccVer.mid(iccVL-1,1)).arg(__INTEL_COMPILER_BUILD_DATE));
-#elif defined _MSC_VER
-	writeLog(QString("Compiled using %1").arg(getMsvcVersionString(_MSC_VER)));
-#else
-	writeLog("Unknown compiler");
-#endif
+	QString compiler = StelUtils::getCompilerInfo();
+	writeLog(compiler.isEmpty() ? "Unknown compiler" : QString("Compiled using %1").arg(compiler));
 
 	// write Qt version
 	writeLog(QString("Qt runtime version: %1").arg(qVersion()));
@@ -109,7 +93,7 @@ void StelLogger::init(const QString& logFilePath)
 	}
 
 	QProcess lspci;
-	lspci.start("lspci -v", QIODevice::ReadOnly);
+	lspci.start("lspci", { "-v" }, QIODevice::ReadOnly);
 	lspci.waitForFinished(300);
 	const QString pciData(lspci.readAll());
 	#if (QT_VERSION>=QT_VERSION_CHECK(5, 14, 0))
@@ -190,9 +174,9 @@ void StelLogger::init(const QString& logFilePath)
 	if(i == 0)
 		writeLog("Could not get processor info.");
 
-#elif defined Q_OS_MAC
+#elif defined Q_OS_MACOS
 	QProcess systemProfiler;
-	systemProfiler.start("/usr/sbin/system_profiler -detailLevel mini SPHardwareDataType SPDisplaysDataType");
+	systemProfiler.start("/usr/sbin/system_profiler", {"-detailLevel mini SPHardwareDataType SPDisplaysDataType"});
 	systemProfiler.waitForStarted();
 	systemProfiler.waitForFinished();
 	const QString systemData(systemProfiler.readAllStandardOutput());
@@ -226,7 +210,7 @@ void StelLogger::init(const QString& logFilePath)
 
 #elif defined Q_OS_BSD4
 	QProcess dmesg;
-	dmesg.start("/sbin/dmesg", QIODevice::ReadOnly);
+	dmesg.start("/sbin/dmesg", {}, QIODevice::ReadOnly);
 	dmesg.waitForStarted();
 	dmesg.waitForFinished();
 	const QString dmesgData(dmesg.readAll());
@@ -304,36 +288,3 @@ void StelLogger::writeLog(QString msg)
 	log += msg;
 	fileMutex.unlock();
 }
-
-QString StelLogger::getMsvcVersionString(int ver)
-{
-	// Defines for _MSC_VER macro: https://docs.microsoft.com/ru-ru/cpp/preprocessor/predefined-macros?view=msvc-160
-	const QMap<int, QString> map = {
-		{1310, "MSVC++ 7.1 (Visual Studio 2003)"          },
-		{1400, "MSVC++ 8.0 (Visual Studio 2005)"          },
-		{1500, "MSVC++ 9.0 (Visual Studio 2008)"          },
-		{1600, "MSVC++ 10.0 (Visual Studio 2010)"         },
-		{1700, "MSVC++ 11.0 (Visual Studio 2012)"         },
-		{1800, "MSVC++ 12.0 (Visual Studio 2013)"         },
-		{1900, "MSVC++ 14.0 (Visual Studio 2015)"         },
-		{1910, "MSVC++ 15.0 (Visual Studio 2017 RTW)"     },
-		{1911, "MSVC++ 15.3 (Visual Studio 2017)"         },
-		{1912, "MSVC++ 15.5 (Visual Studio 2017)"         },
-		{1913, "MSVC++ 15.6 (Visual Studio 2017)"         },
-		{1914, "MSVC++ 15.7 (Visual Studio 2017)"         },
-		{1915, "MSVC++ 15.8 (Visual Studio 2017)"         },
-		{1916, "MSVC++ 15.9 (Visual Studio 2017)"         },
-		{1920, "MSVC++ 16.0 (Visual Studio 2019 RTW)"     },
-		{1921, "MSVC++ 16.1 (Visual Studio 2019)"         },
-		{1922, "MSVC++ 16.2 (Visual Studio 2019)"         },
-		{1923, "MSVC++ 16.3 (Visual Studio 2019)"         },
-		{1924, "MSVC++ 16.4 (Visual Studio 2019)"         },
-		{1925, "MSVC++ 16.5 (Visual Studio 2019)"         },
-		{1926, "MSVC++ 16.6 (Visual Studio 2019)"         },
-		{1927, "MSVC++ 16.7 (Visual Studio 2019)"         },
-		{1928, "MSVC++ 16.8, 16.9 (Visual Studio 2019)"   },
-		{1929, "MSVC++ 16.10, 16.11 (Visual Studio 2019)" },
-		{1930, "MSVC++ 17.0 (Visual Studio 2022 RTW)"     },
-	};
-	return map.value(ver, "unknown MSVC++ version");
-}
