@@ -19,6 +19,7 @@
 
 #include "StelApp.hpp"
 
+#include "Dithering.hpp"
 #include "StelCore.hpp"
 #include "StelMainView.hpp"
 #include "StelSplashScreen.hpp"
@@ -40,8 +41,8 @@
 #include "SolarSystem.hpp"
 #include "NomenclatureMgr.hpp"
 #include "SporadicMeteorMgr.hpp"
+#include "SpecificTimeMgr.hpp"
 #include "StarMgr.hpp"
-#include "StelIniParser.hpp"
 #include "StelProjector.hpp"
 #include "StelLocationMgr.hpp"
 #include "ToastMgr.hpp"
@@ -52,7 +53,6 @@
 #include "StelLocaleMgr.hpp"
 #include "StelSkyCultureMgr.hpp"
 #include "StelFileMgr.hpp"
-#include "StelJsonParser.hpp"
 #include "StelSkyLayerMgr.hpp"
 #include "StelAudioMgr.hpp"
 #include "StelVideoMgr.hpp"
@@ -80,8 +80,12 @@
 #include <QNetworkDiskCache>
 #include <QNetworkProxy>
 #include <QNetworkReply>
+#include <QOpenGLBuffer>
 #include <QOpenGLContext>
+#include <QOpenGLShaderProgram>
+#include <QOpenGLVertexArrayObject>
 #include <QOpenGLFramebufferObject>
+#include <QOpenGLFunctions_3_3_Core>
 #include <QString>
 #include <QStringList>
 #include <QSysInfo>
@@ -93,8 +97,9 @@
 #include <QScreen>
 #include <QDateTime>
 #include <QRegularExpression>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 #include <QRandomGenerator>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QImageReader>
 #endif
 #ifdef ENABLE_SPOUT
 #include <QMessageBox>
@@ -145,10 +150,18 @@ Q_IMPORT_PLUGIN(TelescopeControlStelPluginInterface)
 Q_IMPORT_PLUGIN(SolarSystemEditorStelPluginInterface)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_LENSDISTORTIONESTIMATOR
+Q_IMPORT_PLUGIN(LensDistortionEstimatorStelPluginInterface)
+#endif
+
 #ifdef USE_STATIC_PLUGIN_METEORSHOWERS
 Q_IMPORT_PLUGIN(MeteorShowersStelPluginInterface)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_MISSINGSTARS
+Q_IMPORT_PLUGIN(MissingStarsStelPluginInterface)
+#endif
+
 #ifdef USE_STATIC_PLUGIN_NAVSTARS
 Q_IMPORT_PLUGIN(NavStarsStelPluginInterface)
 #endif
@@ -225,9 +238,7 @@ void StelApp::deinitStatic()
 *************************************************************************/
 StelApp::StelApp(StelMainView *parent)
 	: QObject(parent)
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 	, randomGenerator(Q_NULLPTR)
-#endif
 	, mainWin(parent)
 	, core(Q_NULLPTR)
 	, moduleMgr(Q_NULLPTR)
@@ -248,7 +259,6 @@ StelApp::StelApp(StelMainView *parent)
 #endif
 	, stelGui(Q_NULLPTR)
 	, devicePixelsPerPixel(1.)
-	, globalScalingRatio(1.f)
 	, fps(0)
 	, frame(0)
 	, frameTimeAccum(0.)
@@ -261,7 +271,7 @@ StelApp::StelApp(StelMainView *parent)
 	, totalDownloadedSize(0)
 	, nbUsedCache(0)
 	, totalUsedCacheSize(0)
-	, screenFontSize(13)
+	, screenFontSize(getDefaultGuiFontSize())
 	, renderBuffer(Q_NULLPTR)
 	, viewportEffect(Q_NULLPTR)
 	, gl(Q_NULLPTR)
@@ -284,8 +294,10 @@ StelApp::StelApp(StelMainView *parent)
 	singleton = this;
 
 	moduleMgr = new StelModuleMgr();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 	randomGenerator = new QRandomGenerator(static_cast<quint32>(QDateTime::currentMSecsSinceEpoch()));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	// QImageReader has a new limitation. For super-large landscapes or other textures, we need to circumvent this.
+	QImageReader::setAllocationLimit(1024); // Allow max texture size 16k x 16k
 #endif
 }
 
@@ -316,9 +328,7 @@ StelApp::~StelApp()
 	delete actionMgr; actionMgr = Q_NULLPTR;
 	delete propMgr; propMgr = Q_NULLPTR;
 	delete renderBuffer; renderBuffer = Q_NULLPTR;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 	delete randomGenerator; randomGenerator=Q_NULLPTR;
-#endif
 	Q_ASSERT(singleton);
 	singleton = Q_NULLPTR;
 }
@@ -331,8 +341,6 @@ void StelApp::setupNetworkProxy()
 	QString proxyPass = confSettings->value("proxy/password").toString();
 	QString proxyType = confSettings->value("proxy/type").toString();
 
-	bool useSocksProxy = proxyType.contains("socks", Qt::CaseInsensitive);
-
 	// If proxy settings not found in config, use environment variable
 	// if it is defined.  (Config file over-rides environment).
 	if (proxyHost.isEmpty() && proxyUser.isEmpty() && proxyPass.isEmpty() && proxyPort.isEmpty())
@@ -359,6 +367,7 @@ void StelApp::setupNetworkProxy()
 				QRegularExpressionMatch preMatch=pre.match(proxyString);
 				if (proxyString.indexOf(pre) >= 0)
 				{
+					proxyType = preMatch.captured(1);
 					proxyUser = preMatch.captured(2);
 					proxyPass = preMatch.captured(3);
 					proxyHost = preMatch.captured(4);
@@ -373,6 +382,8 @@ void StelApp::setupNetworkProxy()
 		}
 	}
 
+	bool useSocksProxy = proxyType.contains("socks", Qt::CaseInsensitive);
+
 	if (!proxyHost.isEmpty())
 	{
 		QNetworkProxy proxy;
@@ -439,14 +450,15 @@ void StelApp::init(QSettings* conf)
 	if (devicePixelsPerPixel>1)
 		qDebug() << "Detected a high resolution device! Device pixel ratio:" << devicePixelsPerPixel;
 
-	setScreenFontSize(confSettings->value("gui/screen_font_size", 13).toInt());
-	setGuiFontSize(confSettings->value("gui/gui_font_size", 13).toInt());
+	setScreenFontSize(confSettings->value("gui/screen_font_size", getDefaultGuiFontSize()).toInt());
+	setGuiFontSize(confSettings->value("gui/gui_font_size", getDefaultGuiFontSize()).toInt());
+	setFlagImmediateSave(confSettings->value("gui/immediate_save_details", false).toBool());
 
 	core = new StelCore();
 	if (!fuzzyEquals(saveProjW, -1.) && !fuzzyEquals(saveProjH, -1.))
 		core->windowHasBeenResized(0, 0, saveProjW, saveProjH);
 	
-	//Initializing locale at the begining to show all strings translated
+	//Initializing locale at the beginning to show all strings translated
 	localeMgr = new StelLocaleMgr();
 	localeMgr->init();
 	//SplashScreen::showMessage(q_("Initializing locales..."));
@@ -466,7 +478,7 @@ void StelApp::init(QSettings* conf)
 	cache->setMaximumCacheSize(confSettings->value("main/network_cache_size",300).toInt() * 1024 * 1024);
 	QString cachePath = StelFileMgr::getCacheDir();
 
-	qDebug() << "Cache directory is: " << QDir::toNativeSeparators(cachePath);
+	qDebug().noquote() << "Cache directory:" << QDir::toNativeSeparators(cachePath);
 	cache->setCacheDirectory(cachePath);
 	networkAccessManager->setCache(cache);	
 	connect(networkAccessManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(reportFileDownloadFinished(QNetworkReply*)));
@@ -576,6 +588,14 @@ void StelApp::init(QSettings* conf)
 	LandscapeMgr* landscape = new LandscapeMgr();
 	landscape->init();
 	getModuleMgr().registerModule(landscape);
+	// Only now we can switch to auto-landscape. (GH:#3550)
+	if (landscape->getFlagLandscapeAutoSelection() && (confSettings->value("init_location/location", "auto").toString() == "auto"))
+	{
+		StelLocation loc=core->getCurrentLocation();
+		QColor color=planetLocationMgr->getColorForCoordinates(loc.getLongitude(), loc.getLatitude());
+		QString landscapeAutoName=QString("ZeroColor(%1)").arg(Vec3f(color).toStr());
+		emit core->targetLocationChanged(loc, landscapeAutoName); // inform others about our next location. E.g., let LandscapeMgr load a new landscape.
+	}
 
 	SplashScreen::showMessage(q_("Initializing grid lines..."));
 	GridLinesMgr* gridLines = new GridLinesMgr();
@@ -614,12 +634,18 @@ void StelApp::init(QSettings* conf)
 	custObj->init();
 	getModuleMgr().registerModule(custObj);
 
-	// Init hightlights
+	// Init highlights
 	SplashScreen::showMessage(q_("Initializing highlights..."));
 	HighlightMgr* hlMgr = new HighlightMgr();
 	hlMgr->init();
 	getModuleMgr().registerModule(hlMgr);
 
+	// Init specific time
+	SplashScreen::showMessage(q_("Initializing specific time..."));
+	SpecificTimeMgr* specificTime = new SpecificTimeMgr();
+	specificTime->init();
+	getModuleMgr().registerModule(specificTime);
+
 	//Create the script manager here, maybe some modules/plugins may want to connect to it
 	//It has to be initialized later after all modules have been loaded by calling initScriptMgr
 #ifdef ENABLE_SCRIPTING
@@ -630,7 +656,7 @@ void StelApp::init(QSettings* conf)
 
 	SplashScreen::showMessage(q_("Initializing color scheme..."));
 	// Initialisation of the color scheme
-	emit colorSchemeChanged("color");
+	emit colorSchemeChanged("default");
 	setVisionModeNight(confSettings->value("viewing/flag_night", false).toBool());
 
 	// Enable viewport effect at startup if he set
@@ -652,6 +678,9 @@ void StelApp::init(QSettings* conf)
 
 	// Animation
 	animationScale = confSettings->value("gui/pointer_animation_speed", 1.).toDouble();
+
+	ditherPatternTex = StelApp::getInstance().getTextureManager().getDitheringTexture(0);
+	setupPostProcessor();
 	
 #ifdef ENABLE_SPOUT
 	//qDebug() << "Property spout is" << qApp->property("spout").toString();
@@ -798,6 +827,218 @@ void StelApp::applyRenderBuffer(GLuint drawFbo)
 	viewportEffect->paintViewportBuffer(renderBuffer);
 }
 
+void StelApp::setupPostProcessor()
+{
+	postProcessorVBO.reset(new QOpenGLBuffer(QOpenGLBuffer::VertexBuffer));
+	postProcessorVBO->create();
+	postProcessorVBO->bind();
+	const GLfloat vertices[]=
+	{
+		// full screen quad
+		-1, -1,
+		 1, -1,
+		-1,  1,
+		 1,  1,
+	};
+	GL(gl->glBufferData(GL_ARRAY_BUFFER, sizeof vertices, vertices, GL_STATIC_DRAW));
+
+	postProcessorVAO.reset(new QOpenGLVertexArrayObject);
+	postProcessorVAO->create();
+	postProcessorVAO->bind();
+	gl->glVertexAttribPointer(0, 2, GL_FLOAT, false, 0, 0);
+	postProcessorVBO->release();
+	gl->glEnableVertexAttribArray(0);
+	postProcessorVAO->release();
+
+	postProcessorProgram.reset(new QOpenGLShaderProgram);
+	postProcessorProgram->addShaderFromSourceCode(QOpenGLShader::Vertex,
+		StelOpenGL::globalShaderPrefix(StelOpenGL::VERTEX_SHADER) + R"(
+ATTRIBUTE vec3 vertex;
+VARYING vec2 texcoord;
+void main()
+{
+	gl_Position = vec4(vertex, 1.);
+	texcoord = 0.5*vertex.xy+0.5;
+}
+)");
+	postProcessorProgram->addShaderFromSourceCode(QOpenGLShader::Fragment,
+		StelOpenGL::globalShaderPrefix(StelOpenGL::FRAGMENT_SHADER) +
+		makeDitheringShader() + R"(
+VARYING vec2 texcoord;
+uniform sampler2D tex;
+
+void main()
+{
+	vec4 rgba = texture2D(tex, texcoord);
+	FRAG_COLOR = vec4(dither(rgba.rgb), rgba.a);
+}
+)");
+	StelPainter::linkProg(postProcessorProgram.get(), "Post-processing program");
+	postProcessorProgram->bind();
+	postProcessorUniformLocations.tex           = postProcessorProgram->uniformLocation("tex");
+	postProcessorUniformLocations.rgbMaxValue   = postProcessorProgram->uniformLocation("rgbMaxValue");
+	postProcessorUniformLocations.ditherPattern = postProcessorProgram->uniformLocation("ditherPattern");
+	postProcessorProgram->release();
+
+	if(StelMainView::getInstance().getGLInformation().isHighGraphicsMode)
+	{
+		postProcessorProgramMS.reset(new QOpenGLShaderProgram);
+		postProcessorProgramMS->addShaderFromSourceCode(QOpenGLShader::Vertex,
+			StelOpenGL::globalShaderPrefix(StelOpenGL::VERTEX_SHADER) + R"(
+ATTRIBUTE vec3 vertex;
+void main()
+{
+	gl_Position = vec4(vertex, 1.);
+}
+)");
+		postProcessorProgramMS->addShaderFromSourceCode(QOpenGLShader::Fragment,
+			StelOpenGL::globalShaderPrefix(StelOpenGL::FRAGMENT_SHADER) +
+			makeDitheringShader() + R"(
+uniform sampler2DMS tex;
+uniform int numMultiSamples;
+
+void main()
+{
+	vec4 rgba = vec4(0);
+	for(int n = 0; n < numMultiSamples; ++n)
+		rgba += texelFetch(tex, ivec2(gl_FragCoord.xy), n);
+	rgba /= float(numMultiSamples);
+	FRAG_COLOR = vec4(dither(rgba.rgb), rgba.a);
+}
+)");
+		StelPainter::linkProg(postProcessorProgramMS.get(), "Multisampled post-processing program");
+		postProcessorProgramMS->bind();
+		postProcessorUniformLocationsMS.tex               = postProcessorProgramMS->uniformLocation("tex");
+		postProcessorUniformLocationsMS.rgbMaxValue       = postProcessorProgramMS->uniformLocation("rgbMaxValue");
+		postProcessorUniformLocationsMS.ditherPattern     = postProcessorProgramMS->uniformLocation("ditherPattern");
+		postProcessorUniformLocationsMS.numMultiSamples   = postProcessorProgramMS->uniformLocation("numMultiSamples");
+		postProcessorProgramMS->release();
+	}
+}
+
+void StelApp::highGraphicsModeDraw()
+{
+#if !QT_CONFIG(opengles2)
+	const auto targetFBO = currentFbo;
+	StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
+	const auto w = params.viewportXywh[2] * params.devicePixelsPerPixel;
+	const auto h = params.viewportXywh[3] * params.devicePixelsPerPixel;
+	StelOpenGL::checkGLErrors(__FILE__, __LINE__);
+	if(!sceneFBO || sceneFBO->size() != QSize(w,h))
+	{
+		qDebug().nospace() << "Creating scene FBO with size " << w << "x" << h;
+		const auto internalFormat = GL_RGBA16;
+		QOpenGLFramebufferObjectFormat format;
+		format.setAttachment(QOpenGLFramebufferObject::CombinedDepthStencil);
+		format.setInternalTextureFormat(internalFormat);
+		sceneFBO.reset(new QOpenGLFramebufferObject(w, h, format));
+		GLint maxSamples = 1;
+		GL(gl->glGetIntegerv(GL_MAX_SAMPLES, &maxSamples));
+		const auto samples = confSettings->value("video/multisampling", 0).toInt();
+		numMultiSamples = std::min(samples, maxSamples);
+		if(numMultiSamples > 1)
+		{
+			const auto gl = StelOpenGL::highGraphicsFunctions();
+			if(sceneMultisampledFBO)
+			{
+				GL(gl->glDeleteFramebuffers(1, &sceneMultisampledFBO));
+				GL(gl->glDeleteTextures(1, &sceneMultisampledTex));
+				GL(gl->glDeleteRenderbuffers(1, &sceneMultisampledRenderbuffer));
+			}
+			GL(gl->glGenFramebuffers(1, &sceneMultisampledFBO));
+			GL(gl->glGenTextures(1, &sceneMultisampledTex));
+			GL(gl->glGenRenderbuffers(1, &sceneMultisampledRenderbuffer));
+
+			GL(gl->glBindTexture(GL_TEXTURE_2D_MULTISAMPLE, sceneMultisampledTex));
+			GL(gl->glTexImage2DMultisample(GL_TEXTURE_2D_MULTISAMPLE, numMultiSamples,
+			                                        internalFormat, w, h, true));
+
+			GL(gl->glBindRenderbuffer(GL_RENDERBUFFER, sceneMultisampledRenderbuffer));
+			GL(gl->glRenderbufferStorageMultisample(GL_RENDERBUFFER, numMultiSamples,
+			                                                 GL_DEPTH24_STENCIL8, w, h));
+
+			GL(gl->glBindFramebuffer(GL_FRAMEBUFFER, sceneMultisampledFBO));
+			GL(gl->glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
+			                              GL_TEXTURE_2D_MULTISAMPLE, sceneMultisampledTex, 0));
+			GL(gl->glFramebufferRenderbuffer(GL_FRAMEBUFFER, GL_DEPTH_STENCIL_ATTACHMENT,
+			                                 GL_RENDERBUFFER, sceneMultisampledRenderbuffer));
+			const auto status = gl->glCheckFramebufferStatus(GL_FRAMEBUFFER);
+			if(status != GL_FRAMEBUFFER_COMPLETE)
+			{
+				qCritical().nospace() << __FILE__ << ":" << __LINE__
+				                      << ": warning: framebuffer incomplete, status: "
+				                      << status;
+			}
+		}
+	}
+
+	if(sceneMultisampledFBO)
+	{
+		GL(gl->glBindFramebuffer(GL_FRAMEBUFFER, sceneMultisampledFBO));
+		currentFbo = sceneMultisampledFBO;
+	}
+	else
+	{
+		sceneFBO->bind();
+		currentFbo = sceneFBO->handle();
+	}
+	StelOpenGL::checkGLErrors(__FILE__, __LINE__);
+
+	GL(gl->glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT));
+
+	const QList<StelModule*> modules = moduleMgr->getCallOrders(StelModule::ActionDraw);
+
+	for(auto* module : modules)
+	{
+		module->draw(core);
+	}
+
+	if(sceneMultisampledFBO)
+	{
+		GL(gl->glBindFramebuffer(GL_FRAMEBUFFER, targetFBO));
+		postProcessorProgramMS->bind();
+
+		const int sceneTexSampler = 0;
+		GL(gl->glActiveTexture(GL_TEXTURE0 + sceneTexSampler));
+		GL(gl->glBindTexture(GL_TEXTURE_2D_MULTISAMPLE, sceneMultisampledTex));
+		postProcessorProgramMS->setUniformValue(postProcessorUniformLocationsMS.tex, sceneTexSampler);
+
+		const int ditherTexSampler = 1;
+		ditherPatternTex->bind(ditherTexSampler);
+		postProcessorProgramMS->setUniformValue(postProcessorUniformLocationsMS.ditherPattern, ditherTexSampler);
+		const auto rgbMaxValue=calcRGBMaxValue(core->getDitheringMode());
+		postProcessorProgramMS->setUniformValue(postProcessorUniformLocationsMS.rgbMaxValue,
+		                                        rgbMaxValue[0], rgbMaxValue[1], rgbMaxValue[2]);
+		postProcessorProgramMS->setUniformValue(postProcessorUniformLocationsMS.numMultiSamples, numMultiSamples);
+	}
+	else
+	{
+		GL(gl->glBindFramebuffer(GL_FRAMEBUFFER, targetFBO));
+		postProcessorProgram->bind();
+
+		const int sceneTexSampler = 0;
+		GL(gl->glActiveTexture(GL_TEXTURE0 + sceneTexSampler));
+		GL(gl->glBindTexture(GL_TEXTURE_2D, sceneFBO->texture()));
+		postProcessorProgram->setUniformValue(postProcessorUniformLocations.tex, sceneTexSampler);
+
+		const int ditherTexSampler = 1;
+		ditherPatternTex->bind(ditherTexSampler);
+		postProcessorProgram->setUniformValue(postProcessorUniformLocations.ditherPattern, ditherTexSampler);
+		const auto rgbMaxValue=calcRGBMaxValue(core->getDitheringMode());
+		postProcessorProgram->setUniformValue(postProcessorUniformLocations.rgbMaxValue,
+		                                      rgbMaxValue[0], rgbMaxValue[1], rgbMaxValue[2]);
+
+	}
+
+	postProcessorVAO->bind();
+	GL(gl->glEnable(GL_BLEND));
+	GL(gl->glBlendFunc(GL_ONE,GL_ONE));
+	GL(gl->glDrawArrays(GL_TRIANGLE_STRIP, 0, 4));
+	GL(gl->glDisable(GL_BLEND));
+	postProcessorVAO->release();
+#endif
+}
+
 //! Main drawing function called at each frame
 void StelApp::draw()
 {
@@ -814,11 +1055,19 @@ void StelApp::draw()
 
 	core->preDraw();
 
-	const QList<StelModule*> modules = moduleMgr->getCallOrders(StelModule::ActionDraw);
-	for (auto* module : modules)
+	if(StelMainView::getInstance().getGLInformation().isHighGraphicsMode)
 	{
-		module->draw(core);
+		highGraphicsModeDraw();
 	}
+	else
+	{
+		const QList<StelModule*> modules = moduleMgr->getCallOrders(StelModule::ActionDraw);
+		for (auto* module : modules)
+		{
+			module->draw(core);
+		}
+	}
+
 	core->postDraw();
 #ifdef ENABLE_SPOUT
 	// At this point, the sky scene has been drawn, but no GUI panels.
@@ -829,7 +1078,7 @@ void StelApp::draw()
 }
 
 /*************************************************************************
- Call this when the size of the GL window has changed
+ Call this when the virtual size of the GL window has changed
 *************************************************************************/
 void StelApp::glWindowHasBeenResized(const QRectF& rect)
 {
@@ -853,6 +1102,19 @@ void StelApp::glWindowHasBeenResized(const QRectF& rect)
 #endif
 }
 
+/*************************************************************************
+ Call this when the physical size of the GL window has changed
+*************************************************************************/
+void StelApp::glPhysicalWindowHasBeenResized(const QRectF& rect)
+{
+#ifdef ENABLE_SPOUT
+	if (spoutSender)
+		spoutSender->resize(static_cast<uint>(rect.width()),static_cast<uint>(rect.height()));
+#else
+	Q_UNUSED(rect)
+#endif
+}
+
 // Handle mouse clics
 void StelApp::handleClick(QMouseEvent* inputEvent)
 {
@@ -923,7 +1185,7 @@ void StelApp::handleKeys(QKeyEvent* event)
 	// First try to trigger a shortcut.
 	if (event->type() == QEvent::KeyPress)
 	{
-		if (getStelActionManager()->pushKey(event->key() + event->modifiers()))
+		if (getStelActionManager()->pushKey(event->key() + int(event->modifiers())))
 		{
 			event->setAccepted(true);
 			return;
@@ -1023,11 +1285,27 @@ Vec3f StelApp::getDaylightInfoColor() const
 	return daylightInfoColor;
 }
 
+void StelApp::setFlagImmediateSave(bool b)
+{
+	if (flagImmediateSave!=b)
+	{
+		flagImmediateSave = b;
+		emit flagImmediateSaveChanged(b);
+	}
+}
+
+void StelApp::immediateSave(const QString &key, const QVariant &value)
+{
+	if (getInstance().getFlagImmediateSave())
+		getInstance().getSettings()->setValue(key, value);
+}
+
+
 // Update translations and font for sky everywhere in the program
 void StelApp::updateI18n()
 {
 #ifdef ENABLE_NLS
-	emit(languageChanged());
+	emit languageChanged();
 #endif
 }
 
@@ -1169,7 +1447,11 @@ void StelApp::setAppFont(QFont font)
 {
 	int oldSize=QGuiApplication::font().pixelSize();
 	font.setPixelSize(oldSize);
+	#if (QT_VERSION>=QT_VERSION_CHECK(5,15,0))
+	font.setStyleHint(QFont::AnyStyle, QFont::PreferAntialias);
+	#else
 	font.setStyleHint(QFont::AnyStyle, QFont::OpenGLCompatible);
+	#endif
 	QGuiApplication::setFont(font);
 	emit fontChanged(font);
 }
