@@ -20,8 +20,13 @@
 #ifndef STELAPP_HPP
 #define STELAPP_HPP
 
+#include <memory>
+#include <qopengl.h>
+#include <qguiapplication.h>
 #include <QString>
 #include <QObject>
+#include <QRandomGenerator>
+#include "StelTextureTypes.hpp"
 #include "StelModule.hpp"
 #include "VecMath.hpp"
 
@@ -35,6 +40,9 @@ class StelMainView;
 class StelSkyCultureMgr;
 class StelViewportEffect;
 class QOpenGLFramebufferObject;
+class QOpenGLVertexArrayObject;
+class QOpenGLShaderProgram;
+class QOpenGLBuffer;
 class QOpenGLFunctions;
 class QSettings;
 class QNetworkAccessManager;
@@ -60,7 +68,7 @@ class SpoutSender;
 //! This is the central class of Stellarium.  Only one singleton instance of
 //! this class is created and can be accessed from anywhere else.  This class
 //! is the access point to several "Manager" class which provide application-wide
-//! services for managment of font, textures, localization, sky culture, and in
+//! services for management of font, textures, localization, sky culture, and in
 //! theory all other services used by the other part of the program.
 //!
 //! The StelApp class is also the one managing the StelModule in a generic manner
@@ -79,11 +87,13 @@ class StelApp : public QObject
 	Q_PROPERTY(Vec3f daylightInfoColor	READ getDaylightInfoColor	WRITE setDaylightInfoColor	 NOTIFY daylightInfoColorChanged)
 	Q_PROPERTY(int  screenFontSize          READ getScreenFontSize          WRITE setScreenFontSize          NOTIFY screenFontSizeChanged)
 	Q_PROPERTY(int  guiFontSize             READ getGuiFontSize             WRITE setGuiFontSize             NOTIFY guiFontSizeChanged)
+	Q_PROPERTY(bool flagImmediateSave       READ getFlagImmediateSave       WRITE setFlagImmediateSave       NOTIFY flagImmediateSaveChanged)
 
-	Q_PROPERTY(QString version READ getVersion)
+	Q_PROPERTY(QString version READ getVersion CONSTANT)
 
 public:
 	friend class StelAppGraphicsWidget;
+	friend class StelMainView;
 	friend class StelRootItem;
 
 	//! Create and initialize the main Stellarium application.
@@ -94,7 +104,7 @@ public:
 	StelApp(StelMainView* parent);
 
 	//! Deinitialize and destroy the main Stellarium application.
-	virtual ~StelApp();
+	virtual ~StelApp() Q_DECL_OVERRIDE;
 
 	//! Initialize core and all the modules.
 	void init(QSettings* conf);
@@ -164,6 +174,13 @@ public:
 	//! @return the StelCore instance of the program
 	StelCore* getCore() const {return core;}
 
+	//! get a pseudo-random integer
+	quint32 getRand() const {Q_ASSERT(randomGenerator); return randomGenerator->generate();}
+	int getRandBounded(int lowest, int highest) const {Q_ASSERT(randomGenerator); return randomGenerator->bounded(lowest, highest);}
+	//! shortcut to retrieve a random float [0...1).
+	float getRandF() const {Q_ASSERT(randomGenerator); return static_cast<float>(randomGenerator->generateDouble());}
+	float getRandFp1() const {Q_ASSERT(randomGenerator); return static_cast<float>(randomGenerator->generate()) / (static_cast<float>(RAND_MAX)+1.f);}
+
 	//! Get the common instance of QNetworkAccessManager used in stellarium
 	QNetworkAccessManager* getNetworkAccessManager() const {return networkAccessManager;}
 
@@ -174,7 +191,12 @@ public:
 	QSettings* getSettings() const {return confSettings;}
 
 	//! Return the currently used style
-	const QString getCurrentStelStyle() const {return "color";}
+	const QString getCurrentStelStyle() const {
+		if (qApp->property("onetime_custom_css").isValid())
+			return qApp->property("onetime_custom_css").toString();
+		else
+			return "default";
+	}
 
 	//! Update all object according to the deltaTime in seconds.
 	void update(double deltaTime);
@@ -189,12 +211,6 @@ public:
 	qreal getDevicePixelsPerPixel() const {return devicePixelsPerPixel;}
 	void setDevicePixelsPerPixel(qreal dppp);
 	
-	//! Get the scaling ratio to apply on all display elements, like GUI, text etc..
-	//! When this ratio is 1, all pixel sizes used in Stellarium will look OK on a regular
-	//! computer screen with 96 pixel per inch (reference for tuning sizes).
-	float getGlobalScalingRatio() const {return globalScalingRatio;}
-	void setGlobalScalingRatio(float r) {globalScalingRatio=r;}
-
 	//! Get the fontsize used for screen text.
 	int getScreenFontSize() const { return screenFontSize; }
 	//! Change screen font size.
@@ -210,7 +226,7 @@ public:
 	//! The caller is responsible for destroying the GUI.
 	void setGui(StelGuiBase* b) {stelGui=b;}
 
-#ifndef DISABLE_SCRIPTING
+#ifdef ENABLE_SCRIPTING
 	//! Get the script API proxy (for signal handling)
 	StelMainScriptAPIProxy* getMainScriptAPIProxy() const {return scriptAPIProxy;}
 	//! Get the script manager
@@ -220,6 +236,10 @@ public:
 	static void initStatic();
 	static void deinitStatic();
 
+	//! Allow immediate storing of config.ini entries.
+	//! Storing only takes place if property StelApp.flagImmediateSave is set.
+	static void immediateSave(const QString &key, const QVariant &value);
+
 	//! Add a progression indicator to the GUI (if applicable).
 	//! @return a controller which can be used to indicate the current status.
 	//! The StelApp instance remains the owner of the controller.
@@ -234,13 +254,18 @@ public:
 
 	//! Dump diagnostics about action call priorities
 	void dumpModuleActionPriorities(StelModule::StelModuleActionName actionName) const;
+
+	static constexpr int getDefaultGuiFontSize() { return 13; }
 	
 	///////////////////////////////////////////////////////////////////////////
 	// Scriptable methods
 public slots:
-	//! Call this when the size of the GL window has changed.
+	//! Call this when the virtual size of the GL window has changed.
 	void glWindowHasBeenResized(const QRectF &rect);
 
+	//! Call this when the physical size of the GL window has changed.
+	void glPhysicalWindowHasBeenResized(const QRectF &rect);
+
 	//! Set flag for activating night vision mode.
 	void setVisionModeNight(bool);
 	//! Get flag for activating night vision mode.
@@ -281,6 +306,11 @@ public slots:
 	//! Get info text color
 	Vec3f getDaylightInfoColor() const;
 
+	//! Set flag for storing some settings immediately
+	void setFlagImmediateSave(bool b);
+	//! Get flag about storing some settings immediately
+	bool getFlagImmediateSave() const {return flagImmediateSave;}
+
 	//! Get the current number of frame per second.
 	//! @return the FPS averaged on the last second
 	float getFps() const {return fps;}
@@ -307,7 +337,7 @@ public slots:
 	//! Return the scaled time for animated objects
 	static double getAnimationTime();
 
-	//! Report that a download occured. This is used for statistics purposes.
+	//! Report that a download occurred. This is used for statistics purposes.
 	//! Connect this slot to QNetworkAccessManager::finished() slot to obtain statistics at the end of the program.
 	void reportFileDownloadFinished(QNetworkReply* reply);
 
@@ -327,6 +357,7 @@ signals:
 	void fontChanged(QFont);
 	void overwriteInfoColorChanged(const Vec3f & color);
 	void daylightInfoColorChanged(const Vec3f & color);
+	void flagImmediateSaveChanged(bool);
 
 	//! Called just after a progress bar is added.
 	void progressBarAdded(const StelProgressController*);
@@ -353,11 +384,17 @@ private:
 	//! @param drawFbo the OpenGL fbo we need to render into.
 	void applyRenderBuffer(quint32 drawFbo=0);
 
+	void setupPostProcessor();
+	void highGraphicsModeDraw();
+
 	QString getVersion() const;
 
 	// The StelApp singleton
 	static StelApp* singleton;
 
+	//! The app-global random number generator
+	QRandomGenerator *randomGenerator;
+
 	//! The main window which is the parent of this object
 	StelMainView* mainWin;
 
@@ -373,7 +410,7 @@ private:
 	// Sky cultures manager for the application
 	StelSkyCultureMgr* skyCultureMgr;
 
-	//Actions manager fot the application.  Will replace shortcutMgr.
+	//Actions manager for the application.  Will replace shortcutMgr.
 	StelActionMgr* actionMgr;
 
 	//Property manager for the application
@@ -402,7 +439,7 @@ private:
 
 	StelSkyLayerMgr* skyImageMgr;
 
-#ifndef DISABLE_SCRIPTING
+#ifdef ENABLE_SCRIPTING
 	// The script API proxy object (for bridging threads)
 	StelMainScriptAPIProxy* scriptAPIProxy;
 
@@ -415,9 +452,6 @@ private:
 	// Store the ratio between real device pixel in "Device Independent Pixel"
 	// Usually this value is 1, but for a mac with retina screen this will be value 2.
 	qreal devicePixelsPerPixel;
-
-	// The scaling ratio to apply on all display elements, like GUI, text etc..
-	float globalScalingRatio;
 	
 	float fps;
 	int frame;
@@ -452,9 +486,32 @@ private:
 	QList<StelProgressController*> progressControllers;
 
 	int screenFontSize;
+	int numMultiSamples = 1;
 
 	// Framebuffer object used for viewport effects.
 	QOpenGLFramebufferObject* renderBuffer;
+	std::unique_ptr<QOpenGLBuffer> postProcessorVBO;
+	std::unique_ptr<QOpenGLVertexArrayObject> postProcessorVAO;
+	std::unique_ptr<QOpenGLShaderProgram> postProcessorProgram;
+	std::unique_ptr<QOpenGLShaderProgram> postProcessorProgramMS; // multisampled
+	std::unique_ptr<QOpenGLFramebufferObject> sceneFBO;
+	GLuint sceneMultisampledFBO = 0;
+	GLuint sceneMultisampledTex = 0;
+	GLuint sceneMultisampledRenderbuffer = 0;
+	StelTextureSP ditherPatternTex;
+	struct PostProcessorUniformLocations
+	{
+		int tex;
+		int ditherPattern;
+		int rgbMaxValue;
+	} postProcessorUniformLocations;
+	struct PostProcessorUniformLocationsMS
+	{
+		int tex;
+		int ditherPattern;
+		int rgbMaxValue;
+		int numMultiSamples;
+	} postProcessorUniformLocationsMS;
 	StelViewportEffect* viewportEffect;
 	QOpenGLFunctions* gl;
 	
@@ -465,6 +522,7 @@ private:
 	bool flagOverwriteInfoColor; // Overwrite and use color for text in info panel
 	Vec3f overwriteInfoColor;
 	Vec3f daylightInfoColor;
+	bool flagImmediateSave;       // set true to allow more immediate-mode settings. For now this is limited to detail settings, e.g. orbit or nomenclature details, DSO filter types, ...
 #ifdef 	ENABLE_SPOUT
 	SpoutSender* spoutSender;
 #endif
