@@ -26,6 +26,7 @@
 #include "StelLocation.hpp"
 #include "StelSkyDrawer.hpp"
 #include "StelPropertyMgr.hpp"
+#include "Dithering.hpp"
 #include <QString>
 #include <QStringList>
 #include <QTime>
@@ -64,6 +65,8 @@ class StelCore : public QObject
 	Q_PROPERTY(QString currentTimeZone READ getCurrentTimeZone WRITE setCurrentTimeZone NOTIFY currentTimeZoneChanged)
 	Q_PROPERTY(bool flagUseCTZ READ getUseCustomTimeZone WRITE setUseCustomTimeZone NOTIFY useCustomTimeZoneChanged)
 	Q_PROPERTY(bool flagUseDST READ getUseDST WRITE setUseDST NOTIFY flagUseDSTChanged)
+	Q_PROPERTY(bool startupTimeStop READ getStartupTimeStop WRITE setStartupTimeStop NOTIFY startupTimeStopChanged)
+	Q_PROPERTY(DitheringMode ditheringMode READ getDitheringMode WRITE setDitheringMode NOTIFY ditheringModeChanged)
 
 public:
 	//! @enum FrameType
@@ -71,13 +74,13 @@ public:
 	enum FrameType
 	{
 		FrameUninitialized,			//!< Reference frame is not set (FMajerech: Added to avoid condition on uninitialized value in StelSkyLayerMgr::draw())
-		FrameAltAz,				//!< Altazimuthal reference frame centered on observer.
-		FrameHeliocentricEclipticJ2000,		//!< Fixed-ecliptic reference frame centered on the Sun. GZ: This is J2000 ecliptical / almost VSOP87.
-		FrameObservercentricEclipticJ2000,	//!< Fixed-ecliptic reference frame centered on the Observer. GZ: was ObservercentricEcliptic, but renamed because it is Ecliptic of J2000!
-		FrameObservercentricEclipticOfDate,	//!< Moving ecliptic reference frame centered on the Observer. GZ new for V0.14: Ecliptic of date, i.e. includes the precession of the ecliptic.
+		FrameAltAz,				//!< Altazimuthal reference frame centered on observer: +x=south, +y=east, +z=zenith.
+		FrameHeliocentricEclipticJ2000,		//!< Fixed-ecliptic reference frame centered on the Sun. This is J2000 ecliptical / almost VSOP87.
+		FrameObservercentricEclipticJ2000,	//!< Fixed-ecliptic reference frame centered on the Observer. Was ObservercentricEcliptic, but renamed because it is Ecliptic of J2000!
+		FrameObservercentricEclipticOfDate,	//!< Moving ecliptic reference frame centered on the Observer. Ecliptic of date, i.e. includes the precession of the ecliptic.
 		FrameEquinoxEqu,			//!< Equatorial reference frame at the current equinox centered on the observer.
 							//!< The north pole follows the precession of the planet on which the observer is located.
-							//!< On Earth, this may include nutation if so configured. Has been corrected for V0.14 to really properly reflect ecliptical motion and precession (Vondrak 2011 model) and nutation.
+							//!< On Earth, this may include nutation if so configured. Models ecliptical motion and precession (Vondrak 2011 model) and nutation.
 		FrameJ2000,				//!< Equatorial reference frame at the J2000 equinox centered on the observer. This is also the ICRS reference frame.
 		FrameFixedEquatorial,			//!< Fixed equatorial frame (hour angle/declination). Note that hour angle is counted backwards here and must be treated specially for user I/O.
 		FrameGalactic,				//!< Galactic reference frame centered on observer.
@@ -99,6 +102,7 @@ public:
 		ProjectionMercator,		//!< Mercator projection
 		ProjectionMiller,		//!< Miller cylindrical projection
 		ProjectionCylinder,		//!< Cylinder projection
+		ProjectionCylinderFill		//!< Cylinder projection, no zoom or movement allowed
 	};
 	Q_ENUM(ProjectionType)
 
@@ -194,7 +198,7 @@ public:
 	//! Get the current StelSkyDrawer used in the core.
 	const StelSkyDrawer* getSkyDrawer() const{return skyDrawer;}
 
-	//! Get an instance of StelGeodesicGrid which is garanteed to allow for at least maxLevel levels
+	//! Get an instance of StelGeodesicGrid which is guaranteed to allow for at least maxLevel levels
 	const StelGeodesicGrid* getGeodesicGrid(int maxLevel) const;
 
 	//! Get the instance of movement manager.
@@ -232,6 +236,7 @@ public:
 	Vec3d altAzToJ2000(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
 	Vec3d j2000ToAltAz(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
 	void j2000ToAltAzInPlaceNoRefraction(Vec3f* v) const {v->transfo4d(matJ2000ToAltAz);}
+	void j2000ToAltAzInPlaceNoRefraction(Vec3d* v) const {v->transfo4d(matJ2000ToAltAz);}
 	Vec3d galacticToJ2000(const Vec3d& v) const;
 	Vec3d supergalacticToJ2000(const Vec3d& v) const;
 	//! Transform position vector v from equatorial coordinates of date (which may also include atmospheric refraction) to those of J2000.
@@ -301,6 +306,9 @@ public:
 
 	//! Return the observer heliocentric ecliptic position (GZ: presumably J2000)
 	Vec3d getObserverHeliocentricEclipticPos() const;
+	//! Return the observer heliocentric ecliptic velocity. This includes orbital and diurnal motion;
+	// diurnal motion is omitted if planetocentric coordinates are in use.
+	Vec3d getObserverHeliocentricEclipticVelocity() const;
 
 	//! Get the information on the current location
 	const StelLocation& getCurrentLocation() const;
@@ -370,7 +378,7 @@ public slots:
 	//! @param duration direction of view move duration in s
 	//! @param durationIfPlanetChange direction of view + planet travel move duration in s.
 	//! This is used only if the destination planet is different from the starting one.
-	void moveObserverTo(const StelLocation& target, double duration=1., double durationIfPlanetChange=1.);
+	void moveObserverTo(const StelLocation& target, double duration=1., double durationIfPlanetChange=1., const QString& landscapeID=QString());
 
 	//! Set the current ProjectionType to use
 	void setCurrentProjectionType(StelCore::ProjectionType type);
@@ -400,7 +408,7 @@ public slots:
 	//! Set the mask type.
 	void setMaskType(StelProjector::StelProjectorMaskType m);
 
-	//! Set the flag with decides whether to arrage labels so that
+	//! Set the flag with decides whether to arrange labels so that
 	//! they are aligned with the bottom of a 2d screen, or a 3d dome.
 	void setFlagGravityLabels(bool gravity);
 	//! return whether dome-aligned labels are in use
@@ -436,7 +444,7 @@ public slots:
 	//! Setting to a negative value will move the visible horizon down, this may be desired esp. in cylindrical projection.
 	//! Animation is available via StelMovementMgr::moveViewport()
 	void setViewportVerticalOffset(double newOffsetPct);
-	// Set both viewport offsets. Arguments will be clamped to be inside [-50...50]. I (GZ) hope this will avoid some of the shaking.
+	// Set both viewport offsets. Arguments will be clamped to be inside [-50...50].
 	void setViewportOffset(double newHorizontalOffsetPct, double newVerticalOffsetPct);
 
 	//! Can be used in specialized setups, intended e.g. for multi-projector installations with edge blending.
@@ -488,6 +496,13 @@ public slots:
 	bool getUseDST() const;
 	void setUseDST(const bool b);
 
+	bool getStartupTimeStop() const;
+	void setStartupTimeStop(const bool b);
+
+	DitheringMode getDitheringMode() const { return ditheringMode; }
+	void setDitheringMode(DitheringMode mode);
+	void setDitheringMode(const QString& modeName);
+
 	bool getUseCustomTimeZone(void) const;
 	void setUseCustomTimeZone(const bool b);
 
@@ -531,6 +546,9 @@ public slots:
 	//! Set aberration factor. Values are clamped to 0...5. (Values above 5 cause graphical problems.)
 	void setAberrationFactor(double factor) { if (!fuzzyEquals(aberrationFactor, factor)) { aberrationFactor=qBound(0.,factor, 5.); emit aberrationFactorChanged(factor); }}
 
+	QByteArray getAberrationShader() const;
+	void setAberrationUniforms(QOpenGLShaderProgram& program) const;
+
 	//! @return whether topocentric coordinates are currently used.
 	bool getUseTopocentricCoordinates() const {return flagUseTopocentricCoordinates;}
 	//! Set whether you want computation and simulation of nutation (a slight wobble of Earth's axis, just a few arcseconds).
@@ -655,8 +673,14 @@ public slots:
 	//! Add one tropical year to the simulation time.
 	void addTropicalYear();
 
-	//! Add one calendric month to the simulation time.
-	void addCalendricMonth();
+	//! Add one calendar month to the simulation time.
+	void addCalendarMonth();
+	//! Add one calendar year to the simulation time.
+	void addCalendarYear();
+	//! Add one calendar decade to the simulation time.
+	void addCalendarDecade();
+	//! Add one calendar century to the simulation time.
+	void addCalendarCentury();
 
 	//! Add one Julian year to the simulation time.
 	void addJulianYear();
@@ -667,42 +691,48 @@ public slots:
 	//! Note that 1 GaussY=2 &pi;/k where k is the Gaussian gravitational constant. A massless body orbits one solar mass in 1AU distance in a Gaussian Year.
 	void addGaussianYear();
 
-	//! Subtract one synodic month to the simulation time.
+	//! Subtract one synodic month from the simulation time.
 	void subtractSynodicMonth();
 
-	//! Subtract one saros (223 synodic months) to the simulation time.
+	//! Subtract one saros (223 synodic months) from the simulation time.
 	void subtractSaros();
 
-	//! Subtract one draconic year to the simulation time.
+	//! Subtract one draconic year from the simulation time.
 	void subtractDraconicYear();
-	//! Subtract one draconic month to the simulation time.
+	//! Subtract one draconic month from the simulation time.
 	void subtractDraconicMonth();
 
-	//! Subtract one anomalistic month to the simulation time.
+	//! Subtract one anomalistic month from the simulation time.
 	void subtractAnomalisticMonth();
-	//! Subtract one anomalistic year to the simulation time.
+	//! Subtract one anomalistic year from the simulation time.
 	void subtractAnomalisticYear();
-	//! Subtract n anomalistic years to the simulation time.
+	//! Subtract n anomalistic years from the simulation time.
 	void subtractAnomalisticYears(double n=100.);
 
-	//! Subtract one mean tropical month to the simulation time.
+	//! Subtract one mean tropical month from the simulation time.
 	void subtractMeanTropicalMonth();
-	//! Subtract one mean tropical year to the simulation time.
+	//! Subtract one mean tropical year from the simulation time.
 	void subtractMeanTropicalYear();
-	//! Subtract n mean tropical years to the simulation time.
+	//! Subtract n mean tropical years from the simulation time.
 	void subtractMeanTropicalYears(double n=100.);
-	//! Subtract one tropical year to the simulation time.
+	//! Subtract one tropical year from the simulation time.
 	void subtractTropicalYear();
 
-	//! Subtract one calendric month to the simulation time.
-	void subtractCalendricMonth();
+	//! Subtract one calendar month from the simulation time.
+	void subtractCalendarMonth();
+	//! Subtract one calendar year from the simulation time.
+	void subtractCalendarYear();
+	//! Subtract one calendar decade from the simulation time.
+	void subtractCalendarDecade();
+	//! Subtract one calendar century from the simulation time.
+	void subtractCalendarCentury();
 
-	//! Subtract one Julian year to the simulation time.
+	//! Subtract one Julian year from the simulation time.
 	void subtractJulianYear();
-	//! Subtract n Julian years to the simulation time.
+	//! Subtract n Julian years from the simulation time.
 	void subtractJulianYears(double n=100.);
 
-	//! Subtract one Gaussian year to the simulation time.
+	//! Subtract one Gaussian year from the simulation time.
 	void subtractGaussianYear();
 
 	//! Add a number of Earth Solar days to the current simulation time
@@ -725,7 +755,7 @@ public slots:
 	void setDeltaTCustomNDot(double v) { deltaTCustomNDot=v; }
 	//! Set coefficients for custom equation for calculation of DeltaT
 	//! @param c the coefficients, e.g. -20,0,32
-	void setDeltaTCustomEquationCoefficients(Vec3d c) { deltaTCustomEquationCoeff=c; }
+	void setDeltaTCustomEquationCoefficients(const Vec3d &c) { deltaTCustomEquationCoeff=c; }
 
 	//! Get central year for custom equation for calculation of DeltaT
 	double getDeltaTCustomYear() const { return deltaTCustomYear; }
@@ -757,7 +787,7 @@ public slots:
 	//! Follows 1987PASP...99..695R: Nancy Roman: Identification of a Constellation from a Position
 	//! Data file from ADC catalog VI/42 with its amendment from 1999-12-30.
 	//! @param positionEqJnow position vector in rectangular equatorial coordinates of current epoch&equinox.
-	QString getIAUConstellation(const Vec3d positionEqJnow) const;
+	QString getIAUConstellation(const Vec3d &positionEqJnow) const;
 
 	//! Returns naked-eye limiting magnitude corresponding to the given sky luminance in cd/m².
 	static float luminanceToNELM(float luminance);
@@ -779,14 +809,17 @@ public slots:
 signals:
 	//! This signal is emitted when the observer location has changed.
 	void locationChanged(const StelLocation&);
-	//! This signal is emitted whenever the targetted location changes
-	void targetLocationChanged(const StelLocation&);
+	//! This signal is emitted whenever the targeted location changes, i.e., at the onset of location transitions.
+	//! The second parameter can transmit a landscapeID or should be QString().
+	void targetLocationChanged(const StelLocation& loc, const QString& id);
 	//! This signal is emitted when the current timezone name is changed.
 	void currentTimeZoneChanged(const QString& tz);
 	//! This signal is emitted when custom timezone use is activated (true) or deactivated (false).
 	void useCustomTimeZoneChanged(const bool b);
 	//! This signal is emitted when daylight saving time is enabled or disabled.
 	void flagUseDSTChanged(const bool b);
+	//! This signal is emitted when stop clock at startup is enabled or disabled.
+	void startupTimeStopChanged(const bool b);
 	//! This signal is emitted when the time rate has changed
 	void timeRateChanged(double rate);
 	//! This signal is emitted whenever the time is re-synced.
@@ -801,7 +834,7 @@ signals:
 	//! This signal is emitted when the date has changed for a month.
 	void dateChangedForMonth();
 	//! This signal is emitted when the date has changed by one year.
-	void dateChangedByYear();
+	void dateChangedByYear(const int year);
 	//! This signal indicates a horizontal display flip
 	void flipHorzChanged(bool b);
 	//! This signal indicates a vertical display flip
@@ -825,10 +858,14 @@ signals:
 	//! Emitted when button "Save settings" is pushed
 	void configurationDataSaved();
 	void updateSearchLists();
+	void ditheringModeChanged(DitheringMode mode);
 
 private slots:
 	//! Call this whenever latitude changes. I.e., just connect it to the locationChanged() signal.
 	void updateFixedEquatorialTransformMatrices();
+private:
+	DitheringMode parseDitheringMode(const QString& s);
+
 private:
 	StelToneReproducer* toneReproducer;		// Tones conversion between stellarium world and display device
 	StelSkyDrawer* skyDrawer;
@@ -892,7 +929,7 @@ private:
 	// Time variables
 	double timeSpeed;           // Positive : forward, Negative : Backward, 1 = 1sec/sec
 	//double JDay;              // Current time in Julian day. IN V0.12 TO V0.14, this was JD in TT, and all places where UT was required had to subtract getDeltaT() explicitly.
-	QPair<double,double> JD;    // From 0.14 on: JD.first=JD_UT, JD.second=DeltaT=TT-UT. To gain JD_TT, compute JDE=JD.first+JD.second or better just call getJDE()
+	QPair<double,double> JD;    // From 0.14 on: JD.first=JD_UT, JD.second=DeltaT[seconds]=(TT-UT)*86400. To gain JD_TT, compute JDE=JD.first+JD.second/86400 or better just call getJDE()
 				    // Use is best with calls getJD()/setJD() and getJDE()/setJDE() to explicitly state which flavour of JD you need.
 	double presetSkyTime;
 	QTime initTodayTime;
@@ -900,16 +937,19 @@ private:
 	qint64 milliSecondsOfLastJDUpdate;    // Time in milliseconds when the time rate or time last changed
 	double jdOfLastJDUpdate;         // JD when the time rate or time last changed
 
+	DitheringMode ditheringMode = DitheringMode::Color888;
+
 	QString currentTimeZone;	
 	bool flagUseDST;
 	bool flagUseCTZ; // custom time zone
+	bool startupTimeStop;
 
 	// Variables for equations of DeltaT
 	Vec3d deltaTCustomEquationCoeff;
 	double deltaTCustomNDot;
 	double deltaTCustomYear;
 	double deltaTnDot; // The currently applied nDot correction. (different per algorithm, and displayed in status line.)
-	bool  deltaTdontUseMoon; // true if the currenctly selected algorithm does not do a lunar correction (?????)
+	bool  deltaTdontUseMoon; // true if the currently selected algorithm does not do a lunar correction (?????)
 	double (*deltaTfunc)(const double JD); // This is a function pointer which must be set to a function which computes DeltaT(JD).
 	int deltaTstart;   // begin year of validity range for the selected DeltaT algorithm. (SET INT_MIN to mark infinite)
 	int deltaTfinish;  // end   year of validity range for the selected DeltaT algorithm. (Set INT_MAX to mark infinite)
