@@ -17,7 +17,6 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#include "StelUtils.hpp"
 
 #include <cstdlib>
 #include <QCoreApplication>
@@ -45,6 +44,7 @@
 QStringList StelFileMgr::fileLocations;
 QString StelFileMgr::userDir;
 QString StelFileMgr::screenshotDir;
+QString StelFileMgr::obsListDir;
 QString StelFileMgr::installDir;
 
 void StelFileMgr::init()
@@ -56,8 +56,11 @@ void StelFileMgr::init()
 	{
 		userDir = winApiPath + "\\Stellarium";
 	}
-#elif defined(Q_OS_MAC)
+#elif defined(Q_OS_MACOS)
 	userDir = QDir::homePath() + "/Library/Application Support/Stellarium";
+#elif defined(Q_OS_HAIKU)
+	// Use system settings dir
+	userDir = QDir::homePath() + "/config/settings/Stellarium";
 #else
 	userDir = QDir::homePath() + "/.stellarium";
 #endif
@@ -69,7 +72,7 @@ void StelFileMgr::init()
 	}
 #else
 	QByteArray userDirCand=qgetenv("STEL_USERDIR");
-	if (userDirCand.length()>0)
+	if (!userDirCand.isEmpty())
 	{
 		userDir=QString::fromLocal8Bit(userDirCand);
 	}
@@ -101,7 +104,7 @@ void StelFileMgr::init()
 	}	
 	else
 	{
-	#if defined(Q_OS_MAC)
+	#if defined(Q_OS_MACOS)
 		QString relativePath = "/../Resources";
 		if (QCoreApplication::applicationDirPath().contains("src")) {
 			relativePath = "/../..";
@@ -208,7 +211,7 @@ QString StelFileMgr::findFile(const QString& path, Flags flags)
 	// explicitly specified relative paths
 	if (path[0] == '.')
 	{
-		if (fileFlagsCheck(path, flags))
+		if (fileFlagsCheck(QFileInfo(path), flags))
 			return path;
 		else
 		{
@@ -220,7 +223,7 @@ QString StelFileMgr::findFile(const QString& path, Flags flags)
 	// explicitly specified absolute paths
 	if (isAbsolute(path))
 	{
-		if (fileFlagsCheck(path, flags))
+		if (fileFlagsCheck(QFileInfo(path), flags))
 			return path;
 		else
 		{
@@ -229,7 +232,7 @@ QString StelFileMgr::findFile(const QString& path, Flags flags)
 		}
 	}
 	
-	for (const auto& i : qAsConst(fileLocations))
+	for (const auto& i : std::as_const(fileLocations))
 	{
 		const QFileInfo finfo(i + "/" + path);
 		if (fileFlagsCheck(finfo, flags))
@@ -258,7 +261,7 @@ QStringList StelFileMgr::findFileInAllPaths(const QString &path, const Flags &fl
 	// explicitly specified relative paths
 	if (path[0] == '.')
 	{
-		if (fileFlagsCheck(path, flags))
+		if (fileFlagsCheck(QFileInfo(path), flags))
 			filePaths.append(path);
 		return filePaths;
 	}
@@ -266,12 +269,12 @@ QStringList StelFileMgr::findFileInAllPaths(const QString &path, const Flags &fl
 	// explicitly specified absolute paths
 	if ( isAbsolute(path) )
 	{
-		if (fileFlagsCheck(path, flags))
+		if (fileFlagsCheck(QFileInfo(path), flags))
 			filePaths.append(path);
 		return filePaths;
 	}
 
-	for (const auto& locationPath : qAsConst(fileLocations))
+	for (const auto& locationPath : std::as_const(fileLocations))
 	{
 		const QFileInfo finfo(locationPath + "/" + path);
 		if (fileFlagsCheck(finfo, flags))
@@ -290,10 +293,10 @@ QSet<QString> StelFileMgr::listContents(const QString& path, const StelFileMgr::
 		QSet<QString> dirs = listContents(path, Directory, false);
 		result = listContents(path, flags, false); // root
 		// add results for each sub-directory
-		for (const auto& d : qAsConst(dirs))
+		for (const auto& d : std::as_const(dirs))
 		{
 			QSet<QString> subDirResult = listContents(path + "/" + d, flags, true);
-			for (const auto& r : qAsConst(subDirResult))
+			for (const auto& r : std::as_const(subDirResult))
 			{
 				result.insert(d + "/" + r);
 			}
@@ -305,7 +308,7 @@ QSet<QString> StelFileMgr::listContents(const QString& path, const StelFileMgr::
 	// we append relative paths to the search paths maintained by this class.
 	QStringList listPaths = QFileInfo(path).isAbsolute() ? QStringList("/") : fileLocations;
 
-	for (const auto& li : qAsConst(listPaths))
+	for (const auto& li : std::as_const(listPaths))
 	{
 		QFileInfo thisPath(QDir(li).filePath(path));
 		if (!thisPath.isDir())
@@ -458,6 +461,18 @@ void StelFileMgr::setScreenshotDir(const QString& newDir)
 	screenshotDir = userDirFI.filePath();
 }
 
+QString StelFileMgr::getObsListDir()
+{
+	return obsListDir;
+}
+
+void StelFileMgr::setObsListDir(const QString& newDir)
+{
+	makeSureDirExistsAndIsWritable(newDir);
+	QFileInfo userDirFI(newDir);
+	obsListDir = userDirFI.filePath();
+}
+
 QString StelFileMgr::getLocaleDir()
 {
 #ifdef ENABLE_NLS
@@ -469,7 +484,7 @@ QString StelFileMgr::getLocaleDir()
 	else
 	{
 		// If not found, try to look in the standard build directory (useful for developer)
-		localePath = QCoreApplication::applicationDirPath() + "/../translations";
+		localePath = QFileInfo(QCoreApplication::applicationDirPath() + QString("/../translations"));
 		if (localePath.exists())
 		{
 			return localePath.filePath();
