@@ -62,7 +62,7 @@ public:
 	//! @param url The location of the survey.
 	//! @param releaseDate If known the UTC JD release date of the survey.  Used for cache busting.
 	HipsSurvey(const QString& url, double releaseDate=0.0);
-	virtual ~HipsSurvey();
+	virtual ~HipsSurvey() Q_DECL_OVERRIDE;
 
 	//! Get whether the survey is visible.
 	bool isVisible() const;
@@ -124,12 +124,13 @@ private:
 	int getPropertyInt(const QString& key, int fallback = 0);
 	bool getAllsky();
 	HipsTile* getTile(int order, int pix);
+	// draw a single tile. observerVelocity (in the correct hipsFrame) is necessary for aberration correction. Set to 0 for no aberration correction.
 	void drawTile(int order, int pix, int drawOrder, int splitOrder, bool outside,
-				  const SphericalCap& viewportShape, StelPainter* sPainter, DrawCallback callback);
+				  const SphericalCap& viewportShape, StelPainter* sPainter, Vec3d observerVelocity, DrawCallback callback);
 
 	// Fill the array for a given tile.
 	int fillArrays(int order, int pix, int drawOrder, int splitOrder,
-				   bool outside, StelPainter* sPainter,
+				   bool outside, StelPainter* sPainter, Vec3d observerVelocity,
 				   QVector<Vec3d>& verts, QVector<Vec2f>& tex, QVector<uint16_t>& indices);
 
 	void updateProgressBar(int nb, int total);
