@@ -20,7 +20,6 @@
 #include "StelLocaleMgr.hpp"
 #include "StelApp.hpp"
 #include "StelUtils.hpp"
-#include "StelFileMgr.hpp"
 
 #include <QLocale>
 #include <QDebug>
@@ -74,12 +73,12 @@ void StelLocaleMgr::setAppLanguage(const QString& newAppLanguageName, bool refre
 	Q_ASSERT(StelTranslator::globalTranslator);
 	delete StelTranslator::globalTranslator;
 	StelTranslator::globalTranslator = new StelTranslator("stellarium", newAppLanguageName);
-	qDebug() << "Application language is " << StelTranslator::globalTranslator->getTrueLocaleName();
+	qDebug().noquote() << "Application language:" << StelTranslator::globalTranslator->getTrueLocaleName();
 
 	delete scriptsTranslator;
 	// Update the translator with new locale name
 	scriptsTranslator = new StelTranslator("stellarium-scripts", newAppLanguageName);
-	qDebug() << "Scripts language is " << scriptsTranslator->getTrueLocaleName();
+	qDebug().noquote() << "Scripts language:" << scriptsTranslator->getTrueLocaleName();
 
 	createNameLists();
 	if (refreshAll)
@@ -99,12 +98,12 @@ void StelLocaleMgr::setSkyLanguage(const QString& newSkyLanguageName, bool refre
 	delete skyTranslator;
 	// Update the translator with new locale name
 	skyTranslator = new StelTranslator("stellarium-skycultures", newSkyLanguageName);
-	qDebug() << "Sky language is " << skyTranslator->getTrueLocaleName();
+	qDebug().noquote() << "Sky language:" << skyTranslator->getTrueLocaleName();
 
 	delete planetaryFeaturesTranslator;
 	// Update the translator with new locale name
 	planetaryFeaturesTranslator = new StelTranslator("stellarium-planetary-features", newSkyLanguageName);
-	qDebug() << "Planetary features language is " << planetaryFeaturesTranslator->getTrueLocaleName();
+	qDebug().noquote() << "Planetary features language:" << planetaryFeaturesTranslator->getTrueLocaleName();
 
 	if (refreshAll)
 		StelApp::getInstance().updateI18n();
@@ -147,7 +146,7 @@ const StelTranslator& StelLocaleMgr::getScriptsTranslator() const
 // Return the time in ISO 8601 format that is : %Y-%m-%d %H:%M:%S
 QString StelLocaleMgr::getISO8601TimeLocal(double JD) const
 {
-	return StelUtils::julianDayToISO8601String(JD + core->getUTCOffset(JD)*0.041666666666);
+	return StelUtils::julianDayToISO8601String(JD + core->getUTCOffset(JD)*StelCore::JD_HOUR);
 }
 
 //! get the six ints from an ISO8601 date time, understood to be local time, make a jdate out
@@ -161,16 +160,16 @@ double StelLocaleMgr::getJdFromISO8601TimeLocal(const QString& t, bool* ok) cons
 		return 0.0;
 	}
 
-	jd -= core->getUTCOffset(jd)*0.041666666666;
+	jd -= core->getUTCOffset(jd)*StelCore::JD_HOUR;
 	return jd;
 }
 
 
-// Return a string with the local date formated according to the dateFormat variable
+// Return a string with the local date formatted according to the dateFormat variable
 QString StelLocaleMgr::getPrintableDateLocal(double JD) const
 {
 	int year, month, day, dayOfWeek;
-	const double shift = core->getUTCOffset(JD)*0.041666666666;
+	const double shift = core->getUTCOffset(JD)*StelCore::JD_HOUR;
 	StelUtils::getDateFromJulianDay(JD+shift, &year, &month, &day);
 	dayOfWeek = StelUtils::getDayOfWeek(year, month, day);
 	QString str;
@@ -204,12 +203,12 @@ QString StelLocaleMgr::getPrintableDateLocal(double JD) const
 	return str;
 }
 
-// Return a string with the local time (according to timeZoneMode variable) formated
+// Return a string with the local time (according to timeZoneMode variable) formatted
 // according to the timeFormat variable
 QString StelLocaleMgr::getPrintableTimeLocal(double JD) const
 {
 	int hour, minute, second, millsec;
-	const double shift = core->getUTCOffset(JD)*0.041666666666;
+	const double shift = core->getUTCOffset(JD)*StelCore::JD_HOUR;
 	StelUtils::getTimeFromJulianDay(JD+shift, &hour, &minute, &second, &millsec);
 	QTime t(hour, minute, second, millsec);
 	switch (timeFormat)
@@ -222,7 +221,12 @@ QString StelLocaleMgr::getPrintableTimeLocal(double JD) const
 			return t.toString("hh:mm:ss AP");
 		default:
 			qWarning() << "WARNING: unknown time format, fallback to system default";
+
+#if (QT_VERSION>=QT_VERSION_CHECK(5,14,0))
+			return t.toString(QLocale().dateFormat(QLocale::ShortFormat));
+#else
 			return t.toString(Qt::DefaultLocaleShortDate);
+#endif
 	}
 }
 
