@@ -24,6 +24,11 @@
 #include <QObject>
 #include <QMetaType>
 #include <QMap>
+#include <QImage>
+#ifdef Q_OS_WIN
+#include <QtPositioning/QGeoPositionInfoSource>
+#endif
+#include "VecMath.hpp"
 
 typedef QList<StelLocation> LocationList;
 typedef QMap<QString,StelLocation> LocationMap;
@@ -87,20 +92,40 @@ public:
 	bool deleteUserLocation(const QString& id);
 
 	//! Find list of locations within @param radiusDegrees of selected (usually screen-clicked) coordinates.
-	LocationMap pickLocationsNearby(const QString planetName, const float longitude, const float latitude, const float radiusDegrees);
+	LocationMap pickLocationsNearby(const QString& planetName, const float longitude, const float latitude, const float radiusDegrees);
 	//! Find list of locations in a particular region only.
-	LocationMap pickLocationsInRegion(const QString region);
+	LocationMap pickLocationsInRegion(const QString& region);
 
 	//! return a QStringList of region names by planet (return all list of regions if planet name is empty)
 	QStringList getRegionNames(const QString& planet = "") const;
 
 	//! Pick region name from ISO 3166-1 two-letter country codes
-	static QString pickRegionFromCountryCode(const QString countryCode);
+	static QString pickRegionFromCountryCode(const QString& countryCode);
 	//! Pick region name from country English name
-	static QString pickRegionFromCountry(const QString country);
+	static QString pickRegionFromCountry(const QString& country);
 	//! Pick region name from region code
 	static QString pickRegionFromCode(int regionCode);
 
+	//! Compute UTM coordinates including convergence angle from geographic coordinates (WGS84).
+	//! https://en.wikipedia.org/wiki/Universal_Transverse_Mercator_coordinate_system
+	//! @arg longitude geographic longitude from Greenwich, degrees [-180...+180]
+	//! @arg latitude geographic latitude from equator, degrees. UTM defined for [-80...+84]
+	//! @arg zone UTM zone. If 0, compute best-fit zone.
+	//! @return {{E[m], N[m], zone}, {gamma[rad], k}}
+	//! The returned zone contains the input or, if input was 0 (or missing), the best-fitting zone. North or South is not returned but is trivially found from latitude.
+	static QPair<Vec3d,Vec2d> geo2utm(const double longitude, const double latitude, const int zone=0);
+	//! Compute geographical coordinates (WGS84) from UTM
+	//! https://en.wikipedia.org/wiki/Universal_Transverse_Mercator_coordinate_system
+	//! @arg easting (metres). False Easting of Zone meridian = 500000
+	//! @arg northing (metres). For southern latitudes, equator = 10000000
+	//! @arg zone UTM zone (longitudinal).
+	//! @arg north true for N, false for S latitude zones.
+	//! @return {{longitude[deg], latitude[deg], refLong[deg]}, {gamma[rad], k}}
+	static QPair<Vec3d,Vec2d> utm2geo(const double easting, const double northing, const int zone, const bool north);
+	//! Find UTM zone designation. The letters are usually not important for finding the coordinates.
+	//! This works for the whole globe, even for polar zones, and observes the adjusted zones of Svalbard and Norway.
+	static QPair<int, QChar>utmZone(const double longitude, const double latitude);
+
 public slots:
 	//! Return the StelLocation for a given string
 	//! Can match location name, or coordinates
@@ -112,6 +137,9 @@ public slots:
 	//! return a QStringList of valid timezone names in Stellarium's location database.
 	QStringList getAllTimezoneNames() const;
 
+	//! Retrieve a color from coordinate lookup into the current planet texture (or specialized earth map)
+	QColor getColorForCoordinates(const double lng, const double lat) const;
+
 #ifdef ENABLE_GPS
 	//! Try to get a location from GPS lookup.
 	//! This prefers GPSD on non-Windows platforms, and uses Qt positioning with a NMEA serial device otherwise
@@ -147,9 +175,14 @@ signals:
 private slots:
 	//! Process answer from online lookup of IP address
 	void changeLocationFromNetworkLookup();
+	//! To be connected from StelCore::locationChanged(loc)
+	void changePlanetMapForLocation(StelLocation loc);
 #ifdef ENABLE_GPS
 	void changeLocationFromGPSQuery(const StelLocation& loc);
 	void gpsQueryError(const QString& err);
+	#ifdef Q_OS_WIN
+	void positionUpdated(QGeoPositionInfo gpsPos);
+	#endif
 #endif
 private:
 	void loadRegions();
@@ -179,7 +212,16 @@ private:
 	
 	StelLocation lastResortLocation;
 
+	//! Used to sample a color from our current planet's surface map.
+	//! This must be kept in-sync with the map shown in the LocationDialog.
+	QImage planetSurfaceMap;
+	//! Auxiliary to the surface map. This tracks whether we actually have to load a new image.
+	QString planetName;
+
 	GPSLookupHelper *nmeaHelper,*libGpsHelper;
+#ifdef Q_OS_WIN
+	QGeoPositionInfoSource *positionSource=Q_NULLPTR;
+#endif
 };
 
 #endif // STELLOCATIONMGR_HPP
