@@ -22,8 +22,9 @@
 #define STELMOVEMENTMGR_HPP
 
 #include "StelModule.hpp"
-#include "StelProjector.hpp"
 #include "StelObjectType.hpp"
+#include "VecMath.hpp"
+#include "StelCore.hpp"
 #include <QTimeLine>
 #include <QTimer>
 #include <QCursor>
@@ -99,6 +100,10 @@ class StelMovementMgr : public StelModule
 		   READ getUserMaxFov
 		   WRITE setUserMaxFov
 		   NOTIFY userMaxFovChanged)
+	Q_PROPERTY(double currentFov
+		   READ getCurrentFov
+		   WRITE setFov
+		   NOTIFY currentFovChanged)
 public:
 	//! Possible mount modes defining the reference frame in which head movements occur.
 	//! MountGalactic and MountSupergalactic is currently only available via scripting API: core.clear("galactic") and core.clear("supergalactic")
@@ -175,7 +180,10 @@ public:
 	void moveToObject(const StelObjectP& target, float moveDuration = 1., ZoomingMode zooming = ZoomNone);
 
 public slots:
-	// UNUSED!
+	//! load and process initial viewing position. Can be called later to restore original "default" view.
+	void resetInitViewPos();
+
+	// UNUSED, but scriptable
 	//! Toggle current mount mode between equatorial and altazimuthal
 	void toggleMountMode() {if (getMountMode()==MountAltAzimuthal) setMountMode(MountEquinoxEquatorial); else setMountMode(MountAltAzimuthal);}
 	//! Define whether we should use equatorial mount or altazimuthal
@@ -204,9 +212,9 @@ public slots:
 	//! @return the number of seconds it takes for an auto-move operation to complete.
 	float getAutoMoveDuration(void) const {return autoMoveDuration;}
 
-	//! Set whether auto zoom out will reset the viewing direction to the inital value
+	//! Set whether auto zoom out will reset the viewing direction to the initial value
 	void setFlagAutoZoomOutResetsDirection(bool b) {if (flagAutoZoomOutResetsDirection != b) { flagAutoZoomOutResetsDirection = b; emit flagAutoZoomOutResetsDirectionChanged(b);}}
-	//! Get whether auto zoom out will reset the viewing direction to the inital value
+	//! Get whether auto zoom out will reset the viewing direction to the initial value
 	bool getFlagAutoZoomOutResetsDirection(void) const {return flagAutoZoomOutResetsDirection;}
 
 	//! Get whether keys can control zoom
@@ -249,7 +257,7 @@ public slots:
 	//! StelMovementMgr* mvmgr = GETSTELMODULE(StelMovementMgr);
 	//! mvmgr->moveToJ2000(pos, mvmgr->mountFrameToJ2000(Vec3d(0., 0., 1.)), mvmgr->getAutoMoveDuration());
 	//! @endcode
-	//! @note core::moveToRaDecJ2000 provides a simpler signature for the same function.
+	//! @note The scripting function StelMainScriptAPI::moveToRaDecJ2000() (scripting object core.moveToRaDecJ2000()) provides a simpler signature for the same function.
 	//! @note Objects of class Vec3d are 3-dimensional vectors in a rectangular coordinate system. For
 	//!       J2000 positions, the x-axis points to 0h,0°, the y-axis to 6h,0° and the z-axis points to the
 	//!       celestial pole. You may use a constructor defining three components (x,y,z) or the
@@ -435,7 +443,7 @@ public slots:
 	//! this will avoid any unwanted tracking.
 	void setInhibitAllAutomoves(bool inhibit) { flagInhibitAllAutomoves=inhibit;}
 
-	//! Returns the targetted value of the viewport offset
+	//! Returns the targeted value of the viewport offset
 	Vec2d getViewportOffsetTarget() const { return targetViewportOffset; }
 	double getViewportHorizontalOffsetTarget() const { return targetViewportOffset[0]; }
 	double getViewportVerticalOffsetTarget() const { return targetViewportOffset[1]; }
@@ -448,6 +456,16 @@ public slots:
 	void setUserMaxFov(double max);
 	double getUserMaxFov() const {return userMaxFov; }
 
+	void setFov(double f)
+	{
+		if (core->getCurrentProjectionType()==StelCore::ProjectionCylinderFill)
+			currentFov=180.0;
+		else
+			currentFov=qBound(minFov, f, maxFov);
+
+		emit currentFovChanged(currentFov);
+	}
+
 signals:
 	//! Emitted when the tracking property changes
 	void flagTrackingChanged(bool b);
@@ -461,6 +479,7 @@ signals:
 	void flagEnableMoveKeysChanged(bool b);
 	void flagEnableZoomKeysChanged(bool b);
 	void userMaxFovChanged(double fov);
+	void currentFovChanged(double fov);
 
 private slots:
 	//! Called when the selected object changes.
@@ -479,10 +498,10 @@ private:
 	double maxFov;     // Maximum FOV in degrees. Depends on projection.
 	double userMaxFov; // Custom setting. Can be useful in a planetarium context.
 	double deltaFov;   // requested change of FOV (degrees) used during zooming.
-	void setFov(double f)
-	{
-		currentFov=qBound(minFov, f, maxFov);
-	}
+	StelCore* core;          // The core on which the movement are applied
+	QSettings* conf;
+	class StelObjectMgr* objectMgr;
+
 	// immediately add deltaFov argument to FOV - does not change private var.
 	void changeFov(double deltaFov);
 
@@ -494,9 +513,6 @@ private:
 	//! Make the first screen position correspond to the second (useful for mouse dragging and also time dragging.)
 	void dragView(int x1, int y1, int x2, int y2);
 
-	StelCore* core;          // The core on which the movement are applied
-	QSettings* conf;
-	class StelObjectMgr* objectMgr;
 	bool flagLockEquPos;     // Define if the equatorial position is locked
 	bool flagTracking;       // Define if the selected object is followed
 	bool flagInhibitAllAutomoves; // Required for special installations: If true, there is no automatic centering etc.
@@ -532,6 +548,8 @@ private:
 		Vec3d aim;
 		Vec3d startUp; // The Up vector at start time
 		Vec3d aimUp;   // The Up vector at end time of move
+		Vec3d aimUpCopy;   // The Up vector at end time of move. This gets initialized when the move is configured, never touched during move,
+				   // and ONLY read again when the move is finished and ends in the pole of the view frame.
 		float speed;   // set to 1/duration[ms] during automove setup.
 		float coef;    // Set to 0 at begin of an automove, runs up to 1.
 		// If not null, move to the object instead of the aim.
