@@ -18,9 +18,9 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#include "StelApp.hpp"
+//#include "StelApp.hpp"
 #include "StelOBJ.hpp"
-#include "StelTextureMgr.hpp"
+//#include "StelTextureMgr.hpp"
 #include "StelUtils.hpp"
 
 #include <QBuffer>
@@ -48,7 +48,7 @@ void StelOBJ::clear()
 	*this = StelOBJ();
 }
 
-bool StelOBJ::load(const QString& filename, const VertexOrder vertexOrder)
+bool StelOBJ::load(const QString& filename, const VertexOrder vertexOrder, const bool forceCreateNormals)
 {
 	qCDebug(stelOBJ)<<"Loading"<<filename;
 
@@ -87,11 +87,11 @@ bool StelOBJ::load(const QString& filename, const VertexOrder vertexOrder)
 		buf.open(QIODevice::ReadOnly);
 
 		//perform actual load
-		return load(buf,fi.canonicalPath(),vertexOrder);
+		return load(buf,fi.canonicalPath(),vertexOrder, forceCreateNormals);
 	}
 
 	//perform actual load
-	return load(file,fi.canonicalPath(),vertexOrder);
+	return load(file,fi.canonicalPath(),vertexOrder, forceCreateNormals);
 }
 
 //macro to test out different ways of comparison and their performance
@@ -114,7 +114,7 @@ bool StelOBJ::parseBool(const ParseParams &params, bool &out, int paramsStart)
 	}
 
 
-	const QStringRef& cmd = params.at(paramsStart);
+	const ParseParam& cmd = params.at(paramsStart);
 	out = (CMD_CMP("1") || CMD_CMP("true") || CMD_CMP("TRUE") || CMD_CMP("yes") || CMD_CMP("YES"));
 
 	return true;
@@ -302,23 +302,27 @@ bool StelOBJ::parseFace(const ParseParams& params, const V3Vec& posList, const V
 
 	int vtxAmount = params.size()-1;
 
-	//parse each one seperately
+	//parse each one separately
 	int mode = 0;
 	bool ok = false;
 	//a macro for consistency check
 	#define CHK_MODE(a) if(mode && mode!=a) { qCCritical(stelOBJ)<<"Inconsistent face statement"<<params; return false; } else {mode = a;}
-	//a macro for checking number pasing
+	//a macro for checking number parsing
 	#define CHK_OK(a) do{ a; if(!ok) { qCCritical(stelOBJ)<<"Could not parse number in face statement"<<params; return false; } } while(0)
 	//negative indices indicate relative data, i.e. -1 would mean the last position/texture/normal that was parsed
 	//this macro fixes it up so that it always uses absolute numbers
 	//note: the indices start with 1, this is fixed up later
 	#define FIX_REL(a, list) if(a<0) {a += list.size()+1; }
 
-	//loop to parse each section seperately
+	//loop to parse each section separately
 	for(int i =0; i<vtxAmount;++i)
 	{
 		//split on slash
-		QVector<QStringRef> split = params.at(i+1).split('/');
+		#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		ParseParams split = params.at(i+1).split('/').toVector();
+		#else
+		ParseParams split = params.at(i+1).split('/');
+		#endif
 		switch(split.size())
 		{
 			case 1: //no slash, only position
@@ -439,14 +443,16 @@ StelOBJ::MaterialList StelOBJ::Material::loadFromFile(const QString &filename)
 		//make sure only spaces are the separator
 		QString line = stream.readLine().simplified();
 		//split line by space		
-		#if (QT_VERSION>=QT_VERSION_CHECK(5, 14, 0))
-		QVector<QStringRef> splits = line.splitRef(' ',Qt::SkipEmptyParts);
+		#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		ParseParams splits = ParseParam(line).split(' ', Qt::SkipEmptyParts).toVector();
+		#elif (QT_VERSION>=QT_VERSION_CHECK(5,15,0))
+		ParseParams splits = line.splitRef(' ', Qt::SkipEmptyParts);
 		#else
-		QVector<QStringRef> splits = line.splitRef(' ',QString::SkipEmptyParts);
+		ParseParams splits = line.splitRef(' ', QString::SkipEmptyParts);
 		#endif
 		if(!splits.isEmpty())
 		{
-			const QStringRef& cmd = splits.at(0);
+			const ParseParam& cmd = splits.at(0);
 
 			//macro to make sure a material is currently active
 			#define CHECK_MTL() if(!curMaterial) { ok = false; qCCritical(stelOBJ)<<"Encountered material statement without active material"; }
@@ -623,7 +629,7 @@ StelOBJ::MaterialList StelOBJ::Material::loadFromFile(const QString &filename)
 					curMaterial->illum = static_cast<Illum>(tmp);
 				}
 			}
-			else if(!cmd.startsWith("#"))
+			else if(!cmd.startsWith(QChar('#')))
 			{
 				CHECK_MTL()
 				if(ok)
@@ -658,7 +664,11 @@ bool StelOBJ::Material::parseBool(const QStringList &params, bool &out)
 	ParseParams pp(params.size());
 	for(int i = 0; i< params.size();++i)
 	{
+#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		pp[i] = params.at(i);
+#else
 		pp[i] = QStringRef(&params.at(i));
+#endif
 	}
 	return StelOBJ::parseBool(pp,out,0);
 }
@@ -668,7 +678,11 @@ bool StelOBJ::Material::parseFloat(const QStringList &params, float &out)
 	ParseParams pp(params.size());
 	for(int i = 0; i< params.size();++i)
 	{
-		pp[i] = QStringRef(&params.at(i));
+#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		pp[i] = params.at(i);
+#else
+		pp[i] = ParseParam(&params.at(i));
+#endif
 	}
 	return StelOBJ::parseFloat(pp,out,0);
 }
@@ -678,7 +692,11 @@ bool StelOBJ::Material::parseVec2d(const QStringList &params, Vec2d &out)
 	ParseParams pp(params.size());
 	for(int i = 0; i< params.size();++i)
 	{
-		pp[i] = QStringRef(&params.at(i));
+#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		pp[i] = params.at(i);
+#else
+		pp[i] = ParseParam(&params.at(i));
+#endif
 	}
 	return StelOBJ::parseVec2(pp,out,0);
 }
@@ -705,7 +723,7 @@ void StelOBJ::addObject(const QString &name, CurrentParserState &state)
 	state.currentMaterialGroup = Q_NULLPTR;
 }
 
-bool StelOBJ::load(QIODevice& device, const QString &basePath, const VertexOrder vertexOrder)
+bool StelOBJ::load(QIODevice& device, const QString &basePath, const VertexOrder vertexOrder, const bool forceCreateNormals)
 {
 	clear();
 
@@ -741,14 +759,16 @@ bool StelOBJ::load(QIODevice& device, const QString &basePath, const VertexOrder
 		QString line = stream.readLine().trimmed();
 
 		//split line by whitespace
-		#if (QT_VERSION>=QT_VERSION_CHECK(5, 14, 0))
-		QVector<QStringRef> splits = line.splitRef(separator, Qt::SkipEmptyParts);
+		#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+		ParseParams splits = ParseParam(line).split(separator, Qt::SkipEmptyParts).toVector();
+		#elif (QT_VERSION>=QT_VERSION_CHECK(5,15,0))
+		ParseParams splits = line.splitRef(separator, Qt::SkipEmptyParts);
 		#else
-		QVector<QStringRef> splits = line.splitRef(separator, QString::SkipEmptyParts);
+		ParseParams splits = line.splitRef(separator, QString::SkipEmptyParts);
 		#endif
 		if(!splits.isEmpty())
 		{
-			const QStringRef& cmd = splits.at(0);
+			const ParseParam& cmd = splits.at(0);
 
 			bool ok = true;
 
@@ -917,7 +937,7 @@ bool StelOBJ::load(QIODevice& device, const QString &basePath, const VertexOrder
 			{
 				if(!smoothGroupWarned)
 				{
-					qCWarning(stelOBJ)<<"Smoothing groups are not supported, consider re-exporting your model from blender";
+					qCWarning(stelOBJ)<<"Smoothing groups are not supported, consider re-exporting your model from Blender";
 					smoothGroupWarned = true;
 				}
 			}
@@ -945,11 +965,11 @@ bool StelOBJ::load(QIODevice& device, const QString &basePath, const VertexOrder
 
 	qCDebug(stelOBJ)<<"Loaded OBJ in"<<timer.elapsed()<<"ms";
 	qCDebug(stelOBJ, "Parsed %d positions, %d normals, %d texture coordinates, %d materials",
-		posList.size(), normalList.size(), texList.size(), m_materials.size());
-	qCDebug(stelOBJ, "Created %d vertices, %d faces, %d objects", m_vertices.size(), getFaceCount(), m_objects.size());
+		int(posList.size()), int(normalList.size()), int(texList.size()), int(m_materials.size()));
+	qCDebug(stelOBJ, "Created %d vertices, %d faces, %d objects", int(m_vertices.size()), getFaceCount(), int(m_objects.size()));
 
 	//perform post processing
-	performPostProcessing(normalList.isEmpty());
+	performPostProcessing(normalList.isEmpty() || forceCreateNormals);
 	m_isLoaded = true;
 	return true;
 }
@@ -1265,7 +1285,7 @@ void StelOBJ::performPostProcessing(bool genNormals)
 	QElapsedTimer timer;
 	timer.start();
 
-	//if no normals have been read at all, generate them (we do not support smoothing groups at the time, so this is quite simple)
+	//if no normals have been read at all, or if normals are broken in the OBJ file and flagged as such in the scenery3d.ini, (re-)generate them (we do not support smoothing groups at the time, so this is quite simple)
 	if(genNormals)
 	{
 		generateNormals();
@@ -1331,7 +1351,7 @@ void StelOBJ::transform(const QMatrix4x4 &mat, bool onlyPosition)
 	{
 		Vertex& pVertex = m_vertices[i];
 
-		QVector3D tf = mat * QVector3D(pVertex.position[0], pVertex.position[1], pVertex.position[2]);
+		QVector3D tf = mat.map(QVector3D(pVertex.position[0], pVertex.position[1], pVertex.position[2]));
 		std::copy(&tf[0],&tf[0]+3,pVertex.position);
 
 		if(!onlyPosition)
