@@ -22,15 +22,16 @@
 #include "StelObjectMgr.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
-#include "StelProjector.hpp"
 #include "StelUtils.hpp"
 #include "StelTranslator.hpp"
 #include "StelSkyDrawer.hpp"
 #include "RefractionExtinction.hpp"
 #include "StelLocation.hpp"
+#include "StelObserver.hpp"
 #include "SolarSystem.hpp"
 #include "StelModuleMgr.hpp"
 #include "LandscapeMgr.hpp"
+#include "SpecificTimeMgr.hpp"
 #include "planetsephems/sidereal_time.h"
 #include "planetsephems/precession.h"
 
@@ -103,7 +104,7 @@ Vec3d StelObject::getSupergalacticPos(const StelCore *core) const
 // Meeus, Astronomical Algorithms, 2nd ed. (1998), p.98.
 float StelObject::getParallacticAngle(const StelCore* core) const
 {
-	const double phi=static_cast<double>(core->getCurrentLocation().latitude)*M_PI/180.0;
+	const double phi=static_cast<double>(core->getCurrentLocation().getLatitude())*M_PI/180.0;
 	const Vec3d siderealPos=getSiderealPosApparent(core);
 	double delta, ha;
 	StelUtils::rectToSphe(&ha, &delta, siderealPos);
@@ -165,12 +166,15 @@ Vec4d StelObject::getRTSTime(const StelCore *core, const double altitude) const
 	}
 	if (altitude != 0.)
 		ho = altitude*M_PI_180; // Not sure if we use refraction for off-zero settings?
-	const double phi = static_cast<double>(loc.latitude) * M_PI_180;
-	const double L = static_cast<double>(loc.longitude) * M_PI_180; // OUR longitude. Meeus has it reversed
+	const double phi = static_cast<double>(loc.getLatitude()) * M_PI_180;
+	const double L = static_cast<double>(loc.getLongitude()) * M_PI_180; // OUR longitude. Meeus has it reversed
 	PlanetP obsPlanet = core->getCurrentPlanet();
-	const double rotRate = obsPlanet->getSiderealDay();
+	const double rotDuration = obsPlanet->getSiderealDay();
 	const double currentJD=core->getJD();
 	const double currentJDE=core->getJDE();
+	const double utcShift = core->getUTCOffset(currentJD) / 24.;
+	int year, month, day, currentdate;
+	StelUtils::getDateFromJulianDay(currentJD+utcShift, &year, &month, &currentdate);
 
 	// And convert to equatorial coordinates of date. We can also use this day's current aberration, given the other uncertainties/omissions.
 	const Vec3d eq_2=getEquinoxEquatorialPos(core);
@@ -204,22 +208,51 @@ Vec4d StelObject::getRTSTime(const StelCore *core, const double altitude) const
 	// In terms of chapter 15, where m0, m1 and m2 are fractions of day within the current day, we use mr, mt, ms as fractions of day from currentJD, and they lie within [-1...+1].
 
 	double mr, ms, flag=0.;
-	double mt=-h2*(0.5*rotRate/M_PI);
+	double mt=-h2*(0.5*rotDuration/M_PI);
+	// Transit should occur on current date
+	StelUtils::getDateFromJulianDay(currentJD+mt+utcShift, &year, &month, &day);
+	if (day != currentdate)
+	{
+		if (mt<0.)
+			mt += rotDuration;
+		else
+			mt -= rotDuration;
+	}
 
 	// circumpolar: set rise and set times to lower culmination, i.e. 1/2 rotation from transit
 	if (fabs(cosH0)>1.)
 	{
 		flag = (cosH0<-1.) ? 100 : -100; // circumpolar / never rises
-		mr   = (cosH0<-1.) ? mt-0.5*rotRate : mt;
-		ms   = (cosH0<-1.) ? mt+0.5*rotRate : mt;
+		mr   = (cosH0<-1.) ? mt-0.5*rotDuration : mt;
+		ms   = (cosH0<-1.) ? mt+0.5*rotDuration : mt;
 	}
 	else
 	{
 		const double H0 = acos(cosH0);
 		//omgr->addToExtraInfoString(StelObject::DebugAid, QString("H<sub>0</sub>= %1<br/>").arg(QString::number(H0*M_180_PI, 'f', 6)));
 
-		mr = mt - H0*rotRate/(2.*M_PI);
-		ms = mt + H0*rotRate/(2.*M_PI);
+		mr = mt - H0*rotDuration/(2.*M_PI);
+		ms = mt + H0*rotDuration/(2.*M_PI);
+	}
+
+	// Rise should occur on current date
+	StelUtils::getDateFromJulianDay(currentJD+mr+utcShift, &year, &month, &day);
+	if (day != currentdate)
+	{
+		if (mr<0.)
+			mr += rotDuration;
+		else
+			mr -= rotDuration;
+	}
+
+	// Set should occur on current date
+	StelUtils::getDateFromJulianDay(currentJD+ms+utcShift, &year, &month, &day);
+	if (day != currentdate)
+	{
+		if (ms<0.)
+			ms += rotDuration;
+		else
+			ms -= rotDuration;
 	}
 
 	//omgr->addToExtraInfoString(StelObject::DebugAid, QString("m<sub>t</sub>= %1<br/>").arg(QString::number(mt, 'f', 6)));
@@ -328,6 +361,8 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 {
 	StelApp& app = StelApp::getInstance();
 	StelObjectMgr* omgr=GETSTELMODULE(StelObjectMgr);
+	const StelLocation currentLocation=core->getCurrentLocation();
+	const bool onTransitionToNewLocation=core->getCurrentObserver()->isTraveling();
 	const bool withAtmosphere = core->getSkyDrawer()->getFlagHasAtmosphere();
 	const bool withDecimalDegree = app.getFlagShowDecimalDegrees();
 	const bool useSouthAzimuth = app.getFlagSouthAzimuthUsage();
@@ -336,7 +371,12 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 	const QString cepoch = qc_("on date", "coordinates for current epoch");
 	const QString currentPlanet = core->getCurrentPlanet()->getEnglishName();
 	const QString apparent = " " + (withAtmosphere ? q_("(apparent)") : "");
+	const double currentJD = core->getJD();
+	const double utcShift = core->getUTCOffset(currentJD) / 24.; // Fix DST shift...
+	QString currentObjStr = getEnglishName();
 	QString res, firstCoordinate, secondCoordinate;
+	int currentYear, currentMonth, currentDay;
+	StelUtils::getDateFromJulianDay(currentJD+utcShift, &currentYear, &currentMonth, &currentDay);
 	double az_app, alt_app;
 	StelUtils::rectToSphe(&az_app,&alt_app,getAltAzPosApparent(core));
 	Q_UNUSED(az_app)
@@ -621,7 +661,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		if (withTables)
 		{
 			res += "<table style='margin:0em 0em 0em -0.125em;border-spacing:0px;border:0px;'>";
-			res += QString("<tr><td>%1 (%4):</td><td>%2</td></tr>").arg(eqlObl, firstCoordinate, cepoch);
+			res += QString("<tr><td>%1 (%3):</td><td>%2</td></tr>").arg(eqlObl, firstCoordinate, cepoch);
 		}
 		else
 			res += QString("%1 (%3): %2<br/>").arg(eqlObl, firstCoordinate, cepoch);
@@ -643,7 +683,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 
 	if ((flags&SiderealTime) && (currentPlanet==QStringLiteral("Earth")))
 	{
-		const double longitude=static_cast<double>(core->getCurrentLocation().longitude);
+		const double longitude=static_cast<double>(core->getCurrentLocation().getLongitude());
 		double sidereal=(get_mean_sidereal_time(core->getJD(), core->getJDE())  + longitude) / 15.;
 		sidereal=StelUtils::fmodpos(sidereal, 24.);
 		QString STc = q_("Mean Sidereal Time");
@@ -670,26 +710,43 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		}
 		res += getExtraInfoStrings(flags&SiderealTime).join("");
 		res += omgr->getExtraInfoStrings(flags&SiderealTime).join("");
-		if (withTables && !(flags&RTSTime && getType()!=QStringLiteral("Satellite")))
+		if (withTables && !(flags&RTSTime && !onTransitionToNewLocation && getType()!=QStringLiteral("Satellite") && currentLocation.role!='o'))
 			res += "</table>";
 	}
 
-	if (flags&RTSTime && getType()!=QStringLiteral("Satellite") && !currentPlanet.contains("observer", Qt::CaseInsensitive) && !(core->getCurrentLocation().name.contains("->")))
+	if (flags&RTSTime && getType()!=QStringLiteral("Satellite") && currentLocation.role!='o' && !onTransitionToNewLocation)
 	{
-		const double utcShift = core->getUTCOffset(core->getJD()) / 24.; // Fix DST shift...
-		Vec4d rts = getRTSTime(core);
+		static int prevYear, prevMonth, prevDay;
+		static QString prevObjStr;
+
+		const bool isSun = (getEnglishName()=="Sun");
+		static Vec4d rts;
+		if ((currentYear != prevYear) || (currentMonth != prevMonth) || (currentDay != prevDay) || (currentObjStr != prevObjStr))
+		{
+			rts = getRTSTime(core);
+		}
 		QString sTransit = qc_("Transit", "celestial event; passage across a meridian");
 		QString sRise = qc_("Rise", "celestial event");
 		QString sSet = qc_("Set", "celestial event");
+		const QString dash = QChar(0x2014);
 		double sunrise = 0.;
 		double sunset = 24.;
-		const bool isSun = (getEnglishName()=="Sun");		
 		double hour(0);
+		int year, month, day;
 
 		if (withTables && !(flags&SiderealTime && currentPlanet==QStringLiteral("Earth")))
 			res += "<table style='margin:0em 0em 0em -0.125em;border-spacing:0px;border:0px;'>";
 
-		if (rts[3]==0.)
+		// Rise
+		StelUtils::getDateFromJulianDay(rts[0]+utcShift, &year, &month, &day);
+		if (rts[3]==30 || rts[3]<0 || rts[3]>50 || day != currentDay) // no rise
+		{
+			if (withTables)
+				res += QString("<tr><td>%1:</td><td style='text-align:right;'>%2</td></tr>").arg(sRise, dash);
+			else
+				res += QString("%1: %2<br/>").arg(sRise, dash);
+		}
+		else
 		{
 			hour = StelUtils::getHoursFromJulianDay(rts[0]+utcShift);
 			if (withTables)
@@ -700,14 +757,34 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 			sunrise = hour;
 		}
 
-		hour = StelUtils::getHoursFromJulianDay(rts[1]+utcShift);
-		if (withTables)
-			res += QString("<tr><td>%1:</td><td style='text-align:right;'>%2</td></tr>").arg(sTransit, StelUtils::hoursToHmsStr(hour, true));
-		else
-			res += QString("%1: %2<br/>").arg(sTransit, StelUtils::hoursToHmsStr(hour, true));
-
-		if (rts[3]==0.)
+		// Transit
+		StelUtils::getDateFromJulianDay(rts[1]+utcShift, &year, &month, &day);
+		if (rts[3]==20 || day != currentDay) // no transit
 		{
+			if (withTables)
+				res += QString("<tr><td>%1:</td><td style='text-align:right;'>%2</td></tr>").arg(sTransit, dash);
+			else
+				res += QString("%1: %2<br/>").arg(sTransit, dash);
+		}
+		else {
+			hour = StelUtils::getHoursFromJulianDay(rts[1]+utcShift);
+
+			if (withTables)
+				res += QString("<tr><td>%1:</td><td style='text-align:right;'>%2</td></tr>").arg(sTransit, StelUtils::hoursToHmsStr(hour, true));
+			else
+				res += QString("%1: %2<br/>").arg(sTransit, StelUtils::hoursToHmsStr(hour, true));
+		}
+
+		// Set
+		StelUtils::getDateFromJulianDay(rts[2]+utcShift, &year, &month, &day);
+		if (rts[3]==40 || rts[3]<0 || rts[3]>50 || day != currentDay) // no set
+		{
+			if (withTables)
+				res += QString("<tr><td>%1:</td><td style='text-align:right;'>%2</td></tr>").arg(sSet, dash);
+			else
+				res += QString("%1: %2<br/>").arg(sSet, dash);
+		}
+		else {
 			hour = StelUtils::getHoursFromJulianDay(rts[2]+utcShift);
 			if (withTables)
 				res += QString("<tr><td>%1:</td><td style='text-align:right;'>%2</td></tr>").arg(sSet, StelUtils::hoursToHmsStr(hour, true));
@@ -721,7 +798,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		{
 			QString sMTwilight = qc_("Morning twilight", "celestial event");
 			QString sETwilight = qc_("Evening twilight", "celestial event");
-			const double twilightAltitude = omgr->getTwilightAltitude();
+			const double twilightAltitude = GETSTELMODULE(SpecificTimeMgr)->getTwilightAltitude();
 			QString alt = QString::number(twilightAltitude, 'f', 1);
 			Vec4d twilight = getRTSTime(core, twilightAltitude);
 			if (twilight[3]==0.)
@@ -759,7 +836,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 			else
 				res += q_("This object never rises") + "<br />";
 		}
-		else if (rts[3]>0.)
+		else if (rts[3]>50.)
 		{
 			if (isSun)
 				res += q_("Polar day") + "<br />";
@@ -776,7 +853,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		// Greatest Digression: limiting azimuth and hour angles for stars with upper culmination between pole and zenith
 		double dec_equ, ra_equ;
 		StelUtils::rectToSphe(&ra_equ,&dec_equ,getEquinoxEquatorialPos(core));
-		const double latitude=static_cast<double>(core->getCurrentLocation().latitude)*M_PI_180;
+		const double latitude=static_cast<double>(core->getCurrentLocation().getLatitude())*M_PI_180;
 		if (((latitude>0.) && (dec_equ>=latitude)) || ((latitude<0.) && (dec_equ<=latitude)))
 		{
 			const double theta=acos(tan(latitude)/tan(dec_equ)); // hour angle
@@ -834,6 +911,11 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		}
 		res += getExtraInfoStrings(flags&RTSTime).join(' ');
 		res += omgr->getExtraInfoStrings(flags&RTSTime).join(' ');
+
+		prevObjStr = currentObjStr;
+		prevYear = currentYear;
+		prevMonth = currentMonth;
+		prevDay = currentDay;
 	}
 
 	if (flags&Extra)
@@ -875,22 +957,34 @@ void StelObject::postProcessInfoString(QString& str, const InfoStringGroup& flag
 	str.append(omgr->getExtraInfoStrings(DebugAid).join(' ')); // TBD: Remove for Release builds?
 
 	// hack for avoiding an empty line before table
-	str.replace(QRegularExpression("<br(\\s*/)?><table"), "<table");
+	static const QRegularExpression tableRe("<br(\\s*/)?><table");
+	static const QRegularExpression  brRe("<br(\\s*/)?>\\s*$");
+	str.replace(tableRe, "<table");
 	// chomp trailing line breaks
-	str.replace(QRegularExpression("<br(\\s*/)?>\\s*$"), "");
+	str.replace(brRe, "");
 
 	if (flags&PlainText)
 	{
+		static const QRegularExpression brRe2("<br(\\s*/)?>\\s*");
+		static const QRegularExpression tdRe1("<td\\s*>");
+		static const QRegularExpression tdRe2("<td \\w+='[^']*'>"); // Seen: style, align, colspan, rowspan. Always only one expression.
+		static const QRegularExpression tdRe3("<td \\w+=\"[^\"]*\">");
+		static const QRegularExpression tableRe2("<table\\s*>");
+		static const QRegularExpression tableRe3("<table style='[^']*'>");
+		static const QRegularExpression tableRe4("<table style=\"[^\"]*\">");
 		str.replace("<b>", "");
 		str.replace("</b>", "");
 		str.replace("<h2>", "");
 		str.replace("</h2>", "\n");
-		str.replace(QRegularExpression("<br(\\s*/)?>"), "\n");
+		str.replace(brRe2, "\n");
 		str.replace("<tr>", "");
-		str.replace(QRegularExpression("<td(\\w*)?>"), "");
-		str.replace("<td>", "");
+		str.replace(tdRe1, "");
+		str.replace(tdRe2, "");
+		str.replace(tdRe3, "");
 		str.replace("</tr>", "\n");
-		str.replace(QRegularExpression("<table(\\w*)?>"), "");
+		str.replace(tableRe2, "");
+		str.replace(tableRe3, "");
+		str.replace(tableRe4, "");
 		str.replace("</table>", "");
 	}
 	else if(!(flags&NoFont))
@@ -919,6 +1013,7 @@ QVariantMap StelObject::getInfoMap(const StelCore *core) const
 	Vec3d pos;
 	double ra, dec, alt, az, glong, glat;
 	bool useOldAzimuth = StelApp::getInstance().getFlagSouthAzimuthUsage();
+	QString currentObjStr = getEnglishName();
 
 	map.insert("type", getType());
 	map.insert("object-type", getObjectType());
@@ -935,7 +1030,7 @@ QVariantMap StelObject::getInfoMap(const StelCore *core) const
 	// Sidereal Time and hour angle
 	if (core->getCurrentLocation().planetName=="Earth")
 	{
-		const double longitude=static_cast<double>(core->getCurrentLocation().longitude);
+		const double longitude=static_cast<double>(core->getCurrentLocation().getLongitude());
 		double sidereal=(get_mean_sidereal_time(core->getJD(), core->getJDE())  + longitude) / 15.;
 		sidereal=fmod(sidereal, 24.);
 		if (sidereal < 0.) sidereal+=24.;
@@ -1002,6 +1097,7 @@ QVariantMap StelObject::getInfoMap(const StelCore *core) const
 	// J2000
 	double eclJ2000 = ssmgr->getEarth()->getRotObliquity(2451545.0);
 	double ecl = ssmgr->getEarth()->getRotObliquity(core->getJDE());
+	map.insert("ecliptic-obliquity", ecl*M_180_PI);
 
 	// ecliptic longitude/latitude (J2000 frame)
 	StelUtils::rectToSphe(&ra_equ,&dec_equ, getJ2000EquatorialPos(core));
@@ -1039,7 +1135,19 @@ QVariantMap StelObject::getInfoMap(const StelCore *core) const
 	// 'above horizon' flag
 	map.insert("above-horizon", isAboveRealHorizon(core));
 
-	Vec4d rts = getRTSTime(core);
+	const double currentJD = core->getJD();
+	const double utcShift = core->getUTCOffset(currentJD) / 24.; // Fix DST shift...
+	int currentYear, currentMonth, currentDay;
+	StelUtils::getDateFromJulianDay(currentJD+utcShift, &currentYear, &currentMonth, &currentDay);
+
+	static int prevYear, prevMonth, prevDay;
+	static Vec4d rts;
+	static QString prevObjStr;
+
+	if ((currentYear != prevYear) || (currentMonth != prevMonth) || (currentDay != prevDay) || (currentObjStr != prevObjStr))
+	{
+		rts = getRTSTime(core);
+	}
 	if (rts[3]>-1000.)
 	{
 		const double utcShift = core->getUTCOffset(core->getJD()) / 24.; // Fix DST shift...
@@ -1047,31 +1155,55 @@ QVariantMap StelObject::getInfoMap(const StelCore *core) const
 		StelUtils::getTimeFromJulianDay(rts[1]+utcShift, &hr, &min, &sec);
 		double hours=hr+static_cast<double>(min)/60. + static_cast<double>(sec)/3600.;
 
-		map.insert("transit", StelUtils::hoursToHmsStr(hours, true));
-		map.insert("transit-dhr", hours);
-		if (rts[3]==0.)
+		int year, month, day;
+		StelUtils::getDateFromJulianDay(core->getJD()+utcShift, &year, &month, &currentDay);
+		StelUtils::getDateFromJulianDay(rts[1]+utcShift, &year, &month, &day);
+		if (rts[3]==20 || day != currentDay) // no transit
 		{
+			map.insert("transit", "---");
+		}
+		else {
+			map.insert("transit", StelUtils::hoursToHmsStr(hours, true));
+			map.insert("transit-dhr", hours);
+		}
+
+		StelUtils::getDateFromJulianDay(rts[0]+utcShift, &year, &month, &day);
+		if (rts[3]==30 || rts[3]<0 || rts[3]>50 || day != currentDay) // no rise
+		{
+			map.insert("rise", "---");
+		}
+		else {
 			StelUtils::getTimeFromJulianDay(rts[0]+utcShift, &hr, &min, &sec);
 			hours=hr+static_cast<double>(min)/60. + static_cast<double>(sec)/3600.;
 			map.insert("rise", StelUtils::hoursToHmsStr(hours, true));
 			map.insert("rise-dhr", hours);
+		}
+
+		StelUtils::getDateFromJulianDay(rts[2]+utcShift, &year, &month, &day);
+		if (rts[3]==40 || rts[3]<0 || rts[3]>50 || day != currentDay) // no set
+		{
+			map.insert("set", "---");
+		}
+		else {
 			StelUtils::getTimeFromJulianDay(rts[2]+utcShift, &hr, &min, &sec);
 			hours=hr+static_cast<double>(min)/60. + static_cast<double>(sec)/3600.;
 			map.insert("set", StelUtils::hoursToHmsStr(hours, true));
 			map.insert("set-dhr", hours);
 		}
-		else {
-			map.insert("rise", "---");
-			map.insert("set", "---");
-		}
 	}
+
+	prevObjStr = currentObjStr;
+	prevYear = currentYear;
+	prevMonth = currentMonth;
+	prevDay = currentDay;
+
 	return map;
 }
 
 void StelObject::setExtraInfoString(const InfoStringGroup& flags, const QString &str)
 {
 	extraInfoStrings.remove(flags); // delete all entries with these flags
-	if (str.length()>0)
+	if (!str.isEmpty())
 		extraInfoStrings.insert(flags, str);
 }
 void StelObject::addToExtraInfoString(const StelObject::InfoStringGroup &flags, const QString &str)
@@ -1102,73 +1234,76 @@ QStringList StelObject::getExtraInfoStrings(const InfoStringGroup& flags) const
 
 void StelObject::removeExtraInfoStrings(const InfoStringGroup& flags)
 {
-	QMultiMap<InfoStringGroup, QString>::iterator i = extraInfoStrings.begin();
-	while (i != extraInfoStrings.end())
+#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+	QMutableMultiMapIterator<InfoStringGroup, QString> i(extraInfoStrings);
+#else
+	QMutableMapIterator<InfoStringGroup, QString> i(extraInfoStrings);
+#endif
+	while (i.hasNext())
 	{
+		i.next();
 		if (i.key() & flags)
-			i=extraInfoStrings.erase(i);
-		else
-			++i;
+			i.remove();
 	}
 }
 
 // Add horizontal coordinates of Sun and Moon where useful
 QString StelObject::getSolarLunarInfoString(const StelCore *core, const InfoStringGroup& flags) const
 {
-    QString str;
-    QTextStream oss(&str);
-    static SolarSystem *ssystem=GETSTELMODULE(SolarSystem);
-    PlanetP earth = ssystem->getEarth();
-    if ((core->getCurrentPlanet()==earth) && (flags&SolarLunarPosition))
-    {
-	const bool withTables = StelApp::getInstance().getFlagUseFormattingOutput();
-	const bool withDecimalDegree = StelApp::getInstance().getFlagShowDecimalDegrees();
-
-	if (withTables)
-	    oss << "<table style='margin:0em 0em 0em -0.125em;border-spacing:0px;border:0px;'>";
-	const bool useSouthAzimuth = StelApp::getInstance().getFlagSouthAzimuthUsage();
-	const bool withDesignations = StelApp::getInstance().getFlagUseCCSDesignation();
-	double az, alt;
-	QString azStr, altStr;
-
-	if (getEnglishName()!="Sun")
+	QString str;
+	QTextStream oss(&str);
+	static SolarSystem *ssystem=GETSTELMODULE(SolarSystem);
+	PlanetP earth = ssystem->getEarth();
+	if ((core->getCurrentPlanet()==earth) && (flags&SolarLunarPosition))
 	{
-	    StelUtils::rectToSphe(&az,&alt,ssystem->getSun()->getAltAzPosAuto(core));
-	    az = (useSouthAzimuth? 2. : 3.)*M_PI - az;
-	    if (az > M_PI*2)
-		az -= M_PI*2;
-	    azStr  = (withDecimalDegree ? StelUtils::radToDecDegStr(az, 2)  : StelUtils::radToDmsStr(az,false));
-	    altStr = (withDecimalDegree ? StelUtils::radToDecDegStr(alt, 2) : StelUtils::radToDmsStr(alt,false));
+		const bool withTables = StelApp::getInstance().getFlagUseFormattingOutput();
+		const bool withDecimalDegree = StelApp::getInstance().getFlagShowDecimalDegrees();
 
-	    // TRANSLATORS: Azimuth/Altitude
-	    const QString SolarAzAlt = (withDesignations ? qc_("Solar A/a", "celestial coordinate system") : qc_("Solar Az./Alt.", "celestial coordinate system"));
-	    if (withTables)
-	    {
-		oss << QString("<tr><td>%1:</td><td style='text-align:right;'>%2/</td><td style='text-align:right;'>%3</td></tr>").arg(SolarAzAlt, azStr, altStr);
-	    }
-	    else
-		oss << QString("%1: %2/%3<br/>").arg(SolarAzAlt, azStr, altStr);
-	}
-	if (getEnglishName()!="Moon")
-	{
-	    StelUtils::rectToSphe(&az,&alt,ssystem->getMoon()->getAltAzPosAuto(core));
-	    az = (useSouthAzimuth? 2. : 3.)*M_PI - az;
-	    if (az > M_PI*2)
-		az -= M_PI*2;
-	    azStr  = (withDecimalDegree ? StelUtils::radToDecDegStr(az, 2)  : StelUtils::radToDmsStr(az,false));
-	    altStr = (withDecimalDegree ? StelUtils::radToDecDegStr(alt, 2) : StelUtils::radToDmsStr(alt,false));
+		if (withTables)
+			oss << "<table style='margin:0em 0em 0em -0.125em;border-spacing:0px;border:0px;'>";
+		const bool useSouthAzimuth = StelApp::getInstance().getFlagSouthAzimuthUsage();
+		const bool withDesignations = StelApp::getInstance().getFlagUseCCSDesignation();
+		double az, alt;
+		QString azStr, altStr;
 
-	    // TRANSLATORS: Azimuth/Altitude
-	    const QString LunarAzAlt = (withDesignations ? qc_("Lunar A/a", "celestial coordinate system") : qc_("Lunar Az./Alt.", "celestial coordinate system"));
-	    if (withTables)
-	    {
-		oss << QString("<tr><td>%1:</td><td style='text-align:right;'>%2/</td><td style='text-align:right;'>%3</td></tr>").arg(LunarAzAlt, azStr, altStr);
-	    }
-	    else
-		oss << QString("%1: %2/%3<br/>").arg(LunarAzAlt, azStr, altStr);
+		if (getEnglishName()!="Sun")
+		{
+			StelUtils::rectToSphe(&az,&alt,ssystem->getSun()->getAltAzPosAuto(core));
+			az = (useSouthAzimuth? 2. : 3.)*M_PI - az;
+			if (az > M_PI*2)
+				az -= M_PI*2;
+			azStr  = (withDecimalDegree ? StelUtils::radToDecDegStr(az, 2)  : StelUtils::radToDmsStr(az,false));
+			altStr = (withDecimalDegree ? StelUtils::radToDecDegStr(alt, 2) : StelUtils::radToDmsStr(alt,false));
+
+			// TRANSLATORS: Azimuth/Altitude
+			const QString SolarAzAlt = (withDesignations ? qc_("Solar A/a", "celestial coordinate system") : qc_("Solar Az./Alt.", "celestial coordinate system"));
+			if (withTables)
+			{
+				oss << QString("<tr><td>%1:</td><td style='text-align:right;'>%2/</td><td style='text-align:right;'>%3</td></tr>").arg(SolarAzAlt, azStr, altStr);
+			}
+			else
+				oss << QString("%1: %2/%3<br/>").arg(SolarAzAlt, azStr, altStr);
+		}
+		if (getEnglishName()!="Moon")
+		{
+			StelUtils::rectToSphe(&az,&alt,ssystem->getMoon()->getAltAzPosAuto(core));
+			az = (useSouthAzimuth? 2. : 3.)*M_PI - az;
+			if (az > M_PI*2)
+				az -= M_PI*2;
+			azStr  = (withDecimalDegree ? StelUtils::radToDecDegStr(az, 2)  : StelUtils::radToDmsStr(az,false));
+			altStr = (withDecimalDegree ? StelUtils::radToDecDegStr(alt, 2) : StelUtils::radToDmsStr(alt,false));
+
+			// TRANSLATORS: Azimuth/Altitude
+			const QString LunarAzAlt = (withDesignations ? qc_("Lunar A/a", "celestial coordinate system") : qc_("Lunar Az./Alt.", "celestial coordinate system"));
+			if (withTables)
+			{
+				oss << QString("<tr><td>%1:</td><td style='text-align:right;'>%2/</td><td style='text-align:right;'>%3</td></tr>").arg(LunarAzAlt, azStr, altStr);
+			}
+			else
+				oss << QString("%1: %2/%3<br/>").arg(LunarAzAlt, azStr, altStr);
+		}
+		if (withTables)
+			oss << "</table>";
 	}
-	if (withTables)
-	    oss << "</table>";
-    }
-    return str;
+	return str;
 }
