@@ -21,6 +21,7 @@
 #define STELOBJECT_HPP
 
 #include "VecMath.hpp"
+// Ignore clangd warning! Inclusion is OK.
 #include "StelObjectType.hpp"
 #include "StelRegionObject.hpp"
 
@@ -132,6 +133,7 @@ public:
 	//! - glat : galactic latitude in decimal degrees
 	//! - sglong : supergalactic longitude in decimal degrees
 	//! - sglat : supergalactic latitude in decimal degrees
+	//! - ecliptic-obliquity : mean ecliptic obliquity of date in decimal degrees
 	//! - elong : ecliptic longitude in decimal degrees (on Earth only!)
 	//! - elat : ecliptic latitude in decimal degrees (on Earth only!)
 	//! - elongJ2000 : ecliptic longitude (Earth's J2000 frame) in decimal degrees
@@ -158,7 +160,10 @@ public:
 	//! Return object's type. It should be the name of the class.
 	virtual QString getType() const = 0;
 
-	//! Return object's type. It should be English lowercase name of the type of the object.
+	//! Return object's type. It should be English lowercase name of the astronomical type of the object.
+	//! The purpose of this string is a distinction or further refinement over object class name retrieved with getType():
+	//! Planet objects can be planets, moons, or even the Sun. The Sun should however return "star".
+	//! Nebula objects should return their actual type like "open cluster", "galaxy", "nebula", ...
 	virtual QString getObjectType() const = 0;
 	//! Return object's type. It should be translated lowercase name of the type of the object.
 	virtual QString getObjectTypeI18n() const = 0;
@@ -183,7 +188,7 @@ public:
 	//! Return translated object's name
 	virtual QString getNameI18n() const = 0;
 
-	//! Get observer-centered equatorial coordinates at equinox J2000
+	//! Get observer-centered equatorial coordinates at equinox J2000, including aberration
 	virtual Vec3d getJ2000EquatorialPos(const StelCore* core) const = 0;
 
 	//! Get observer-centered equatorial coordinate at the current equinox
@@ -246,7 +251,11 @@ public:
 	//!       *  +100. for circumpolar objects. Rise and set give lower culmination times.
 	//!       *  -100. for objects never rising. Rise and set give transit times.
 	//!       * -1000. is used as "invalid" value. The result should then not be used.
+	//!       *   +20. (Planet objects only) no transit time on current date.
+	//!       *   +30. (Planet objects only) no rise time on current date.
+	//!       *   +40. (Planet objects only) no set time on current date.
 	//! @note This is an abbreviated version of the method implemented in the Planet class.
+
 	virtual Vec4d getRTSTime(const StelCore* core, const double altitude=0.) const;
 
 	//! Return object's apparent V magnitude as seen from observer, without including extinction.
@@ -274,7 +283,7 @@ public:
 	//! with the circle center assumed to be at getJ2000EquatorialPos().
 	//! @return radius in degree. This value is the apparent angular size of the object, and is independent of the current FOV.
 	//! @note The default implementation just returns zero.
-	virtual double getAngularRadius(const StelCore* core) const {Q_UNUSED(core) Q_ASSERT(0); return 0;}
+	virtual double getAngularRadius(const StelCore* core) const { Q_UNUSED(core) return 0.; }
 
 	//! Return airmass value for the object (for atmosphere-dependent calculations)
 	//! @param core
@@ -287,7 +296,7 @@ public slots:
 	//! @note This should be used with caution. Usually you want to use addToExtraInfoString().
 	//! @note: If this breaks some const declaration, you can use StelObjectMgr::setExtraInfoString() instead.
 	virtual void setExtraInfoString(const InfoStringGroup& flags, const QString &str);
-	//! Add str to the extra string. This should be preferrable over hard setting.
+	//! Add str to the extra string. This should be preferable over hard setting.
 	//! Can be used by plugins to show extra info for the selected object, or for debugging.
 	//! The strings will be shown in the InfoString for the selected object, below the default fields per-flag.
 	//! Additional coordinates not fitting into one of the predefined coordinate sets should be flagged with OtherCoords,
