@@ -37,7 +37,11 @@ class StelCore;
 class StelObjectMgr : public StelModule
 {
 	Q_OBJECT
-	Q_PROPERTY(double twilightAltitude READ getTwilightAltitude WRITE setTwilightAltitude NOTIFY twilightAltitudeChanged)
+	Q_PROPERTY(bool objectPointerVisibility
+		   READ getFlagSelectedObjectPointer
+		   WRITE setFlagSelectedObjectPointer
+		   NOTIFY flagSelectedObjectPointerChanged)
+
 public:
 	StelObjectMgr();
 	virtual ~StelObjectMgr() Q_DECL_OVERRIDE;
@@ -73,12 +77,12 @@ public:
 	//! @return true if a object with the passed name was found
 	bool findAndSelectI18n(const QString &nameI18n, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
 
-	//! Find and select an object from its translated name and object type name.
+	//! Find and select an object from its translated name and object type name (i.e., the Stellarium class name).
 	//! @param action define whether to add to, replace, or remove from the existing selection
 	//! @param nameI18n the case sensitive object translated name
-	//! @param objtype the type of the object
+	//! @param objtype the type of the object (i.e., the Stellarium class name)
 	//! @return true if a object with the passed name was found
-	bool findAndSelectI18n(const QString &name, const QString &objtype, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
+	bool findAndSelectI18n(const QString &nameI18n, const QString &objtype, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
 
 	//! Find and select an object from its standard program name.
 	//! @param action define whether to add to, replace, or remove from the existing selection
@@ -86,10 +90,10 @@ public:
 	//! @return true if a object with the passed name was found
 	bool findAndSelect(const QString &name, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
 
-	//! Find and select an object from its standard program name and object type name.
+	//! Find and select an object from its standard program name and object type name (i.e., the Stellarium class name).
 	//! @param action define whether to add to, replace, or remove from the existing selection
 	//! @param name the case sensitive object translated name
-	//! @param objtype the type of the object
+	//! @param objtype the type of the object (i.e., the Stellarium class name)
 	//! @return true if a object with the passed name was found
 	bool findAndSelect(const QString &name, const QString &objtype, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
 
@@ -112,27 +116,22 @@ public:
 	//! Notify that we want to select the given object.
 	//! @param obj the StelObject to select
 	//! @param action action define whether to add to, replace, or remove from the existing selection
-	//! @return true if at least 1 object was sucessfully selected
+	//! @return true if at least 1 object was successfully selected
 	bool setSelectedObject(const StelObjectP obj, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
 
 	//! Notify that we want to select the given objects.
 	//! @param objs a vector of objects to select
 	//! @param action define whether to add to, replace, or remove from the existing selection
-	//! @return true if at least 1 object was sucessfully selected
+	//! @return true if at least 1 object was successfully selected
 	bool setSelectedObject(const QList<StelObjectP>& objs, StelModule::StelModuleSelectAction action=StelModule::ReplaceSelection);
 
 	//! Get the list of objects which was recently selected by the user.
 	const QList<StelObjectP>& getSelectedObject() const {return lastSelectedObjects;}
 
-	//! Return the list objects of type "withType" which was recently selected by the user.
+	//! Return the list objects of type "type" which was recently selected by the user.
 	//! @param type return only objects of the given type
 	QList<StelObjectP> getSelectedObject(const QString& type) const;
 
-	//! Set whether a pointer is to be drawn over selected object.
-	void setFlagSelectedObjectPointer(bool b) {objectPointerVisibility=b;}
-	//! Get whether a pointer is to be drawn over selected object.
-	bool getFlagSelectedObjectPointer(void) const {return objectPointerVisibility;}
-
 	//! Find any kind of object by its translated name.
 	StelObjectP searchByNameI18n(const QString &name) const;
 
@@ -169,75 +168,11 @@ public:
 	//! Return a list of enabled fields (custom info strings)
 	StelObject::InfoStringGroup getCustomInfoStrings();
 
-	//! Get twilight altitude [degrees]
-	double getTwilightAltitude() const {return twilightAltitude;}
-
 	//! Retrieve an (unsorted) QStringList of all extra info strings that match flags.
 	//! Normally the order matches the order of addition, but this cannot be guaranteed.
 	QStringList getExtraInfoStrings(const StelObject::InfoStringGroup& flags) const;
 
 public slots:
-	//! Set twilight altitude [degrees]
-	void setTwilightAltitude(double alt);
-
-	//! Set simulation time to the time of next transit of selected object
-	void nextTransit();
-	//! Set simulation time to the time of previous transit of selected object
-	void previousTransit();
-	//! Set simulation time to the time of today's transit of selected object
-	void todayTransit();
-
-	//! Set simulation time to the time of next rising of selected object (if applicable)
-	//! @note for circumpolar objects, this sets to time of lower culmination
-	//! @note for permanently invisible objects, this sets to time of transit
-	void nextRising();
-	//! Set simulation time to the time of previous rising of selected object (if applicable)
-	//! @note for circumpolar objects, this sets to time of lower culmination
-	//! @note for permanently invisible objects, this sets to time of transit
-	void previousRising();
-	//! Set simulation time to the time of today's rising of selected object (if applicable)
-	//! @note for circumpolar objects, this sets to time of lower culmination
-	//! @note for permanently invisible objects, this sets to time of transit
-	void todayRising();
-
-	//! Set simulation time to the time of next setting of selected object (if applicable)
-	//! @note for circumpolar objects, this sets to time of lower culmination
-	//! @note for permanently invisible objects, this sets to time of transit
-	void nextSetting();
-	//! Set simulation time to the time of previous setting of selected object (if applicable)
-	//! @note for circumpolar objects, this sets to time of lower culmination
-	//! @note for permanently invisible objects, this sets to time of transit
-	void previousSetting();
-	//! Set simulation time to the time of today's setting of selected object (if applicable)
-	//! @note for circumpolar objects, this sets to time of lower culmination
-	//! @note for permanently invisible objects, this sets to time of transit
-	void todaySetting();
-
-	//! Set simulation time to this day's morning when Sun reaches twilightAltitude
-	void todayMorningTwilight();
-	//! Set simulation time to this day's evening when Sun reaches twilightAltitude
-	void todayEveningTwilight();
-	//! Set simulation time to the previous day's morning when Sun reaches twilightAltitude
-	void previousMorningTwilight();
-	//! Set simulation time to the previous day's evening when Sun reaches twilightAltitude
-	void previousEveningTwilight();
-	//! Set simulation time to the next day's morning when Sun reaches twilightAltitude
-	void nextMorningTwilight();
-	//! Set simulation time to the next day's evening when Sun reaches twilightAltitude
-	void nextEveningTwilight();
-
-	//! Set simulation time to this day's morning when selected object reaches current altitude
-	void todayMorningAtAltitude();
-	//! Set simulation time to the next morning when selected object reaches current altitude
-	void nextMorningAtAltitude();
-	//! Set simulation time to the previous morning when selected object reaches current altitude
-	void previousMorningAtAltitude();
-	//! Set simulation time to this day's evening when selected object reaches current altitude
-	void todayEveningAtAltitude();
-	//! Set simulation time to the next evening when selected object reaches current altitude
-	void nextEveningAtAltitude();
-	//! Set simulation time to the previous evening when selected object reaches current altitude
-	void previousEveningAtAltitude();
 
 	//! @note These functions were copied over from StelObject. Given that setExtraInfoString is non-const and some functions where these methods are useful are const, we can use the StelObjectMgr as "carrier object".
 	//! Allow additions to the Info String. Can be used by plugins to show extra info for the selected object, or for debugging.
@@ -245,7 +180,7 @@ public slots:
 	//! @note This should be used with caution. Usually you want to use addToExtraInfoString().
 	virtual void setExtraInfoString(const StelObject::InfoStringGroup& flags, const QString &str);
 
-	//! Add str to the extra string. This should be preferrable over hard setting.
+	//! Add str to the extra string. This should be preferable over hard setting.
 	//! Can be used by plugins to show extra info for the selected object, or for debugging.
 	//! The strings will be shown in the InfoString for the selected object, below the default fields per-flag.
 	//! Additional coordinates not fitting into one of the predefined coordinate sets should be flagged with OtherCoords,
@@ -262,13 +197,22 @@ public slots:
 	//! The behaviour of DebugAid texts depends on the use case.
 	void removeExtraInfoStrings(const StelObject::InfoStringGroup& flags);
 
+	//! Set whether a pointer is to be drawn over selected object.
+	void setFlagSelectedObjectPointer(bool b)
+	{
+		objectPointerVisibility=b;
+		emit flagSelectedObjectPointerChanged(b);
+
+	}
+	//! Get whether a pointer is to be drawn over selected object.
+	bool getFlagSelectedObjectPointer(void) { return objectPointerVisibility; }
+
 signals:
 	//! Indicate that the selected StelObjects has changed.
 	//! @param action define if the user requested that the objects are added to the selection or just replace it
 	void selectedObjectChanged(StelModule::StelModuleSelectAction);
-
-	//! Signal that the configurable twilight altitude for the sun has changed.
-	void twilightAltitudeChanged(double alt);
+	//! Indicate that the visibility of pointer for selected StelObjects has changed.
+	void flagSelectedObjectPointerChanged(bool b);
 
 private:
 	// The list of StelObjectModule that are referenced in Stellarium
@@ -294,9 +238,6 @@ private:
 	//! Weight of the distance factor when choosing the best object to select.
 	float distanceWeight;
 
-	//! configurable altitude for the sun for "goto next twilight" actions
-	double twilightAltitude;
-
 	//! Location for additional object info that can be set for special purposes (at least for debugging, but maybe others), even via scripting.
 	//! Modules are allowed to add new strings to be displayed in the various getInfoString() methods of subclasses.
 	//! This helps avoiding screen collisions if a plugin wants to display some additional object information.
