@@ -38,14 +38,14 @@ class StelObjectModule : public StelModule
 	Q_OBJECT
 public:
 	StelObjectModule();
-	~StelObjectModule();
+	~StelObjectModule() Q_DECL_OVERRIDE;
 	
 	//! Search for StelObject in an area around a specified point.
 	//! The function searches in a disk of diameter limitFov centered on v.
 	//! Only visible objects (i.e. currently displayed on screen) should be returned.
-	//! @param v equatorial position at epoch J2000.
+	//! @param v equatorial position at epoch J2000 (without aberration).
 	//! @param limitFov angular diameter of the searching zone in degree.
-	//! @param core the core instance to use.
+	//! @param core the StelCore instance to use.
 	//! @return the list of all the displayed objects contained in the defined zone.
 	virtual QList<StelObjectP> searchAround(const Vec3d& v, double limitFov, const StelCore* core) const = 0;
 	
@@ -65,10 +65,9 @@ public:
 	//! Find and return the list of at most maxNbItem objects auto-completing passed object name
 	//! @param objPrefix the first letters of the searched object
 	//! @param maxNbItem the maximum number of returned object names
-	//! @param useStartOfWords decide if start of word is searched
-	//! @param inEnglish list translated names (false) or in English (true)
+	//! @param useStartOfWords decide if start of word is searched	
 	//! @return a list of matching object name by order of relevance, or an empty list if nothing matches
-	virtual QStringList listMatchingObjects(const QString& objPrefix, int maxNbItem=5, bool useStartOfWords=false, bool inEnglish=false) const;
+	virtual QStringList listMatchingObjects(const QString& objPrefix, int maxNbItem=5, bool useStartOfWords=false) const;
 
 	//! List all StelObjects.
 	//! @param inEnglish list names in English (true) or translated (false)
