@@ -21,12 +21,9 @@
 #include "StelUtils.hpp"
 #include "SolarSystem.hpp"
 #include "Planet.hpp"
-#include "StelLocaleMgr.hpp"
-#include "StelTranslator.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 
-#include "StelLocationMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "LandscapeMgr.hpp"
 
@@ -40,6 +37,8 @@ class ArtificialPlanet : public Planet
 public:
 	ArtificialPlanet(const PlanetP& orig);
 	void setDest(const PlanetP& dest);
+	//! computes position and orientation between itself and @variable dest.
+	//! @param f1 mixing factor. [0...1]. 1 means dest.
 	void computeAverage(double f1);
 	//! This does nothing, but avoids a crash.
 	virtual void computePosition(const double dateJDE, const Vec3d &aberrationPush) Q_DECL_OVERRIDE;
@@ -52,7 +51,7 @@ private:
 };
 
 ArtificialPlanet::ArtificialPlanet(const PlanetP& orig) :
-		Planet("art", 0, 0, Vec3f(0,0,0), 0, 0, "", "", "", Q_NULLPTR, Q_NULLPTR, Q_NULLPTR, false, true, false, false, "artificial"),
+		Planet("art", 0, 0, Vec3f(0,0,0), 0, 0, "", "", "", "", Q_NULLPTR, Q_NULLPTR, Q_NULLPTR, false, true, false, false, "artificial"),
 		dest(Q_NULLPTR), orig_name(orig->getEnglishName()), orig_name_i18n(orig->getNameI18n())
 {
 	// set parent = sun:
@@ -212,21 +211,21 @@ double StelObserver::getDistanceFromCenter(void) const
 Vec4d StelObserver::getTopographicOffsetFromCenter(void) const
 {
 	if (getHomePlanet()->getEquatorialRadius()==0.0) // the transitional ArtificialPlanet or SpaceShipObserver have this
-		return Vec4d(0.,0.,static_cast<double>(currentLocation.latitude)*(M_PI/180.0),currentLocation.altitude/(1000.0*AU));
+		return Vec4d(0.,0.,static_cast<double>(currentLocation.getLatitude())*(M_PI/180.0),currentLocation.altitude/(1000.0*AU));
 
-	return getHomePlanet()->getRectangularCoordinates(static_cast<double>(currentLocation.longitude),
-							  static_cast<double>(currentLocation.latitude),
+	return getHomePlanet()->getRectangularCoordinates(static_cast<double>(currentLocation.getLongitude()),
+							  static_cast<double>(currentLocation.getLatitude()),
 							  currentLocation.altitude);
 }
 
 // For Earth we require JD, for other planets JDE to describe rotation!
 Mat4d StelObserver::getRotAltAzToEquatorial(double JD, double JDE) const
 {
-	double lat = qBound(-90.0, static_cast<double>(currentLocation.latitude), 90.0);
+	double lat = qBound(-90.0, static_cast<double>(currentLocation.getLatitude()), 90.0);
 	// TODO: Figure out how to keep continuity in sky as we reach poles
 	// otherwise sky jumps in rotation when reach poles in equatorial mode
 	// This is a kludge
-	return Mat4d::zrotation((getHomePlanet()->getSiderealTime(JD, JDE)+static_cast<double>(currentLocation.longitude))*M_PI/180.)
+	return Mat4d::zrotation((getHomePlanet()->getSiderealTime(JD, JDE)+static_cast<double>(currentLocation.getLongitude()))*M_PI/180.)
 		* Mat4d::yrotation((90.-lat)*M_PI/180.);
 }
 
@@ -235,9 +234,11 @@ Mat4d StelObserver::getRotEquatorialToVsop87(void) const
 	return getHomePlanet()->getRotEquatorialToVsop87();
 }
 
+// The transit can be cut short by feeding atimeToGo, a value smaller than the transition time
 SpaceShipObserver::SpaceShipObserver(const StelLocation& startLoc, const StelLocation& target, double atransitSeconds, double atimeToGo) : StelObserver(startLoc),
 		moveStartLocation(startLoc), moveTargetLocation(target), artificialPlanet(Q_NULLPTR), timeToGo(atimeToGo), transitSeconds(atransitSeconds)
 {
+	Q_ASSERT((atimeToGo<0) || (atimeToGo>=0 && atimeToGo<=atransitSeconds));
 	if(timeToGo<0.0)
 		timeToGo = transitSeconds;
 
@@ -263,6 +264,13 @@ SpaceShipObserver::SpaceShipObserver(const StelLocation& startLoc, const StelLoc
 		artificialPlanet = QSharedPointer<Planet>(artPlanet);
 	}
 	planet = targetPlanet;
+	// avoid confusion with debug messages...
+	currentLocation.region=QString();
+	currentLocation.state=QString();
+	currentLocation.isUserLocation=true;
+	currentLocation.role='X';
+	currentLocation.landscapeKey=moveTargetLocation.landscapeKey;
+	currentLocation.ianaTimeZone=moveTargetLocation.ianaTimeZone;
 }
 
 SpaceShipObserver::~SpaceShipObserver()
@@ -274,6 +282,7 @@ SpaceShipObserver::~SpaceShipObserver()
 bool SpaceShipObserver::update(double deltaTime)
 {
 	if (timeToGo <= 0.) return false; // Already over.
+	if (deltaTime==0.) return false;
 	timeToGo -= deltaTime;
 	SolarSystem* ss = GETSTELMODULE(SolarSystem);
 
@@ -282,21 +291,6 @@ bool SpaceShipObserver::update(double deltaTime)
 	{
 		timeToGo = 0.;
 		currentLocation = moveTargetLocation;
-		LandscapeMgr* lmgr = GETSTELMODULE(LandscapeMgr);
-
-		// we have to avoid auto-select landscape in case the selected new landscape is on our target planet (true if landscape sets location). (LP:#1700199)
-		if ( (lmgr->getFlagLandscapeAutoSelection()) && !(lmgr->getFlagLandscapeSetsLocation()) )
-		{
-			QString pType = ss->getPlanetType(currentLocation.planetName);
-			// If we have a landscape for target planet then set it or check and use
-			// landscape type of target planet, otherwise use default landscape
-			if (lmgr->getAllLandscapeNames().indexOf(currentLocation.planetName)>0)
-				lmgr->setCurrentLandscapeName(currentLocation.planetName);
-			else if (lmgr->getAllLandscapeIDs().indexOf(pType)>0)
-				lmgr->setCurrentLandscapeID(pType);
-			else
-				lmgr->setCurrentLandscapeID(lmgr->getDefaultLandscapeID());
-		}
 	}
 	else
 	{
@@ -313,9 +307,9 @@ bool SpaceShipObserver::update(double deltaTime)
 
 		// Move the lon/lat/alt on the planet
 		const float moveToMult = 1.f-static_cast<float>(timeToGo/transitSeconds);
-		currentLocation.latitude = moveStartLocation.latitude - moveToMult*(moveStartLocation.latitude-moveTargetLocation.latitude);
-		currentLocation.longitude = moveStartLocation.longitude - moveToMult*(moveStartLocation.longitude-moveTargetLocation.longitude);
-		currentLocation.altitude = int(moveStartLocation.altitude - moveToMult*(moveStartLocation.altitude-moveTargetLocation.altitude));		
+		currentLocation.setLatitude( moveStartLocation.getLatitude() - moveToMult*(moveStartLocation.getLatitude()-moveTargetLocation.getLatitude()));
+		currentLocation.setLongitude(moveStartLocation.getLongitude() - moveToMult*(moveStartLocation.getLongitude()-moveTargetLocation.getLongitude()));
+		currentLocation.altitude = int(moveStartLocation.altitude - moveToMult*(moveStartLocation.altitude-moveTargetLocation.altitude));
 	}
 	return true;
 }
