@@ -20,16 +20,19 @@
 #ifndef STELPAINTER_HPP
 #define STELPAINTER_HPP
 
+#include <memory>
 #include "StelOpenGL.hpp"
 #include "VecMath.hpp"
 #include "StelSphereGeometry.hpp"
 #include "StelProjectorType.hpp"
-#include "StelProjector.hpp"
+#include "StelTextureTypes.hpp"
 #include <QString>
 #include <QVarLengthArray>
 #include <QFontMetrics>
 
+class QOpenGLBuffer;
 class QOpenGLShaderProgram;
+class QOpenGLVertexArrayObject;
 
 //! @class StelPainter
 //! Provides functions for performing openGL drawing operations.
@@ -63,15 +66,6 @@ public:
 		TriangleFan                 = 0x0006  //!< GL_TRIANGLE_FAN
 	};
 
-	enum class DitheringMode
-	{
-		Disabled,    //!< Dithering disabled, will leave the infamous color bands
-		Color565,    //!< 16-bit color (AKA High color) with R5_G6_B5 layout
-		Color666,    //!< TN+film typical color depth in TrueColor mode
-		Color888,    //!< 24-bit color (AKA True color)
-		Color101010, //!< 30-bit color (AKA Deep color)
-	};
-
 	explicit StelPainter(const StelProjectorP& prj);
 	~StelPainter();
 
@@ -140,6 +134,12 @@ public:
 	//! Draw a simple circle, 2d viewport coordinates in pixel
 	void drawCircle(float x, float y, float r);
 
+	//! Draw a simple ellipse, 2d viewport coordinates in pixel
+	//! @param rx: radius in x axis
+	//! @param ry: radius in y axis
+	//! @param angle: rotation (counterclockwise), radians [0..2pi]
+	void drawEllipse(double x, double y, double rx, double ry, double angle);
+
 	//! Draw a square using the current texture at the given projected 2d position.
 	//! This method is not thread safe.
 	//! @param x x position in the viewport in pixel.
@@ -285,7 +285,7 @@ public:
 	//! This method needs to be called once before exit.
 	static void deinitGLShaders();
 
-	// Thoses methods should eventually be replaced by a single setVertexArray
+	// These methods should eventually be replaced by a single setVertexArray
 	//! use instead of glVertexPointer
 	void setVertexPointer(int size, GLenum type, const void* pointer) {
 		vertexArray.size = size; vertexArray.type = type; vertexArray.pointer = pointer;
@@ -334,8 +334,6 @@ public:
 	//! @return true if the link was successful.
 	static bool linkProg(class QOpenGLShaderProgram* prog, const QString& name);
 
-	DitheringMode getDitheringMode() const { return ditheringMode; }
-
 private:
 	friend class StelTextureMgr;
 	friend class StelTexture;
@@ -364,7 +362,7 @@ private:
 
 	// From text-use-opengl-buffer
 	static QCache<QByteArray, struct StringTexture> texCache;
-	struct StringTexture* getTexTexture(const QString& str, int pixelSize) const;
+	struct StringTexture* getTextTexture(const QString& str, int pixelSize) const;
 
 	//! Struct describing one opengl array
 	typedef struct ArrayDesc
@@ -374,12 +372,15 @@ private:
 		GLenum type;				// The data type of each coordinate (GL_SHORT, GL_INT, GL_FLOAT, or GL_DOUBLE).
 		const void* pointer;	// Pointer to the first coordinate of the first vertex in the array.
 		bool enabled;			// Define whether the array is enabled or not.
+		size_t vertexSizeInBytes() const;
 	} ArrayDesc;
 
 	//! Project an array using the current projection.
 	//! @return a descriptor of the new array
 	ArrayDesc projectArray(const ArrayDesc& array, int offset, int count, const unsigned short *indices=Q_NULLPTR);
 
+	void drawFixedColorWideLinesAsQuads(const ArrayDesc& vertexArray, int count, int offset, const Mat4f& projMat, DrawingMode mode);
+
 	//! Project the passed triangle on the screen ensuring that it will look smooth, even for non linear distortion
 	//! by splitting it into subtriangles. The resulting vertex arrays are appended to the passed out* ones.
 	//! The size of each edge must be < 180 deg.
@@ -426,6 +427,16 @@ private:
 	static QOpenGLShaderProgram* colorShaderProgram;
 	static BasicShaderVars colorShaderVars;
 
+	static QOpenGLShaderProgram* textShaderProgram;
+	struct TextShaderVars {
+		int projectionMatrix;
+		int texCoord;
+		int vertex;
+		int textColor;
+		int texture;
+	};
+	static TextShaderVars textShaderVars;
+
 	static QOpenGLShaderProgram* texturesShaderProgram;
 	struct TexturesShaderVars {
 		int projectionMatrix;
@@ -433,8 +444,6 @@ private:
 		int vertex;
 		int texColor;
 		int texture;
-		int bayerPattern;
-		int rgbMaxValue;
 	};
 	static TexturesShaderVars texturesShaderVars;
 	static QOpenGLShaderProgram* texturesColorShaderProgram;
@@ -444,15 +453,31 @@ private:
 		int vertex;
 		int color;
 		int texture;
-		int bayerPattern;
-		int rgbMaxValue;
 		int saturation;
 	};
 	static TexturesColorShaderVars texturesColorShaderVars;
 
-	GLuint bayerPatternTex=0;
-	DitheringMode ditheringMode;
-	static DitheringMode parseDitheringMode(QString const& s);
+	static QOpenGLShaderProgram* wideLineShaderProgram;
+	struct WideLineShaderVars {
+		int projectionMatrix;
+		int viewportSize;
+		int lineWidth;
+		int color;
+		int vertex;
+	};
+	static WideLineShaderVars wideLineShaderVars;
+
+	static QOpenGLShaderProgram* colorfulWideLineShaderProgram;
+	struct ColorfulWideLineShaderVars {
+		int projectionMatrix;
+		int viewportSize;
+		int lineWidth;
+		int color;
+		int vertex;
+	};
+	static ColorfulWideLineShaderVars colorfulWideLineShaderVars;
+
+	static bool multisamplingEnabled;
 
 	//! The descriptor for the current opengl vertex array
 	ArrayDesc vertexArray;
@@ -462,9 +487,11 @@ private:
 	ArrayDesc normalArray;
 	//! The descriptor for the current opengl color array
 	ArrayDesc colorArray;
-};
 
-Q_DECLARE_METATYPE(StelPainter::DitheringMode)
+	std::unique_ptr<QOpenGLVertexArrayObject> vao;
+	std::unique_ptr<QOpenGLBuffer> verticesVBO;
+	std::unique_ptr<QOpenGLBuffer> indicesVBO;
+};
 
 #endif // STELPAINTER_HPP
 
