@@ -22,13 +22,14 @@
 #include <QObject>
 #include <QSet>
 #include <QMetaProperty>
+#include "StelApp.hpp"
 
 class StelProperty;
 
 //! Abstract base class for a StelProperty proxy implementation, which allow reacting to the
 //! StelProperty::changed event using a specific type instead of reacting to the QVariant version.
 //! This is required for some connections such as in the UI.
-//! The intented use is to subclass this class and implement the onPropertyChanged() slot,
+//! The intended use is to subclass this class and implement the onPropertyChanged() slot,
 //! re-emitting the "changed" event with a type-converted value.
 class StelPropertyProxy : public QObject
 {
@@ -194,6 +195,8 @@ signals:
 //!
 //!	//alternatively, use this to skip having to get the StelProperty instance:
 //!	//StelApp::getInstance().getStelPropertyManager()->setStelPropertyValue("MyCustomModule.awesomeProperty", 123);
+//!     // or even, much shorter, assuming awesomeProperty is an int,
+//!     // GETSTELPROPERTYVALUE("MyCustomModule.awesomeProperty").toInt();
 //!
 //!	//to see the effect
 //!	MyCustomModule *module = GETSTELMODULE(MyCustomModule);
@@ -337,4 +340,6 @@ private:
 	StelPropertyMap propMap;
 };
 
+#define GETSTELPROPERTYVALUE(pName) StelApp::getInstance().getStelPropertyManager()->getStelPropertyValue(pName, false)
+
 #endif
