@@ -40,27 +40,28 @@ StelSkyCultureMgr::StelSkyCultureMgr()
 
 	QSet<QString> cultureDirNames = StelFileMgr::listContents("skycultures",StelFileMgr::Directory);
 	
-	for (const auto& dir : qAsConst(cultureDirNames))
+	for (const auto& dir : std::as_const(cultureDirNames))
 	{
 		QString pdFile = StelFileMgr::findFile("skycultures/" + dir + "/info.ini");
 		if (pdFile.isEmpty())
 		{
 			qWarning() << "WARNING: unable to successfully read info.ini file from skyculture dir" << QDir::toNativeSeparators(dir);
-			return;
+			continue;
 		}
 		QSettings pd(pdFile, StelIniFormat);
 		dirToNameEnglish[dir].englishName = pd.value("info/name").toString();
 		dirToNameEnglish[dir].author = pd.value("info/author").toString();
 		dirToNameEnglish[dir].credit = pd.value("info/credit").toString();		
 		dirToNameEnglish[dir].license = pd.value("info/license", "").toString();
+		dirToNameEnglish[dir].region = pd.value("info/region", "").toString();
 		QString boundariesStr = pd.value("info/boundaries", "none").toString();
-		static const QMap<QString, StelSkyCulture::BOUNDARIES>boundariesMap={
-			{ "none",    StelSkyCulture::NONE},
-			{ "iau",     StelSkyCulture::IAU},
-			{ "generic", StelSkyCulture::IAU}, // deprecated, add warning below
-			{ "own",     StelSkyCulture::OWN},
+		static const QMap<QString, StelSkyCulture::BoundariesType> boundariesMap = {
+			{ "none",    StelSkyCulture::BoundariesType::None},
+			{ "iau",     StelSkyCulture::BoundariesType::IAU},
+			{ "generic", StelSkyCulture::BoundariesType::IAU}, // deprecated, add warning below
+			{ "own",     StelSkyCulture::BoundariesType::Own},
 		};
-		StelSkyCulture::BOUNDARIES boundaries = boundariesMap.value(boundariesStr.toLower(), StelSkyCulture::NONE);
+		const auto boundariesType = boundariesMap.value(boundariesStr.toLower(), StelSkyCulture::BoundariesType::None);
 		if (boundariesStr.contains("generic", Qt::CaseInsensitive))
 		{
 			qDebug() << "Skyculture " << dir << "'s boundaries is given with deprecated 'generic'. Please edit info.ini and change to 'iau'";
@@ -70,7 +71,7 @@ StelSkyCultureMgr::StelSkyCultureMgr()
 			qDebug() << "Skyculture " << dir << "'s boundaries value unknown:" << boundariesStr;
 			qDebug() << "Please edit info.ini and change to a supported value. For now, this equals 'none'";
 		}
-		dirToNameEnglish[dir].boundaries = boundaries;
+		dirToNameEnglish[dir].boundariesType = boundariesType;
 		// Use 'traditional' as default
 		QString classificationStr = pd.value("info/classification", "traditional").toString();
 		static const QMap <QString, StelSkyCulture::CLASSIFICATION>classificationMap={
@@ -99,10 +100,17 @@ StelSkyCultureMgr::~StelSkyCultureMgr()
 //! Init itself from a config file.
 void StelSkyCultureMgr::init()
 {
-	defaultSkyCultureID = StelApp::getInstance().getSettings()->value("localization/sky_culture", "western").toString();
+	defaultSkyCultureID = StelApp::getInstance().getSettings()->value("localization/sky_culture", "modern").toString();
+	if (defaultSkyCultureID=="western") // switch to new Sky Culture ID
+		defaultSkyCultureID = "modern";
 	setCurrentSkyCultureID(defaultSkyCultureID);
 }
 
+void StelSkyCultureMgr::reloadSkyCulture()
+{
+	emit currentSkyCultureChanged(currentSkyCultureDir);
+}
+
 //! Set the current sky culture from the passed directory
 bool StelSkyCultureMgr::setCurrentSkyCultureID(const QString& cultureDir)
 {
@@ -110,17 +118,21 @@ bool StelSkyCultureMgr::setCurrentSkyCultureID(const QString& cultureDir)
 	if(cultureDir==currentSkyCultureDir)
 		return false;
 
+	QString scID = cultureDir;
+	bool result = true;
 	// make sure culture definition exists before attempting or will die
 	if (directoryToSkyCultureEnglish(cultureDir) == "")
 	{
 		qWarning() << "Invalid sky culture directory: " << QDir::toNativeSeparators(cultureDir);
-		return false;
+		scID = "modern";
+		result = false;
 	}
-	currentSkyCultureDir = cultureDir;
-	currentSkyCulture = dirToNameEnglish[cultureDir];
+
+	currentSkyCultureDir = scID;
+	currentSkyCulture = dirToNameEnglish[scID];
 
 	emit currentSkyCultureChanged(currentSkyCultureDir);
-	return true;
+	return result;
 }
 
 // Set the default sky culture from the ID.
@@ -151,9 +163,9 @@ QString StelSkyCultureMgr::getCurrentSkyCultureEnglishName() const
 	return currentSkyCulture.englishName;
 }
 
-int StelSkyCultureMgr::getCurrentSkyCultureBoundariesIdx() const
+StelSkyCulture::BoundariesType StelSkyCultureMgr::getCurrentSkyCultureBoundariesType() const
 {
-	return currentSkyCulture.boundaries;
+	return currentSkyCulture.boundariesType;
 }
 
 int StelSkyCultureMgr::getCurrentSkyCultureClassificationIdx() const
@@ -232,6 +244,11 @@ QString StelSkyCultureMgr::getCurrentSkyCultureHtmlLicense() const
 			color = "#33ff33"; // "green" area; free license
 			description = q_("This sky culture is provided under GNU General Public License. You can use it for commercial and non-commercial purposes, freely adapt it and share adapted work.");
 		}
+		else if (license.contains("MIT", Qt::CaseSensitive))
+		{
+			color = "#33ff33"; // "green" area; free license
+			description = q_("This sky culture is provided under MIT License. You can use it for commercial and non-commercial purposes, freely adapt it and share adapted work.");
+		}
 		else if (license.startsWith("CC", Qt::CaseSensitive) || license.contains("Creative Commons", Qt::CaseInsensitive))
 		{
 			description = q_("This sky culture is provided under Creative Commons License.");
@@ -279,6 +296,25 @@ QString StelSkyCultureMgr::getCurrentSkyCultureHtmlLicense() const
 	return html;
 }
 
+QString StelSkyCultureMgr::getCurrentSkyCultureHtmlRegion() const
+{
+	QString html = "", region = currentSkyCulture.region.trimmed();
+	QString description = q_("The region indicates the geographical area of origin of a given sky culture.");
+
+	// special case: modern sky culture
+	if (getCurrentSkyCultureID().contains("modern", Qt::CaseInsensitive))
+	{
+		// TRANSLATIONS: This is the name of a geographical "pseudo-region" on Earth
+		region = N_("World");
+		description = q_("All 'modern' sky cultures are based on the IAU-approved 88 constellations with standardized boundaries and are used worldwide. The origins of these constellations are pan-European.");
+	}
+
+	if (!region.isEmpty()) // Region marker is always 'green'
+		html = QString("<dl><dt><span style='color:#33ff33;'>%4</span> <strong>%1 %2</strong></dt><dd><em>%3</em></dd></dl>").arg(q_("Region:"), q_(region), description, QChar(0x25CF));
+
+	return html;
+}
+
 bool StelSkyCultureMgr::setCurrentSkyCultureNameI18(const QString& cultureName)
 {
 	return setCurrentSkyCultureID(skyCultureI18ToDirectory(cultureName));
@@ -351,6 +387,7 @@ QString StelSkyCultureMgr::getCurrentSkyCultureHtmlDescription() const
 	description.append(getCurrentSkyCultureHtmlReferences());
 	description.append(getCurrentSkyCultureHtmlLicense());
 	description.append(getCurrentSkyCultureHtmlClassification());
+	description.append(getCurrentSkyCultureHtmlRegion());
 
 	return description;
 }
@@ -370,7 +407,7 @@ QString StelSkyCultureMgr::getCurrentSkyCultureHtmlReferences() const
 		QString record;
 		// Allow empty and comment lines where first char (after optional blanks) is #
 		static const QRegularExpression commentRx("^(\\s*#.*|\\s*)$");
-		reference = QString("<h2>%1</h2><ol>").arg(q_("References"));
+		reference = QString("<h2>%1</h2><ol>").arg(q_("References / Further Reading"));
 		int totalRecords=0;
 		int readOk=0;
 		int lineNumber=0;
