@@ -38,13 +38,13 @@ public:
 	//! Most traditional skies do not have boundaries.
 	//! Some atlases in the 18th and 19th centuries had curved boundaries that differed between authors.
 	//! Only IAU implemented "approved" boundaries, but a similar technique could be used for other skycultures.
-	enum BOUNDARIES
+	enum class BoundariesType
 	{
-		NONE = -1,
+		None = -1,
 		IAU,
-		OWN
+		Own
 	};
-	Q_ENUM(BOUNDARIES)
+	Q_ENUM(BoundariesType)
 
 	//! Since V0.19. A rough classification scheme that may allow filtering and at least some rough idea of quality control.
 	//! In future versions, this scheme could be refined or changed, and external reviewers
@@ -94,8 +94,10 @@ public:
 	QString credit;
 	//! The license
 	QString license;
-	//! Type of the boundaries (enum)
-	BOUNDARIES boundaries;
+	//! The name of region
+	QString region;
+	//! Type of the boundaries
+	BoundariesType boundariesType;
 	//! Classification of sky culture (enum)
 	CLASSIFICATION classification;
 };
@@ -145,14 +147,12 @@ public slots:
 	//! @param id the sky culture ID.
 	//! @return true on success; else false.
 	bool setCurrentSkyCultureID(const QString& id);
+	//! Reload the current sky culture
+	void reloadSkyCulture();
 
 	//! Get the type of boundaries of the current sky culture
 	//! Config option: info/boundaries
-	//! Keys:
-	//! - none (-1; using by default)
-	//! - generic (0)
-	//! - own (1)
-	int getCurrentSkyCultureBoundariesIdx() const;
+	StelSkyCulture::BoundariesType getCurrentSkyCultureBoundariesType() const;
 
 	//! Get the classification index for the current sky culture
 	//! Config option: info/classification
@@ -169,6 +169,9 @@ public slots:
 	//! @return a localized HTML description of the license for the current sky culture
 	QString getCurrentSkyCultureHtmlLicense() const;
 
+	//! @return a localized HTML description of the region for the current sky culture
+	QString getCurrentSkyCultureHtmlRegion() const;
+
 	//! @return a localized HTML description of the references for the current sky culture
 	QString getCurrentSkyCultureHtmlReferences() const;
 
