@@ -35,7 +35,9 @@
 #include "Landscape.hpp"
 
 #include <QOpenGLContext>
+#include <QOpenGLVertexArrayObject>
 #include <QOpenGLShaderProgram>
+#include <QOpenGLBuffer>
 #include <QStringList>
 #include <QSettings>
 #include <QDebug>
@@ -48,6 +50,8 @@
 StelSkyDrawer::StelSkyDrawer(StelCore* acore) :
 	core(acore),
 	eye(acore->getToneReproducer()),
+	vao(new QOpenGLVertexArrayObject),
+	vbo(new QOpenGLBuffer(QOpenGLBuffer::VertexBuffer)),
 	maxAdaptFov(180.f),
 	minAdaptFov(0.1f),
 	lnfovFactor(0.f),
@@ -160,31 +164,31 @@ void StelSkyDrawer::init()
 	// Create shader program
 	QOpenGLShader vshader(QOpenGLShader::Vertex);
 	const char *vsrc =
-		"attribute mediump vec2 pos;\n"
-		"attribute mediump vec2 texCoord;\n"
-		"attribute mediump vec3 color;\n"
+		"ATTRIBUTE mediump vec2 pos;\n"
+		"ATTRIBUTE mediump vec2 texCoord;\n"
+		"ATTRIBUTE mediump vec3 color;\n"
 		"uniform mediump mat4 projectionMatrix;\n"
-		"varying mediump vec2 texc;\n"
-		"varying mediump vec3 outColor;\n"
+		"VARYING mediump vec2 texc;\n"
+		"VARYING mediump vec3 outColor;\n"
 		"void main(void)\n"
 		"{\n"
 		"    gl_Position = projectionMatrix * vec4(pos.x, pos.y, 0, 1);\n"
 		"    texc = texCoord;\n"
 		"    outColor = color;\n"
 		"}\n";
-	vshader.compileSourceCode(vsrc);
+	vshader.compileSourceCode(StelOpenGL::globalShaderPrefix(StelOpenGL::VERTEX_SHADER) + vsrc);
 	if (!vshader.log().isEmpty()) { qWarning() << "StelSkyDrawer::init(): Warnings while compiling vshader: " << vshader.log(); }
 
 	QOpenGLShader fshader(QOpenGLShader::Fragment);
 	const char *fsrc =
-		"varying mediump vec2 texc;\n"
-		"varying mediump vec3 outColor;\n"
+		"VARYING mediump vec2 texc;\n"
+		"VARYING mediump vec3 outColor;\n"
 		"uniform sampler2D tex;\n"
 		"void main(void)\n"
 		"{\n"
-		"    gl_FragColor = texture2D(tex, texc)*vec4(outColor, 1.);\n"
+		"    FRAG_COLOR = texture2D(tex, texc)*vec4(outColor, 1.);\n"
 		"}\n";
-	fshader.compileSourceCode(fsrc);
+	fshader.compileSourceCode(StelOpenGL::globalShaderPrefix(StelOpenGL::FRAGMENT_SHADER) + fsrc);
 	if (!fshader.log().isEmpty()) { qWarning() << "StelSkyDrawer::init(): Warnings while compiling fshader: " << fshader.log(); }
 
 	starShaderProgram = new QOpenGLShaderProgram(QOpenGLContext::currentContext());
@@ -197,9 +201,57 @@ void StelSkyDrawer::init()
 	starShaderVars.color = starShaderProgram->attributeLocation("color");
 	starShaderVars.texture = starShaderProgram->uniformLocation("tex");
 
+	vbo->create();
+	vbo->bind();
+	vbo->setUsagePattern(QOpenGLBuffer::StreamDraw);
+	vbo->allocate(maxPointSources*6*sizeof(StarVertex) + maxPointSources*6*2);
+
+	if(vao->create())
+	{
+		vao->bind();
+		setupCurrentVAO();
+		vao->release();
+	}
+
+	vbo->release();
+
 	update(0);
 }
 
+void StelSkyDrawer::setupCurrentVAO()
+{
+	vbo->bind();
+	starShaderProgram->setAttributeBuffer(starShaderVars.pos, GL_FLOAT, 0, 2, sizeof(StarVertex));
+	starShaderProgram->setAttributeBuffer(starShaderVars.color, GL_UNSIGNED_BYTE, offsetof(StarVertex,color), 3, sizeof(StarVertex));
+	starShaderProgram->setAttributeBuffer(starShaderVars.texCoord, GL_UNSIGNED_BYTE, maxPointSources*6*sizeof(StarVertex), 2, 0);
+	vbo->release();
+	starShaderProgram->enableAttributeArray(starShaderVars.pos);
+	starShaderProgram->enableAttributeArray(starShaderVars.color);
+	starShaderProgram->enableAttributeArray(starShaderVars.texCoord);
+}
+
+void StelSkyDrawer::bindVAO()
+{
+	if(vao->isCreated())
+		vao->bind();
+	else
+		setupCurrentVAO();
+}
+
+void StelSkyDrawer::releaseVAO()
+{
+	if(vao->isCreated())
+	{
+		vao->release();
+	}
+	else
+	{
+		starShaderProgram->disableAttributeArray(starShaderVars.pos);
+		starShaderProgram->disableAttributeArray(starShaderVars.color);
+		starShaderProgram->disableAttributeArray(starShaderVars.texCoord);
+	}
+}
+
 void StelSkyDrawer::update(double)
 {
 	float fov = static_cast<float>(core->getMovementMgr()->getCurrentFov());
@@ -215,7 +267,7 @@ void StelSkyDrawer::update(double)
 
 	if (getFlagHasAtmosphere() && core->getJD()>2387627.5) // JD given is J1825.0; ignore Bortle scale index before that.
 	{
-        // GZ: Light pollution must take global atmosphere setting into acount!
+        // GZ: Light pollution must take global atmosphere setting into account!
         // moved parts from setBortleScale() here
         // This formula is a fit to a set of values calibrated by hand, looking at the faintest star in stellarium at around 40 deg FOV.
         // It should roughly match the scale described at http://en.wikipedia.org/wiki/Bortle_Dark-Sky_Scale
@@ -397,43 +449,37 @@ void StelSkyDrawer::postDrawPointSource(StelPainter* sPainter)
 	const Mat4f& m = sPainter->getProjector()->getProjectionMatrix();
 	const QMatrix4x4 qMat(m[0], m[4], m[8], m[12], m[1], m[5], m[9], m[13], m[2], m[6], m[10], m[14], m[3], m[7], m[11], m[15]);
 	
+	vbo->bind();
+	vbo->write(0, vertexArray, nbPointSources*6*sizeof(StarVertex));
+	vbo->write(maxPointSources*6*sizeof(StarVertex), textureCoordArray, nbPointSources*6*2);
+	vbo->release();
+
 	starShaderProgram->bind();
-	starShaderProgram->setAttributeArray(starShaderVars.pos, GL_FLOAT, reinterpret_cast<GLfloat*>(vertexArray), 2, sizeof(StarVertex));
-	starShaderProgram->enableAttributeArray(starShaderVars.pos);
-	starShaderProgram->setAttributeArray(starShaderVars.color, GL_UNSIGNED_BYTE, reinterpret_cast<GLubyte*>(&(vertexArray[0].color)), 3, sizeof(StarVertex));
-	starShaderProgram->enableAttributeArray(starShaderVars.color);
 	starShaderProgram->setUniformValue(starShaderVars.projectionMatrix, qMat);
-	starShaderProgram->setAttributeArray(starShaderVars.texCoord, GL_UNSIGNED_BYTE, static_cast<GLubyte*>(textureCoordArray), 2, 0);
-	starShaderProgram->enableAttributeArray(starShaderVars.texCoord);
 	
+	bindVAO();
 	glDrawArrays(GL_TRIANGLES, 0, static_cast<GLsizei>(nbPointSources)*6);
-	
-	starShaderProgram->disableAttributeArray(starShaderVars.pos);
-	starShaderProgram->disableAttributeArray(starShaderVars.color);
-	starShaderProgram->disableAttributeArray(starShaderVars.texCoord);
+	releaseVAO();
+
 	starShaderProgram->release();
 	
 	nbPointSources = 0;
 }
 
 // Draw a point source halo.
-bool StelSkyDrawer::drawPointSource(StelPainter* sPainter, const Vec3f& v, const RCMag& rcMag, const Vec3f& color, bool checkInScreen, float twinkleFactor)
+bool StelSkyDrawer::drawPointSource(StelPainter* sPainter, const Vec3d& v, const RCMag& rcMag, const Vec3f& color, bool checkInScreen, float twinkleFactor)
 {
 	Q_ASSERT(sPainter);
 
 	if (rcMag.radius<=0.f)
 		return false;
 
-	Vec3f win;
+	Vec3d win;
 	if (!(checkInScreen ? sPainter->getProjector()->projectCheck(v, win) : sPainter->getProjector()->project(v, win)))
 		return false;
 
-	const float radius = rcMag.radius;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+	const float radius = rcMag.radius * static_cast<float>(sPainter->getProjector()->getDevicePixelsPerPixel());
 	const float frand=StelApp::getInstance().getRandF();
-#else
-	const float frand=static_cast<float>(qrand())/static_cast<float>(RAND_MAX);
-#endif
 
 	// Random coef for star twinkling. twinkleFactor can introduce height-dependent twinkling.
 	const float tw = ((flagStarTwinkle && (flagHasAtmosphere || flagForcedTwinkle))) ? (1.f-twinkleFactor*static_cast<float>(twinkleAmount)*frand)*rcMag.luminance : rcMag.luminance;
@@ -484,7 +530,7 @@ void StelSkyDrawer::drawSunCorona(StelPainter* painter, const Vec3f& v, float ra
 	// For some reason we must mix color with the given alpha as well, else mixing does not work.
 	painter->setColor(color*alpha, alpha);
 	// pre-compensate the automatic scaling of sprite painting on HiDPI screens
-	radius /= static_cast<float>(painter->getProjector()->getDevicePixelsPerPixel())*StelApp::getInstance().getGlobalScalingRatio();
+	radius /= static_cast<float>(painter->getProjector()->getDevicePixelsPerPixel());
 	// Our corona image was made in 2008-08-01 near Khovd, Mongolia. It shows the correct parallactic angle for its location and time, we must add this, and subtract the ecliptic/equator angle from that date of 15.43 degrees.
 	painter->drawSprite2dMode(win[0], win[1], radius, -angle+44.65f-15.43f);
 
@@ -492,7 +538,7 @@ void StelSkyDrawer::drawSunCorona(StelPainter* painter, const Vec3f& v, float ra
 }
 
 // Terminate drawing of a 3D model, draw the halo
-void StelSkyDrawer::postDrawSky3dModel(StelPainter* painter, const Vec3f& v, float illuminatedArea, float mag, const Vec3f& color, const bool isSun)
+void StelSkyDrawer::postDrawSky3dModel(StelPainter* painter, const Vec3d& v, float illuminatedArea, float mag, const Vec3f& color, const bool isSun)
 {
 	const float pixPerRad = painter->getProjector()->getPixelPerRadAtCenter();
 	// Assume a disk shape
@@ -568,9 +614,7 @@ void StelSkyDrawer::postDrawSky3dModel(StelPainter* painter, const Vec3f& v, flo
 			Q_ASSERT(lmgr);
 			Landscape *landscape=lmgr->getCurrentLandscape();
 			Q_ASSERT(landscape);
-			// Preliminary: create new Vec3d here. Later: consider replacing to vec3d in the arguments!
-			Vec3d vec=v.toVec3d();
-			float opacity=(landscape->getFlagShow() ? landscape->getOpacity(core->j2000ToAltAz(vec, StelCore::RefractionAuto)) : 0.0f);
+			float opacity=(landscape->getFlagShow() ? landscape->getOpacity(core->j2000ToAltAz(v, StelCore::RefractionAuto)) : 0.0f);
 			reportLuminanceInFov(qMin(700.f, qMin(wl/50, (60.f*60.f)/(fov*fov)*6.f))*(1.0f-opacity));
 		}
 	}
@@ -830,9 +874,9 @@ static Vec3f Gamma(float gamma,const Vec3f &x)
 void StelSkyDrawer::initColorTableFromConfigFile(QSettings* conf)
 {
 	std::map<float,Vec3f> color_map;
-	for (float bV=-0.5f;bV<=4.0f;bV+=0.01f)
+	for (int bV100=-50;bV100<=400;bV100++)
 	{
-		QString entry = QString::asprintf("bv_color_%+5.2f", static_cast<double>(bV));
+		QString entry = QString::asprintf("bv_color_%+5.2f", static_cast<double>(bV100)*0.01);
 		const QStringList s(conf->value(QString("stars/") + entry).toStringList());
 		if (!s.isEmpty())
 		{
@@ -841,7 +885,7 @@ void StelSkyDrawer::initColorTableFromConfigFile(QSettings* conf)
 				c = Vec3f(s[0]);
 			else
 				c =Vec3f(s);
-			color_map[bV] = Gamma(eye->getDisplayGamma(),c);
+			color_map[bV100*0.01f] = Gamma(eye->getDisplayGamma(),c);
 		}
 	}
 
