@@ -23,15 +23,17 @@
 #include "StelApp.hpp"
 #include "RefractionExtinction.hpp"
 #include "StelTextureTypes.hpp"
-#include "StelProjectorType.hpp"
 #include "VecMath.hpp"
-#include "StelOpenGL.hpp"
 
+#include <memory>
 #include <QObject>
 #include <QImage>
 #include <QSettings>
+#include <QOpenGLFunctions>
 
+class QOpenGLVertexArrayObject;
 class StelToneReproducer;
+class QOpenGLBuffer;
 class StelCore;
 class StelPainter;
 
@@ -108,12 +110,12 @@ public:
 	//! @param checkInScreen whether source in screen should be checked to avoid unnecessary drawing.
 	//! @param twinkleFactor allows height-dependent twinkling. Recommended value: min(1,1-0.9*sin(altitude)). Allowed values [0..1]
 	//! @return true if the source was actually visible and drawn
-	bool drawPointSource(StelPainter* sPainter, const Vec3f& v, const RCMag &rcMag, int bVindex, bool checkInScreen=false, float twinkleFactor=1.0f)
+	bool drawPointSource(StelPainter* sPainter, const Vec3d& v, const RCMag &rcMag, int bVindex, bool checkInScreen=false, float twinkleFactor=1.0f)
 	{
 		return drawPointSource(sPainter, v, rcMag, colorTable[bVindex], checkInScreen, twinkleFactor);
 	}
 
-	bool drawPointSource(StelPainter* sPainter, const Vec3f& v, const RCMag &rcMag, const Vec3f& bcolor, bool checkInScreen=false, float twinkleFactor=1.0f);
+	bool drawPointSource(StelPainter* sPainter, const Vec3d& v, const RCMag &rcMag, const Vec3f& bcolor, bool checkInScreen=false, float twinkleFactor=1.0f);
 
 	//! Draw an image of the solar corona onto the screen at position v.
 	//! @param radius depends on the actually used texture and current disk size of the sun.
@@ -128,7 +130,7 @@ public:
 	//! @param mag the source integrated magnitude
 	//! @param color the object halo RGB color
 	//! @param isSun the object is the sun (will be drawn with different texture)
-	void postDrawSky3dModel(StelPainter* p, const Vec3f& v, float illuminatedArea, float mag, const Vec3f& color = Vec3f(1.f,1.f,1.f), const bool isSun=false);
+	void postDrawSky3dModel(StelPainter* p, const Vec3d& v, float illuminatedArea, float mag, const Vec3f& color = Vec3f(1.f,1.f,1.f), const bool isSun=false);
 
 	//! Compute RMag and CMag from magnitude.
 	//! @param mag the object integrated V magnitude
@@ -215,7 +217,7 @@ public slots:
 	bool getFlagStarSpiky() const {return flagStarSpiky;}
 
 	//! Get the magnitude of the currently faintest visible point source
-	//! It depends on the zoom level, on the eye adapation and on the point source rendering parameters
+	//! It depends on the zoom level, on the eye adaptation and on the point source rendering parameters
 	//! @return the limit V mag at which a point source will be displayed
 	float getLimitMagnitude() const {return limitMagnitude;}
 
@@ -255,7 +257,7 @@ public slots:
 	void setCustomPlanetMagnitudeLimit(double limit) { customPlanetMagLimit=limit; emit customPlanetMagLimitChanged(limit);}
 
 	//! Get the luminance of the faintest visible object (e.g. RGB<0.05)
-	//! It depends on the zoom level, on the eye adapation and on the point source rendering parameters
+	//! It depends on the zoom level, on the eye adaptation and on the point source rendering parameters
 	//! @return the limit V luminance at which an object will be visible
 	float getLimitLuminance() const {return limitLuminance;}
 
@@ -300,7 +302,7 @@ public slots:
 	//! Set the radius of the big halo texture used when a 3d model is very bright.
 	void setBig3dModelHaloRadius(float r) {big3dModelHaloRadius=r;}
 
-	// GZ These are to find out the best sky parameters. Maybe keep this as program feature for debugging/expert mode?
+	// These are to find out the best sky parameters. Program feature for debugging/expert mode.
 	// These will be connected from AtmosphereDialog and forward the settings to SkyLight class.
 
 	void setFlagDrawSunAfterAtmosphere(bool val){
@@ -329,7 +331,7 @@ public slots:
 		emit flagTfromKChanged(val);
 		}
 
-		double getT(void) const {return static_cast<double>(turbidity);}
+	double getT(void) const {return static_cast<double>(turbidity);}
 	void setT(double newT){
 	    turbidity=static_cast<float>(newT);
 		QSettings* conf = StelApp::getInstance().getSettings();
@@ -376,7 +378,6 @@ signals:
 	void atmosphereTemperatureChanged(double celsius);
 	void atmospherePressureChanged(double mbar);
 
-	// GZ atmosphere tweaks
 	void flagTfromKChanged(bool b);
 	void flagDrawSunAfterAtmosphereChanged(bool b);
 	void flagEarlySunHaloChanged(bool b);
@@ -432,9 +433,19 @@ private:
 	//! is displayed with a halo of size targetRadius
 	float findWorldLumForMag(float mag, float targetRadius) const;
 
+	//! Binds actual VAO if it's supported, sets up the relevant state manually otherwise.
+	void bindVAO();
+	//! Sets the vertex attribute states for the currently bound VAO so that glDraw* commands can work.
+	void setupCurrentVAO();
+	//! Binds zero VAO if VAO is supported, manually disables the relevant vertex attributes otherwise.
+	void releaseVAO();
+
 	StelCore* core;
 	StelToneReproducer* eye;
 
+	std::unique_ptr<QOpenGLVertexArrayObject> vao;
+	std::unique_ptr<QOpenGLBuffer> vbo;
+
 	Extinction extinction;
 	Refraction refraction;
 
@@ -547,8 +558,7 @@ private:
 	double daylightLabelThreshold;
 
 	float big3dModelHaloRadius;
-	// Settings for Atmospheric tweaks:
-	bool flagDrawSunAfterAtmosphere;
+	bool flagDrawSunAfterAtmosphere; // Overdraw to avoid color mixing. Useful to allow deep-red suns, but may also look ugly.
 	bool flagEarlySunHalo; // Used to select if solar halo is plotted before (true) or after (default, false) the 3D sphere.
 	bool flagTfromK; // true to compute T from extinction k
 	float turbidity; // atmospheric turbidity: Preetham sky usable for 2<T<6, best at T=5.
