@@ -19,7 +19,6 @@
 
 #include "StelTranslator.hpp"
 #include "StelFileMgr.hpp"
-#include "StelUtils.hpp"
 
 #include <QFile>
 #include <QDebug>
@@ -96,7 +95,7 @@ void StelTranslator::initSystemLanguage()
 }
 
 
-//! Convert from ISO639-1 2(+3) letters langage code to native language name
+//! Convert from ISO639-1 2(+3) letters language code to native language name
 QString StelTranslator::iso639_1CodeToNativeName(const QString& languageCode)
 {
 	if (languageCode=="C")
@@ -119,7 +118,7 @@ QString StelTranslator::iso639_1CodeToNativeName(const QString& languageCode)
 	return languageCode;
 }
 
-//! Convert from native language name to ISO639-1 2(+3) letters langage code
+//! Convert from native language name to ISO639-1 2(+3) letters language code
 QString StelTranslator::nativeNameToIso639_1Code(const QString& languageName)
 {
 	QMap<QString, QString>::ConstIterator iter;
@@ -158,8 +157,9 @@ QStringList StelTranslator::getAvailableIso639_1Codes(const QString& localeDir)
 		return QStringList();
 	}
 
+	const QStringList entries=dir.entryList(QDir::Files, QDir::Name);
 	QStringList result;
-	for (auto path : dir.entryList(QDir::Files, QDir::Name))
+	for (auto path : entries)
 	{
 		if (!path.endsWith(".qm"))
 			continue;
@@ -190,7 +190,8 @@ void StelTranslator::initIso639_1LanguageCodes(const QString& fileName)
 		if (record.startsWith("//") || record.startsWith("#") || record.isEmpty()) // skip comments and empty lines
 			continue;
 
-		record.remove(QRegularExpression("[\\n\\r]*$")); // chomp new lines
+		static const QRegularExpression nlExp("[\\n\\r]*$");
+		record.remove(nlExp); // chomp new lines
 		#if (QT_VERSION>=QT_VERSION_CHECK(5, 14, 0))
 		const QStringList& fields = record.split("\t", Qt::SkipEmptyParts);
 		#else
