@@ -40,7 +40,7 @@
 #define SPEED_OF_LIGHT 299792.458
 // Ecliptic obliquity of J2000.0, degrees
 #define EPS_0 23.4392803055555555555556
-// Equatorial radius of the Earth in km
+// Equatorial radius of the Earth in km (WGS-84)
 #define EARTH_RADIUS 6378.1366
 // Equatorial radius of the Sun in km
 #define SUN_RADIUS 696000.
@@ -82,15 +82,24 @@
 //! @namespace StelUtils contains general purpose utility functions.
 namespace StelUtils
 {
-	//! Return the full name of stellarium, i.e. "stellarium 0.9.0"
+	//! Return the full name of stellarium, i.e. "Stellarium 23.1"
 	QString getApplicationName();
 
-	//! Return the version of stellarium, i.e. "0.9.0"
+	//! Return the version of stellarium, i.e. "23.1.0"
 	QString getApplicationVersion();
 
-	//! Return the name and the version of operating system, i.e. "Mac OS X 10.7"
+	//! Return the public version of stellarium, i.e. "23.1"
+	QString getApplicationPublicVersion();
+
+	//! Return the series of stellarium, i.e. "23.0"
+	QString getApplicationSeries();
+
+	//! Return the name and the version of operating system, i.e. "macOS 12.5"
 	QString getOperatingSystemInfo();
 
+	//! Return the name and the version of compiler, which was used for building the planetarium, i.e. "GCC 9.3.0"
+	QString getCompilerInfo();
+
 	//! Return the user agent name, i.e. "Stellarium/0.15.0 (Linux)"
 	QString getUserAgentString();
 
@@ -253,7 +262,7 @@ namespace StelUtils
 	//! @param lat double* to store latitude in radian
 	//! @param v the input 3D vector
 	inline void rectToSphe(double *lng, double *lat, const Vec3d& v){
-		double r = v.length();
+		double r = v.norm();
 		*lat = asin(v[2]/r);
 		*lng = atan2(v[1],v[0]);
 	}
@@ -263,7 +272,7 @@ namespace StelUtils
 	//! @param lat float* to store latitude in radian
 	//! @param v the input 3D vector
 	inline void rectToSphe(float *lng, float *lat, const Vec3d& v){
-		double r = v.length();
+		double r = v.norm();
 		*lat = static_cast<float>(asin(v[2]/r));
 		*lng = static_cast<float>(atan2(v[1],v[0]));
 	}
@@ -274,7 +283,7 @@ namespace StelUtils
 	//! @param lat float* to store latitude in radian
 	//! @param v the input 3D vector
 	inline void rectToSphe(float *lng, float *lat, const Vec3f& v){
-		float r = v.length();
+		float r = v.norm();
 		*lat = asinf(v[2]/r);
 		*lng = atan2f(v[1],v[0]);
 	}
@@ -284,7 +293,7 @@ namespace StelUtils
 	//! @param lat double* to store latitude in radian
 	//! @param v the input 3D vector
 	inline void rectToSphe(double *lng, double *lat, const Vec3f &v){
-		double r = static_cast<double>(v.length());
+		double r = static_cast<double>(v.norm());
 		*lat = asin(static_cast<double>(v[2])/r);
 		*lng = atan2(static_cast<double>(v[1]),static_cast<double>(v[0]));
 	}
@@ -305,7 +314,7 @@ namespace StelUtils
 	//! @param r double*   length of radius vector (distance)
 	//! @param v the input 3D vector
 	inline void rectToSphe(double *lng, double *lat, double *r, const Vec3d& v){
-		*r = v.length();
+		*r = v.norm();
 		*lat = asin(v[2] / *r);
 		*lng = atan2(v[1],v[0]);
 	}
@@ -356,9 +365,12 @@ namespace StelUtils
 		return (value & -value) == value;
 	}
 
-	//! Return the first power of two bigger than the given value.
+	//! Return the smallest power of two greater than or equal to the given value.
 	int getBiggerPowerOfTwo(int value);
 
+	//! Return the largest power of two smaller than or equal to the given value
+	int getSmallerPowerOfTwo(const int value);
+
 	//! Return the inverse sinus hyperbolic of z.
 	inline double asinh(const double z){
 		return (z>0 ? std::log(z + std::sqrt(z*z+1)) :
@@ -379,6 +391,13 @@ namespace StelUtils
 			ret+=b;
 		return ret;
 	}
+	//! Integer interval modulo. [a..b)
+	inline int amod(const int x, const int a, const int b){
+		if (a==b)
+			return x;
+		int ret = imod(x-a, b-a);
+		return ret+a;
+	}
 	//! Double modulo where the result is always nonnegative. [0..(b
 	inline double fmodpos(const double a, const double b){
 		double ret = fmod(a, b);
@@ -397,7 +416,7 @@ namespace StelUtils
 	//! Floor integer division provides truncating to the next lower integer, also for negative numerators.
 	//! https://stackoverflow.com/questions/2622441/c-integer-floor-function
 	//! @returns floor(num/den)
-	inline long intFloorDiv (long num, long den)
+	inline int intFloorDiv (int num, int den)
 	{
 	  if (0 < (num^den)) // lgtm [cpp/bitwise-sign-check]
 	    return num/den;
@@ -410,16 +429,16 @@ namespace StelUtils
 	}
 
 	//! version of intFloorDiv() for large integers.
-	inline long intFloorDivLL(long long num, long long den)
+	inline int intFloorDivLL(qint64 num, qint64 den)
 	{
 	  if (0 < (num^den)) // lgtm [cpp/bitwise-sign-check]
-	    return static_cast<long>(num/den);
+	    return int(num/den);
 	  else
 	    {
 	      lldiv_t res = lldiv(num,den);
-	      long long ret=  (res.rem)? res.quot-1
+	      qint64 ret= (res.rem)? res.quot-1
 			      : res.quot;
-	      return static_cast<long>(ret);
+	      return int(ret);
 	    }
 	}
 
@@ -468,10 +487,16 @@ namespace StelUtils
 	//! Return a day number of week for date
 	//! @return number of day: 0 - sunday, 1 - monday,..
 	int getDayOfWeek(int year, int month, int day);
-	inline int getDayOfWeek(double JD){ double d= fmodpos(JD+1.5, 7);
+	inline int getDayOfWeek(double JD)
+	{
+		double d= fmodpos(JD+1.5, 7);
 		return std::lround(floor(d));
 	}
 
+	//! Format the discovery date
+	//! @return QString representing the formatted date
+	QString localeDiscoveryDateString(const QString& discovery);
+
 	//! Get the current Julian Date from system time.
 	//! @return the current Julian Date
 	double getJDFromSystem();
@@ -526,6 +551,10 @@ namespace StelUtils
 	//! Find day number for date in year.
 	//! Meeus, Astronomical Algorithms 2nd ed., 1998, ch.7, p.65
 	int dayInYear(const int year, const int month, const int day);
+	//! Find date from day number within year and the year.
+	//! Meeus, AA 2nd, 1998, ch.7 p.66
+	//! @returns Vec3i(year, month, day)
+	Vec3i dateFromDayYear(const int day, const int year);
 	//! Return a fractional year like YYYY.ddddd. For negative years, the year number is decreased. E.g. -500.5 occurs in -501.
 	double yearFraction(const int year, const int month, const double day);
 
@@ -564,6 +593,9 @@ namespace StelUtils
 	//! Convert days (float) to a time string
 	QString daysFloatToDHMS(float days);
 
+	//! The method to splitting the text by substrings by some limit of string length
+	QString wrapText(const QString& s, const int limit = 52);
+
 	//! Get Delta-T estimation for a given date.
 	//! This is just an "empty" correction function, returning 0.
 	double getDeltaTwithoutCorrection(const double jDay);
@@ -798,7 +830,7 @@ namespace StelUtils
 	//! Get Delta-T estimation for a given date.
 	//! Implementation of algorithm by Reingold & Dershowitz (1997, 2001, 2002, 2007, 2018) for DeltaT computation.
 	//! This is again mostly a data fit based on the table in Meeus, Astronomical Algorithms (1991).
-	//! This is the version given in the 4rd edition ("the ultimate edition"; 2018) which added the fit
+	//! This is the version given in the 4th edition ("the ultimate edition"; 2018) which added the fit
 	//! for -500..1699 and 2006..2150 omitted from previous editions.
 	//! Calendrical Calculations: The Ultimate Edition / Edward M. Reingold, Nachum Dershowitz - 4th Edition,
 	//! Cambridge University Press, 2018. - 660p. ISBN: 9781107057623, DOI: 10.1017/9781107415058
@@ -831,7 +863,7 @@ namespace StelUtils
 	double getDeltaTByIslamSadiqQureshi(const double jDay);
 
 	//! Get Delta-T estimation for a given date.
-	//! Implementation of polinomial approximation of time period 1620-2013 for DeltaT by M. Khalid, Mariam Sultana and Faheem Zaidi (2014).
+	//! Implementation of polynomial approximation of time period 1620-2013 for DeltaT by M. Khalid, Mariam Sultana and Faheem Zaidi (2014).
 	//! Source: Delta T: Polynomial Approximation of Time Period 1620-2013
 	//! Journal of Astrophysics, Vol. 2014, Article ID 480964
 	//! https://doi.org/10.1155/2014/480964
