@@ -107,7 +107,7 @@ StelViewportDistorterFisheyeToSphericMirror::StelViewportDistorterFisheyeToSpher
 	newProjectorParams.viewportXywh[0] = (screen_w-newProjectorParams.viewportXywh[2]) >> 1;
 	newProjectorParams.viewportXywh[1] = (screen_h-newProjectorParams.viewportXywh[3]) >> 1;
 
-	StelApp::getInstance().getCore()->setCurrentStelProjectorParams(newProjectorParams);
+	core->setCurrentStelProjectorParams(newProjectorParams);
 
 	// init transformation
 	VertexPoint *vertex_point_array = Q_NULLPTR;
@@ -144,7 +144,7 @@ StelViewportDistorterFisheyeToSphericMirror::StelViewportDistorterFisheyeToSpher
 				rc &= prj->forward(v);
 				const float x = static_cast<float>(newProjectorParams.viewportCenter[0]) + v[0] * view_scaling_factor;
 				const float y = static_cast<float>(newProjectorParams.viewportCenter[1]) + v[1] * view_scaling_factor;
-				vertex_point.h = rc ? static_cast<double>((vX^vY).length()) : 0.0;
+				vertex_point.h = rc ? static_cast<double>((vX^vY).norm()) : 0.0;
 
 				// sharp image up to the border of the fisheye image, at the cost of
 				// accepting clamping artefacts. You can get rid of the clamping
@@ -325,6 +325,7 @@ void StelViewportDistorterFisheyeToSphericMirror::paintViewportBuffer(const QOpe
 {
 	StelPainter sPainter(StelApp::getInstance().getCore()->getProjection2d());
 	QOpenGLFunctions* gl = sPainter.glFuncs();
+	GL(gl->glActiveTexture(GL_TEXTURE0));
 	GL(gl->glBindTexture(GL_TEXTURE_2D, buf->texture()));
 	GL(gl->glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR));
 	GL(gl->glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR));
