@@ -24,17 +24,15 @@
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelPainter.hpp"
-#include "StelObserver.hpp"
 
 #include "StelTexture.hpp"
-#include "StelTextureMgr.hpp"
 #include "StelToneReproducer.hpp"
 #include "StelTranslator.hpp"
 #include "StelUtils.hpp"
-#include "StelFileMgr.hpp"
 #include "StelMovementMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "LandscapeMgr.hpp"
+#include "StelLocaleMgr.hpp"
 
 #include <QDebug>
 #include <QElapsedTimer>
@@ -78,6 +76,7 @@ Comet::Comet(const QString& englishName,
 		  roughness,
 		  atexMapName,
 		  "", // no normalmap.
+		  "", // no horizon map
 		  aobjModelName,
 		  coordFunc,
 		  orbitPtr,
@@ -89,7 +88,11 @@ Comet::Comet(const QString& englishName,
 		  pTypeStr),
 	  slopeParameter(-10.f), // -10 == uninitialized: used in getVMagnitude()
 	  isCometFragment(false),
-	  nameIsProvisionalDesignation(false),
+	  iauDesignation(""),
+	  extraDesignations(),
+	  extraDesignationsHtml(),
+	  discoverer(""),
+	  discoveryDate(""),
 	  tailFactors(-1., -1.), // mark "invalid"
 	  tailActive(false),
 	  tailBright(false),
@@ -100,7 +103,7 @@ Comet::Comet(const QString& englishName,
 	  dustTailBrightnessFactor(dustTailBrightnessFact),
 	  intensityFovScale(1.0f),
 	  intensityMinFov(0.001f), // when zooming in further, Coma is no longer visible.
-	  intensityMaxFov(0.010f) // when zooming out further, MilkyComa is fully visible (when enabled).
+	  intensityMaxFov(0.010f) // when zooming out further, Coma is fully visible (when enabled).
 {
 	this->outgas_intensity =outgas_intensity;
 	this->outgas_falloff   =outgas_falloff;
@@ -123,7 +126,7 @@ void Comet::setAbsoluteMagnitudeAndSlope(const float magnitude, const float slop
 	if ((slope < -2.5f) || (slope > 25.0f))
 	{
 		// Slope G can become slightly smaller than 0. -10 is mark of invalidity.
-		qDebug() << "Warning: Suspect slope parameter value" << slope << "for comet" << englishName << "(rarely exceeding -1...20)";
+		qDebug() << "Warning: Suspect slope parameter value" << slope << "for comet" << getEnglishName() << "(rarely exceeding -1...20)";
 		return;
 	}
 	absoluteMagnitude = magnitude;
@@ -132,7 +135,35 @@ void Comet::setAbsoluteMagnitudeAndSlope(const float magnitude, const float slop
 
 void Comet::translateName(const StelTranslator &translator)
 {
-	nameI18 = translator.qtranslate(englishName, "comet");
+	static const QRegularExpression cometNamePattern("^(.+)[(](.+)[)]\\s*$");
+	QRegularExpressionMatch matchCometName = cometNamePattern.match(englishName);
+	if (matchCometName.hasMatch())
+		nameI18 = QString("%1(%2)").arg(matchCometName.captured(1),translator.qtranslate(matchCometName.captured(2), "comet"));
+	else
+		nameI18 = translator.qtranslate(englishName, "comet");
+}
+
+QString Comet::getInfoStringName(const StelCore *core, const InfoStringGroup& flags) const
+{
+	Q_UNUSED(core) Q_UNUSED(flags)
+	QString str;
+	QTextStream oss(&str);
+
+	oss << "<h2>";
+	oss << getNameI18n(); // UI translation can differ from sky translation
+
+	if (!getExtraDesignations().isEmpty())
+		oss << QString(" - %1").arg(extraDesignationsHtml.join(" - "));
+
+	if (sphereScale != 1.)
+	{
+		oss.setRealNumberNotation(QTextStream::FixedNotation);
+		oss.setRealNumberPrecision(1);
+		oss << QString::fromUtf8(" (\xC3\x97") << sphereScale << ")";
+	}
+	oss << "</h2>";
+
+	return str;
 }
 
 QString Comet::getInfoStringAbsoluteMagnitude(const StelCore *core, const InfoStringGroup& flags) const
@@ -174,7 +205,7 @@ QString Comet::getInfoStringSize(const StelCore *core, const InfoStringGroup &fl
 		QString comaEst = q_("Coma diameter (estimate)");
 		const double coma = floor(static_cast<double>(tailFactors[0])*AU/1000.0)*1000.0;
 		const double tail = static_cast<double>(tailFactors[1])*AU;
-		const double distanceKm = AU * getJ2000EquatorialPos(core).length();
+		const double distanceKm = AU * getJ2000EquatorialPos(core).norm();
 		// Try to estimate tail length in degrees.
 		// TODO: Take projection effect into account!
 		// The estimates here assume that the tail is seen from the side.
@@ -201,9 +232,15 @@ QString Comet::getInfoStringSize(const StelCore *core, const InfoStringGroup &fl
 // Nothing interesting?
 QString Comet::getInfoStringExtra(const StelCore *core, const InfoStringGroup &flags) const
 {
-	Q_UNUSED(core) Q_UNUSED(flags)
-
-	return QString();
+	Q_UNUSED(core)
+	QString str;
+	QTextStream oss(&str);
+	if (flags&Extra)
+	{
+		if (!discoveryDate.isEmpty())
+			oss << QString("%1: %2<br/>").arg(q_("Discovered"), getDiscoveryCircumstances());
+	}
+	return str;
 }
 
 QVariantMap Comet::getInfoMap(const StelCore *core) const
@@ -215,6 +252,15 @@ QVariantMap Comet::getInfoMap(const StelCore *core) const
 	return map;
 }
 
+QString Comet::getDiscoveryCircumstances() const
+{
+	QString ddate = StelUtils::localeDiscoveryDateString(discoveryDate);
+	if (discoverer.isEmpty())
+		return ddate;
+	else
+		return QString("%1 (%2)").arg(ddate, discoverer);
+}
+
 double Comet::getSiderealPeriod() const
 {
 	const double semiMajorAxis=static_cast<KeplerOrbit*>(orbitPtr)->getSemimajorAxis();
@@ -233,8 +279,8 @@ float Comet::getVMagnitude(const StelCore* core) const
 	//Calculate distances
 	const Vec3d& observerHeliocentricPosition = core->getObserverHeliocentricEclipticPos();
 	const Vec3d& cometHeliocentricPosition = getHeliocentricEclipticPos();
-	const float cometSunDistance = static_cast<float>(cometHeliocentricPosition.length());
-	const float observerCometDistance = static_cast<float>((observerHeliocentricPosition - cometHeliocentricPosition).length());
+	const float cometSunDistance = static_cast<float>(cometHeliocentricPosition.norm());
+	const float observerCometDistance = static_cast<float>((observerHeliocentricPosition - cometHeliocentricPosition).norm());
 
 	//Calculate apparent magnitude
 	//Sources: http://www.clearskyinstitute.com/xephem/help/xephem.html#mozTocId564354
@@ -257,7 +303,7 @@ void Comet::update(int deltaTime)
 	StelCore* core=StelApp::getInstance().getCore();
 	double dateJDE=core->getJDE();
 
-	if (!static_cast<KeplerOrbit*>(orbitPtr)->objectDateValid(dateJDE)) return; // don't do anything if out of useful date range. This allows having hundreds of comet elements.
+	if (!static_cast<KeplerOrbit*>(orbitPtr)->objectDateGoodEnoughForOrbits(dateJDE)) return; // don't do anything if out of useful date range. This allows having hundreds of comet elements.
 
 	//GZ: I think we can make deltaJDtail adaptive, depending on distance to sun! For some reason though, this leads to a crash!
 	//deltaJDtail=StelCore::JD_SECOND * qBound(1.0, eclipticPos.length(), 20.0);
@@ -286,7 +332,7 @@ void Comet::update(int deltaTime)
 				computeParabola(gasparameter, gasTailEndRadius, -0.5f*gasparameter, gastailVertexArr,  tailTexCoordArr, tailIndices);
 				//gastailColorArr.fill(Vec3f(0.3,0.3,0.3), gastailVertexArr.length());
 				// Now we make a skewed parabola. Skew factor (xOffset, last arg) is rather ad-hoc/empirical. TBD later: Find physically correct solution.
-				computeParabola(dustparameter, dustTailWidthFactor*gasTailEndRadius, -0.5f*dustparameter, dusttailVertexArr, tailTexCoordArr, tailIndices, 25.0f*static_cast<float>(static_cast<KeplerOrbit*>(orbitPtr)->getVelocity().length()));
+				computeParabola(dustparameter, dustTailWidthFactor*gasTailEndRadius, -0.5f*dustparameter, dusttailVertexArr, tailTexCoordArr, tailIndices, 25.0f*static_cast<float>(static_cast<KeplerOrbit*>(orbitPtr)->getVelocity().norm()));
 				//dusttailColorArr.fill(Vec3f(0.3,0.3,0.3), dusttailVertexArr.length());
 
 
@@ -300,7 +346,7 @@ void Comet::update(int deltaTime)
 				//Mat4d dustTailRot=Mat4d::rotation(eclposNrm^(-velocity), 0.15f*std::acos(eclposNrm.dot(-velocity))); // GZ: This scale factor of 0.15 is empirical from photos of Halley and Hale-Bopp.
 				// The curved tail is curved towards positive X. We first rotate around the Z axis into a direction opposite of the motion vector, then again the antisolar rotation applies.
 				// In addition, we let the dust tail already start with a light tilt.
-				dustTailRot=gasTailRot * Mat4d::zrotation(atan2(velocity[1], velocity[0]) + M_PI) * Mat4d::yrotation(5.0*velocity.length());
+				dustTailRot=gasTailRot * Mat4d::zrotation(atan2(velocity[1], velocity[0]) + M_PI) * Mat4d::yrotation(5.0*velocity.norm());
 
 				// Rotate vertex arrays:
 				Vec3d* gasVertices= static_cast<Vec3d*>(gastailVertexArr.data());
@@ -353,7 +399,7 @@ void Comet::update(int deltaTime)
 		// Not only correct the color values for extinction, but for twilight conditions, also make tail end less visible.
 		// I consider sky brightness over 1cd/m^2 as reason to shorten tail.
 		// Below this brightness, the tail brightness loss by this method is insignificant:
-		// Just counting through the vertices might make a spiral apperance. Maybe even better than stackwise? Let's see...
+		// Just counting through the vertices might make a spiral appearance. Maybe even better than stackwise? Let's see...
 		const float avgAtmLum=GETSTELMODULE(LandscapeMgr)->getAtmosphereAverageLuminance();
 		const float brightnessDecreasePerVertexFromHead=1.0f/(COMET_TAIL_SLICES*COMET_TAIL_STACKS)  * avgAtmLum;
 		float brightnessPerVertexFromHead=1.0f;
@@ -365,7 +411,7 @@ void Comet::update(int deltaTime)
 			// Gastail extinction:
 			Vec3d vertAltAz=core->j2000ToAltAz(gastailVertexArr.at(i), StelCore::RefractionOn);
 			vertAltAz.normalize();
-			Q_ASSERT(fabs(vertAltAz.lengthSquared()-1.0) < 0.001);
+			Q_ASSERT(fabs(vertAltAz.normSquared()-1.0) < 0.001);
 			float oneMag=0.0f;
 			extinction.forward(vertAltAz, &oneMag);
 			float extinctionFactor=std::pow(0.4f, oneMag); // drop of one magnitude: factor 2.5 or 40%
@@ -374,7 +420,7 @@ void Comet::update(int deltaTime)
 			// dusttail extinction:
 			vertAltAz=core->j2000ToAltAz(dusttailVertexArr.at(i), StelCore::RefractionOn);
 			vertAltAz.normalize();
-			Q_ASSERT(fabs(vertAltAz.lengthSquared()-1.0) < 0.001);
+			Q_ASSERT(fabs(vertAltAz.normSquared()-1.0) < 0.001);
 			oneMag=0.0f;
 			extinction.forward(vertAltAz, &oneMag);
 			extinctionFactor=std::pow(0.4f, oneMag); // drop of one magnitude: factor 2.5 or 40%
@@ -415,7 +461,7 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 	{
 		return;
 	}
-	if (!static_cast<KeplerOrbit*>(orbitPtr)->objectDateValid(core->getJDE())) return; // don't draw at all if out of useful date range. This allows having hundreds of comet elements.
+	if (!static_cast<KeplerOrbit*>(orbitPtr)->objectDateGoodEnoughForOrbits(core->getJDE())) return; // don't draw at all if out of useful date range. This allows having hundreds of comet elements.
 
 	Mat4d mat = Mat4d::translation(eclipticPos+aberrationPush) * rotLocalToParent;
 	// This removed totally the Planet shaking bug!!!
@@ -436,7 +482,7 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 	{
 		// Draw the name, and the circle if it's not too close from the body it's turning around
 		// this prevents name overlapping (ie for jupiter satellites)
-		float ang_dist = 300.f*static_cast<float>(atan(getEclipticPos().length()/getEquinoxEquatorialPos(core).length())/core->getMovementMgr()->getCurrentFov());
+		float ang_dist = 300.f*static_cast<float>(atan(getEclipticPos().norm()/getEquinoxEquatorialPos(core).norm())/core->getMovementMgr()->getCurrentFov());
 		// if (ang_dist==0.f) ang_dist = 1.f; // if ang_dist == 0, the Planet is sun.. --> GZ: we can remove it.
 
 		// by putting here, only draw orbit if Comet is visible for clarity
@@ -450,10 +496,13 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 	else
 		if (!projectionValid && prj.data()->getNameI18() == q_("Orthographic"))
 			return; // End prematurely. This excludes bad "ghost" comet tail on the wrong hemisphere in ortho projection! Maybe also Fisheye, but it's less problematic.
+	else if (permanentDrawingOrbits) // A special case for demos
+			drawOrbit(core);
+
 
 	// If comet is too faint to be seen, don't bother rendering. (Massive speedup if people have hundreds of comets!)
 	// This test moved here so that hints are still drawn.
-	if ((getVMagnitude(core)-3.0f) > core->getSkyDrawer()->getLimitMagnitude())
+	if ((getVMagnitude(core)-5.0f) > core->getSkyDrawer()->getLimitMagnitude())
 	{
 		return;
 	}
@@ -515,7 +564,7 @@ void Comet::drawComa(StelCore* core, StelProjector::ModelViewTranformP transfo)
 // Formula found at http://www.projectpluto.com/update7b.htm#comet_tail_formula
 Vec2f Comet::getComaDiameterAndTailLengthAU() const
 {
-	const float r = static_cast<float>(getHeliocentricEclipticPos().length());
+	const float r = static_cast<float>(getHeliocentricEclipticPos().norm());
 	const float mhelio = absoluteMagnitude + slopeParameter * log10(r);
 	const float Do = powf(10.0f, ((-0.0033f*mhelio - 0.07f) * mhelio + 3.25f));
 	const float common = 1.0f - powf(10.0f, (-2.0f*r));
@@ -601,3 +650,41 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 	createTailIndices=false;
 	createTailTextureCoords=false;
 }
+
+void Comet::setIAUDesignation(const QString& designation)
+{
+	static const QRegularExpression periodicDesignationPattern("^(\\d+)P/");
+	static const QRegularExpression periodicCometPattern("^P/([\\w\\s]+)$");
+	QRegularExpressionMatch matchPeriodicNumber = periodicDesignationPattern.match(englishName);
+	QRegularExpressionMatch matchPeriodicComet  = periodicCometPattern.match(designation);
+	if (matchPeriodicNumber.hasMatch() && matchPeriodicComet.hasMatch())
+	{
+		// combined designation for numbered periodic comets - 1P/1982 U1 or 146P/1984 W1
+		iauDesignation = QString("%1P/%2").arg(matchPeriodicNumber.captured(1), matchPeriodicComet.captured(1));
+	}
+	else
+		iauDesignation = designation;
+}
+
+void Comet::setExtraDesignations(QStringList codes)
+{
+	extraDesignations = codes;
+	for (const auto& c : codes)
+	{
+		extraDesignationsHtml << renderDiscoveryDesignationHtml(c);
+	}
+}
+
+QString Comet::renderDiscoveryDesignationHtml(const QString &plainTextName)
+{
+	static const QRegularExpression discoveryDesignationPattern("^(\\d{4}[a-z]{1})(\\d+)$");
+	QRegularExpressionMatch match=discoveryDesignationPattern.match(plainTextName);
+	if (match.hasMatch())
+	{
+		QString main = match.captured(1);
+		QString suffix = match.captured(2);
+		return (QString("%1<sub>%2</sub>").arg(main, suffix));
+	}
+	else
+		return plainTextName;
+}
