@@ -73,10 +73,12 @@ public:
 	//! \todo Find better sources for the g,k system
 	virtual float getVMagnitude(const StelCore* core) const Q_DECL_OVERRIDE;
 	//! sets the nameI18 property with the appropriate translation.
-	//! Function overriden to handle the problem with name conflicts.
+	//! Function overridden to handle the problem with name conflicts.
 	virtual void translateName(const StelTranslator& trans) Q_DECL_OVERRIDE;
 	virtual QString getEnglishName(void) const Q_DECL_OVERRIDE {return englishName;}
 	virtual QString getNameI18n(void) const Q_DECL_OVERRIDE {return nameI18;}
+	//! gets an IAU designation.
+	virtual QString getIAUDesignation() const Q_DECL_OVERRIDE { return iauDesignation; }
 
 	//! \brief sets absolute magnitude and slope parameter.
 	//! These are the parameters in the IAU's two-parameter magnitude system
@@ -85,6 +87,24 @@ public:
 	//! as the same parameters in MinorPlanet.
 	void setAbsoluteMagnitudeAndSlope(const float magnitude, const float slope);
 
+	//! sets an IAU designation.
+	void setIAUDesignation(const QString& designation);
+
+	//! set date, discovery and perihelion codes of the comet.
+	void setExtraDesignations(QStringList codes);
+
+	//! set the discovery circumstances of comet
+	//! @param date of discovery
+	//! @param name of discoverer
+	void setDiscoveryData(const QString& date, const QString& name) { discoveryDate = date; discoverer = name; }
+
+	//! renders the subscript in a comet discovery designation with HTML.
+	//! This subscript only ever appears in the super rare case when a comet is first labeled as asteroid.
+	static QString renderDiscoveryDesignationHtml(const QString& plainText);
+
+	//! get list of comet codes
+	QStringList getExtraDesignations() const { return extraDesignations; }
+
 	//! get sidereal period for comet, days, or returns 0 if not possible (parabolic, hyperbolic orbit)
 	virtual double getSiderealPeriod() const Q_DECL_OVERRIDE;
 
@@ -96,12 +116,15 @@ public:
 
 protected:
 	// components for Planet::getInfoString() that are overridden here:
+	virtual QString getInfoStringName(const StelCore *core, const InfoStringGroup& flags) const Q_DECL_OVERRIDE;
 	virtual QString getInfoStringAbsoluteMagnitude(const StelCore *core, const InfoStringGroup& flags) const Q_DECL_OVERRIDE;
 	//! Any flag=Size information to be displayed
 	virtual QString getInfoStringSize(const StelCore *core, const InfoStringGroup& flags) const Q_DECL_OVERRIDE;
 	//! Any flag=Extra information to be displayed at the end
 	virtual QString getInfoStringExtra(const StelCore *core, const InfoStringGroup& flags) const Q_DECL_OVERRIDE;
 
+	virtual QString getDiscoveryCircumstances() const Q_DECL_OVERRIDE;
+
 private:
 	//! @returns estimates for (Coma diameter [AU], gas tail length [AU]).
 	//! Using the formula from Guide found by the GSoC2012 initiative at http://www.projectpluto.com/update7b.htm#comet_tail_formula
@@ -127,7 +150,12 @@ private:
 
 	float slopeParameter;
 	bool isCometFragment;
-	bool nameIsProvisionalDesignation;
+	QString iauDesignation;
+	QStringList extraDesignations;
+	QStringList extraDesignationsHtml;
+	// Discovery data
+	QString discoverer;
+	QString discoveryDate;
 
 	//GZ Tail additions
 	Vec2f tailFactors; // result of latest call to getComaDiameterAndTailLengthAU(); Results cached here for infostring. [0]=Coma diameter, [1] gas tail length.
@@ -147,7 +175,6 @@ private:
 	float intensityMinFov;
 	float intensityMaxFov;
 
-
 	// These are static to avoid having index arrays for each comet when all are equal.
 	static bool createTailIndices;
 	static bool createTailTextureCoords;
