@@ -24,7 +24,6 @@
 
 #include "StelObject.hpp"
 #include "StelTranslator.hpp"
-#include "StelUtils.hpp"
 #include "StelFader.hpp"
 #include "StelTextureTypes.hpp"
 #include "StelSphereGeometry.hpp"
@@ -46,7 +45,7 @@ class StelPainter;
 //! boundary shape from file constellation_boundaries.dat and an (optional) artistic pictorial representation.
 //! GZ NEW: The nativeName should be accessible in a GUI option, so that e.g. original names as written in a
 //! concrete book where a skyculture has been taken from can be assured even when translation is available.
-//! TODO: There should be a distinction between constellations and asterisms, which are "inofficial" figures within a sky culture.
+//! TODO: There should be a distinction between constellations and asterisms, which are "unofficial" figures within a sky culture.
 //! For example, Western sky culture has a "Big Dipper", "Coathanger", etc. These would be nice to see, but in different style.
 class Constellation : public StelObject
 {
