@@ -34,8 +34,8 @@
 #include "StelFileMgr.hpp"
 #include "StelCore.hpp"
 #include "StelPainter.hpp"
-#include "StelSkyDrawer.hpp"
-#include "SolarSystem.hpp"
+#include "Planet.hpp"
+#include "StelUtils.hpp"
 
 #include <vector>
 #include <QDebug>
@@ -46,8 +46,6 @@
 #include <QStringList>
 #include <QDir>
 
-using namespace std;
-
 // constructor which loads all data from appropriate files
 ConstellationMgr::ConstellationMgr(StarMgr *_hip_stars)
 	: hipStarMgr(_hip_stars),
@@ -139,7 +137,7 @@ void ConstellationMgr::init()
 	addAction("actionShow_Constellation_Deselect", displayGroup, N_("Remove selection of constellations"), this, "deselectConstellations()", "W");
 	addAction("actionShow_Constellation_Select", displayGroup, N_("Select all constellations"), this, "selectAllConstellations()", "Alt+W");
 	// Reload the current sky culture
-	addAction("actionShow_Starlore_Reload", displayGroup, N_("Reload the sky culture"), this, "reloadSkyCulture()", "Ctrl+Alt+I");
+	addAction("actionShow_SkyCulture_Reload", displayGroup, N_("Reload the sky culture"), this, "reloadSkyCulture()", "Ctrl+Alt+I");
 }
 
 /*************************************************************************
@@ -154,15 +152,11 @@ double ConstellationMgr::getCallOrder(StelModuleActionName actionName) const
 
 void ConstellationMgr::reloadSkyCulture()
 {
-	updateSkyCulture(StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureID());
+	StelApp::getInstance().getSkyCultureMgr().reloadSkyCulture();
 }
 
 void ConstellationMgr::updateSkyCulture(const QString& skyCultureDir)
 {
-	// Check if the sky culture changed since last load, if not don't load anything
-	if (lastLoadedSkyCulture == skyCultureDir)
-		return;
-
 	// Find constellation art.  If this doesn't exist, warn, but continue using ""
 	// the loadLinesAndArt function knows how to handle this (just loads lines).
 	QString conArtFile = StelFileMgr::findFile("skycultures/"+skyCultureDir+"/constellationsart.fab");
@@ -195,11 +189,11 @@ void ConstellationMgr::updateSkyCulture(const QString& skyCultureDir)
 
 	// load constellation boundaries
 	StelApp *app = &StelApp::getInstance();
-	int idx = app->getSkyCultureMgr().getCurrentSkyCultureBoundariesIdx();
-	if (idx>=0)
+	const auto idx = app->getSkyCultureMgr().getCurrentSkyCultureBoundariesType();
+	if (idx != StelSkyCulture::BoundariesType::None)
 	{
 		// OK, the current sky culture has boundaries!
-		if (idx==1)
+		if (idx == StelSkyCulture::BoundariesType::Own)
 		{
 			// boundaries = own
 			fic = StelFileMgr::findFile("skycultures/" + skyCultureDir + "/constellation_boundaries.dat");
@@ -261,7 +255,7 @@ void ConstellationMgr::selectedObjectChange(StelModule::StelModuleSelectAction a
 	else
 	{
 		QList<StelObjectP> newSelectedObject;
-		if (StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureBoundariesIdx()==0) // generic IAU boundaries
+		if (StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureBoundariesType()==StelSkyCulture::BoundariesType::IAU)
 			newSelectedObject = omgr->getSelectedObject();
 		else
 			newSelectedObject = omgr->getSelectedObject("Star");
@@ -297,7 +291,7 @@ void ConstellationMgr::deselectConstellations(void)
 		}
 
 		// If any constellation is selected at the moment, then let's do not touch to it!
-		if (omgr->getWasSelected() && selected.size()>0)
+		if (omgr->getWasSelected() && !selected.empty())
 			selected.pop_back();
 
 		// Let's hide all previously selected constellations
@@ -349,7 +343,7 @@ void ConstellationMgr::selectConstellationByObjectName(const QString &englishNam
 	if (!getFlagIsolateSelected())
 		setFlagIsolateSelected(true); // Enable isolated selection
 
-	if (StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureBoundariesIdx()==0) // generic IAU boundaries
+	if (StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureBoundariesType()==StelSkyCulture::BoundariesType::IAU)
 		setSelectedConst(isObjectIn(GETSTELMODULE(StelObjectMgr)->searchByName(englishName).data()));
 	else
 		setSelectedConst(isStarIn(GETSTELMODULE(StelObjectMgr)->searchByName(englishName).data()));
@@ -657,7 +651,7 @@ void ConstellationMgr::loadLinesAndArt(const QString &fileName, const QString &a
 
 			QVector<Vec3d> contour;
 			contour.reserve(texCoords.size());
-			for (const auto& v : qAsConst(texCoords))
+			for (const auto& v : std::as_const(texCoords))
 			{
 				Vec3d vertex = X * Vec3d(static_cast<double>(v[0]) * texSizeX, static_cast<double>(v[1]) * texSizeY, 0.);
 				// Originally the projected texture plane remained as tangential plane.
@@ -819,7 +813,7 @@ void ConstellationMgr::loadNames(const QString& namesFile)
 	// lines which look like records - we use the RE to extract the fields
 	// which will be available in recRx.capturedTexts()
 	// abbreviation is allowed to start with a dot to mark as "hidden".
-	static const QRegularExpression recRx("^\\s*(\\.?\\w+)\\s+\"(.*)\"\\s+_[(]\"(.*)\"[)]\\s*([\\,\\d\\s]*)\\n");
+	static const QRegularExpression recRx("^\\s*(\\.?\\S+)\\s+\"(.*)\"\\s+_[(]\"(.*)\"[)]\\s*([\\,\\d\\s]*)\\n");
 	static const QRegularExpression ctxRx("(.*)\",\\s*\"(.*)");
 
 	// keep track of how many records we processed.
@@ -1362,7 +1356,7 @@ bool ConstellationMgr::loadBoundaries(const QString& boundaryFile)
 	double DE, RA;
 	Vec3d XYZ;
 	unsigned numc;
-	vector<Vec3d> *points = Q_NULLPTR;
+	std::vector<Vec3d> *points = Q_NULLPTR;
 	QString consname, data = "";
 	unsigned int i = 0;
 
@@ -1390,7 +1384,7 @@ bool ConstellationMgr::loadBoundaries(const QString& boundaryFile)
 		if(num == 0)
 			continue; // empty line
 
-		points = new vector<Vec3d>;
+		points = new std::vector<Vec3d>;
 
 		for (unsigned int j=0;j<num;j++)
 		{
@@ -1523,7 +1517,7 @@ void ConstellationMgr::setSelected(const StelObject *s)
 		setSelectedConst(Q_NULLPTR);
 	else
 	{
-		if (StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureBoundariesIdx()==0) // generic IAU boundaries
+		if (StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureBoundariesType()==StelSkyCulture::BoundariesType::IAU)
 			setSelectedConst(isObjectIn(s));
 		else
 			setSelectedConst(isStarIn(s));
