@@ -81,11 +81,12 @@ class GridLinesMgr : public StelModule
 	Q_PROPERTY(bool eclipticLineDisplayed		READ getFlagEclipticLine	WRITE setFlagEclipticLine		NOTIFY eclipticLineDisplayedChanged)
 	Q_PROPERTY(bool eclipticPartsDisplayed		READ getFlagEclipticParts	WRITE setFlagEclipticParts		NOTIFY eclipticPartsDisplayedChanged)
 	Q_PROPERTY(bool eclipticPartsLabeled		READ getFlagEclipticLabeled	WRITE setFlagEclipticLabeled		NOTIFY eclipticPartsLabeledChanged)
+	Q_PROPERTY(bool eclipticDatesLabeled           READ getFlagEclipticDatesLabeled WRITE setFlagEclipticDatesLabeled	NOTIFY eclipticDatesLabeledChanged)
 	Q_PROPERTY(Vec3f eclipticLineColor		READ getColorEclipticLine	WRITE setColorEclipticLine		NOTIFY eclipticLineColorChanged)
 
 	Q_PROPERTY(bool eclipticJ2000LineDisplayed	READ getFlagEclipticJ2000Line	 WRITE setFlagEclipticJ2000Line		NOTIFY eclipticJ2000LineDisplayedChanged)
 	Q_PROPERTY(bool eclipticJ2000PartsDisplayed	READ getFlagEclipticJ2000Parts	 WRITE setFlagEclipticJ2000Parts	NOTIFY eclipticJ2000PartsDisplayedChanged)
-	Q_PROPERTY(bool eclipticJ2000PartsLabeled		READ getFlagEclipticJ2000Labeled WRITE setFlagEclipticJ2000Labeled	NOTIFY eclipticJ2000PartsLabeledChanged)
+	Q_PROPERTY(bool eclipticJ2000PartsLabeled	READ getFlagEclipticJ2000Labeled WRITE setFlagEclipticJ2000Labeled	NOTIFY eclipticJ2000PartsLabeledChanged)
 	Q_PROPERTY(Vec3f eclipticJ2000LineColor		READ getColorEclipticJ2000Line	 WRITE setColorEclipticJ2000Line	NOTIFY eclipticJ2000LineColorChanged)
 
 	Q_PROPERTY(bool invariablePlaneLineDisplayed	READ getFlagInvariablePlaneLine	 WRITE setFlagInvariablePlaneLine	NOTIFY invariablePlaneLineDisplayedChanged)
@@ -111,6 +112,9 @@ class GridLinesMgr : public StelModule
 	Q_PROPERTY(bool longitudePartsLabeled	READ getFlagLongitudeLabeled	WRITE setFlagLongitudeLabeled		NOTIFY longitudePartsLabeledChanged)
 	Q_PROPERTY(Vec3f longitudeLineColor		READ getColorLongitudeLine	WRITE setColorLongitudeLine		NOTIFY longitudeLineColorChanged)
 
+	Q_PROPERTY(bool quadratureLineDisplayed		READ getFlagQuadratureLine	WRITE setFlagQuadratureLine		NOTIFY quadratureLineDisplayedChanged)
+	Q_PROPERTY(Vec3f quadratureLineColor		READ getColorQuadratureLine	WRITE setColorQuadratureLine		NOTIFY quadratureLineColorChanged)
+
 	Q_PROPERTY(bool horizonLineDisplayed		READ getFlagHorizonLine		WRITE setFlagHorizonLine		NOTIFY horizonLineDisplayedChanged)
 	Q_PROPERTY(bool horizonPartsDisplayed	READ getFlagHorizonParts	WRITE setFlagHorizonParts		NOTIFY horizonPartsDisplayedChanged)
 	Q_PROPERTY(bool horizonPartsLabeled		READ getFlagHorizonLabeled	WRITE setFlagHorizonLabeled		NOTIFY horizonPartsLabeledChanged)
@@ -450,6 +454,11 @@ public slots:
 	void setFlagEclipticLabeled(const bool displayed);
 	//! Accessor for displaying Ecliptic line partition labels.
 	bool getFlagEclipticLabeled() const;
+	//! Setter for displaying Ecliptic line partition labels of dates for Solar position in the current year.
+	void setFlagEclipticDatesLabeled(const bool displayed);
+	//! Accessor for displaying Ecliptic line partition labels of dates for Solar position in the current year.
+	bool getFlagEclipticDatesLabeled() const;
+
 	//! Get the current color of the Ecliptic Line.
 	Vec3f getColorEclipticLine() const;
 	//! Set the color of the Ecliptic Line.
@@ -562,6 +571,20 @@ public slots:
 	//! @endcode
 	void setColorLongitudeLine(const Vec3f& newColor);
 
+	//! Setter for displaying quadrature line.
+	void setFlagQuadratureLine(const bool displayed);
+	//! Accessor for displaying quadrature line.
+	bool getFlagQuadratureLine() const;
+	//! Get the current color of the quadrature line.
+	Vec3f getColorQuadratureLine() const;
+	//! Set the color of the quadrature line.
+	//! @param newColor The color of quadrature line
+	//! @code
+	//! // example of usage in scripts
+	//! GridLinesMgr.setColorQuadratureLine(Vec3f(1.0,0.0,0.0));
+	//! @endcode
+	void setColorQuadratureLine(const Vec3f& newColor);
+
 	//! Setter for displaying Horizon Line.
 	void setFlagHorizonLine(const bool displayed);
 	//! Accessor for displaying Horizon Line.
@@ -984,6 +1007,7 @@ signals:
 	void eclipticLineDisplayedChanged(const bool displayed);
 	void eclipticPartsDisplayedChanged(const bool displayed);
 	void eclipticPartsLabeledChanged(const bool displayed);
+	void eclipticDatesLabeledChanged(const bool displayed);
 	void eclipticLineColorChanged(const Vec3f & newColor);
 	void invariablePlaneLineDisplayedChanged(const bool displayed);
 	//void invariablePlanePartsDisplayedChanged(const bool displayed);
@@ -1009,6 +1033,8 @@ signals:
 	void longitudePartsDisplayedChanged(const bool displayed);
 	void longitudePartsLabeledChanged(const bool displayed);
 	void longitudeLineColorChanged(const Vec3f & newColor);
+	void quadratureLineDisplayedChanged(const bool displayed);
+	void quadratureLineColorChanged(const Vec3f & newColor);
 	void horizonLineDisplayedChanged(const bool displayed);
 	void horizonPartsDisplayedChanged(const bool displayed);
 	void horizonPartsLabeledChanged(const bool displayed);
@@ -1095,6 +1121,7 @@ private:
 	SkyLine * equatorJ2000Line;		// Celestial Equator line of J2000
 	SkyLine * fixedEquatorLine;		// Fixed Celestial Equator line (hour angles)
 	SkyLine * eclipticLine;			// Ecliptic line
+	SkyLine * eclipticWithDateLine;		// Ecliptic line (line actually invisible!) with date partitions for the current year indicating Solar position at midnight
 	SkyLine * eclipticJ2000Line;		// Ecliptic line of J2000
 	SkyLine * invariablePlaneLine;		// Invariable Plane of the Solar System (WGCCRE2015 report)
 	SkyLine * solarEquatorLine;		// Projected Solar equator (WGCCRE2015 report)
@@ -1102,6 +1129,7 @@ private:
 	SkyLine * precessionCircleS;		// Southern precession circle
 	SkyLine * meridianLine;			// Meridian line
 	SkyLine * longitudeLine;		// Opposition/conjunction longitude line
+	SkyLine * quadratureLine;		// Quadrature line
 	SkyLine * horizonLine;			// Horizon line
 	SkyLine * galacticEquatorLine;		// line depicting the Galactic equator as defined by the IAU definition of Galactic coordinates (System II, 1958)
 	SkyLine * supergalacticEquatorLine;	// line depicting the Supergalactic equator
