@@ -21,15 +21,15 @@
 #define LANDSCAPE_HPP
 
 #include "VecMath.hpp"
-#include "StelToneReproducer.hpp"
-#include "StelProjector.hpp"
 
 #include "StelFader.hpp"
-#include "StelUtils.hpp"
 #include "StelTextureTypes.hpp"
 #include "StelLocation.hpp"
+#include "StelProjectorType.hpp"
 #include "StelSphereGeometry.hpp"
 
+#include <memory>
+
 #include <QMap>
 #include <QImage>
 #include <QList>
@@ -40,6 +40,9 @@ class QSettings;
 class StelLocation;
 class StelCore;
 class StelPainter;
+class QOpenGLBuffer;
+class QOpenGLShaderProgram;
+class QOpenGLVertexArrayObject;
 
 //! @class Landscape
 //! Store and manages the displaying of the Landscape.
@@ -73,6 +76,7 @@ public:
 
 	Landscape(float _radius = 2.f);
 	virtual ~Landscape();
+	virtual void initGL();
 	//! Load landscape.
 	//! @param landscapeIni A reference to an existing QSettings object which describes the landscape
 	//! @param landscapeId The name of the directory for the landscape files (e.g. "ocean")
@@ -102,7 +106,7 @@ public:
 	double getBrightness() const { return static_cast<double>(landscapeBrightness); }
 	//! Returns the lightscape brightness
 	double getLightscapeBrightness() const { return static_cast<double>(lightScapeBrightness); }
-	//! Returns the lightscape brighness modulated with the fader's target state (i.e. binary on/off)
+	//! Returns the lightscape brightness modulated with the fader's target state (i.e. binary on/off)
 	double getTargetLightscapeBrightness() const { return static_cast<double>(lightScapeBrightness * illumFader); }
 	//! Gets the currently effective lightscape brightness (modulated by the fader)
 	double getEffectiveLightscapeBrightness() const { return static_cast<double>(lightScapeBrightness * illumFader.getInterstate()); }
@@ -125,8 +129,14 @@ public:
 	void setFlagShowLabels(const bool b) {labelFader=b;}
 	//! Get whether labels are displayed
 	bool getFlagShowLabels() const {return static_cast<bool>(labelFader);}
-	//! change font and fontsize for landscape labels
-	void setLabelFontSize(const int size){fontSize=size;}
+	//! Change font and fontsize for landscape labels
+	void setLabelFontSize(const int size){ fontSize=size; }
+	//! Get fontsize for landscape labels
+	int getLabelFontSize() { return fontSize; }
+	//! Get color for landscape labels
+	Vec3f getLabelColor() const { return labelColor; }
+	//! Set color for landscape labels
+	void setLabelColor(const Vec3f& c) { labelColor=c; }
 
 	//! Get landscape name
 	QString getName() const {return name;}
@@ -169,6 +179,8 @@ public:
 	//! Get the sine of the limiting altitude (can be used to short-cut drawing below horizon, like star fields). There is no set here, value is only from landscape.ini
 	double getSinMinAltitudeLimit() const {return sinMinAltitudeLimit;}
 
+	void setTransparency(const double f) { landscapeTransparency=f; }
+
 	//! Find opacity in a certain direction. (New in V0.13 series)
 	//! can be used to find sunrise or visibility questions on the real-world landscape horizon.
 	//! Default implementation indicates the horizon equals math horizon.
@@ -190,6 +202,9 @@ public:
 	bool hasLandscapePolygon() const {return !horizonPolygon.isNull();}
 
 protected:
+	void setupCurrentVAO();
+	void bindVAO();
+	void releaseVAO();
 	//! Load attributes common to all landscapes
 	//! @param landscapeIni A reference to an existing QSettings object which describes the landscape
 	//! @param landscapeId The name of the directory for the landscape files (e.g. "ocean")
@@ -205,12 +220,19 @@ protected:
 	//! @param polyAngleRotateZ possibility to set some final calibration offset like meridian convergence correction.
 	//! @param listMode keys which indicate angular units for the angles
 	void createPolygonalHorizon(const QString& lineFileName, const float polyAngleRotateZ=0.0f, const QString &listMode="azDeg_altDeg");
+	void drawHorizonLine(StelCore* core, StelPainter& painter);
 
 	//! search for a texture in landscape directory, else global textures directory
 	//! @param basename The name of a texture file, e.g. "fog.png"
 	//! @param landscapeId The landscape ID (directory name) to which the texture belongs
 	//! @note returns an empty string if file not found.
 	static const QString getTexturePath(const QString& basename, const QString& landscapeId);
+
+	std::unique_ptr<QOpenGLVertexArrayObject> vao;
+	std::unique_ptr<QOpenGLBuffer> vbo;
+	StelProjectorP prevProjector;
+	std::unique_ptr<QOpenGLShaderProgram> renderProgram;
+
 	double radius;
 	QString name;          //! Read from landscape.ini:[landscape]name
 	QString author;        //! Read from landscape.ini:[landscape]author
@@ -232,6 +254,7 @@ protected:
 				  //! Not in landscape.ini: Used in special cases where the horizon may rotate, e.g. on a ship.
 
 	double sinMinAltitudeLimit; //! Minimal altitude of landscape cover. Can be used to construct bounding caps, so that e.g. no stars are drawn below this altitude. Default -0.035, i.e. sin(-2 degrees).
+	double landscapeTransparency;
 
 	StelLocation location; //! OPTIONAL. If present, can be used to set location.
 	/** May be given in landscape.ini:light_pollution_luminance in cd/m². Default: no change.
@@ -253,7 +276,8 @@ protected:
 	int fontSize;     //! Used for landscape labels (optionally indicating landscape features)
 	Vec3f labelColor; //! Color for the landscape labels.
 	unsigned int memorySize;   //!< holds an approximate value of memory consumption (for cache cost estimate)
-    bool multisamplingEnabled_;
+	bool multisamplingEnabled_;
+	bool initialized = false;
 };
 
 //! @class LandscapeOldStyle
@@ -289,10 +313,19 @@ protected:
 	} landscapeTexCoord;
 
 private:
-	void drawFog(StelCore* core, StelPainter&) const;
+	// Low-GL versions draw in the bad old way, suitable for low OpenGL versions like GL<3 or GLES2.
+	// This makes polygons stick in all directions on large FoV in some projections.
+	void drawLowGL(StelCore* core, bool onlyPolygon);
+	void drawFogLowGL(StelCore* core, StelPainter&) const;
 	// drawLight==true for illumination layer, it then selects only the self-illuminating panels.
-	void drawDecor(StelCore* core, StelPainter&, const bool drawLight=false) const;
-	void drawGround(StelCore* core, StelPainter&) const;
+	void drawDecorLowGL(StelCore* core, StelPainter&, bool drawLight = false) const;
+	void drawGroundLowGL(StelCore* core, StelPainter&) const;
+
+	void drawFog(StelCore* core, int firstFreeTexSampler) const;
+	// drawLight==true for illumination layer, it then selects only the self-illuminating panels.
+	void drawDecor(StelCore* core, int firstFreeTexSampler, bool drawLight = false) const;
+	void drawGround(StelCore* core, int firstFreeTexSampler) const;
+
 	QVector<Vec3d> groundVertexArr;
 	QVector<Vec2f> groundTexCoordArr;
 	StelTextureSP* sideTexs;
@@ -320,6 +353,27 @@ private:
 	};
 
 	QList<LOSSide> precomputedSides;
+
+	static constexpr unsigned SIDES_BATCH_SIZE = 8;
+	struct
+	{
+		int mapTex;
+		int vshift;
+		int tanMode;
+		int calibrated;
+		int brightness;
+		int whatToRender;
+		int decorAngleShift;
+		int firstSideInBatch;
+		int sidePresenceMask;
+		int sideAngularHeight;
+		int fogCylinderHeight;
+		int totalNumberOfSides;
+		int numberOfSidesInBatch;
+		int projectionMatrixInverse;
+		int sideTexN[SIDES_BATCH_SIZE];
+		int perSideTexCoords[SIDES_BATCH_SIZE];
+	} shaderVars;
 };
 
 /////////////////////////////////////////////////////////
@@ -339,6 +393,8 @@ public:
 	virtual void load(const QSettings& landscapeIni, const QString& landscapeId) Q_DECL_OVERRIDE;
 	virtual void draw(StelCore* core, bool onlyPolygon) Q_DECL_OVERRIDE;
 	virtual float getOpacity(Vec3d azalt) const Q_DECL_OVERRIDE;
+	// To allow ad-hoc "zero" landscapes with color from map
+	void setGroundColor(const Vec3f &color);
 private:
 	// we have inherited: horizonFileName, horizonPolygon, horizonPolygonLineColor
 	Vec3f groundColor; //! specified in landscape.ini[landscape]ground_color.
@@ -378,6 +434,13 @@ private:
 	QImage *mapImage;          //!< The same image as mapTex, but stored in-mem for sampling.
 
 	float texFov;
+	struct
+	{
+		int texFov;
+		int mapTex;
+		int brightness;
+		int projectionMatrixInverse;
+	} shaderVars;
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -435,6 +498,15 @@ private:
 	float illumTexBottom;	   //!< zenithal bottom angle of the illumination texture, radians
 	QImage *mapImage;          //!< The same image as mapTex, but stored in-mem for opacity sampling.
 	Vec3f bottomCapColor;      //!< The bottomCap, if specified, will be drawn in this color
+	struct
+	{
+		int mapTex;
+		int mapTexTop;
+		int brightness;
+		int mapTexBottom;
+		int bottomCapColor;
+		int projectionMatrixInverse;
+	} shaderVars;
 };
 
 #endif // LANDSCAPE_HPP
