@@ -25,70 +25,93 @@
 #include "StelModule.hpp"
 #include "StelUtils.hpp"
 #include "Landscape.hpp"
+#include "Skylight.hpp"
 
+#include <memory>
 #include <QMap>
 #include <QStringList>
 #include <QCache>
 
 class Atmosphere;
 class QSettings;
+class QTimer;
 
 
 //! @class Cardinals manages the display of cardinal points
 class Cardinals
 {
-    Q_GADGET
+	Q_GADGET
 public:
-    enum CompassDirection
-    {
-	// Cardinals (4-wind compass rose)
-	dN	=  1,	// north
-	dS	=  2,	// south
-	dE	=  3,	// east
-	dW	=  4,	// west
-	// Intercardinals (or ordinals) (8-wind compass rose)
-	dNE	=  5,	// northeast
-	dSE	=  6,	// southeast
-	dNW	=  7,	// northwest
-	dSW	=  8,	// southwest
-	// Secondary Intercardinals (16-wind compass rose)
-	dNNE	=  9,	// north-northeast
-	dENE	= 10,	// east-northeast
-	dESE	= 11,	// east-southeast
-	dSSE	= 12,	// south-southeast
-	dSSW	= 13,	// south-southwest
-	dWSW	= 14,	// west-southwest
-	dWNW	= 15,	// west-northwest
-	dNNW	= 16	// north-northwest
-    };
-    Q_ENUM(CompassDirection)
+	enum CompassDirection
+	{
+		// Cardinals (4-wind compass rose)
+		dN	=  1,	// north
+		dS	=  2,	// south
+		dE	=  3,	// east
+		dW	=  4,	// west
+		// Intercardinals (or ordinals) (8-wind compass rose)
+		dNE	=  5,	// northeast
+		dSE	=  6,	// southeast
+		dNW	=  7,	// northwest
+		dSW	=  8,	// southwest
+		// Secondary Intercardinals (16-wind compass rose)
+		dNNE	=  9,	// north-northeast
+		dENE	= 10,	// east-northeast
+		dESE	= 11,	// east-southeast
+		dSSE	= 12,	// south-southeast
+		dSSW	= 13,	// south-southwest
+		dWSW	= 14,	// west-southwest
+		dWNW	= 15,	// west-northwest
+		dNNW	= 16,	// north-northwest
+		// Tertiary Intercardinals (32-wind compass rose)
+		dNbE	= 17,	// north by east
+		dNEbN	= 18,	// northeast by north
+		dNEbE	= 19,	// northeast by east
+		dEbN	= 20,	// east by north
+		dEbS	= 21,	// east by south
+		dSEbE	= 22,	// southeast by east
+		dSEbS	= 23,	// southeast by south
+		dSbE	= 24,	// south by east
+		dSbW	= 25,	// south by west
+		dSWbS	= 26,	// southwest by south
+		dSWbW	= 27,	// southwest by west
+		dWbS	= 28,	// west by south
+		dWbN	= 29,	// west by north
+		dNWbW	= 30,	// northwest by west
+		dNWbN	= 31,	// northwest by north
+		dNbW	= 32	// north by west
+	};
+	Q_ENUM(CompassDirection)
 
-    Cardinals();
-    virtual ~Cardinals();
-    void draw(const StelCore* core, double latitude) const;
-    void setColor(const Vec3f& c) {color = c;}
-    Vec3f getColor() const {return color;}
-    void updateI18n();
-    void update(double deltaTime);
-    void setFadeDuration(float duration);
-    void setFlagShowCardinals(bool b) { fader4WCR = b; }
-    bool getFlagShowCardinals() const { return fader4WCR; }
+	Cardinals();
+	virtual ~Cardinals();
+	void draw(const StelCore* core, double latitude) const;
+	void setColor(const Vec3f& c) {color = c;}
+	Vec3f getColor() const {return color;}
+	void updateI18n();
+	void update(double deltaTime);
+	void setFadeDuration(float duration);
+	void setFlagShowCardinals(bool b) { fader4WCR = b; }
+	bool getFlagShowCardinals() const { return fader4WCR; }
 
-    void setFlagShow4WCRLabels(bool b) { fader4WCR = b; }
-    bool getFlagShow4WCRLabels() const { return fader4WCR; }
-    void setFlagShow8WCRLabels(bool b) { fader8WCR = b; }
-    bool getFlagShow8WCRLabels() const { return fader8WCR; }
-    void setFlagShow16WCRLabels(bool b) { fader16WCR = b; }
-    bool getFlagShow16WCRLabels() const { return fader16WCR; }
+	void setFlagShow4WCRLabels(bool b) { fader4WCR = b; }
+	bool getFlagShow4WCRLabels() const { return fader4WCR; }
+	void setFlagShow8WCRLabels(bool b) { fader8WCR = b; }
+	bool getFlagShow8WCRLabels() const { return fader8WCR; }
+	void setFlagShow16WCRLabels(bool b) { fader16WCR = b; }
+	bool getFlagShow16WCRLabels() const { return fader16WCR; }
+	void setFlagShow32WCRLabels(bool b) { fader32WCR = b; }
+	bool getFlagShow32WCRLabels() const { return fader32WCR; }
 private:
-    class StelPropertyMgr* propMgr;
-    QFont font4WCR, font8WCR, font16WCR;
-    Vec3f color;
-    static constexpr float cp = static_cast<float>(1./(1.+M_SQRT2)); // dimension for secondary intercardinals
-    static const QMap<Cardinals::CompassDirection, Vec3f> rose4winds, rose8winds, rose16winds;
-    QMap<Cardinals::CompassDirection, QString> labels;
-    LinearFader fader4WCR, fader8WCR, fader16WCR;
-    int screenFontSize;
+	class StelPropertyMgr* propMgr;
+	QFont font4WCR, font8WCR, font16WCR, font32WCR;
+	Vec3f color;
+	static constexpr float q8 = M_SQRT2*0.5f; // dimension for intercardinals
+	static const float sp8, cp8, s1p16, c1p16, s3p16, c3p16; // dimensions for 2nd/3rd intercardinals
+	static const QMap<Cardinals::CompassDirection, Vec3f> rose4winds, rose8winds, rose16winds, rose32winds;
+	QMap<Cardinals::CompassDirection, QString> labels;
+	LinearFader fader4WCR, fader8WCR, fader16WCR, fader32WCR;
+	int screenFontSize;
 };
 
 //! @class LandscapeMgr
@@ -117,6 +140,42 @@ class LandscapeMgr : public StelModule
 		   READ getFlagAtmosphereNoScatter
 		   WRITE setFlagAtmosphereNoScatter
 		   NOTIFY atmosphereNoScatterChanged)
+	Q_PROPERTY(QString atmosphereModel
+		   READ getAtmosphereModel
+		   WRITE setAtmosphereModel
+		   NOTIFY atmosphereModelChanged)
+	Q_PROPERTY(QString atmosphereModelPath
+		   READ getAtmosphereModelPath
+		   WRITE setAtmosphereModelPath
+		   NOTIFY atmosphereModelPathChanged)
+	Q_PROPERTY(QString defaultAtmosphereModelPath
+		   READ getDefaultAtmosphereModelPath
+		   SCRIPTABLE false
+		   CONSTANT)
+	Q_PROPERTY(bool atmosphereShowMySkyStoppedWithError
+		   READ getAtmosphereShowMySkyStoppedWithError
+		   WRITE setAtmosphereShowMySkyStoppedWithError
+		   NOTIFY atmosphereStoppedWithErrorChanged)
+	Q_PROPERTY(QString atmosphereShowMySkyStatusText
+		   READ getAtmosphereShowMySkyStatusText
+		   WRITE setAtmosphereShowMySkyStatusText
+		   NOTIFY atmosphereStatusTextChanged)
+	Q_PROPERTY(bool flagAtmosphereZeroOrderScattering
+		   READ getFlagAtmosphereZeroOrderScattering
+		   WRITE setFlagAtmosphereZeroOrderScattering
+		   NOTIFY flagAtmosphereZeroOrderScatteringChanged)
+	Q_PROPERTY(bool flagAtmosphereSingleScattering
+		   READ getFlagAtmosphereSingleScattering
+		   WRITE setFlagAtmosphereSingleScattering
+		   NOTIFY flagAtmosphereSingleScatteringChanged)
+	Q_PROPERTY(bool flagAtmosphereMultipleScattering
+		   READ getFlagAtmosphereMultipleScattering
+		   WRITE setFlagAtmosphereMultipleScattering
+		   NOTIFY flagAtmosphereMultipleScatteringChanged)
+	Q_PROPERTY(int atmosphereEclipseSimulationQuality
+		   READ getAtmosphereEclipseSimulationQuality
+		   WRITE setAtmosphereEclipseSimulationQuality
+		   NOTIFY atmosphereEclipseSimulationQualityChanged)
 	Q_PROPERTY(bool cardinalPointsDisplayed
 		   READ getFlagCardinalPoints
 		   WRITE setFlagCardinalPoints
@@ -129,6 +188,10 @@ class LandscapeMgr : public StelModule
 		   READ getFlagOrdinal16WRPoints
 		   WRITE setFlagOrdinal16WRPoints
 		   NOTIFY ordinal16WRPointsDisplayedChanged)
+	Q_PROPERTY(bool ordinal32WRPointsDisplayed
+		   READ getFlagOrdinal32WRPoints
+		   WRITE setFlagOrdinal32WRPoints
+		   NOTIFY ordinal32WRPointsDisplayedChanged)
 	Q_PROPERTY(Vec3f cardinalPointsColor
 		   READ getColorCardinalPoints
 		   WRITE setColorCardinalPoints
@@ -190,7 +253,8 @@ class LandscapeMgr : public StelModule
 		   WRITE setCurrentLandscapeID
 		   NOTIFY currentLandscapeChanged)
 	Q_PROPERTY(QStringList allLandscapeNames
-		   READ getAllLandscapeNames)
+		   READ getAllLandscapeNames
+		   NOTIFY landscapesChanged)
 	Q_PROPERTY(QString currentLandscapeName
 		   READ getCurrentLandscapeName
 		   WRITE setCurrentLandscapeName
@@ -202,6 +266,22 @@ class LandscapeMgr : public StelModule
 		   READ getDefaultLandscapeID
 		   WRITE setDefaultLandscapeID
 		   NOTIFY defaultLandscapeChanged)
+	Q_PROPERTY(int labelFontSize
+		   READ getLabelFontSize
+		   WRITE setLabelFontSize
+		   NOTIFY labelFontSizeChanged)
+	Q_PROPERTY(Vec3f labelColor
+		   READ getLabelColor
+		   WRITE setLabelColor
+		   NOTIFY labelColorChanged)
+	Q_PROPERTY(double landscapeTransparency
+		   READ getLandscapeTransparency
+		   WRITE setLandscapeTransparency
+		   NOTIFY landscapeTransparencyChanged)
+	Q_PROPERTY(bool flagLandscapeUseTransparency
+		   READ getFlagLandscapeUseTransparency
+		   WRITE setFlagLandscapeUseTransparency
+		   NOTIFY flagLandscapeUseTransparencyChanged)
 
 public:
 	LandscapeMgr();
@@ -347,7 +427,7 @@ public slots:
 	//! @return false if the new landscape could not be set (e.g. no landscape of that ID was found). True on success.
 	bool setDefaultLandscapeID(const QString& id);
 
-	//! Return a pseudo HTML formatted string with all informations on the current landscape
+	//! Return a pseudo HTML formatted string with all information on the current landscape
 	QString getCurrentLandscapeHtmlDescription() const;
 
 	//! Return a pseudo HTML formatted string with information from description or ini file
@@ -375,6 +455,14 @@ public slots:
 	bool getFlagLabels() const;
 	//! Set flag for displaying landscape labels
 	void setFlagLabels(const bool on);
+	//! Get the fontsize for landscape labels
+	int getLabelFontSize() const;
+	//! Set the fontsize for landscape labels
+	void setLabelFontSize(const int size);
+	//! Get color for landscape labels
+	Vec3f getLabelColor() const;
+	//! Set color for landscape labels
+	void setLabelColor(const Vec3f& c);
 
 	//! Retrieve flag for rendering polygonal line (if one is defined)
 	bool getFlagPolyLineDisplayed() const {return flagPolyLineDisplayedOnly;}
@@ -422,6 +510,11 @@ public slots:
 	//! Set flag for displaying intercardinal (or ordinal) points (16-wind compass rose directions).
 	void setFlagOrdinal16WRPoints(const bool displayed);
 
+	//! Get flag for displaying intercardinal (or ordinal) points (32-wind compass rose directions).
+	bool getFlagOrdinal32WRPoints() const;
+	//! Set flag for displaying intercardinal (or ordinal) points (32-wind compass rose directions).
+	void setFlagOrdinal32WRPoints(const bool displayed);
+
 	//! Get Cardinals Points color.
 	Vec3f getColorCardinalPoints() const;
 	//! Set Cardinals Points color.
@@ -432,6 +525,32 @@ public slots:
 	//! Set flag for displaying Atmosphere.
 	void setFlagAtmosphere(const bool displayed);
 
+	QString getAtmosphereModel() const;
+	void setAtmosphereModel(const QString& model);
+
+	QString getAtmosphereModelPath() const;
+	void setAtmosphereModelPath(const QString& path);
+
+	QString getDefaultAtmosphereModelPath() const;
+
+	bool getAtmosphereShowMySkyStoppedWithError() const;
+	void setAtmosphereShowMySkyStoppedWithError(bool error);
+
+	QString getAtmosphereShowMySkyStatusText() const;
+	void setAtmosphereShowMySkyStatusText(const QString& text);
+
+	bool getFlagAtmosphereZeroOrderScattering() const;
+	void setFlagAtmosphereZeroOrderScattering(bool enable);
+
+	bool getFlagAtmosphereSingleScattering() const;
+	void setFlagAtmosphereSingleScattering(bool enable);
+
+	bool getFlagAtmosphereMultipleScattering() const;
+	void setFlagAtmosphereMultipleScattering(bool enable);
+
+	int getAtmosphereEclipseSimulationQuality() const;
+	void setAtmosphereEclipseSimulationQuality(int quality);
+
 	//! Get flag for suppressing Atmosphere scatter (blue light) while displaying all other effects (refraction, extinction).
 	bool getFlagAtmosphereNoScatter() const;
 	//! Set flag for suppressing Atmosphere scatter (blue light) while displaying all other effects (refraction, extinction).
@@ -445,6 +564,23 @@ public slots:
 	//! Set atmosphere fade duration in s.
 	void setAtmosphereFadeDuration(const float f);
 
+	double getLandscapeTransparency() const;
+	void setLandscapeTransparency(const double f);
+	//! Return the value of the flag determining if a transparency should be used.
+	bool getFlagLandscapeUseTransparency() const {return flagLandscapeUseTransparency; }
+	//! Set the value of the flag determining if a transparency should be used.
+	void setFlagLandscapeUseTransparency(bool b)
+	{
+		if (b!=flagLandscapeUseTransparency)
+		{
+			flagLandscapeUseTransparency=b;
+			emit flagLandscapeUseTransparencyChanged(b);
+		}
+		if (b==false)
+			landscape->setTransparency(0.0);
+	}
+
+
 	/*
 	//This method has been removed, use StelSkyDrawer::getBortleScaleIndex instead, or StelMainScriptAPI::getBortleScaleIndex in scripts
 	//Also, if required, please use StelSkyDrawer::setBortleScaleIndex or StelMainScriptAPI::setBortleScaleIndex instead of LandscapeMgr::setAtmosphereBortleLightPollution
@@ -557,17 +693,31 @@ public slots:
 		return landscape->getOpacity(azalt);
 	}
 
+	void showMessage(const QString& message);
+	void clearMessage();
+
 signals:
 	void atmosphereDisplayedChanged(const bool displayed);
+	void atmosphereModelChanged(const QString& model);
+	void atmosphereModelPathChanged(const QString& model);
+	void atmosphereStoppedWithErrorChanged(bool error);
+	void atmosphereStatusTextChanged(const QString& status);
+	void flagAtmosphereZeroOrderScatteringChanged(bool value);
+	void flagAtmosphereSingleScatteringChanged(bool value);
+	void flagAtmosphereMultipleScatteringChanged(bool value);
+	void atmosphereEclipseSimulationQualityChanged(unsigned quality);
 	void atmosphereNoScatterChanged(const bool noScatter);
 	void cardinalPointsDisplayedChanged(const bool displayed);
 	void ordinalPointsDisplayedChanged(const bool displayed);
 	void ordinal16WRPointsDisplayedChanged(const bool displayed);
+	void ordinal32WRPointsDisplayedChanged(const bool displayed);
 	void cardinalPointsColorChanged(const Vec3f & newColor) const;
 	void fogDisplayedChanged(const bool displayed);
 	void landscapeDisplayedChanged(const bool displayed);
 	void illuminationDisplayedChanged(const bool displayed);
 	void labelsDisplayedChanged(const bool displayed);
+	void labelFontSizeChanged(const int size);
+	void labelColorChanged(const Vec3f &c);
 	void flagPolyLineDisplayedChanged(const bool enabled);
 	void polyLineThicknessChanged(const int thickness);
 	void flagUseLightPollutionFromDatabaseChanged(const bool usage);
@@ -577,6 +727,8 @@ signals:
 	void flagLandscapeSetsMinimalBrightnessChanged(const bool value);
 	void defaultMinimalBrightnessChanged(const double value);
 	void setFlagEnvironmentAutoEnableChanged(const bool enabled);
+	void landscapeTransparencyChanged(const double value);
+	void flagLandscapeUseTransparencyChanged(const bool value);
 
 	//! Emitted whenever the default landscape is changed
 	//! @param id the landscape id of the new default landscape
@@ -614,8 +766,14 @@ signals:
 
 private slots:
 	//! Reacts to StelCore::locationChanged.
+	//! If flagLightPollutionFromDatabase is active,
+	//! this applies light pollution information from the new location
 	void onLocationChanged(const StelLocation &loc);
-	void onTargetLocationChanged(const StelLocation &loc);
+	//! To be connected to StelCore::targetLocationChanged.
+	//! This sets landscape with landscapeID.
+	//! If that is empty and flagLandscapeAutoSelection==true, set a landscape fitting to loc's planet.
+	//! Does not set loc itself!
+	void onTargetLocationChanged(const StelLocation &loc, const QString &landscapeID);
 
 	//! Translate labels to new language settings.
 	void updateI18n();
@@ -623,6 +781,8 @@ private slots:
 	void increaseLightPollution();
 	void reduceLightPollution();
 	void cyclicChangeLightPollution();
+	void createAtmosphere();
+	void resetToFallbackAtmosphere();
 
 private:
 	//! Get light pollution luminance level in cd/m².
@@ -641,18 +801,27 @@ private:
 	//! @returns an empty string, if no such landscape was found.
 	static QString getLandscapePath(const QString landscapeID);
 
-	Atmosphere* atmosphere;			// Atmosphere
+	Skylight skylight; // Is used by AtmospherePreetham, but must not be deleted & re-created,
+                       // otherwise StelPropertyMgr::registerObject will break.
+	std::unique_ptr<Atmosphere> atmosphere; // Atmosphere
+	std::unique_ptr<Atmosphere> loadingAtmosphere; // Atmosphere that's in the process of loading
 	Cardinals* cardinalPoints;		// Cardinals points
 	Landscape* landscape;			// The landscape i.e. the fog, the ground and "decor"
 	Landscape* oldLandscape;		// Used only during transitions to newly loaded landscape.
 
-	// Define whether the observer location is to be updated when the landscape is updated.
+	// Used to display error messages: e.g. when atmosphere model fails
+	LinearFader messageFader;
+	QString messageToShow;
+	QTimer* messageTimer = nullptr;
+
+	//! Define whether the observer location is to be updated when the landscape is updated and includes location info.
 	bool flagLandscapeSetsLocation;
 
+	//! Define whether on location change onto another planet a landscape for the new planet shall be loaded.
 	bool flagLandscapeAutoSelection;
 
 	bool flagLightPollutionFromDatabase;
-	bool atmosphereNoScatter; // true to suppress actual blue-sky rendering but keep refraction & extinction
+	bool atmosphereNoScatter; //!< true to suppress actual blue-sky rendering but keep refraction & extinction
 
 	//! control drawing of a Polygonal line, if one is defined.
 	bool flagPolyLineDisplayedOnly;
@@ -668,6 +837,11 @@ private:
 	//! Indicate auto-enable atmosphere and landscape for planets with atmospheres in location window
 	bool flagEnvironmentAutoEnabling;
 
+	//! Indicate use of the default transparency value specified in config.ini.
+	bool flagLandscapeUseTransparency;
+	//! A transparency value
+	double landscapeTransparency;
+
 	//! The ID of the currently loaded landscape
 	QString currentLandscapeID;
 
@@ -689,6 +863,14 @@ private:
 
 	//! Core current planet name, used to react to planet change.
 	QString currentPlanetName;
+
+	bool needToRecreateAtmosphere=false;
+	bool atmosphereZeroOrderScatteringEnabled=false;
+	bool atmosphereSingleScatteringEnabled=true;
+	bool atmosphereMultipleScatteringEnabled=true;
+
+	QString atmosphereShowMySkyStatusText;
+	bool atmosphereShowMySkyStoppedWithError=false;
 };
 
 #endif // LANDSCAPEMGR_HPP
