@@ -21,15 +21,14 @@
 
 #include "Nebula.hpp"
 #include "NebulaMgr.hpp"
+#include "Planet.hpp"
 #include "StelTexture.hpp"
 
 #include "StelUtils.hpp"
 #include "StelApp.hpp"
-#include "StelTextureMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelCore.hpp"
 #include "StelPainter.hpp"
-#include "SolarSystem.hpp"
 #include "RefractionExtinction.hpp"
 
 #include <QTextStream>
@@ -42,24 +41,9 @@
 
 const QString Nebula::NEBULA_TYPE = QStringLiteral("Nebula");
 
-StelTextureSP Nebula::texCircle;
-StelTextureSP Nebula::texCircleLarge;
 StelTextureSP Nebula::texRegion;
-StelTextureSP Nebula::texGalaxy;
-StelTextureSP Nebula::texGalaxyLarge;
-StelTextureSP Nebula::texOpenCluster;
-StelTextureSP Nebula::texOpenClusterLarge;
-StelTextureSP Nebula::texOpenClusterXLarge;
-StelTextureSP Nebula::texGlobularCluster;
-StelTextureSP Nebula::texGlobularClusterLarge;
+StelTextureSP Nebula::texPointElement;
 StelTextureSP Nebula::texPlanetaryNebula;
-StelTextureSP Nebula::texDiffuseNebula;
-StelTextureSP Nebula::texDiffuseNebulaLarge;
-StelTextureSP Nebula::texDiffuseNebulaXLarge;
-StelTextureSP Nebula::texDarkNebula;
-StelTextureSP Nebula::texDarkNebulaLarge;
-StelTextureSP Nebula::texOpenClusterWithNebulosity;
-StelTextureSP Nebula::texOpenClusterWithNebulosityLarge;
 bool  Nebula::drawHintProportional = false;
 bool  Nebula::surfaceBrightnessUsage = false;
 bool  Nebula::designationUsage = false;
@@ -68,7 +52,7 @@ Vec3f Nebula::labelColor = Vec3f(0.4f,0.3f,0.5f);
 QMap<Nebula::NebulaType, Vec3f>Nebula::hintColorMap;
 bool Nebula::flagUseTypeFilters = false;
 Nebula::CatalogGroup Nebula::catalogFilters = Nebula::CatalogGroup(Nebula::CatNone);
-Nebula::TypeGroup Nebula::typeFilters = Nebula::TypeGroup(Nebula::AllTypes);
+Nebula::TypeGroup Nebula::typeFilters = Nebula::TypeGroup(Nebula::TypeAll);
 bool Nebula::flagUseArcsecSurfaceBrightness = false;
 bool Nebula::flagUseShortNotationSurfaceBrightness = true;
 bool Nebula::flagUseOutlines = false;
@@ -136,7 +120,7 @@ Nebula::Nebula()
 	, PGC_nb(0)
 	, UGC_nb(0)
 	, Arp_nb(0)
-	, VV_nb(0)		
+	, VV_nb(0)
 	, DWB_nb(0)
 	, Tr_nb(0)
 	, St_nb(0)
@@ -152,6 +136,8 @@ Nebula::Nebula()
 	, VdBH_nb("")
 	, withoutID(false)
 	, nameI18("")
+	, discoverer("")
+	, discoveryYear("")
 	, mTypeString()
 	, bMag(99.)
 	, vMag(99.)
@@ -246,13 +232,13 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 	if (flags&Name)
 	{
 		QStringList extraNames=getExtraInfoStrings(Name);
-		if (extraNames.length()>0)
+		if (!extraNames.isEmpty())
 			oss << q_("Additional names: ") << extraNames.join(", ") << "<br/>";
 	}
 	if (flags&CatalogNumber)
 	{
 		QStringList extraCat=getExtraInfoStrings(CatalogNumber);
-		if (extraCat.length()>0)
+		if (!extraCat.isEmpty())
 			oss << q_("Additional catalog numbers: ") << extraCat.join(", ") << "<br/>";
 	}
 
@@ -260,9 +246,9 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 	{
 		QString mt = getMorphologicalTypeString();
 		if (mt.isEmpty())
-			oss << QString("%1: <b>%2</b>").arg(q_("Type"), getTypeString()) << "<br>";
+			oss << QString("%1: <b>%2</b>").arg(q_("Type"), getObjectTypeI18n()) << "<br>";
 		else
-			oss << QString("%1: <b>%2</b> (%3)").arg(q_("Type"), getTypeString(), mt) << "<br>";
+			oss << QString("%1: <b>%2</b> (%3)").arg(q_("Type"), getObjectTypeI18n(), mt) << "<br>";
 		oss << getExtraInfoStrings(ObjectType).join("");
 	}
 
@@ -297,7 +283,7 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 			if (getAirmass(core)>-1.f && getSurfaceBrightnessWithExtinction(core)<99.f) // Don't show extincted surface brightness much below horizon where model is meaningless.
 			{
 				oss << QString("%1: <b>%2</b> %5 (%3: <b>%4</b> %5)").arg(sb, QString::number(getSurfaceBrightness(core, flagUseArcsecSurfaceBrightness), 'f', 2),
-											  ae, QString::number(getSurfaceBrightnessWithExtinction(core, flagUseArcsecSurfaceBrightness), 'f', 2), mu) << "<br />";
+				                                                          ae, QString::number(getSurfaceBrightnessWithExtinction(core, flagUseArcsecSurfaceBrightness), 'f', 2), mu) << "<br />";
 			}
 			else
 				oss << QString("%1: <b>%2</b> %3").arg(sb, QString::number(getSurfaceBrightness(core, flagUseArcsecSurfaceBrightness), 'f', 2), mu) << "<br />";
@@ -430,8 +416,10 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 
 			oss << QString("%1: %2 %3").arg(q_("Parallax"), px, qc_("mas", "parallax")) << "<br />";
 		}
+		if (!discoverer.isEmpty())
+			oss << QString("%1: %2 (%3)").arg(q_("Discoverer"), discoverer, StelUtils::localeDiscoveryDateString(discoveryYear)) << "<br />";
 		if (!getMorphologicalTypeDescription().isEmpty())
-			oss << QString("%1: %2.").arg(q_("Morphological description"), getMorphologicalTypeDescription()) << "<br />";
+			oss << StelUtils::wrapText(QString("%1: %2.").arg(q_("Morphological description"), getMorphologicalTypeDescription())) << "<br />";
 	}
 
 	oss << getSolarLunarInfoString(core, flags);
@@ -445,7 +433,7 @@ QVariantMap Nebula::getInfoMap(const StelCore *core) const
 {
 	QVariantMap map = StelObject::getInfoMap(core);
 
-	map["type"]=getTypeString(); // replace "Nebula" type by detail. This is localized. Maybe add argument such as getTypeString(bool translated=true)?
+	map["type"]=getObjectTypeI18n(); // replace "Nebula" type by detail. This is localized.
 	map.insert("morpho", getMorphologicalTypeString());
 	map.insert("surface-brightness", getSurfaceBrightness(core));
 	map.insert("designations", withoutID ? QString() : designations.join(" - "));
@@ -510,7 +498,7 @@ QString Nebula::getI18nAliases() const
 					firstLine = false;
 				}
 				if (i>3 && ((i-2) % 4)==0 && !firstLine &&  i<asize)
-						aliases.append("<br />");
+					aliases.append("<br />");
 			}
 		}
 		else
@@ -569,9 +557,9 @@ float Nebula::getSelectPriority(const StelCore* core) const
 
 	if (drawer->getFlagNebulaMagnitudeLimit() && (mag>static_cast<float>(drawer->getCustomNebulaMagnitudeLimit())))
 		return selectPriority+mLim;
-	
+
 	const float maxMagHint = nebMgr->computeMaxMagHint(drawer);
-	// make very easy to select if labeled	
+	// make very easy to select if labeled
 	if (surfaceBrightnessUsage)
 	{
 		lim = mag = getSurfaceBrightness(core);
@@ -583,7 +571,7 @@ float Nebula::getSelectPriority(const StelCore* core) const
 	else if (nType==NebHII) // Sharpless and LBN
 		lim=10.0f - 2.0f*qMin(1.5f, majorAxisSize); // Unfortunately, in Sh catalog, we always have mag=99=unknown!
 
-	if (std::min(mLim, lim)<=maxMagHint || outlineSegments.size()>0 || nType==NebRegion) // High priority for big DSO (with outlines) or regions
+	if (std::min(mLim, lim)<=maxMagHint || !outlineSegments.empty() || nType==NebRegion) // High priority for big DSO (with outlines) or regions
 		selectPriority = -10.f;
 	else
 		selectPriority -= 5.f;
@@ -655,22 +643,22 @@ float Nebula::getVisibilityLevelByMagnitude(void) const
 {
 	StelCore* core = StelApp::getInstance().getCore();
 
+	const float mLim = 15.0f;
 	float lim = qMin(vMag, bMag);
-	float mLim = 15.0f;
 
 	if (surfaceBrightnessUsage)
 	{
 		lim = getSurfaceBrightness(core) - 3.f;
-		if (lim > 90.f) lim = mLim + 1.f;		
+		if (lim > 90.f) lim = mLim + 1.f;
 	}
 	else
 	{
-		float mag = getVMagnitude(core);
 		if (lim > 90.f) lim = mLim;
 
 		// Dark nebulae. Not sure how to assess visibility from opacity? --GZ
 		if (nType==NebDn)
 		{
+			const float mag = getVMagnitude(core);
 			// GZ: ad-hoc visibility formula: assuming good visibility if objects of mag9 are visible, "usual" opacity 5 and size 30', better visibility (discernability) comes with higher opacity and larger size,
 			// 9-(opac-5)-2*(angularSize-0.5)
 			// GZ Not good for non-Barnards. weak opacity and large surface are antagonists. (some LDN are huge, but opacity 2 is not much to discern).
@@ -680,10 +668,11 @@ float Nebula::getVisibilityLevelByMagnitude(void) const
 			else
 				lim = (B_nb>0 ? 9.0f : 12.0f); // GZ I assume LDN objects are rather elusive.
 		}
-		else if (nType==NebHII) // NebHII={Sharpless, LBN, RCW}
-		{ // artificially increase visibility of (most) Sharpless objects? No magnitude recorded:-(
-			lim=9.0f;
-		}		
+		else if (nType==NebHII) // NebHII={Sharpless, LBN, RCW} but also M42.
+		{
+			// artificially increase visibility of (most) Sharpless and LBN objects. No magnitude recorded:-(
+			lim=qMin(lim, 10.0f);
+		}
 	}
 
 	if (nType==NebRegion) // special case for regions
@@ -695,16 +684,11 @@ float Nebula::getVisibilityLevelByMagnitude(void) const
 void Nebula::drawOutlines(StelPainter &sPainter, float maxMagHints) const
 {
 	size_t segments = outlineSegments.size();
-	Vec3f color = getHintColor(nType);
 
 	// tune limits for outlines
 	float oLim = getVisibilityLevelByMagnitude() - 3.f;
 
-	float lum = 1.f;
-	Vec3f col(color*lum*hintsBrightness);
-	if (!objectInDisplayedType())
-		col.set(0.f,0.f,0.f);
-	sPainter.setColor(col, 1);
+	sPainter.setColor(getHintColor(nType), objectInDisplayedType() ? hintsBrightness : 0.f);
 
 	StelCore *core=StelApp::getInstance().getCore();
 	Vec3d vel=core->getCurrentPlanet()->getHeliocentricEclipticVelocity();
@@ -743,6 +727,243 @@ void Nebula::drawOutlines(StelPainter &sPainter, float maxMagHints) const
 	}
 }
 
+void Nebula::renderDarkNebulaMarker(StelPainter& sPainter, const float x, const float y,
+                                    float size, const Vec3f color) const
+{
+	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
+	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	size *= scale;
+
+	const float roundRadius = 0.35 * size;
+	const int numPointsInArc = std::lround(std::clamp(5*size/35, 5.f, 16.f));
+	std::vector<float> vertexData;
+	vertexData.reserve(numPointsInArc*2*4);
+	const float leftOuterX = x - size;
+	const float leftInnerX = leftOuterX + roundRadius;
+	const float bottomOuterY = y - size;
+	const float bottomInnerY = bottomOuterY + roundRadius;
+	const float rightOuterX = x + size;
+	const float rightInnerX = rightOuterX - roundRadius;
+	const float topOuterY = y + size;
+	const float topInnerY = topOuterY - roundRadius;
+	const float gap = 0.15*size;
+	const float*const cossin = StelUtils::ComputeCosSinRhoZone((M_PIf/2)/(numPointsInArc-1),
+	                                                           numPointsInArc-1, 0);
+	sPainter.setBlending(true);
+	sPainter.setLineSmooth(true);
+	sPainter.setLineWidth(scale * std::clamp(2*size/35, 1.f, 2.5f));
+	sPainter.setColor(color, hintsBrightness);
+	sPainter.enableClientStates(true);
+
+	vertexData.clear();
+	vertexData.push_back(x-gap);
+	vertexData.push_back(bottomOuterY);
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(leftInnerX   - roundRadius*sina);
+		vertexData.push_back(bottomInnerY - roundRadius*cosa);
+	}
+	vertexData.push_back(leftOuterX);
+	vertexData.push_back(y-gap);
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData.data());
+	sPainter.drawFromArray(StelPainter::LineStrip, vertexData.size() / 2, 0, false);
+
+	vertexData.clear();
+	vertexData.push_back(leftOuterX);
+	vertexData.push_back(y+gap);
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(leftInnerX - roundRadius*cosa);
+		vertexData.push_back(topInnerY  + roundRadius*sina);
+	}
+	vertexData.push_back(x-gap);
+	vertexData.push_back(topOuterY);
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData.data());
+	sPainter.drawFromArray(StelPainter::LineStrip, vertexData.size() / 2, 0, false);
+
+	vertexData.clear();
+	vertexData.push_back(x+gap);
+	vertexData.push_back(topOuterY);
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(rightInnerX + roundRadius*sina);
+		vertexData.push_back(topInnerY   + roundRadius*cosa);
+	}
+	vertexData.push_back(rightOuterX);
+	vertexData.push_back(y+gap);
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData.data());
+	sPainter.drawFromArray(StelPainter::LineStrip, vertexData.size() / 2, 0, false);
+
+	vertexData.clear();
+	vertexData.push_back(rightOuterX);
+	vertexData.push_back(y-gap);
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(rightInnerX  + roundRadius*cosa);
+		vertexData.push_back(bottomInnerY - roundRadius*sina);
+	}
+	vertexData.push_back(x+gap);
+	vertexData.push_back(bottomOuterY);
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData.data());
+	sPainter.drawFromArray(StelPainter::LineStrip, vertexData.size() / 2, 0, false);
+
+	sPainter.enableClientStates(false);
+}
+
+void Nebula::renderMarkerRoundedRect(StelPainter& sPainter, const float x, const float y,
+                                     float size, const Vec3f color) const
+{
+	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
+	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	size *= scale;
+
+	const float roundRadius = 0.35 * size;
+	const int numPointsInArc = std::lround(std::clamp(5*size/35, 5.f, 16.f));
+	std::vector<float> vertexData;
+	vertexData.reserve(numPointsInArc*2*4);
+	const float leftOuterX = x - size;
+	const float leftInnerX = leftOuterX + roundRadius;
+	const float bottomOuterY = y - size;
+	const float bottomInnerY = bottomOuterY + roundRadius;
+	const float rightOuterX = x + size;
+	const float rightInnerX = rightOuterX - roundRadius;
+	const float topOuterY = y + size;
+	const float topInnerY = topOuterY - roundRadius;
+	const float*const cossin = StelUtils::ComputeCosSinRhoZone((M_PIf/2)/(numPointsInArc-1),
+	                                                           numPointsInArc-1, 0);
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(leftInnerX   - roundRadius*sina);
+		vertexData.push_back(bottomInnerY - roundRadius*cosa);
+	}
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(leftInnerX - roundRadius*cosa);
+		vertexData.push_back(topInnerY  + roundRadius*sina);
+	}
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(rightInnerX + roundRadius*sina);
+		vertexData.push_back(topInnerY   + roundRadius*cosa);
+	}
+	for(int n = 0; n < numPointsInArc; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		vertexData.push_back(rightInnerX  + roundRadius*cosa);
+		vertexData.push_back(bottomInnerY - roundRadius*sina);
+	}
+	const auto vertCount = vertexData.size() / 2;
+	sPainter.setBlending(true);
+	sPainter.setLineSmooth(true);
+	sPainter.setLineWidth(scale * std::clamp(2*size/35, 1.f, 2.5f));
+	sPainter.setColor(color, hintsBrightness);
+	sPainter.enableClientStates(true);
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData.data());
+	sPainter.drawFromArray(StelPainter::LineLoop, vertCount, 0, false);
+	sPainter.enableClientStates(false);
+}
+
+void Nebula::renderRoundMarker(StelPainter& sPainter, const float x, const float y,
+                               float size, const Vec3f color, const bool crossed) const
+{
+	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
+	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	size *= scale;
+
+	sPainter.setBlending(true);
+	sPainter.setLineSmooth(true);
+	sPainter.setLineWidth(scale * std::clamp(size/7, 1.f, 2.5f));
+	sPainter.setColor(color, hintsBrightness);
+
+	sPainter.drawCircle(x, y, size);
+	if(!crossed) return;
+
+	sPainter.enableClientStates(true);
+	const float vertexData[] = {x-size, y,
+	                            x+size, y,
+	                            x, y-size,
+	                            x, y+size};
+	const auto vertCount = std::size(vertexData) / 2;
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData);
+	sPainter.drawFromArray(StelPainter::Lines, vertCount, 0, false);
+	sPainter.enableClientStates(false);
+}
+
+void Nebula::renderEllipticMarker(StelPainter& sPainter, const float x, const float y, float size,
+                                  const float aspectRatio, const float angle, const Vec3f color) const
+{
+	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
+	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	size *= scale;
+
+	const float radiusY = 0.35 * size;
+	const float radiusX = aspectRatio * radiusY;
+	const int numPoints = std::lround(std::clamp(size/3, 32.f, 4096.f));
+	std::vector<float> vertexData;
+	vertexData.reserve(numPoints*2);
+	const float*const cossin = StelUtils::ComputeCosSinTheta(numPoints);
+	const auto cosa = std::cos(angle);
+	const auto sina = std::sin(angle);
+	for(int n = 0; n < numPoints; ++n)
+	{
+		const auto cosb = cossin[2*n], sinb = cossin[2*n+1];
+		const auto pointX = radiusX*sinb;
+		const auto pointY = radiusY*cosb;
+		vertexData.push_back(x + pointX*cosa - pointY*sina);
+		vertexData.push_back(y + pointY*cosa + pointX*sina);
+	}
+	const auto vertCount = vertexData.size() / 2;
+	sPainter.setBlending(true);
+	sPainter.setLineSmooth(true);
+	sPainter.setLineWidth(scale * std::clamp(size/40, 1.f, 2.f));
+	sPainter.setColor(color, hintsBrightness);
+	sPainter.enableClientStates(true);
+	sPainter.setVertexPointer(2, GL_FLOAT, vertexData.data());
+	sPainter.drawFromArray(StelPainter::LineLoop, vertCount, 0, false);
+	sPainter.enableClientStates(false);
+}
+
+void Nebula::renderMarkerPointedCircle(StelPainter& sPainter, const float x, const float y,
+                                       float size, const Vec3f color, const bool insideRect) const
+{
+	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
+	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	size *= scale;
+
+	texPointElement->bind();
+	sPainter.setColor(color, hintsBrightness);
+	sPainter.setBlending(true, GL_SRC_ALPHA, GL_ONE);
+	const auto numPoints = StelUtils::getSmallerPowerOfTwo(std::clamp(int(0.4f*size), 8, 4096));
+	const auto spriteSize = std::min(0.25f * 2*M_PIf*size / numPoints, 5.f);
+	if(insideRect)
+		size -= spriteSize*2;
+	const float*const cossin = StelUtils::ComputeCosSinRhoZone((2*M_PIf)/numPoints, numPoints, 0);
+	for(int n = 0; n < numPoints; ++n)
+	{
+		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
+		sPainter.drawSprite2dMode(x - size*sina, y - size*cosa, spriteSize);
+	}
+}
+
+float Nebula::getHintSize(StelPainter& sPainter) const
+{
+	const float size = 6.0f;
+	float scaledSize = 0.0f;
+	if (drawHintProportional)
+		scaledSize = static_cast<float>(getAngularRadius(Q_NULLPTR)) *(M_PI_180f*2.f)*static_cast<float>(sPainter.getProjector()->getPixelPerRadAtCenter());
+	if (nType==NebRegion)
+		scaledSize = 12.f;
+
+	return qMax(size, scaledSize);
+}
+
 void Nebula::drawHints(StelPainter& sPainter, float maxMagHints, StelCore *core) const
 {
 	size_t segments = outlineSegments.size();
@@ -758,11 +979,10 @@ void Nebula::drawHints(StelPainter& sPainter, float maxMagHints, StelCore *core)
 
 	Vec3f color = getHintColor(nType);
 
-	const float size = 6.0f;
-	float scaledSize = 0.0f;
-	if (drawHintProportional)
-		scaledSize = static_cast<float>(getAngularRadius(Q_NULLPTR)) *(M_PI_180f*2.f)*static_cast<float>(sPainter.getProjector()->getPixelPerRadAtCenter());
-	float finalSize=qMax(size, scaledSize);
+	float finalSize = getHintSize(sPainter);
+
+	if (!objectInDisplayedType())
+		return;
 
 	switch (nType)
 	{
@@ -774,65 +994,54 @@ void Nebula::drawHints(StelPainter& sPainter, float maxMagHints, StelCore *core)
 		case NebBLL:
 		case NebBLA:
 		case NebRGx:
-		case NebGxCl:			
-			if (finalSize > 35.f)
-				Nebula::texGalaxyLarge->bind();
-			else
-				Nebula::texGalaxy->bind();
-			break;
+		case NebGxCl:
+		{
+			// The rotation angle in renderEllipticMarker() is relative to screen. Make sure to compute correct angle from 90+orientationAngle.
+			// Find an on-screen direction vector from a point offset somewhat in declination from our object.
+			Vec3d XYZrel(getJ2000EquatorialPos(core));
+			XYZrel[2]*=0.95; XYZrel.normalize();
+			Vec3d XYrel;
+			sPainter.getProjector()->project(XYZrel, XYrel);
+			const auto screenAngle = atan2(XYrel[1]-XY[1], XYrel[0]-XY[0]);
+			renderEllipticMarker(sPainter, XY[0], XY[1], finalSize, 2, screenAngle + orientationAngle*M_PI_180f, color);
+			return;
+		}
 		case NebOc:
 		case NebSA:
 		case NebSC:
 		case NebCl:
-			if (finalSize > 75.f)
-				Nebula::texOpenClusterXLarge->bind();
-			else if (finalSize > 35.f)
-				Nebula::texOpenClusterLarge->bind();
-			else
-				Nebula::texOpenCluster->bind();
-			break;
+			renderMarkerPointedCircle(sPainter, XY[0], XY[1], finalSize, color, false);
+			return;
 		case NebGc:
-			if (finalSize > 35.f)
-				Nebula::texGlobularClusterLarge->bind();
-			else
-				Nebula::texGlobularCluster->bind();
-			break;
+			renderRoundMarker(sPainter, XY[0], XY[1], finalSize, color, true);
+			return;
 		case NebN:
 		case NebHII:
 		case NebMolCld:
 		case NebYSO:
-		case NebRn:		
+		case NebRn:
 		case NebSNR:
 		case NebBn:
 		case NebEn:
 		case NebSNC:
 		case NebSNRC:
-			if (finalSize > 75.f)
-				Nebula::texDiffuseNebulaXLarge->bind();
-			else if (finalSize > 35.f)
-				Nebula::texDiffuseNebulaLarge->bind();
-			else
-				Nebula::texDiffuseNebula->bind();
-			break;
+			renderMarkerRoundedRect(sPainter, XY[0], XY[1], finalSize, color);
+			return;
 		case NebPn:
 		case NebPossPN:
 		case NebPPN:
 			Nebula::texPlanetaryNebula->bind();
 			break;
 		case NebDn:
-			if (finalSize > 35.f)
-				Nebula::texDarkNebulaLarge->bind();
-			else
-				Nebula::texDarkNebula->bind();
-			break;
+			renderDarkNebulaMarker(sPainter, XY[0], XY[1], finalSize, color);
+			return;
 		case NebCn:
-			if (finalSize > 35.f)
-				Nebula::texOpenClusterWithNebulosityLarge->bind();
-			else
-				Nebula::texOpenClusterWithNebulosity->bind();
-			break;
+		{
+			renderMarkerRoundedRect(sPainter, XY[0], XY[1], finalSize, getHintColor(NebN));
+			renderMarkerPointedCircle(sPainter, XY[0], XY[1], finalSize, getHintColor(NebCl), true);
+			return;
+		}
 		case NebRegion:
-			finalSize = size*2.f;
 			Nebula::texRegion->bind();
 			break;
 		//case NebEMO:
@@ -840,34 +1049,14 @@ void Nebula::drawHints(StelPainter& sPainter, float maxMagHints, StelCore *core)
 		//case NebSymbioticStar:
 		//case NebEmissionLineStar:
 		default:
-			if (finalSize > 35.f)
-				Nebula::texCircleLarge->bind();
-			else
-				Nebula::texCircle->bind();
+			renderRoundMarker(sPainter, XY[0], XY[1], finalSize, color, false);
+			return;
 	}
 
-	float lum = 1.f;
-	Vec3f col(color*lum*hintsBrightness);
-	if (!objectInDisplayedType())
-		col.set(0.f,0.f,0.f);
+	sPainter.setColor(color, hintsBrightness);
+	sPainter.setBlending(true, GL_SRC_ALPHA, GL_ONE);
 
-	sPainter.setColor(col, 1);
-	sPainter.setBlending(true, GL_ONE, GL_ONE);
-
-	// Rotation looks good only for galaxies.
-	if ((nType <=NebQSO) || (nType==NebBLA) || (nType==NebBLL) )
-	{
-		// The rotation angle in drawSprite2dMode() is relative to screen. Make sure to compute correct angle from 90+orientationAngle.
-		// Find an on-screen direction vector from a point offset somewhat in declination from our object.
-		Vec3d XYZrel(getJ2000EquatorialPos(core));
-		XYZrel[2]*=0.95; XYZrel.normalize();
-		Vec3d XYrel;
-		sPainter.getProjector()->project(XYZrel, XYrel);
-		float screenAngle = static_cast<float>(atan2(XYrel[1]-XY[1], XYrel[0]-XY[0]));
-		sPainter.drawSprite2dMode(static_cast<float>(XY[0]), static_cast<float>(XY[1]), finalSize, screenAngle*M_180_PIf + orientationAngle);
-	}
-	else	// no galaxy
-		sPainter.drawSprite2dMode(static_cast<float>(XY[0]), static_cast<float>(XY[1]), finalSize);
+	sPainter.drawSprite2dMode(static_cast<float>(XY[0]), static_cast<float>(XY[1]), finalSize);
 }
 
 void Nebula::drawLabel(StelPainter& sPainter, float maxMagLabel) const
@@ -882,14 +1071,13 @@ void Nebula::drawLabel(StelPainter& sPainter, float maxMagLabel) const
 
 	sPainter.setColor(labelColor, objectInDisplayedType() ? hintsBrightness : 0.f);
 
-	const float size = static_cast<float>(getAngularRadius(Q_NULLPTR))*(M_PI_180f*2.f)*sPainter.getProjector()->getPixelPerRadAtCenter();
-	const float shift = 5.f + (drawHintProportional ? size*0.9f : 0.f);
+	const float shift = 15.f + (drawHintProportional ? getHintSize(sPainter) : 0.f);
 
 	QString str = getNameI18n();
 	if (str.isEmpty() || designationUsage)
 		str = getDSODesignation();
 
-	sPainter.drawText(static_cast<float>(XY[0])+shift, static_cast<float>(XY[1])+shift, str, 0, 0, 0, false);
+	sPainter.drawText(static_cast<float>(XY[0]), static_cast<float>(XY[1]), str, 0, shift, shift, false);
 }
 
 QString Nebula::getDSODesignation() const
@@ -1013,7 +1201,7 @@ void Nebula::readDSO(QDataStream &in)
 	if (VdBHa_nb > 0) designations << QString("vdB-Ha %1").arg(VdBHa_nb);
 
 	StelUtils::spheToRect(ra,dec,XYZ);
-	Q_ASSERT(fabs(XYZ.lengthSquared()-1.)<1e-9);
+	Q_ASSERT(fabs(XYZ.normSquared()-1.)<1e-9);
 	nType = static_cast<Nebula::NebulaType>(oType);
 	pointRegion = SphericalRegionP(new SphericalPoint(getJ2000EquatorialPos(Q_NULLPTR)));
 }
@@ -1040,7 +1228,7 @@ bool Nebula::objectInDisplayedType() const
 		case NebIGx:
 			cntype = 2; // Interacting Galaxies
 			break;
-		case NebOc:		
+		case NebOc:
 		case NebCl:
 		case NebSA:
 		case NebSC:
@@ -1094,7 +1282,7 @@ bool Nebula::objectInDisplayedType() const
 		|| (typeFilters&TypeDarkNebulae          && cntype==6)
 		|| (typeFilters&TypePlanetaryNebulae     && cntype==7)
 		|| (typeFilters&TypeSupernovaRemnants    && cntype==8)
-		|| (typeFilters&TypeOpenStarClusters     && (typeFilters&TypeBrightNebulae || typeFilters&TypeHydrogenRegions) && cntype==9)
+		|| ((typeFilters&TypeOpenStarClusters || typeFilters&TypeBrightNebulae || typeFilters&TypeHydrogenRegions) && cntype==9)
 		|| (typeFilters&TypeGalaxyClusters       && cntype==10)
 		|| (typeFilters&TypeOther                && cntype==12));
 
@@ -1124,7 +1312,7 @@ bool Nebula::objectInDisplayedCatalog() const
 		|| ((catalogFilters&CatPNG)   && !(PNG_nb.isEmpty()))
 		|| ((catalogFilters&CatSNRG)  && !(SNRG_nb.isEmpty()))
 		|| ((catalogFilters&CatACO)   && (!ACO_nb.isEmpty()))
-		|| ((catalogFilters&CatHCG)   && (!HCG_nb.isEmpty()))		
+		|| ((catalogFilters&CatHCG)   && (!HCG_nb.isEmpty()))
 		|| ((catalogFilters&CatESO)   && (!ESO_nb.isEmpty()))
 		|| ((catalogFilters&CatVdBH)  && (!VdBH_nb.isEmpty()))
 		|| ((catalogFilters&CatDWB)   && (DWB_nb>0))
@@ -1348,7 +1536,7 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 				rtx << qc_("undocumented reflection nebulae", "Reflection Nebulae Classification");
 				break;
 		}
-		r = rtx.join(",<br />");
+		r = rtx.join(", ");
 	}
 
 
@@ -1414,7 +1602,7 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 	return r;
 }
 
-QString Nebula::getTypeString(Nebula::NebulaType nType)
+QString Nebula::getTypeStringI18n(Nebula::NebulaType nType)
 {
 	return q_(typeEnglishStringMap.value(nType, q_("undocumented type")));
 }
@@ -1424,7 +1612,7 @@ Vec3d Nebula::getJ2000EquatorialPos(const StelCore* core) const
 	if ((core) && (core->getUseAberration()) && (core->getCurrentPlanet()))
 	{
 		Vec3d pos=XYZ;
-		Q_ASSERT_X(fabs(pos.lengthSquared()-1.0)<0.0001, "Nebula aberration", "vertex length not unity");
+		Q_ASSERT_X(fabs(pos.normSquared()-1.0)<0.0001, "Nebula aberration", "vertex length not unity");
 		//pos.normalize(); // Yay - not required!
 		Vec3d vel=core->getCurrentPlanet()->getHeliocentricEclipticVelocity();
 		vel=StelCore::matVsop87ToJ2000*vel*core->getAberrationFactor()*(AU/(86400.0*SPEED_OF_LIGHT));
