@@ -58,12 +58,14 @@ class NebulaMgr : public StelObjectModule
 		   WRITE setFlagUseTypeFilters
 		   NOTIFY flagUseTypeFiltersChanged)
 	//StelProperties
-	Q_PROPERTY(Nebula::TypeGroup typeFilters
+	// This used to be of type Nebula::TypeGroup, however on Qt6 this does not work and was changed to int.
+	Q_PROPERTY(int typeFilters
 		   READ getTypeFilters
 		   WRITE setTypeFilters
 		   NOTIFY typeFiltersChanged
 		   )
-	Q_PROPERTY(Nebula::CatalogGroup catalogFilters
+	// This used to be of type Nebula::CatalogGroup, however on Qt6 this does not work and was changed to int.
+	Q_PROPERTY(int catalogFilters
 		   READ getCatalogFilters
 		   WRITE setCatalogFilters
 		   NOTIFY catalogFiltersChanged
@@ -254,11 +256,6 @@ class NebulaMgr : public StelObjectModule
 		   WRITE setProtoplanetaryNebulaColor
 		   NOTIFY protoplanetaryNebulaeColorChanged
 		   )
-	Q_PROPERTY(Vec3f clusterWithNebulosityColor
-		   READ getClusterWithNebulosityColor
-		   WRITE setClusterWithNebulosityColor
-		   NOTIFY clusterWithNebulosityColorChanged
-		   )
 	Q_PROPERTY(Vec3f hydrogenRegionsColor
 		   READ getHydrogenRegionColor
 		   WRITE setHydrogenRegionColor
@@ -392,11 +389,21 @@ public:
 	///////////////////////////////////////////////////////////////////////////
 	// Properties setters and getters
 public slots:
-	void setCatalogFilters(Nebula::CatalogGroup cflags);
-	Nebula::CatalogGroup getCatalogFilters() const { return Nebula::catalogFilters; }
+	void setCatalogFilters(int cflags);
+	int getCatalogFilters() const { return int(Nebula::catalogFilters); }
+	//! Activate all catalogs
+	void selectAllCatalogs();
+	//! Activate a useful selection of catalogs: M, NGC, IC
+	void selectStandardCatalogs();
+	//! Disable all catalogs
+	void selectNoneCatalogs();
+	//! retrieve configured catalogs from config.ini.
+	void loadCatalogFilters();
+	//! store configured catalogs into config.ini.
+	void storeCatalogFilters();
 
-	void setTypeFilters(Nebula::TypeGroup tflags);
-	Nebula::TypeGroup getTypeFilters() const { return Nebula::typeFilters; }
+	void setTypeFilters(int tflags);
+	int getTypeFilters() const { return int(Nebula::typeFilters); }
 
 	//! Set the default color used to draw the nebula symbols (default circles, etc).
 	//! @param c The color of the nebula symbols
@@ -579,16 +586,6 @@ public slots:
 	//! Get current value of the dark nebula color.
 	const Vec3f getDarkNebulaColor(void) const;
 
-	//! Set the color used to draw the cluster associated with nebulosity symbols.
-	//! @param c The color of the cluster associated with nebulosity symbols
-	//! @code
-	//! // example of usage in scripts
-	//! NebulaMgr.setClusterWithNebulosityColor(Vec3f(0.2,0.2,0.2));
-	//! @endcode
-	void setClusterWithNebulosityColor(const Vec3f& c);
-	//! Get current value of the cluster associated with nebulosity color.
-	const Vec3f getClusterWithNebulosityColor(void) const;
-
 	//! Set the color used to draw the star cluster symbols (Open/Globular).
 	//! @param c The color of the cluster symbols
 	//! @code
@@ -864,9 +861,9 @@ signals:
 	//! Emitted when filter types are changed.
 	void flagUseTypeFiltersChanged(bool b);
 	//! Emitted when the catalog filter is changed
-	void catalogFiltersChanged(Nebula::CatalogGroup flags);
+	void catalogFiltersChanged(int flags); // emits an int cast of Nebula::CatalogGroup
 	//! Emitted when the type filter is changed
-	void typeFiltersChanged(Nebula::TypeGroup flags);
+	void typeFiltersChanged(int flags); // emits an int cast of Nebula::TypeGroup
 	void hintsProportionalChanged(bool b);
 	void flagOutlinesDisplayedChanged(bool b);
 	void flagAdditionalNamesDisplayedChanged(bool b);
@@ -905,7 +902,6 @@ signals:
 	void emissionNebulaeColorChanged(const Vec3f & color) const;
 	void possiblePlanetaryNebulaeColorChanged(const Vec3f & color) const;
 	void protoplanetaryNebulaeColorChanged(const Vec3f & color) const;
-	void clusterWithNebulosityColorChanged(const Vec3f & color) const;
 	void hydrogenRegionsColorChanged(const Vec3f & color) const;
 	void interstellarMatterColorChanged(const Vec3f & color) const;
 	void emissionObjectsColorChanged(const Vec3f & color) const;
@@ -991,6 +987,9 @@ private:
 	bool loadDSONames(const QString& filename);
 	// Load outlines for DSO
 	bool loadDSOOutlines(const QString& filename);
+	// Load discovery data for DSO
+	// TODO: Move these data into main DSO catalog to fast reading (v4)
+	bool loadDSODiscoveryData(const QString& filename);
 
 	QVector<NebulaP> dsoArray;		// The DSO list
 	QHash<unsigned int, NebulaP> dsoIndex;
