@@ -27,10 +27,8 @@
 #include <QList>
 
 #include "StelObject.hpp"
-#include "StelTextureTypes.hpp"
 #include "StelFader.hpp"
 #include "StelTranslator.hpp"
-#include "Planet.hpp"
 #include "SolarSystem.hpp"
 
 class StelPainter;
@@ -132,7 +130,7 @@ public:
 	};
 	Q_ENUM(PlanetCoordinateOrientation)
 
-	NomenclatureItem(PlanetP nPlanet, int nId, const QString& nName, const QString& nContext, NomenclatureItemType nItemType, double nLatitude, double nLongitude, double nSize);
+	NomenclatureItem(PlanetP nPlanet, int nId, const QString& nName, const QString& nContext, const QString& nOrigin, NomenclatureItemType nItemType, double nLatitude, double nLongitude, double nSize);
 	virtual ~NomenclatureItem() Q_DECL_OVERRIDE;
 
 	//! Get the type of object
@@ -192,6 +190,8 @@ public:
 	static bool getFlagLabels(void){ return labelsFader;}
 	void setFlagHideLocalNomenclature(bool b) { hideLocalNomenclature=b; }
 	bool getFlagHideLocalNomenclature() const { return hideLocalNomenclature; }
+	void setFlagShowSpecialNomenclatureOnly(bool b) { showSpecialNomenclatureOnly=b; }
+	bool getFlagShowSpecialNomenclatureOnly() const { return showSpecialNomenclatureOnly; }
 	//QString getEnglishPlanetName(void) const {return planet->getEnglishName();}
 	PlanetP getPlanet(void) const { return planet;}
 	//! get latitude [degrees]
@@ -212,7 +212,12 @@ private:
 	mutable Vec3d XYZ;     // holds J2000 position in space (i.e. including planet position, offset from planetocenter)
 	mutable double jde;    // jde time of XYZ value
 	static Vec3f color;
+	static bool flagOutlineCraters; // draw craters and satellite features as ellipses?
 	static bool hideLocalNomenclature;
+	static bool showTerminatorZoneOnly;
+	static int terminatorMinAltitude;
+	static int terminatorMaxAltitude;
+	static bool showSpecialNomenclatureOnly;
 
 	// ratio of angular size of feature to the FOV
 	float getAngularDiameterRatio(const StelCore *core) const;
@@ -243,7 +248,7 @@ private:
 
 	PlanetP planet;
 	int identificator;
-	QString englishName, context, nameI18n;
+	QString englishName, context, nameI18n, origin, originI18n;
 	NomenclatureItemType nType; // Type of nomenclature item
 	mutable double latitude;    // degrees
 	mutable double longitude;   // degrees. Declared mutable to allow change in otherwise const methods (for special points)
