@@ -39,7 +39,6 @@
 NomenclatureMgr::NomenclatureMgr() : StelObjectModule()
 {
 	setObjectName("NomenclatureMgr");
-	conf = StelApp::getInstance().getSettings();
 	font.setPixelSize(StelApp::getInstance().getScreenFontSize());
 	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSize(int)));
 	ssystem = GETSTELMODULE(SolarSystem);
@@ -66,9 +65,15 @@ void NomenclatureMgr::init()
 	loadNomenclature();
 	loadSpecialNomenclature();
 
-	setColor(Vec3f(conf->value("color/planet_nomenclature_color", "0.1,1.0,0.1").toString()));
-	setFlagLabels(conf->value("astro/flag_planets_nomenclature", false).toBool());
-	setFlagHideLocalNomenclature(conf->value("astro/flag_hide_local_nomenclature", true).toBool());
+	QSettings *conf = StelApp::getInstance().getSettings();
+	setColor(Vec3f(                    conf->value("color/planet_nomenclature_color", "0.1,1.0,0.1").toString()));
+	setFlagShowNomenclature(           conf->value("astro/flag_planets_nomenclature", false).toBool());
+	setFlagShowTerminatorZoneOnly(     conf->value("astro/flag_planets_nomenclature_terminator_only", false).toBool());
+	setTerminatorMinAltitude(          conf->value("astro/planet_nomenclature_solar_altitude_min", -5).toInt());
+	setTerminatorMaxAltitude(          conf->value("astro/planet_nomenclature_solar_altitude_max", 40).toInt());
+	setFlagOutlineCraters(             conf->value("astro/flag_planets_nomenclature_outline_craters", false).toBool());
+	setFlagHideLocalNomenclature(      conf->value("astro/flag_hide_local_nomenclature", true).toBool());
+	setFlagShowSpecialNomenclatureOnly(conf->value("astro/flag_special_nomenclature_only", false).toBool());
 
 	GETSTELMODULE(StelObjectMgr)->registerStelObjectMgr(this);
 
@@ -77,16 +82,17 @@ void NomenclatureMgr::init()
 	connect(ssystem, SIGNAL(solarSystemDataReloaded()), this, SLOT(updateNomenclatureData()));
 
 	QString displayGroup = N_("Display Options");
-	addAction("actionShow_Planets_Nomenclature", displayGroup, N_("Nomenclature labels"), "nomenclatureDisplayed", "Alt+N");
+	addAction("actionShow_Planets_Nomenclature", displayGroup, N_("Nomenclature labels"), "flagShowNomenclature", "Alt+N");
+	addAction("actionShow_Planets_Nomenclature_SpecialPoints_Only", displayGroup, N_("Special nomenclature points only"), "specialNomenclatureOnlyDisplayed");
 }
 
 void NomenclatureMgr::updateNomenclatureData()
 {
-	bool flag = getFlagLabels();
+	bool flag = getFlagShowNomenclature();
 	loadNomenclature();
 	loadSpecialNomenclature();
 	updateI18n();
-	setFlagLabels(flag);
+	setFlagShowNomenclature(flag);
 }
 
 void NomenclatureMgr::loadSpecialNomenclature()
@@ -96,31 +102,31 @@ void NomenclatureMgr::loadSpecialNomenclature()
 	for (const auto& p: ss)
 	{
 		const double size = p->getEquatorialRadius()*AU*0.25; // formal radius of point is 25% of equatorial radius
-		NomenclatureItemP nomNP = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("North Pole"), "", NomenclatureItem::niSpecialPointPole, 90., 0., size));
+		NomenclatureItemP nomNP = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("North Pole"), "", "", NomenclatureItem::niSpecialPointPole, 90., 0., size));
 		if (!nomNP.isNull())
 			nomenclatureItems.insert(p, nomNP);
 		featureId++;
-		NomenclatureItemP nomSP = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("South Pole"), "", NomenclatureItem::niSpecialPointPole, -90., 0., size));
+		NomenclatureItemP nomSP = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("South Pole"), "", "", NomenclatureItem::niSpecialPointPole, -90., 0., size));
 		if (!nomSP.isNull())
 			nomenclatureItems.insert(p, nomSP);
 		featureId++;
 		// longitude is fake, used just to define the object
-		NomenclatureItemP nomE = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("East"), "", NomenclatureItem::niSpecialPointEast, 0., 0., size));
+		NomenclatureItemP nomE = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("East"), "", "", NomenclatureItem::niSpecialPointEast, 0., 0., size));
 		if (!nomE.isNull())
 			nomenclatureItems.insert(p, nomE);
 		featureId++;
 		// longitude is fake, used just to define the object
-		NomenclatureItemP nomW = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("West"), "", NomenclatureItem::niSpecialPointWest, 0., 180., size));
+		NomenclatureItemP nomW = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("West"), "", "", NomenclatureItem::niSpecialPointWest, 0., 180., size));
 		if (!nomW.isNull())
 			nomenclatureItems.insert(p, nomW);
 		featureId++;
 		// longitude is fake, used just to define the object
-		NomenclatureItemP nomC = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("Centre"), "", NomenclatureItem::niSpecialPointCenter, 0., 180., size));
+		NomenclatureItemP nomC = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("Centre"), "", "", NomenclatureItem::niSpecialPointCenter, 0., 180., size));
 		if (!nomC.isNull())
 			nomenclatureItems.insert(p, nomC);
 		featureId++;
 		// longitude is fake, used just to define the object
-		NomenclatureItemP nomS = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("Subsolar"), "", NomenclatureItem::niSpecialPointSubSolar, 0., 180., size));
+		NomenclatureItemP nomS = NomenclatureItemP(new NomenclatureItem(p, featureId, N_("Subsolar"), "", "", NomenclatureItem::niSpecialPointSubSolar, 0., 180., size));
 		if (!nomS.isNull())
 			nomenclatureItems.insert(p, nomS);
 		featureId++;
@@ -147,7 +153,8 @@ void NomenclatureMgr::loadNomenclature()
 	//	latitude of surface feature		: float (decimal degrees)
 	//	longitude of surface feature		: float (decimal degrees)
 	//	diameter of surface feature		: float (kilometers)
-	static const QRegularExpression recRx("^\\s*(\\w+)\\s+(\\d+)\\s+_[(]\"(.*)\"[)]\\s+(\\w+)\\s+([\\-\\+\\.\\d]+)\\s+([\\-\\+\\.\\d]+)\\s+([\\-\\+\\.\\d]+)(.*)");
+	//	translatable origin of name		: string
+	static const QRegularExpression recRx("^\\s*(\\w+)\\s+(\\d+)\\s+_[(]\"(.*)\"[)]\\s+(\\w+)\\s+([\\-\\+\\.\\d]+)\\s+([\\-\\+\\.\\d]+)\\s+([\\-\\+\\.\\d]+)\\s+_[(]\"(.*)\"[)](.*)");
 	static const QRegularExpression ctxRx("(.*)\",\\s*\"(.*)");
 
 	QString surfNamesFile = StelFileMgr::findFile("data/nomenclature.dat"); // compressed version of file nomenclature.fab
@@ -180,10 +187,10 @@ void NomenclatureMgr::loadNomenclature()
 		PlanetP p;
 
 		int featureId;
-		QString name, planet = "", planetName = "", context = "";
+		QString name, planet = "", planetName = "", context = "", origin = "";
 		NomenclatureItem::NomenclatureItemType ntype;
 		double latitude, longitude, size;
-		QStringList faultPlanets;
+		QStringList missingPlanets;
 
 		while (!buf.atEnd())
 		{
@@ -200,11 +207,9 @@ void NomenclatureMgr::loadNomenclature()
 				qWarning() << "ERROR - cannot parse record at line" << lineNumber << "in surface nomenclature file" << QDir::toNativeSeparators(surfNamesFile);
 			else
 			{
-				// Read the planet name
+				// Read planet name, feature ID, context
 				planet	= recMatch.captured(1).trimmed();
-				// Read the ID of feature
 				featureId	= recMatch.captured(2).toInt();
-				// Read the name of feature and context
 				QString ctxt	= recMatch.captured(3).trimmed();
 				QRegularExpressionMatch ctxMatch=ctxRx.match(ctxt);
 				if (ctxMatch.hasMatch())
@@ -220,12 +225,16 @@ void NomenclatureMgr::loadNomenclature()
 				// Read the type of feature
 				QString ntypecode	= recMatch.captured(4).trimmed();
 				ntype = NomenclatureItem::getNomenclatureItemType(ntypecode.toUpper());
-				// Read the latitude of feature
+				// Read lat/long/size of feature
 				latitude	= recMatch.captured(5).toDouble();
-				// Read the longitude of feature
 				longitude	= recMatch.captured(6).toDouble();
-				// Read the size of feature
 				size		= recMatch.captured(7).toDouble();
+				QString otxt	= recMatch.captured(8).trimmed();
+				QRegularExpressionMatch otxMatch=ctxRx.match(otxt);
+				if (otxMatch.hasMatch())
+					origin  = otxMatch.captured(1).trimmed();
+				else
+					origin  = otxt;
 
 				if (planetName.isEmpty() || planet!=planetName)
 				{
@@ -237,24 +246,24 @@ void NomenclatureMgr::loadNomenclature()
 
 				if (!p.isNull())
 				{
-					NomenclatureItemP nom = NomenclatureItemP(new NomenclatureItem(p, featureId, name, context, ntype, latitude, longitude, size));
+					NomenclatureItemP nom = NomenclatureItemP(new NomenclatureItem(p, featureId, name, context, origin, ntype, latitude, longitude, size));
 					if (!nom.isNull())
 						nomenclatureItems.insert(p, nom);
 
 					readOk++;
 				}
 				else
-					faultPlanets << planet;
+					missingPlanets.append(planet);
 			}
 		}
 
 		buf.close();
 		qDebug() << "Loaded" << readOk << "/" << totalRecords << "items of planetary surface nomenclature";
 
-		faultPlanets.removeDuplicates();
-		int err = faultPlanets.size();
-		if (err>0)
-			qDebug() << "WARNING - These planets to assign nomenclature items were not found:" << faultPlanets.join(", ");
+		missingPlanets.removeDuplicates();
+		if (!missingPlanets.isEmpty())
+			// Nothing to worry about - We still don't include all objects.
+			qInfo() << "INFO: Cannot find these planetary objects to assign nomenclature items:" << missingPlanets.join(", ");
 	}
 }
 
@@ -284,7 +293,7 @@ void NomenclatureMgr::draw(StelCore* core)
 		// Early exit if the planet is not visible or too small to render the labels.
 		const Vec3d equPos = p->getJ2000EquatorialPos(core);
 		const double r = p->getEquatorialRadius() * static_cast<double>(p->getSphereScale());
-		double angularSize = atan2(r, equPos.length());
+		double angularSize = atan2(r, equPos.norm());
 		double screenSize = angularSize * static_cast<double>(painter.getProjector()->getPixelPerRadAtCenter());
 		if (screenSize < 50)
 			continue;
@@ -357,7 +366,7 @@ QList<StelObjectP> NomenclatureMgr::searchAround(const Vec3d& av, double limitFo
 
 StelObjectP NomenclatureMgr::searchByName(const QString& englishName) const
 {
-	if (getFlagLabels())
+	if (getFlagShowNomenclature())
 	{
 		NomenclatureItem::NomenclatureItemType niType;
 		for (const auto& nItem : nomenclatureItems)
@@ -374,7 +383,7 @@ StelObjectP NomenclatureMgr::searchByName(const QString& englishName) const
 
 StelObjectP NomenclatureMgr::searchByNameI18n(const QString& nameI18n) const
 {
-	if (getFlagLabels())
+	if (getFlagShowNomenclature())
 	{
 		NomenclatureItem::NomenclatureItemType niType;
 		for (const auto& nItem : nomenclatureItems)
@@ -393,7 +402,7 @@ QStringList NomenclatureMgr::listAllObjects(bool inEnglish) const
 {
 	QStringList result;
 
-	if (getFlagLabels())
+	if (getFlagShowNomenclature())
 	{
 		NomenclatureItem::NomenclatureItemType niType;
 		if (inEnglish)
@@ -422,7 +431,7 @@ QStringList NomenclatureMgr::listAllObjectsByType(const QString &objType, bool i
 {
 	QStringList result;
 
-	if (getFlagLabels())
+	if (getFlagShowNomenclature())
 	{
 		int type = objType.toInt();
 		switch (type)
@@ -466,7 +475,7 @@ QStringList NomenclatureMgr::listAllObjectsByType(const QString &objType, bool i
 
 NomenclatureItemP NomenclatureMgr::searchByEnglishName(QString nomenclatureItemEnglishName) const
 {
-	if (getFlagLabels())
+	if (getFlagShowNomenclature())
 	{
 		NomenclatureItem::NomenclatureItemType niType;
 		for (const auto& p : nomenclatureItems)
@@ -491,23 +500,84 @@ const Vec3f& NomenclatureMgr::getColor(void) const
 	return NomenclatureItem::color;
 }
 
-void NomenclatureMgr::setFlagLabels(bool b)
+void NomenclatureMgr::setFlagShowNomenclature(bool b)
 {
-	if (getFlagLabels() != b)
+	if (getFlagShowNomenclature() != b)
 	{
 		NomenclatureItem::setFlagLabels(b);
-		emit nomenclatureDisplayedChanged(b);
+		emit flagShowNomenclatureChanged(b);
 	}
 }
 
-bool NomenclatureMgr::getFlagLabels() const
+bool NomenclatureMgr::getFlagShowNomenclature() const
 {
 	return NomenclatureItem::getFlagLabels();
 }
 
+// Set flag which determines if only nomenclature along the terminator should be shown.
+void NomenclatureMgr::setFlagShowTerminatorZoneOnly(bool b)
+{
+	if (b!=NomenclatureItem::showTerminatorZoneOnly)
+	{
+		NomenclatureItem::showTerminatorZoneOnly=b;
+		StelApp::immediateSave("astro/flag_planets_nomenclature_terminator_only", b);
+		emit flagShowTerminatorZoneOnlyChanged(b);
+	}
+}
+// Get flag which determines if only nomenclature along the terminator should be shown.
+bool NomenclatureMgr::getFlagShowTerminatorZoneOnly() const
+{
+	return NomenclatureItem::showTerminatorZoneOnly;
+}
+
+// Set minimum solar altitude (degrees) to draw only nomenclature along the terminator.
+void NomenclatureMgr::setTerminatorMinAltitude(int deg)
+{
+	if (deg!=NomenclatureItem::terminatorMinAltitude)
+	{
+		NomenclatureItem::terminatorMinAltitude=qBound(-90, deg, 90);
+		StelApp::immediateSave("astro/planet_nomenclature_solar_altitude_min", NomenclatureItem::terminatorMinAltitude);
+		emit terminatorMinAltitudeChanged(NomenclatureItem::terminatorMinAltitude);
+	}
+}
+// Get minimum solar altitude (degrees) to draw only nomenclature along the terminator.
+int NomenclatureMgr::getTerminatorMinAltitude() const
+{
+	return NomenclatureItem::terminatorMinAltitude;
+}
+
+// Set maximum solar altitude (degrees) to draw only nomenclature along the terminator.
+void NomenclatureMgr::setTerminatorMaxAltitude(int deg)
+{
+	if (deg!=NomenclatureItem::terminatorMaxAltitude)
+	{
+		NomenclatureItem::terminatorMaxAltitude=qBound(-90, deg, 90);
+		StelApp::immediateSave("astro/planet_nomenclature_solar_altitude_max", NomenclatureItem::terminatorMaxAltitude);
+		emit terminatorMaxAltitudeChanged(NomenclatureItem::terminatorMaxAltitude);
+	}
+}
+// Get maximum solar altitude (degrees) to draw only nomenclature along the terminator.
+int NomenclatureMgr::getTerminatorMaxAltitude() const
+{
+	return NomenclatureItem::terminatorMaxAltitude;
+}
+
+void NomenclatureMgr::setFlagOutlineCraters(bool b)
+{
+	NomenclatureItem::flagOutlineCraters = b;
+	StelApp::immediateSave("astro/flag_planets_nomenclature_outline_craters", b);
+	emit flagOutlineCratersChanged(b);
+}
+
+bool NomenclatureMgr::getFlagOutlineCraters() const
+{
+	return NomenclatureItem::flagOutlineCraters;
+}
+
 void NomenclatureMgr::setFlagHideLocalNomenclature(bool b)
 {
 	NomenclatureItem::hideLocalNomenclature = b;
+	StelApp::immediateSave("astro/flag_hide_local_nomenclature", b);
 	emit localNomenclatureHidingChanged(b);
 }
 
@@ -516,13 +586,25 @@ bool NomenclatureMgr::getFlagHideLocalNomenclature() const
 	return NomenclatureItem::hideLocalNomenclature;
 }
 
+void NomenclatureMgr::setFlagShowSpecialNomenclatureOnly(bool b)
+{
+	NomenclatureItem::showSpecialNomenclatureOnly = b;
+	StelApp::immediateSave("astro/flag_special_nomenclature_only", b);
+	emit specialNomenclatureOnlyDisplayingChanged(b);
+}
+
+bool NomenclatureMgr::getFlagShowSpecialNomenclatureOnly() const
+{
+	return NomenclatureItem::showSpecialNomenclatureOnly;
+}
+
 // Update i18 names from english names according to current sky culture translator
 void NomenclatureMgr::updateI18n()
 {
 	NomenclatureItem::createNameLists();
 	const StelTranslator& trans = StelApp::getInstance().getLocaleMgr().getPlanetaryFeaturesTranslator();
 	const StelTranslator& transSpecial = StelApp::getInstance().getLocaleMgr().getAppStelTranslator();
-	for (const auto& i : qAsConst(nomenclatureItems))
+	for (const auto& i : std::as_const(nomenclatureItems))
 	{
 		NomenclatureItem::NomenclatureItemType niType = i->getNomenclatureType();
 		if (niType>=NomenclatureItem::niSpecialPointPole)
