@@ -36,18 +36,14 @@ typedef QSharedPointer<NomenclatureItem> NomenclatureItemP;
 class NomenclatureMgr : public StelObjectModule
 {
 	Q_OBJECT	
-	Q_PROPERTY(bool nomenclatureDisplayed
-		   READ getFlagLabels
-		   WRITE setFlagLabels
-		   NOTIFY nomenclatureDisplayedChanged)
-	Q_PROPERTY(bool localNomenclatureHided
-		   READ getFlagHideLocalNomenclature
-		   WRITE setFlagHideLocalNomenclature
-		   NOTIFY localNomenclatureHidingChanged)
-	Q_PROPERTY(Vec3f nomenclatureColor
-		   READ getColor
-		   WRITE setColor
-		   NOTIFY nomenclatureColorChanged)
+	Q_PROPERTY(bool flagShowNomenclature             READ getFlagShowNomenclature            WRITE setFlagShowNomenclature            NOTIFY flagShowNomenclatureChanged)
+	Q_PROPERTY(bool flagShowTerminatorZoneOnly       READ getFlagShowTerminatorZoneOnly      WRITE setFlagShowTerminatorZoneOnly      NOTIFY flagShowTerminatorZoneOnlyChanged)
+	Q_PROPERTY(int terminatorMinAltitude             READ getTerminatorMinAltitude           WRITE setTerminatorMinAltitude           NOTIFY terminatorMinAltitudeChanged)
+	Q_PROPERTY(int terminatorMaxAltitude             READ getTerminatorMaxAltitude           WRITE setTerminatorMaxAltitude           NOTIFY terminatorMaxAltitudeChanged)
+	Q_PROPERTY(bool flagOutlineCraters               READ getFlagOutlineCraters              WRITE setFlagOutlineCraters              NOTIFY flagOutlineCratersChanged)
+	Q_PROPERTY(bool flagHideLocalNomenclature        READ getFlagHideLocalNomenclature       WRITE setFlagHideLocalNomenclature       NOTIFY localNomenclatureHidingChanged)
+	Q_PROPERTY(bool specialNomenclatureOnlyDisplayed READ getFlagShowSpecialNomenclatureOnly WRITE setFlagShowSpecialNomenclatureOnly NOTIFY specialNomenclatureOnlyDisplayingChanged)
+	Q_PROPERTY(Vec3f nomenclatureColor               READ getColor WRITE setColor NOTIFY nomenclatureColorChanged)
 
 public:
 	NomenclatureMgr();
@@ -105,23 +101,53 @@ public slots:
 	const Vec3f& getColor(void) const;
 
 	//! Set flag which determines if nomenclature labels are drawn or hidden.
-	void setFlagLabels(bool b);
+	void setFlagShowNomenclature(bool b);
 	//! Get the current value of the flag which determines if nomenclature labels are drawn or hidden.
-	bool getFlagLabels() const;
+	bool getFlagShowNomenclature() const;
+
+	//! Set flag which determines if only nomenclature along the terminator should be shown.
+	void setFlagShowTerminatorZoneOnly(bool b);
+	//! Get flag which determines if only nomenclature along the terminator should be shown.
+	bool getFlagShowTerminatorZoneOnly() const;
+
+	//! Set minimum solar altitude (degrees) to draw only nomenclature along the terminator.
+	void setTerminatorMinAltitude(int deg);
+	//! Get minimum solar altitude (degrees) to draw only nomenclature along the terminator.
+	int getTerminatorMinAltitude() const;
+
+	//! Set maximum solar altitude (degrees) to draw only nomenclature along the terminator.
+	void setTerminatorMaxAltitude(int deg);
+	//! Get maximum solar altitude (degrees) to draw only nomenclature along the terminator.
+	int getTerminatorMaxAltitude() const;
+
+	//! Set flag which determines if craters and satellite features (which are usually also craters) are outlined as ellipses.
+	void setFlagOutlineCraters(bool b);
+	//! Get the current value of the flag which determines if craters and satellite features (which are usually also craters) are outlined as ellipses.
+	bool getFlagOutlineCraters() const;
 
 	//! Set flag which determines if nomenclature labels are drawn or hidden on the celestial body of observer.
 	void setFlagHideLocalNomenclature(bool b);
 	//! Get the current value of the flag which determines if nomenclature labels are drawn or hidden on the celestial body of observer.
 	bool getFlagHideLocalNomenclature() const;
 
+	//! Set flag which determines if special nomenclature labels only are drawn or hidden.
+	void setFlagShowSpecialNomenclatureOnly(bool b);
+	//! Get the current value of the flag which determines if special nomenclature labels only are drawn or hidden.
+	bool getFlagShowSpecialNomenclatureOnly() const;
+
 	//! Translate nomenclature names.
 	void updateI18n();
 
 	void updateNomenclatureData();
 
 signals:
-	void nomenclatureDisplayedChanged(bool b);
+	void flagShowNomenclatureChanged(bool b);
+	void flagShowTerminatorZoneOnlyChanged(bool b);
+	void terminatorMinAltitudeChanged(int deg);
+	void terminatorMaxAltitudeChanged(int deg);
+	void flagOutlineCratersChanged(bool b);
 	void localNomenclatureHidingChanged(bool b);
+	void specialNomenclatureOnlyDisplayingChanged(bool b);
 	void nomenclatureColorChanged(const Vec3f & color) const;
 
 private slots:
@@ -138,7 +164,6 @@ private:
 
 	// Font used for displaying our text
 	QFont font;
-	QSettings* conf;
 	StelTextureSP texPointer;	
 	QMultiHash<PlanetP, NomenclatureItemP> nomenclatureItems;
 };
