@@ -20,6 +20,8 @@
 #ifndef PLANET_HPP
 #define PLANET_HPP
 
+#include <memory>
+#include <qopengl.h>
 #include "StelObject.hpp"
 #include "StelProjector.hpp"
 #include "StelPropertyMgr.hpp"
@@ -28,7 +30,6 @@
 #include "GeomMath.hpp"
 #include "StelFader.hpp"
 #include "StelTextureTypes.hpp"
-#include "StelProjectorType.hpp"
 #include "RotationElements.hpp"
 
 #include <QCache>
@@ -58,6 +59,7 @@ class QOpenGLBuffer;
 class QOpenGLFunctions;
 class QOpenGLShaderProgram;
 class QOpenGLTexture;
+class QOpenGLVertexArrayObject;
 #ifdef DEBUG_SHADOWMAP
 class QOpenGLFramebufferObject;
 #endif
@@ -80,7 +82,7 @@ class SolarEclipseBessel
 {
 public:
 	SolarEclipseBessel(double &besX, double &besY,
-		double &besDec, double &besTf1, double &besTf2, double &besL1, double &besL2, double &besMu);
+	                   double &besDec, double &besTf1, double &besTf2, double &besL1, double &besL2, double &besMu);
 };
 
 // Class to calculate solar eclipse data at given time
@@ -88,9 +90,17 @@ class SolarEclipseData
 {
 public:
 	SolarEclipseData(double JD, double &dRatio, double &latDeg, double &lngDeg, double &altitude,
-		double &pathWidth, double &duration, double &magnitude);
+	                 double &pathWidth, double &duration, double &magnitude);
 };
 
+
+//! @class Planet
+//! The Planet class is used for the major planets, moons, "Observer" planets, and artificial objects ("Spaceship").
+//! Major planets and many moons have their own positional computation, the others, and derivatives Comet and MinorPlanet, use KeplerOrbit for their position.
+//! "Observer" objects (Solar System Observer, Earth Observer, Mars Observer, Jupiter Observer, Saturn Observer, Uranus Observer, Neptune Observer)
+//! are positioned with a GimbalOrbit and can be rotated around their parent by keyboard interaction.
+//! These are oriented parallel to their parents' polar axis. The actual observer location must be on the North pole so that the vertical screen axis
+//! aligns with the parent planet's rotational axis.
 class Planet : public StelObject
 {
 public:
@@ -112,7 +122,7 @@ public:
 		isObserver,     // ssystem.ini: type="observer"
 		isArtificial,   // Used in transitions from planet to planet.
 		isAsteroid,     // ssystem.ini: type="asteroid". all types >= isAsteroid are "Minor Bodies".
-				// Put other things (spacecraft etc) before isAsteroid.
+		                // Put other things (spacecraft etc) before isAsteroid.
 		isPlutino,      // ssystem.ini: type="plutino"
 		isComet,        // ssystem.ini: type="comet"
 		isDwarfPlanet,  // ssystem.ini: type="dwarf planet"
@@ -127,9 +137,9 @@ public:
 
 	enum PlanetOrbitColorStyle
 	{
-		ocsOneColor,		// One color for all orbits
-		ocsGroups,		// Separate colors for each group of Solar system bodies
-		ocsMajorPlanets		// Separate colors for each of major planets of Solar system
+		ocsOneColor,            // One color for all orbits
+		ocsGroups,              // Separate colors for each group of Solar system bodies
+		ocsMajorPlanets         // Separate colors for each of major planets of Solar system
 	};
 	Q_ENUM(PlanetOrbitColorStyle)
 
@@ -150,7 +160,7 @@ public:
 	enum PositionQuality
 	{
 		Position,                   // Good enough for positions.
-		OrbitPlotting		    // Good enough for orbitplotting?
+		OrbitPlotting               // Good enough for orbitplotting?
 	};
 	Q_ENUM(PositionQuality)
 
@@ -163,6 +173,7 @@ public:
 	       float roughness,
 	       const QString& texMapName,
 	       const QString& normalMapName,
+	       const QString& ahorizonMapName,
 	       const QString& objModelName,
 	       posFuncType _coordFunc,
 	       Orbit *anOrbitPtr,
@@ -223,6 +234,8 @@ public:
 	//! - libration_l (on Earth for Moon only; degrees)
 	//! - libration_b (on Earth for Moon only; degrees)
 	//! - colongitude (on Earth for Moon only; degrees)
+	//! - phase-name (on Earth for Moon only; string)
+	//! - age (on Earth for Moon only; days. This is currently "elongation angle age" only, not time since last conjunction!)
 	//! - penumbral-eclipse-magnitude (on Earth for Moon only)
 	//! - umbral-eclipse-magnitude (on Earth for Moon only)
 	virtual QVariantMap getInfoMap(const StelCore *core) const  Q_DECL_OVERRIDE;
@@ -232,9 +245,15 @@ public:
 	virtual float getVMagnitude(const StelCore* core) const Q_DECL_OVERRIDE;
 	virtual float getSelectPriority(const StelCore* core) const Q_DECL_OVERRIDE;
 	virtual Vec3f getInfoColor(void) const Q_DECL_OVERRIDE;
+	//! @return "Planet". For technical reasons this is also returned by Comets and MinorPlanets and the Sun. A better type is returned by getObjectType()
 	virtual QString getType(void) const Q_DECL_OVERRIDE {return PLANET_TYPE;}
-	virtual QString getObjectType(void) const Q_DECL_OVERRIDE { return getPlanetTypeString(); }
-	virtual QString getObjectTypeI18n(void) const Q_DECL_OVERRIDE { return q_(getPlanetTypeString()); }
+	//! Get more specific Planet type for scripts
+	//! @return an English type description of planet (star, planet, moon, observer, artificial, asteroid, plutino, comet, dwarf planet, cubewano, scattered disc object, Oort cloud object, sednoid, interstellar object)
+	virtual QString getObjectType(void) const Q_DECL_OVERRIDE { return pTypeMap.value(pType); }
+	//! Get more specific Planet type for scripts
+	//! @return a localized type description of planet (star, planet, moon, observer, artificial, asteroid, plutino, comet, dwarf planet, cubewano, scattered disc object, Oort cloud object, sednoid, interstellar object)
+	virtual QString getObjectTypeI18n(void) const Q_DECL_OVERRIDE { return q_(pTypeMap.value(pType)); }
+	//! @return English name of planet
 	virtual QString getID(void) const Q_DECL_OVERRIDE { return englishName; }
 	//! A Planet's own eclipticPos is in VSOP87 ref. frame (practically equal to ecliptic of J2000 for us) coordinates relative to the parent body (sun, planet).
 	//! To get J2000 equatorial coordinates, we require heliocentric ecliptical positions (adding up parent positions) of observer and Planet.
@@ -244,6 +263,7 @@ public:
 	virtual Vec3d getJ2000EquatorialPos(const StelCore *core) const Q_DECL_OVERRIDE;
 	virtual QString getEnglishName(void) const Q_DECL_OVERRIDE;
 	virtual QString getNameI18n(void) const Q_DECL_OVERRIDE;
+	virtual QString getIAUDesignation(void) const;
 	QString getNativeName(void) const { return nativeName; }
 	QString getNativeNameI18n(void) const { return nativeNameMeaningI18n; }
 	QString getCommonEnglishName(void) const {return englishName;}
@@ -298,8 +318,9 @@ public:
 	//! Get albedo
 	double getAlbedo(void) const { return static_cast<double>(albedo); }
 
+	//! @return texture map name
 	const QString& getTextMapName() const {return texMapName;}
-	const QString getPlanetTypeString() const {return pTypeMap.value(pType);}
+	//! @return a type code enum
 	PlanetType getPlanetType() const {return pType;}
 	Orbit* getOrbit() const {return orbitPtr;}
 
@@ -307,13 +328,23 @@ public:
 	void setNativeNameMeaning(QString planet) { nativeNameMeaning = planet; }
 
 	//! set the IAU moon number (designation of the moon), if any.
-	void setIAUMoonNumber(QString designation);
+	void setIAUMoonNumber(const QString& designation);
+
+	//! set value for color index B-V
+	void setColorIndexBV(float bv=99.f);
+
+	//! set the discovery circumstances of celestial body
+	//! @param date of discovery
+	//! @param name of discoverer
+	void setDiscoveryData(const QString& date, const QString& name) { discoveryDate = date; discoverer = name; }
 
 	//! Return the absolute magnitude (read from file ssystem.ini)
 	float getAbsoluteMagnitude() const {return absoluteMagnitude;}
 	//! Return the mean opposition magnitude, defined as V(1,0)+5log10(a(a-1))
 	//! A return value of 100 signals invalid result.
 	float getMeanOppositionMagnitude() const;
+	//! Return the mass in kg
+	double getMass() const { return massKg; }
 	//
 	static ApparentMagnitudeAlgorithm getApparentMagnitudeAlgorithm()  { return vMagAlgorithm; }
 	static const QString getApparentMagnitudeAlgorithmString()  { return vMagAlgorithmMap.value(vMagAlgorithm); }
@@ -357,10 +388,10 @@ public:
 	//! _w0, _w1 to be given in degrees!
 	//! If _ra0 is not zero, we understand WGCCRE data ra0, ra1, de0, de1, w0, w1 are used.
 	void setRotationElements(const QString name, const double _period, const double _offset, const double _epoch,
-				 const double _obliquity, const double _ascendingNode,
-				 const double _ra0, const double _ra1,
-				 const double _de0, const double _de1,
-				 const double _w0,  const double _w1);
+	                         const double _obliquity, const double _ascendingNode,
+	                         const double _ra0, const double _ra1,
+	                         const double _de0, const double _de1,
+	                         const double _w0,  const double _w1);
 
 	//! Note: The only place where this is used is to build up orbits for planet moons w.r.t. the parent planet orientation.
 	double getRotAscendingNode(void) const {return re.ascendingNode; }
@@ -392,8 +423,18 @@ public:
 	//! rho*a=planetocentric distance of point [AU]
 	Vec4d getRectangularCoordinates(const double longDeg, const double latDeg, const double altMetres=0.) const;
 
+	//! Retrieve the hourly proper motion of Solar system bodies
+	//! @return [hourlyMotion, positionAngle, deltaAlpha, deltaDelta]
+	//! where hourlyMotion = hourly proper motion [radians]
+	//! positionAngle = position angle (the direction of proper motion) [radians]
+	//! deltaAlpha = hourly motion in R.A. [radians]
+	//! deltaDelta = hourly motion in Dec. [radians]
+	Vec4d getHourlyProperMotion(const StelCore *core) const;
+
 	//! Get the phase angle (radians) for an observer at pos obsPos in heliocentric coordinates (in AU)
 	double getPhaseAngle(const Vec3d& obsPos) const;
+	//! Check whether the planet is in a waning phase, i.e. its phase angle is increasing
+	bool isWaning(const Vec3d& observerPosition, const Vec3d& observerVelocity) const;
 	//! Get the elongation angle (radians) for an observer at pos obsPos in heliocentric coordinates (in AU)
 	double getElongation(const Vec3d& obsPos) const;
 	//! Get the angular radius (degrees) of the planet spheroid (i.e. without the rings)
@@ -418,12 +459,12 @@ public:
 	//!                         stay in sync with the texture. (GRS is moving). Set this to true to return the
 	//!                         incorrect, graphics-only longitude.
 	//! first[0]  = 10.26 phi_e     [rad] Planetocentric latitude of sub-earth point
-	//! first[1]  = 10.26 phi'_e	[rad] Planetographic latitude of sub-earth point
-	//! first[2]  = 10.26 lambda'_e	[rad] Planetographic longitude of sub-earth point (0..2pi)
-	//! first[3]  = 10.29 P_n	[rad] Position angle of axis north pole in equatorial coordinates of date
-	//! second[0] = 10.26 phi_s	[rad] Planetocentric latitude of sub-solar point
-	//! second[1] = 10.26 phi'_s	[rad] Planetographic latitude of sub-solar point
-	//! second[2] = 10.26 lambda'_s	[rad] Planetographic longitude of sub-solar point (0..2pi)
+	//! first[1]  = 10.26 phi'_e    [rad] Planetographic latitude of sub-earth point
+	//! first[2]  = 10.26 lambda'_e [rad] Planetographic longitude of sub-earth point (0..2pi)
+	//! first[3]  = 10.29 P_n       [rad] Position angle of axis north pole in equatorial coordinates of date
+	//! second[0] = 10.26 phi_s     [rad] Planetocentric latitude of sub-solar point
+	//! second[1] = 10.26 phi'_s    [rad] Planetographic latitude of sub-solar point
+	//! second[2] = 10.26 lambda'_s [rad] Planetographic longitude of sub-solar point (0..2pi)
 	//! @note: For the Moon, it is more common to give Libration angles, where L=-lambda'_e, B=phi'_e.
 	//! @note: For Jupiter, this returns central meridian in L_II.
 	//! @note: For Saturn, this returns central meridian in L_III (rotation of magnetic field).
@@ -497,8 +538,8 @@ public:
 	double deltaJDE;                // time difference between positional updates.
 	double deltaOrbitJDE;
 	bool closeOrbit;                // whether to connect the beginning of the orbit line to
-					// the end: good for elliptical orbits, bad for parabolic
-					// and hyperbolic orbits
+	                                // the end: good for elliptical orbits, bad for parabolic
+	                                // and hyperbolic orbits
 
 	static Vec3f orbitColor;
 	static void setOrbitColor(const Vec3f& oc) {orbitColor = oc;}
@@ -598,6 +639,13 @@ public:
 	//!       * -1000. is used as "invalid" value. The result should then not be used.
 	//! @note This is based on Meeus, Astronomical Algorithms (2nd ed.), but deviates in details.
 	//! @note Limitation for efficiency: If this is a planet moon from another planet, we compute RTS for the parent planet instead!
+	virtual Vec4d getClosestRTSTime(const StelCore* core, const double altitude=0.) const;
+
+	//! Adaptation of getClosestRTSTime() to compute times of rise, transit and set for a solar system object for current location and date.
+	//! @note The fourth element flags particular conditions:
+	//!       *   +20 for objects with no transit time on current date.
+	//!       *   +30 for objects with no rise time on current date.
+	//!       *   +40 for objects with no set time on current date.
 	virtual Vec4d getRTSTime(const StelCore* core, const double altitude=0.) const Q_DECL_OVERRIDE;
 
 	void resetTextures();
@@ -618,6 +666,8 @@ protected:
 	//! Any flag=Extra information to be displayed at the end
 	virtual QString getInfoStringExtra(const StelCore *core, const InfoStringGroup& flags) const;
 
+	virtual QString getDiscoveryCircumstances() const;
+
 protected:
 	struct PlanetOBJModel
 	{
@@ -686,7 +736,7 @@ protected:
 
 	//! Draw the circle and name of the Planet
 	void drawHints(const StelCore* core, const QFont& planetNameFont);
-    
+
 	PlanetOBJModel* loadObjModel() const;
 
 	QString englishName;             // english planet name
@@ -696,40 +746,43 @@ protected:
 	QString nativeNameMeaningI18n;   // Can be used in a skyculture
 	QString texMapName;              // Texture file path
 	QString normalMapName;           // Texture file path
+	QString horizonMapName;          // Texture file path
 	RotationElements re;             // Rotation and axis orientation parameters
 	double siderealPeriod;           // sidereal period (Planet year or a moon's sidereal month) [earth days]
 	double equatorialRadius;         // Planet's equatorial radius in AU
 	double oneMinusOblateness;       // OneMinusOblateness=(polar radius)/(equatorial radius). Geometric flattening f=1-oneMinusOblateness (ExplanSup2013 10.1)
 	Vec3d eclipticPos;               // Position in AU in the rectangular ecliptic coordinate system (J2000) centered on the parent body.
-					 // To get heliocentric coordinates, use getHeliocentricEclipticPos()
+	                                 // To get heliocentric coordinates, use getHeliocentricEclipticPos()
 	Vec3d eclipticVelocity;          // Speed in AU/d in the rectangular ecliptic coordinate system (J2000) around the parent body.
-					 // NEW FEATURE in late 2017. For now, this may be 0/0/0 when we are not yet able to compute it.
-					 // to get velocity, preferrably read getEclipticVelocity() and getHeliocentricEclipticVelocity()
-					 // The "State Vector" [Heafner 1999] can be formed from (JDE, eclipticPos, eclipticVelocity)
+	                                 // NEW FEATURE in late 2017. For now, this may be 0/0/0 when we are not yet able to compute it.
+	                                 // to get velocity, preferably read getEclipticVelocity() and getHeliocentricEclipticVelocity()
+	                                 // The "State Vector" [Heafner 1999] can be formed from (JDE, eclipticPos, eclipticVelocity)
 	Vec3d aberrationPush;            // 0.21.2+: a small displacement to be applied if aberred positions are requested.
 	Vec3d screenPos;                 // Used to store temporarily the 2D position on screen. We need double for moons. Observe Styx from Pluto w/o atmosphere to see that.
 	Vec3f haloColor;                 // used for drawing the planet halo. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
 
 	float absoluteMagnitude;         // since 2017 this moved to the Planet class: V(1,0) from Explanatory Supplement or WGCCRE2009 paper for the planets, H in the H,G magnitude system for Minor planets, H10 for comets.
-					 // This is the apparent visual magnitude when 1AU from sun and observer, with zero phase angle.
+	                                 // This is the apparent visual magnitude when 1AU from sun and observer, with zero phase angle.
+	double massKg;                   // 23.1+: mass of the planet in kg
 	float albedo;                    // Planet albedo. Used for magnitude computation when no other formula in use. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
 	float roughness;                 // Oren-Nayar roughness for Moon and OBJ-based models
 	float outgas_intensity;          // The intensity of a pseudo-outgas effect, based on an inverse exponential Lambert shading, with the light at the viewing position
-					 // Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
+	                                 // Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
 	float outgas_falloff;            // Exponent for falloff of outgas effect, should probably be < 1
-					 // Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
+	                                 // Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
 	Mat4d rotLocalToParent;          // retro-documented:
-					 // rotation matrix of axis orientation with respect to the rotation axes of the parent body.
-					 // For planets, this is the axis orientation w.r.t. VSOP87A/J2000 ecliptical system.
-					 // For planets' satellites, this used to be a rotation into the planet's equatorial system.
-					 // 0.21+: if rot_pole... data available in ssystem_*.ini (and therefore re.method==WGCCRE), this is not the rotation from planet axes over ICRF to the VSOP frame on which Stellarium is defined.
-					 //
+	                                 // rotation matrix of axis orientation with respect to the rotation axes of the parent body.
+	                                 // For planets, this is the axis orientation w.r.t. VSOP87A/J2000 ecliptical system.
+	                                 // For planets' satellites, this used to be a rotation into the planet's equatorial system.
+	                                 // 0.21+: if rot_pole... data available in ssystem_*.ini (and therefore re.method==WGCCRE), this is not the rotation from planet axes over ICRF to the VSOP frame on which Stellarium is defined.
+	                                 //
 	float axisRotation;              // Rotation angle of the Planet on its axis, degrees.
-					 // For Earth, this should be Greenwich Mean Sidereal Time GMST.
-					 // For V0.21+, and for planets computed after the IAU2009/WGCCRE papers this is angle W (rotDeg),
-					 // i.e. angle between ascending node of body equator w.r.t. ICRF equator and its prime meridian.
+	                                 // For Earth, this should be Greenwich Mean Sidereal Time GMST.
+	                                 // For V0.21+, and for planets computed after the IAU2009/WGCCRE papers this is angle W (rotDeg),
+	                                 // i.e. angle between ascending node of body equator w.r.t. ICRF equator and its prime meridian.
 	StelTextureSP texMap;            // Planet map texture
 	StelTextureSP normalMap;         // Planet normal map texture
+	StelTextureSP horizonMap;        // Planet horizon map texture
 
 	PlanetOBJModel* objModel;               // Planet model (when it has been loaded)
 	QFuture<PlanetOBJModel*>* objModelLoader;// For async loading of the OBJ file
@@ -739,14 +792,14 @@ protected:
 
 	Ring* rings;                     // Planet rings
 	double distance;                 // Temporary variable used to store the distance to a given point
-					 // it is used for sorting while drawing
+	                                 // it is used for sorting while drawing
 	double sphereScale;              // Artificial scaling for better viewing.
 	double lastJDE;                  // caches JDE of last positional computation
 
-	posFuncType coordFunc;		// callback for the calculation of the equatorial rectangular heliocentric position at time JDE.
-	Orbit* orbitPtr;		// Usually a KeplerOrbit for positional computations of Minor Planets, Comets and Moons.
-					// For an "observer", it is GimbalOrbit.
-					// For the major planets, it is Q_NULLPTR.
+	posFuncType coordFunc;           // callback for the calculation of the equatorial rectangular heliocentric position at time JDE.
+	Orbit* orbitPtr;                 // Usually a KeplerOrbit for positional computations of Minor Planets, Comets and Moons.
+	                                 // For an "observer", it is GimbalOrbit.
+	                                 // For the major planets, it is Q_NULLPTR.
 
 	OsculatingFunctType *const osculatingFunc;
 	QSharedPointer<Planet> parent;           // Planet parent i.e. sun for earth
@@ -759,6 +812,7 @@ protected:
 	bool halo;                       // Does the planet have a halo?
 	PlanetType pType;                // Type of body
 	bool multisamplingEnabled_;
+	bool planetShadowsSupersampEnabled_;
 
 	static ApparentMagnitudeAlgorithm vMagAlgorithm;
 
@@ -767,6 +821,7 @@ protected:
 	static Vec3f labelColor;
 	static StelTextureSP hintCircleTex;
 	static const QMap<PlanetType, QString> pTypeMap; // Maps fast type to english name.
+	static const QMap<QString, QString> nPlanetMap; // Maps fast IAU number to IAU designation.
 	static const QMap<ApparentMagnitudeAlgorithm, QString> vMagAlgorithmMap;
 	static bool drawMoonHalo;
 	static bool drawSunHalo;
@@ -777,9 +832,22 @@ protected:
 private:
 	class StelPropertyMgr* propMgr;
 	QString iauMoonNumber;
+	float b_v;
+	// Discovery data
+	QString discoverer;
+	QString discoveryDate;
 	// File path for texture and normal map; both variables used for saving original names of files
 	QString texMapFileOrig;
 	QString normalMapFileOrig;
+	QString horizonMapFileOrig;
+
+	std::unique_ptr<QOpenGLVertexArrayObject> sphereVAO;
+	std::unique_ptr<QOpenGLVertexArrayObject> ringsVAO;
+	GLuint sphereVBO=0;
+	GLuint ringsVBO=0;
+
+	std::unique_ptr<QOpenGLVertexArrayObject> surveyVAO;
+	GLuint surveyVBO=0;
 
 	const QString getContextString() const;
 	QPair<double, double> getLunarEclipseMagnitudes() const;
@@ -794,6 +862,7 @@ private:
 
 		// Common uniforms
 		int projectionMatrix;
+		int hasAtmosphere;
 		int tex;
 		int lightDirection;
 		int eyeDirection;
@@ -813,6 +882,7 @@ private:
 		int earthShadow;
 		int eclipsePush; // apparent brightness push for partial Lunar Eclipse (make bright rim overbright)
 		int normalMap;
+		int horizonMap;
 
 		// Rings-specific variables
 		int isRing;
@@ -860,7 +930,7 @@ private:
 	static PlanetShaderVars transformShaderVars;
 	static QOpenGLShaderProgram* transformShaderProgram;
 
-	static bool shaderError;		// True if loading shaders caused errors
+	static bool shaderError;  // True if loading shaders caused errors
 
 	static bool shadowInitialized;
 	static Vec2f shadowPolyOffset;
@@ -878,11 +948,11 @@ private:
 	static void deinitFBO();
 
 	static QOpenGLShaderProgram* createShader(const QString& name,
-						  PlanetShaderVars& vars,
-						  const QByteArray& vSrc,
-						  const QByteArray& fSrc,
-						  const QByteArray& prefix=QByteArray(),
-						  const QMap<QByteArray,int>& fixedAttributeLocations=QMap<QByteArray,int>());
+	                                          PlanetShaderVars& vars,
+	                                          const QByteArray& vSrc,
+	                                          const QByteArray& fSrc,
+	                                          const QByteArray& prefix=QByteArray(),
+	                                          const QMap<QByteArray,int>& fixedAttributeLocations=QMap<QByteArray,int>());
 
 	// Cache of positions in the parent ecliptic coordinates in AU.
 	// Used only for orbit plotting
