@@ -26,7 +26,6 @@
 #include "StelObject.hpp"
 #include "StelTexture.hpp"
 
-#include "StelToneReproducer.hpp"
 #include "StelTranslator.hpp"
 #include "StelGeodesicGrid.hpp"
 #include "StelApp.hpp"
@@ -37,12 +36,10 @@
 #include "StelFileMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelCore.hpp"
-#include "StelIniParser.hpp"
 #include "StelPainter.hpp"
 #include "StelJsonParser.hpp"
 #include "ZoneArray.hpp"
 #include "StelSkyDrawer.hpp"
-#include "RefractionExtinction.hpp"
 #include "StelModuleMgr.hpp"
 #include "ConstellationMgr.hpp"
 #include "Planet.hpp"
@@ -65,7 +62,7 @@ static QStringList component_array;
 
 // This number must be incremented each time the content or file format of the stars catalogs change
 // It can also be incremented when the defaultStarsConfig.json file change.
-// It should always matchs the version field of the defaultStarsConfig.json file
+// It should always match the version field of the defaultStarsConfig.json file
 static const int StarCatalogFormatVersion = 12;
 
 // Initialise statics
@@ -170,7 +167,7 @@ double StarMgr::getCallOrder(StelModuleActionName actionName) const
 
 StarMgr::~StarMgr(void)
 {
-	for (auto* z : qAsConst(gridLevels))
+	for (auto* z : std::as_const(gridLevels))
 		delete z;
 	gridLevels.clear();
 	if (hipIndex)
@@ -235,7 +232,7 @@ QString StarMgr::getCrossIdentificationDesignations(QString hip)
 {
 	QStringList designations;
 	auto cr = crossIdMap.find(hip);
-	if (cr==crossIdMap.end() && hip.rightRef(1).toUInt()==0)
+	if (cr==crossIdMap.end() && hip.right(1).toUInt()==0)
 		cr = crossIdMap.find(hip.left(hip.size()-1));
 
 	if (cr!=crossIdMap.end())
@@ -455,7 +452,7 @@ void StarMgr::init()
 	texPointer = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/pointeur2.png");   // Load pointer texture
 
 	StelApp::getInstance().getCore()->getGeodesicGrid(maxGeodesicGridLevel)->visitTriangles(maxGeodesicGridLevel,initTriangleFunc,this);
-	for (auto* z : qAsConst(gridLevels))
+	for (auto* z : std::as_const(gridLevels))
 		z->scaleAxis();
 	StelApp *app = &StelApp::getInstance();
 	connect(app, SIGNAL(languageChanged()), this, SLOT(updateI18n()));
@@ -520,7 +517,7 @@ bool StarMgr::checkAndLoadCatalog(const QVariantMap& catDesc)
 	if (!checked)
 	{
 		// The file is not checked but we found it, maybe from a previous download/version
-		qWarning() << "Found file " << QDir::toNativeSeparators(catalogFilePath) << ", checking md5sum..";
+		qWarning().noquote() << "Found file" << QDir::toNativeSeparators(catalogFilePath) << ", checking md5sum...";
 
 		QFile file(catalogFilePath);
 		if(file.open(QIODevice::ReadOnly | QIODevice::Unbuffered))
@@ -538,19 +535,27 @@ bool StarMgr::checkAndLoadCatalog(const QVariantMap& catDesc)
 				while (!file.atEnd())
 				{
 					qint64 sz = file.read(mmd5buf, maxStarBufMd5);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+					md5Hash.addData(QByteArrayView(mmd5buf, static_cast<int>(sz)));
+#else
 					md5Hash.addData(mmd5buf, static_cast<int>(sz));
+#endif
 				}
 				free(mmd5buf);
 			}
 			else
 			{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+				md5Hash.addData(QByteArrayView(reinterpret_cast<const char*>(cat), static_cast<int>(cat_sz)));
+#else
 				md5Hash.addData(reinterpret_cast<const char*>(cat), static_cast<int>(cat_sz));
+#endif
 				file.unmap(cat);
 			}
 			file.close();
 			if (md5Hash.result().toHex()!=catDesc.value("checksum").toByteArray())
 			{
-				qWarning() << "Error: File " << QDir::toNativeSeparators(catalogFileName) << " is corrupt, MD5 mismatch! Found " << md5Hash.result().toHex() << " expected " << catDesc.value("checksum").toByteArray();
+				qWarning().noquote() << "Error: File" << QDir::toNativeSeparators(catalogFileName) << "is corrupt, MD5 mismatch! Found" << md5Hash.result().toHex() << "expected" << catDesc.value("checksum").toByteArray();
 				file.remove();
 				return false;
 			}
@@ -564,7 +569,7 @@ bool StarMgr::checkAndLoadCatalog(const QVariantMap& catDesc)
 	{
 		if (z->level<gridLevels.size())
 		{
-			qWarning() << QDir::toNativeSeparators(catalogFileName) << ", " << z->level << ": duplicate level";
+			qWarning().noquote() << QDir::toNativeSeparators(catalogFileName) << ", " << z->level << ": duplicate level";
 			delete z;
 			return true;
 		}
@@ -580,7 +585,7 @@ void StarMgr::setCheckFlag(const QString& catId, bool b)
 {
 	// Update the starConfigFileFullPath file to take into account that we now have a new catalog
 	int idx=0;
-	for (const auto& catV : qAsConst(catalogsDescription))
+	for (const auto& catV : std::as_const(catalogsDescription))
 	{
 		++idx;
 		QVariantMap m = catV.toMap();
@@ -621,7 +626,7 @@ void StarMgr::loadData(QVariantMap starsConfig)
 		hipIndex[i].z = Q_NULLPTR;
 		hipIndex[i].s = Q_NULLPTR;
 	}
-	for (auto* z : qAsConst(gridLevels))
+	for (auto* z : std::as_const(gridLevels))
 		z->updateHipIndex(hipIndex);
 
 	const QString cat_hip_sp_file_name = starsConfig.value("hipSpectralFile").toString();
@@ -633,7 +638,7 @@ void StarMgr::loadData(QVariantMap starsConfig)
 	{
 		QString tmpFic = StelFileMgr::findFile("stars/default/" + cat_hip_sp_file_name);
 		if (tmpFic.isEmpty())
-			qWarning() << "ERROR while loading data from " << QDir::toNativeSeparators(("stars/default/" + cat_hip_sp_file_name));
+			qWarning() << "ERROR while loading data from" << QDir::toNativeSeparators(("stars/default/" + cat_hip_sp_file_name));
 		else
 			spectral_array = initStringListFromFile(tmpFic);
 	}
@@ -653,7 +658,7 @@ void StarMgr::loadData(QVariantMap starsConfig)
 	}
 
 	lastMaxSearchLevel = maxGeodesicGridLevel;
-	qDebug() << "Finished loading star catalogue data, max_geodesic_level: " << maxGeodesicGridLevel;	
+	qDebug() << "Finished loading star catalogue data, max_geodesic_level:" << maxGeodesicGridLevel;
 }
 
 void StarMgr::populateHipparcosLists()
@@ -738,11 +743,11 @@ int StarMgr::loadCommonNames(const QString& commonNameFile)
 	additionalNamesIndex.clear();
 	additionalNamesIndexI18n.clear();
 
-	qDebug() << "Loading star names from" << QDir::toNativeSeparators(commonNameFile);
+	qDebug().noquote() << "Loading star names from" << QDir::toNativeSeparators(commonNameFile);
 	QFile cnFile(commonNameFile);
 	if (!cnFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(commonNameFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(commonNameFile);
 		return 0;
 	}
 
@@ -758,11 +763,11 @@ int StarMgr::loadCommonNames(const QString& commonNameFile)
 	// "   677|_("Alpheratz")"
 	// "113368|_("Fomalhaut")"
 	// Note: Stellarium doesn't support sky cultures made prior to version 0.10.6 now!
-	static const QRegularExpression recordRx("^\\s*(\\d+)\\s*\\|[_]*[(]\"(.*)\"[)]\\s*([\\,\\d\\s]*)\\n");
+	static const QRegularExpression recordRx("^\\s*(\\d+)\\s*\\|[_]*[(]\"(.*)\"[)]\\s*([\\,\\d\\s]*)");
 
 	while(!cnFile.atEnd())
 	{
-		record = QString::fromUtf8(cnFile.readLine());
+		record = QString::fromUtf8(cnFile.readLine()).trimmed();
 		lineNumber++;
 		if (commentRx.match(record).hasMatch())
 			continue;
@@ -771,8 +776,9 @@ int StarMgr::loadCommonNames(const QString& commonNameFile)
 		QRegularExpressionMatch recMatch=recordRx.match(record);
 		if (!recMatch.hasMatch())
 		{
-			qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(commonNameFile)
+			qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(commonNameFile)
 				   << " - record does not match record pattern";
+			qWarning().noquote() << "Problematic record:" << record;
 			continue;
 		}
 		else
@@ -782,14 +788,14 @@ int StarMgr::loadCommonNames(const QString& commonNameFile)
 			int hip = recMatch.captured(1).toInt(&ok);
 			if (!ok)
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(commonNameFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(commonNameFile)
 					   << " - failed to convert " << recMatch.captured(1) << "to a number";
 				continue;
 			}
 			QString englishCommonName = recMatch.captured(2).trimmed();
 			if (englishCommonName.isEmpty())
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(commonNameFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(commonNameFile)
 					   << " - empty name field";
 				continue;
 			}
@@ -835,7 +841,7 @@ int StarMgr::loadCommonNames(const QString& commonNameFile)
 	}
 	cnFile.close();
 
-	qDebug() << "Loaded" << readOk << "/" << totalRecords << "common star names";
+	qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "common star names";
 	return 1;
 }
 
@@ -847,19 +853,19 @@ void StarMgr::loadSciNames(const QString& sciNameFile, const bool extraData)
 	{
 		sciExtraDesignationsMapI18n.clear();
 		sciExtraDesignationsIndexI18n.clear();
-		qDebug() << "Loading scientific star extra names from" << QDir::toNativeSeparators(sciNameFile);
+		qDebug().noquote() << "Loading scientific star extra names from" << QDir::toNativeSeparators(sciNameFile);
 	}
 	else
 	{
 		sciDesignationsMapI18n.clear();
 		sciDesignationsIndexI18n.clear();
-		qDebug() << "Loading scientific star names from" << QDir::toNativeSeparators(sciNameFile);
+		qDebug().noquote() << "Loading scientific star names from" << QDir::toNativeSeparators(sciNameFile);
 	}
 
 	QFile snFile(sciNameFile);
 	if (!snFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(sciNameFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(sciNameFile);
 		return;
 	}
 	const QStringList& allRecords = QString::fromUtf8(snFile.readAll()).split('\n');
@@ -882,7 +888,7 @@ void StarMgr::loadSciNames(const QString& sciNameFile, const bool extraData)
 		const QStringList& fields = record.split('|');
 		if (fields.size()!=2)
 		{
-			qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(sciNameFile)
+			qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(sciNameFile)
 				   << " - record does not match record pattern";
 			continue;
 		}
@@ -893,7 +899,7 @@ void StarMgr::loadSciNames(const QString& sciNameFile, const bool extraData)
 			int hip = fields.at(0).toInt(&ok);
 			if (!ok)
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(sciNameFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(sciNameFile)
 					   << " - failed to convert " << fields.at(0) << "to a number";
 				continue;
 			}
@@ -901,7 +907,7 @@ void StarMgr::loadSciNames(const QString& sciNameFile, const bool extraData)
 			QString sci_name = fields.at(1).trimmed();
 			if (sci_name.isEmpty())
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(sciNameFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(sciNameFile)
 					   << " - empty name field";
 				continue;
 			}
@@ -936,9 +942,9 @@ void StarMgr::loadSciNames(const QString& sciNameFile, const bool extraData)
 	}
 
 	if (extraData)
-		qDebug() << "Loaded" << readOk << "/" << totalRecords << "scientific star extra names";
+		qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "scientific star extra names";
 	else
-		qDebug() << "Loaded" << readOk << "/" << totalRecords << "scientific star names";
+		qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "scientific star names";
 }
 
 // Load GCVS from file
@@ -947,11 +953,11 @@ void StarMgr::loadGcvs(const QString& GcvsFile)
 	varStarsMapI18n.clear();
 	varStarsIndexI18n.clear();
 
-	qDebug() << "Loading variable stars from" << QDir::toNativeSeparators(GcvsFile);
+	qDebug().noquote() << "Loading variable stars from" << QDir::toNativeSeparators(GcvsFile);
 	QFile vsFile(GcvsFile);
 	if (!vsFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(GcvsFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(GcvsFile);
 		return;
 	}
 	const QStringList& allRecords = QString::fromUtf8(vsFile.readAll()).split('\n');
@@ -976,7 +982,7 @@ void StarMgr::loadGcvs(const QString& GcvsFile)
 		int hip = fields.at(0).toInt(&ok);
 		if (!ok)
 		{
-			qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(GcvsFile)
+			qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(GcvsFile)
 				   << " - failed to convert " << fields.at(0) << "to a number";
 			continue;
 		}
@@ -1013,7 +1019,7 @@ void StarMgr::loadGcvs(const QString& GcvsFile)
 		++readOk;
 	}
 
-	qDebug() << "Loaded" << readOk << "/" << totalRecords << "variable stars";
+	qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "variable stars";
 }
 
 // Load WDS from file
@@ -1022,11 +1028,11 @@ void StarMgr::loadWds(const QString& WdsFile)
 	wdsStarsMapI18n.clear();
 	wdsStarsIndexI18n.clear();
 
-	qDebug() << "Loading double stars from" << QDir::toNativeSeparators(WdsFile);
+	qDebug().noquote() << "Loading double stars from" << QDir::toNativeSeparators(WdsFile);
 	QFile dsFile(WdsFile);
 	if (!dsFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(WdsFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(WdsFile);
 		return;
 	}
 	const QStringList& allRecords = QString::fromUtf8(dsFile.readAll()).split('\n');
@@ -1072,7 +1078,7 @@ void StarMgr::loadWds(const QString& WdsFile)
 		++readOk;
 	}
 
-	qDebug() << "Loaded" << readOk << "/" << totalRecords << "double stars";
+	qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "double stars";
 }
 
 // Load cross-identification data from file
@@ -1083,11 +1089,11 @@ void StarMgr::loadCrossIdentificationData(const QString& crossIdFile)
 	hdStarsIndex.clear();	
 	hrStarsIndex.clear();
 
-	qDebug() << "Loading cross-identification data from" << QDir::toNativeSeparators(crossIdFile);
+	qDebug().noquote() << "Loading cross-identification data from" << QDir::toNativeSeparators(crossIdFile);
 	QFile ciFile(crossIdFile);
 	if (!ciFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(crossIdFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(crossIdFile);
 		return;
 	}
 	const QStringList& allRecords = QString::fromUtf8(ciFile.readAll()).split('\n');
@@ -1112,7 +1118,7 @@ void StarMgr::loadCrossIdentificationData(const QString& crossIdFile)
 		const QStringList& fields = record.split('\t');
 		if (fields.size()!=5)
 		{
-			qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(crossIdFile)
+			qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(crossIdFile)
 				   << " - record does not match record pattern";
 			continue;
 		}
@@ -1123,7 +1129,7 @@ void StarMgr::loadCrossIdentificationData(const QString& crossIdFile)
 			int hip = fields.at(0).toInt(&ok);
 			if (!ok)
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(crossIdFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(crossIdFile)
 					   << " - failed to convert " << fields.at(0) << "to a number";
 				continue;
 			}
@@ -1145,7 +1151,7 @@ void StarMgr::loadCrossIdentificationData(const QString& crossIdFile)
 		}
 	}
 
-	qDebug() << "Loaded" << readOk << "/" << totalRecords << "cross-identification data records for stars";
+	qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "cross-identification data records for stars";
 }
 
 void StarMgr::loadPlxErr(const QString& plxErrFile)
@@ -1153,11 +1159,11 @@ void StarMgr::loadPlxErr(const QString& plxErrFile)
 	// TODO: This is temporary solution for display parallax errors until format of stars catalogs will not be changed!
 	hipParallaxErrors.clear();
 
-	qDebug() << "Loading parallax errors data from" << QDir::toNativeSeparators(plxErrFile);
+	qDebug().noquote() << "Loading parallax errors data from" << QDir::toNativeSeparators(plxErrFile);
 	QFile ciFile(plxErrFile);
 	if (!ciFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(plxErrFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(plxErrFile);
 		return;
 	}
 	const QStringList& allRecords = QString::fromUtf8(ciFile.readAll()).split('\n');
@@ -1180,7 +1186,7 @@ void StarMgr::loadPlxErr(const QString& plxErrFile)
 		const QStringList& fields = record.split('\t');
 		if (fields.size()!=2)
 		{
-			qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(plxErrFile)
+			qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(plxErrFile)
 				   << " - record does not match record pattern";
 			continue;
 		}
@@ -1191,7 +1197,7 @@ void StarMgr::loadPlxErr(const QString& plxErrFile)
 			int hip = fields.at(0).toInt(&ok);
 			if (!ok)
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(plxErrFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(plxErrFile)
 					   << " - failed to convert " << fields.at(0) << "to a number";
 				continue;
 			}
@@ -1201,7 +1207,7 @@ void StarMgr::loadPlxErr(const QString& plxErrFile)
 		}
 	}
 
-	qDebug() << "Loaded" << readOk << "/" << totalRecords << "parallax error data records for stars";
+	qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "parallax error data records for stars";
 }
 
 void StarMgr::loadPMData(const QString &pmDataFile)
@@ -1209,11 +1215,11 @@ void StarMgr::loadPMData(const QString &pmDataFile)
 	// TODO: This is temporary solution for display parallax errors until format of stars catalogs will not be changed!
 	hipPMData.clear();
 
-	qDebug() << "Loading proper motion data from" << QDir::toNativeSeparators(pmDataFile);
+	qDebug().noquote() << "Loading proper motion data from" << QDir::toNativeSeparators(pmDataFile);
 	QFile ciFile(pmDataFile);
 	if (!ciFile.open(QIODevice::ReadOnly | QIODevice::Text))
 	{
-		qWarning() << "WARNING - could not open" << QDir::toNativeSeparators(pmDataFile);
+		qWarning().noquote() << "WARNING - could not open" << QDir::toNativeSeparators(pmDataFile);
 		return;
 	}
 	const QStringList& allRecords = QString::fromUtf8(ciFile.readAll()).split('\n');
@@ -1236,7 +1242,7 @@ void StarMgr::loadPMData(const QString &pmDataFile)
 		const QStringList& fields = record.split('\t');
 		if (fields.size()!=3)
 		{
-			qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(pmDataFile)
+			qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(pmDataFile)
 				   << " - record does not match record pattern";
 			continue;
 		}
@@ -1247,7 +1253,7 @@ void StarMgr::loadPMData(const QString &pmDataFile)
 			int hip = fields.at(0).toInt(&ok);
 			if (!ok)
 			{
-				qWarning() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(pmDataFile)
+				qWarning().noquote() << "WARNING - parse error at line" << lineNumber << "in" << QDir::toNativeSeparators(pmDataFile)
 					   << " - failed to convert " << fields.at(0) << "to a number";
 				continue;
 			}
@@ -1260,7 +1266,7 @@ void StarMgr::loadPMData(const QString &pmDataFile)
 		}
 	}
 
-	qDebug() << "Loaded" << readOk << "/" << totalRecords << "proper motion data records for stars";
+	qDebug().noquote() << "Loaded" << readOk << "/" << totalRecords << "proper motion data records for stars";
 }
 
 int StarMgr::getMaxSearchLevel() const
@@ -1316,7 +1322,7 @@ void StarMgr::draw(StelCore* core)
 	RCMag rcmag_table[RCMAG_TABLE_SIZE];
 	
 	// Draw all the stars of all the selected zones
-	for (const auto* z : qAsConst(gridLevels))
+	for (const auto* z : std::as_const(gridLevels))
 	{
 		int limitMagIndex=RCMAG_TABLE_SIZE;
 		const float mag_min = 0.001f*z->mag_min;
@@ -1414,7 +1420,7 @@ QList<StelObjectP > StarMgr::searchAround(const Vec3d& vv, double limFov, const
 	Vec3d e1 = v + h1;
 	Vec3d e2 = v - h0;
 	Vec3d e3 = v - h1;
-	f = 1.0/e0.length();
+	f = 1.0/e0.norm();
 	e0 *= f;
 	e1 *= f;
 	e2 *= f;
@@ -1518,8 +1524,8 @@ StelObjectP StarMgr::searchByName(const QString& name) const
 {
 	QString objw = name.toUpper();
 
-	// Search by HP number if it's an HP formatted number
-	static const QRegularExpression rx("^\\s*(HP|HIP)\\s*(\\d+)\\s*$", QRegularExpression::CaseInsensitiveOption);
+	// Search by HP number if it's an HP formatted number. The final part (A/B/...) is ignored
+	static const QRegularExpression rx("^\\s*(HP|HIP)\\s*(\\d+)\\s*.*$", QRegularExpression::CaseInsensitiveOption);
 	QRegularExpressionMatch match=rx.match(objw);
 	if (match.hasMatch())
 		return searchHP(match.captured(2).toInt());
@@ -1659,7 +1665,7 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 		{
 			k.next();
 			QStringList names = getAdditionalNames(k.value()).split(" - ");
-			for (const auto &name : qAsConst(names))
+			for (const auto &name : std::as_const(names))
 			{
 				if (useStartOfWords && name.startsWith(objw, Qt::CaseInsensitive))
 					found = true;
@@ -1683,7 +1689,7 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 		{
 			l.next();
 			QStringList names = getAdditionalEnglishNames(l.value()).split(" - ");
-			for (const auto &name : qAsConst(names))
+			for (const auto &name : std::as_const(names))
 			{
 				if (useStartOfWords && name.startsWith(objw, Qt::CaseInsensitive))
 					found = true;
@@ -1723,7 +1729,7 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 			if (maxNbItem<=0)
 				break;
 			QStringList names = getSciName(it.value()).split(" - ");
-			for (const auto &name : qAsConst(names))
+			for (const auto &name : std::as_const(names))
 			{
 				if (useStartOfWords && name.startsWith(objPrefix, Qt::CaseInsensitive))
 					found = true;
@@ -1752,7 +1758,7 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 			if (maxNbItem<=0)
 				break;
 			QStringList names = getSciName(it.value()).split(" - ");
-			for (const auto &name : qAsConst(names))
+			for (const auto &name : std::as_const(names))
 			{
 				if (useStartOfWords && name.startsWith(objPrefix, Qt::CaseInsensitive))
 					found = true;
@@ -1781,7 +1787,7 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 			if (maxNbItem<=0)
 				break;
 			QStringList names = getSciExtraName(it.value()).split(" - ");
-			for (const auto &name : qAsConst(names))
+			for (const auto &name : std::as_const(names))
 			{
 				if (useStartOfWords && name.startsWith(objPrefix, Qt::CaseInsensitive))
 					found = true;
@@ -1810,7 +1816,7 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 			if (maxNbItem<=0)
 				break;
 			QStringList names = getSciExtraName(it.value()).split(" - ");
-			for (const auto &name : qAsConst(names))
+			for (const auto &name : std::as_const(names))
 			{
 				if (useStartOfWords && name.startsWith(objPrefix, Qt::CaseInsensitive))
 					found = true;
@@ -1846,8 +1852,8 @@ QStringList StarMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem
 			break;
 	}
 
-	// Add exact Hp catalogue numbers
-	static const QRegularExpression hpRx("^(HIP|HP)\\s*(\\d+)\\s*$", QRegularExpression::CaseInsensitiveOption);
+	// Add exact Hp catalogue numbers. The final part (A/B/...) is ignored
+	static const QRegularExpression hpRx("^(HIP|HP)\\s*(\\d+)\\s*.*$", QRegularExpression::CaseInsensitiveOption);
 	QRegularExpressionMatch match=hpRx.match(objw);
 	if (match.hasMatch())
 	{
@@ -1955,8 +1961,8 @@ void StarMgr::updateSkyCulture(const QString& skyCultureDir)
 	else
 		loadCommonNames(fic);
 
-	// Turn on sci names/catalog names for western cultures only
-	setFlagSciNames(skyCultureDir.contains("western", Qt::CaseInsensitive));
+	// Turn on sci names/catalog names for modern cultures only
+	setFlagSciNames(skyCultureDir.contains("modern", Qt::CaseInsensitive));
 	updateI18n();
 }
 
@@ -2160,7 +2166,7 @@ QStringList StarMgr::listAllObjectsByType(const QString &objType, bool inEnglish
 	QString starName;
 	if (isStarT1)
 	{
-		for (const auto& star : qAsConst(starsT1))
+		for (const auto& star : std::as_const(starsT1))
 		{
 			starName = inEnglish ? star->getEnglishName() : star->getNameI18n();
 			if (!starName.isEmpty())
@@ -2172,7 +2178,7 @@ QStringList StarMgr::listAllObjectsByType(const QString &objType, bool inEnglish
 
 	if (isStarT2)
 	{
-		for (const auto& star : qAsConst(starsT2))
+		for (const auto& star : std::as_const(starsT2))
 		{
 			starName = inEnglish ? star.firstKey()->getEnglishName() : star.firstKey()->getNameI18n();
 			if (!starName.isEmpty())
