@@ -21,6 +21,8 @@
 #include "ZodiacalLight.hpp"
 #include "SolarSystem.hpp"
 #include "StelFader.hpp"
+// For debugging draw() only:
+//#include "StelObjectMgr.hpp"
 #include "StelTexture.hpp"
 #include "StelUtils.hpp"
 #include "StelFileMgr.hpp"
@@ -40,6 +42,15 @@
 
 #include <QDebug>
 #include <QSettings>
+#include <QOpenGLBuffer>
+#include <QOpenGLShaderProgram>
+#include <QOpenGLVertexArrayObject>
+
+namespace
+{
+constexpr int FS_QUAD_COORDS_PER_VERTEX = 2;
+constexpr int SKY_VERTEX_ATTRIB_INDEX = 0;
+}
 
 // Class which manages the displaying of the Zodiacal Light
 ZodiacalLight::ZodiacalLight()
@@ -50,7 +61,6 @@ ZodiacalLight::ZodiacalLight()
 	, intensityMinFov(0.25) // when zooming in further, Z.L. is no longer visible.
 	, intensityMaxFov(2.5) // when zooming out further, Z.L. is fully visible (when enabled).
 	, lastJD(-1.0E6)
-	, vertexArray()
 {
 	setObjectName("ZodiacalLight");
 	fader = new LinearFader();
@@ -61,9 +71,6 @@ ZodiacalLight::~ZodiacalLight()
 {
 	delete fader;
 	fader = Q_NULLPTR;
-	
-	delete vertexArray;
-	vertexArray = Q_NULLPTR;
 }
 
 void ZodiacalLight::init()
@@ -71,18 +78,36 @@ void ZodiacalLight::init()
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
 
+	auto& gl = *QOpenGLContext::currentContext()->functions();
+
 	// The Paper describes brightness values over the complete sky, so also the texture covers the full sky. 
 	// The data hole around the sun has been filled by useful values.
-	tex = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/zodiacallight_2004.png");
+	mainTex = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/zodiacallight_2004.png");
+	mainTex->bind(0);
+	gl.glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
+	mainTex->release();
 	setFlagShow(conf->value("astro/flag_zodiacal_light", true).toBool());
 	setIntensity(conf->value("astro/zodiacal_light_intensity",1.).toDouble());
 
-	vertexArray = new StelVertexArray(StelPainter::computeSphereNoLight(1.,1.,60,30,1, true)); // 6x6 degree quads
-	vertexArray->colors.resize(vertexArray->vertex.length());
-	vertexArray->colors.fill(color);
+	vbo.reset(new QOpenGLBuffer(QOpenGLBuffer::VertexBuffer));
+	vbo->create();
+	vbo->bind();
+	const GLfloat vertices[]=
+	{
+		// full screen quad
+		-1, -1,
+		 1, -1,
+		-1,  1,
+		 1,  1,
+	};
+	gl.glBufferData(GL_ARRAY_BUFFER, sizeof vertices, vertices, GL_STATIC_DRAW);
+	vbo->release();
 
-	eclipticalVertices=vertexArray->vertex;
-	// This vector is used to keep original vertices, these will be modified in update().
+	vao.reset(new QOpenGLVertexArrayObject);
+	vao->create();
+	bindVAO();
+	setupCurrentVAO();
+	releaseVAO();
 
 	QString displayGroup = N_("Display Options");
 	addAction("actionShow_ZodiacalLight", displayGroup, N_("Zodiacal Light"), "flagZodiacalLightDisplayed", "Ctrl+Shift+Z");
@@ -91,6 +116,36 @@ void ZodiacalLight::init()
 	connect(core, SIGNAL(locationChanged(StelLocation)), this, SLOT(handleLocationChanged(StelLocation)));
 }
 
+void ZodiacalLight::setupCurrentVAO()
+{
+	auto& gl = *QOpenGLContext::currentContext()->functions();
+	vbo->bind();
+	gl.glVertexAttribPointer(0, FS_QUAD_COORDS_PER_VERTEX, GL_FLOAT, false, 0, 0);
+	vbo->release();
+	gl.glEnableVertexAttribArray(SKY_VERTEX_ATTRIB_INDEX);
+}
+
+void ZodiacalLight::bindVAO()
+{
+	if(vao->isCreated())
+		vao->bind();
+	else
+		setupCurrentVAO();
+}
+
+void ZodiacalLight::releaseVAO()
+{
+	if(vao->isCreated())
+	{
+		vao->release();
+	}
+	else
+	{
+		auto& gl = *QOpenGLContext::currentContext()->functions();
+		gl.glDisableVertexAttribArray(SKY_VERTEX_ATTRIB_INDEX);
+	}
+}
+
 void ZodiacalLight::handleLocationChanged(const StelLocation &loc)
 {
 	// This just forces update() to re-compute longitude.
@@ -121,7 +176,6 @@ void ZodiacalLight::update(double deltaTime)
 		// The ZL texture has its bright spot in the winter solstice point.
 		// The computation here returns solar longitude for Earth, and antilongitude for the Moon, therefore we either add or subtract pi/2.
 
-		double lambdaSun;
 		if (core->getCurrentLocation().planetName=="Earth")
 		{
 			double eclJDE = GETSTELMODULE(SolarSystem)->getEarth()->getRotObliquity(core->getJDE());
@@ -136,12 +190,6 @@ void ZodiacalLight::update(double deltaTime)
 			lambdaSun=atan2(obsPos[1], obsPos[0])  -M_PI*0.5;
 		}
 
-		Mat4d rotMat=Mat4d::zrotation(lambdaSun);
-		for (int i=0; i<eclipticalVertices.size(); ++i)
-		{
-			Vec3d tmp=eclipticalVertices.at(i);
-			vertexArray->vertex.replace(i, rotMat * tmp);
-		}
 		lastJD=currentJD;
 	}
 }
@@ -178,15 +226,6 @@ void ZodiacalLight::draw(StelCore* core)
 	// Test if we are not on Earth. Texture would not fit, so don't draw then.
 	if (! QString("Earth Moon").contains(core->getCurrentLocation().planetName)) return;
 
-	StelSkyDrawer *drawer=core->getSkyDrawer();
-	int bortle=drawer->getBortleScaleIndex();
-	// Test for light pollution, return if too bad.
-	if ( (drawer->getFlagHasAtmosphere()) && (bortle > 5) ) return;
-
-	float atmFadeIntensity = GETSTELMODULE(LandscapeMgr)->getAtmosphereFadeIntensity();
-    const float nelm = StelCore::luminanceToNELM(drawer->getLightPollutionLuminance());
-	float bortleIntensity = 1.f+(15.5f-2*nelm)*atmFadeIntensity; // smoothed Bortle index moderated by atmosphere fader.
-
 	// The ZL is best observed from Earth only. On the Moon, we must be happy with ZL along the J2000 ecliptic. (Sorry for LP:1628765, I don't find a general solution.)
 	StelProjector::ModelViewTranformP transfo;
 	if (core->getCurrentLocation().planetName == "Earth")
@@ -194,16 +233,116 @@ void ZodiacalLight::draw(StelCore* core)
 	else
 		transfo = core->getObservercentricEclipticJ2000ModelViewTransform();
 
-	const StelProjectorP prj = core->getProjection(transfo);
+	const StelProjectorP projector = core->getProjection(transfo);
+	const auto drawer=core->getSkyDrawer();
+	const auto& extinction=drawer->getExtinction();
+
+	if(!renderProgram || !prevProjector || !projector->isSameProjection(*prevProjector))
+	{
+		renderProgram.reset(new QOpenGLShaderProgram);
+		prevProjector = projector;
+
+		const auto vert =
+			StelOpenGL::globalShaderPrefix(StelOpenGL::VERTEX_SHADER) +
+			R"(
+ATTRIBUTE highp vec3 vertex;
+VARYING highp vec3 ndcPos;
+void main()
+{
+	gl_Position = vec4(vertex, 1.);
+	ndcPos = vertex;
+}
+)";
+		bool ok = renderProgram->addShaderFromSourceCode(QOpenGLShader::Vertex, vert);
+		if(!renderProgram->log().isEmpty())
+			qWarning().noquote() << "ZodiacalLight: Warnings while compiling vertex shader:\n" << renderProgram->log();
+		if(!ok) return;
+
+		const auto frag =
+			StelOpenGL::globalShaderPrefix(StelOpenGL::FRAGMENT_SHADER) +
+			projector->getUnProjectShader() +
+			extinction.getForwardTransformShader() +
+			R"(
+VARYING highp vec3 ndcPos;
+uniform sampler2D mainTex;
+uniform vec3 brightness;
+uniform mat4 projectionMatrixInverse;
+uniform bool extinctionEnabled;
+uniform float bortleIntensity;
+uniform float lambdaSun;
+void main(void)
+{
+	const float PI = 3.14159265;
+	vec4 winPos = projectionMatrixInverse * vec4(ndcPos, 1);
+	bool ok = false;
+	vec3 modelPos = unProject(winPos.x, winPos.y, ok).xyz;
+	if(!ok)
+	{
+		FRAG_COLOR = vec4(0);
+		return;
+	}
+	modelPos = normalize(modelPos);
+	float modelZenithAngle = acos(-modelPos.z);
+	float modelLongitude = atan(modelPos.x, modelPos.y) + lambdaSun;
+	vec2 texc = vec2(modelLongitude/(2.*PI), modelZenithAngle/PI);
+
+	float extinctionFactor;
+	if(extinctionEnabled)
+	{
+		vec3 worldPos = winPosToWorldPos(winPos.x, winPos.y, ok);
+		vec3 altAzViewDir = worldPosToAltAzPos(worldPos);
+		float mag = extinctionMagnitude(altAzViewDir);
+		extinctionFactor=pow(0.4, mag) * (1.1-bortleIntensity*0.1); // Drop of one magnitude: factor 2.5 or 40%, and further reduced by light pollution.
+	}
+	else
+	{
+		extinctionFactor = 1.;
+	}
+
+    vec4 color = texture2D(mainTex, texc)*vec4(brightness,1)*extinctionFactor;
+	FRAG_COLOR = color;
+}
+)";
+		ok = renderProgram->addShaderFromSourceCode(QOpenGLShader::Fragment, frag);
+		if(!renderProgram->log().isEmpty())
+			qWarning().noquote() << "ZodiacalLight: Warnings while compiling fragment shader:\n" << renderProgram->log();
+
+		if(!ok) return;
+
+		renderProgram->bindAttributeLocation("vertex", SKY_VERTEX_ATTRIB_INDEX);
+
+		if(!StelPainter::linkProg(renderProgram.get(), "ZodiacalLight render program"))
+			return;
+
+		renderProgram->bind();
+		shaderVars.mainTex          = renderProgram->uniformLocation("mainTex");
+		shaderVars.lambdaSun        = renderProgram->uniformLocation("lambdaSun");
+		shaderVars.brightness       = renderProgram->uniformLocation("brightness");
+		shaderVars.bortleIntensity  = renderProgram->uniformLocation("bortleIntensity");
+		shaderVars.extinctionEnabled= renderProgram->uniformLocation("extinctionEnabled");
+		shaderVars.projectionMatrixInverse = renderProgram->uniformLocation("projectionMatrixInverse");
+		renderProgram->release();
+	}
+	if(!renderProgram || !renderProgram->isLinked())
+		return;
+
+	int bortle=drawer->getBortleScaleIndex();
+	// Test for light pollution, return if too bad.
+	if ( (drawer->getFlagHasAtmosphere()) && (bortle > 5) ) return;
+
+	float atmFadeIntensity = GETSTELMODULE(LandscapeMgr)->getAtmosphereFadeIntensity();
+	const float nelm = StelCore::luminanceToNELM(drawer->getLightPollutionLuminance());
+	const float bortleIntensity = 1.f+(15.5f-2*nelm)*atmFadeIntensity; // smoothed Bortle index moderated by atmosphere fader.
+
 	StelToneReproducer* eye = core->getToneReproducer();
 
-	Q_ASSERT(tex);	// A texture must be loaded before calling this
+	Q_ASSERT(mainTex);	// A texture must be loaded before calling this
 
 	// Default ZL color is white (sunlight), or whatever has been set e.g. by script.
 	Vec3f c = color;
 
 	// ZL is quite sensitive to light pollution. I scale to make it less visible.
-	float lum = drawer->surfaceBrightnessToLuminance(13.5f + 0.5f*bortleIntensity); // (8.0f + 0.5*bortle);
+	const float lum = drawer->surfaceBrightnessToLuminance(13.5f + 0.5f*bortleIntensity); // (8.0f + 0.5*bortle);
 
 	// Get the luminance scaled between 0 and 1
 	float aLum =eye->adaptLuminanceScaled(lum*fader->getInterstate());
@@ -217,9 +356,15 @@ void ZodiacalLight::draw(StelCore* core)
 
 	// Better: adapt brightness by atmospheric brightness
 	const float atmLum = GETSTELMODULE(LandscapeMgr)->getAtmosphereAverageLuminance();
-	if (atmLum>0.05f) return; // 10cd/m^2 at sunset, 3.3 at civil twilight (sun at -6deg). 0.0145 sun at -12, 0.0004 sun at -18,  0.01 at Full Moon!?
-	//qDebug() << "AtmLum: " << atmLum;
-	float atmFactor=20.0f*(0.05f-atmLum);
+	if (atmLum>0.05f) return; // Approximate values for Preetham: 10cd/m^2 at sunset, 3.3 at civil twilight (sun at -6deg). 0.0145 sun at -12, 0.0004 sun at -18,  0.01 at Full Moon!?
+	// The atmLum of Bruneton's model is about 1/2 higher than that of Preetham/Schaefer. We must rebalance that!
+	float atmFactor=20.0f;
+	if (GETSTELMODULE(LandscapeMgr)->getAtmosphereModel()=="showmysky")
+		atmFactor=20.0f*(0.05f-0.2f*atmLum); // The factor 0.2f was found empirically. Nominally it should be 0.667, but 0.2 or at least 0.4 looks better.
+	else
+		atmFactor=20.0f*(0.05f-atmLum);
+
+	//GETSTELMODULE(StelObjectMgr)->addToExtraInfoString(StelObject::DebugAid, QString("ZL AtmFactor: %1<br/>").arg(QString::number(atmFactor, 'f', 4)));
 	Q_ASSERT(atmFactor<=1.0f);
 	Q_ASSERT(atmFactor>=0.0f);
 	c*=atmFactor*atmFactor;
@@ -228,41 +373,30 @@ void ZodiacalLight::draw(StelCore* core)
 	if (c[1]<0) c[1]=0;
 	if (c[2]<0) c[2]=0;
 
+	renderProgram->bind();
+
 	const bool withExtinction=(drawer->getFlagHasAtmosphere() && drawer->getExtinction().getExtinctionCoefficient()>=0.01f);
 
-	if ((withExtinction) && (core->getCurrentLocation().planetName=="Earth")) // If anybody switches on atmosphere on the moon, there will be no extinction.
-	{
-		// We must process the vertices to find geometric altitudes in order to compute vertex colors.
-		const Extinction& extinction=drawer->getExtinction();
-		const double epsDate=getPrecessionAngleVondrakCurrentEpsilonA();
-		vertexArray->colors.clear();
+	renderProgram->setUniformValue(shaderVars.extinctionEnabled, withExtinction);
+	renderProgram->setUniformValue(shaderVars.bortleIntensity, bortleIntensity);
 
-		for (int i=0; i<vertexArray->vertex.size(); ++i)
-		{
-			Vec3d eclPos=vertexArray->vertex.at(i);
-			Q_ASSERT(fabs(eclPos.lengthSquared()-1.0) < 0.001);
-			double ecLon, ecLat, ra, dec;
-			StelUtils::rectToSphe(&ecLon, &ecLat, eclPos);
-			StelUtils::eclToEqu(ecLon, ecLat, epsDate, &ra, &dec);
-			Vec3d eqPos;
-			StelUtils::spheToRect(ra, dec, eqPos);
-			Vec3d vertAltAz=core->equinoxEquToAltAz(eqPos, StelCore::RefractionOn);
-			Q_ASSERT(fabs(vertAltAz.lengthSquared()-1.0) < 0.001);
+	const int mainTexSampler = 0;
+	mainTex->bind(mainTexSampler);
+	renderProgram->setUniformValue(shaderVars.mainTex, mainTexSampler);
 
-			float oneMag=0.0f;
-			extinction.forward(vertAltAz, &oneMag);
-			float extinctionFactor=std::pow(0.4f , oneMag) * (1.1f-bortleIntensity*0.1f);// Drop of one magnitude: factor 2.5 or 40%, and further reduced by light pollution.
-			Vec3f thisColor=Vec3f(c[0]*extinctionFactor, c[1]*extinctionFactor, c[2]*extinctionFactor);
-			vertexArray->colors.append(thisColor);
-		}
-	}
-	else
-		vertexArray->colors.fill(Vec3f(c[0], c[1], c[2]));
+	renderProgram->setUniformValue(shaderVars.projectionMatrixInverse, projector->getProjectionMatrix().toQMatrix().inverted());
+	renderProgram->setUniformValue(shaderVars.brightness, c.toQVector());
+	renderProgram->setUniformValue(shaderVars.lambdaSun, GLfloat(lambdaSun));
 
-	StelPainter sPainter(prj);
-	sPainter.setCullFace(true);
-	sPainter.setBlending(true, GL_ONE, GL_ONE);
-	tex->bind();
-	sPainter.drawStelVertexArray(*vertexArray);
-	sPainter.setCullFace(false);
+	projector->setUnProjectUniforms(*renderProgram);
+	extinction.setForwardTransformUniforms(*renderProgram);
+
+	auto& gl = *QOpenGLContext::currentContext()->functions();
+
+	gl.glEnable(GL_BLEND);
+	gl.glBlendFunc(GL_ONE,GL_ONE); // allow colored sky background
+	bindVAO();
+	gl.glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
+	releaseVAO();
+	gl.glDisable(GL_BLEND);
 }
