@@ -38,22 +38,22 @@ AstroCalcChart::AstroCalcChart(QSet<Series> which) : QChart(), yAxisR(Q_NULLPTR)
 	{
 		// To avoid "spline tremor" we need line series for azimuths (0/360° rollover) and magnitudes (in case of shadow transits)
 		if (QList<Series>({CurrentTime, TransitTime, AzVsTime, RightAscension1, RightAscension2, Magnitude1, Magnitude2}).contains(s))
-			map.insert(s, new QtCharts::QLineSeries(this));
+			map.insert(s, new QLineSeries(this));
 		else
-			map.insert(s, new QtCharts::QSplineSeries(this));
+			map.insert(s, new QSplineSeries(this));
 	// map.value(s)->setPointsVisible(true); // useful for debugging only.
 	}
 
 	setBackgroundBrush(QBrush(QColor(86, 87, 90)));
 	AstroCalcChart::retranslate();
 
-	xAxis=new QtCharts::QDateTimeAxis(this);
-	yAxis=new QtCharts::QValueAxis(this);
+	xAxis=new QDateTimeAxis(this);
+	yAxis=new QValueAxis(this);
 	if (QSet<AstroCalcChart::Series>({AngularSize2, Declination2,          Distance2,
 					  Elongation2,  HeliocentricDistance2, Magnitude2,
 					  PhaseAngle2,  Phase2,                RightAscension2, TransitAltitude2,
 					  pcDistanceDeg}).intersect(which).count())
-		yAxisR=new QtCharts::QValueAxis(this);
+		yAxisR=new QValueAxis(this);
 	if (QSet<AstroCalcChart::Series>({pcDistanceAU, pcDistanceDeg, MonthlyElevation,
 					 AngularSize1, Declination1, Distance1, Elongation1, HeliocentricDistance1, Magnitude1, PhaseAngle1, Phase1, RightAscension1, TransitAltitude1}).intersect(which).count())
 	{
@@ -246,7 +246,7 @@ void AstroCalcChart::showToolTip(const QPointF &point, bool show)
 {
 	if (show)
 	{
-		QtCharts::QLineSeries *series=dynamic_cast<QtCharts::QLineSeries *>(sender());
+		QLineSeries *series=dynamic_cast<QLineSeries *>(sender());
 		AstroCalcChart::Series seriesCode=map.key(series);
 		QString units("°");
 		QDateTime date=QDateTime::fromMSecsSinceEpoch(qint64(point.x()), Qt::UTC);
@@ -264,7 +264,9 @@ void AstroCalcChart::showToolTip(const QPointF &point, bool show)
 						  AstroCalcChart::Distance1, AstroCalcChart::Distance2,
 						  AstroCalcChart::HeliocentricDistance1, AstroCalcChart::HeliocentricDistance2,
 						  AstroCalcChart::RightAscension1, AstroCalcChart::RightAscension2,
-						  AstroCalcChart::Phase1, AstroCalcChart::Phase2, AstroCalcChart::pcDistanceAU}).contains(seriesCode))
+						  AstroCalcChart::Phase1, AstroCalcChart::Phase2, AstroCalcChart::pcDistanceAU,
+						  AstroCalcChart::Magnitude1, AstroCalcChart::Magnitude2,
+						  AstroCalcChart::AngularSize1, AstroCalcChart::AngularSize2}).contains(seriesCode))
 		{
 			units="";
 		}
@@ -309,8 +311,8 @@ QPair<QDateTime, QDateTime> AstroCalcChart::findXRange(const double JD, const Se
 			break;
 		case AstroCalcChart::pcDistanceAU:
 		case AstroCalcChart::pcDistanceDeg:
-			startDate=StelUtils::jdToQDateTime(baseJD-300, Qt::UTC);
-			endDate=StelUtils::jdToQDateTime(baseJD+300, Qt::UTC);
+			startDate=StelUtils::jdToQDateTime(baseJD-150, Qt::UTC);
+			endDate=StelUtils::jdToQDateTime(baseJD+150, Qt::UTC);
 			break;
 		default: // 2-curves page
 			StelUtils::getDateFromJulianDay(baseJD, &year, &month, &day);
@@ -319,7 +321,7 @@ QPair<QDateTime, QDateTime> AstroCalcChart::findXRange(const double JD, const Se
 			break;
 	}
 	//qDebug() << "findXRange(): Date Range set for series " << series << ":" << startDate << " to " << endDate;
-	return QPair(startDate, endDate);
+	return QPair<QDateTime, QDateTime>(startDate, endDate);
 }
 
 QPair<double, double> AstroCalcChart::findYRange(const Series series) const
@@ -399,6 +401,7 @@ void AstroCalcChart::setupAxes(const double jd, const int periods, const QString
 	{
 		xAxis->setTickCount(21); // step is 30 days. 20 intervals.
 		xRange=findXRange(jd, AstroCalcChart::pcDistanceAU, 1);
+		xAxis->setFormat("<div style=\"text-align:center\">dd.<br/>MMM</div>");
 	}
 	else
 	{
@@ -511,7 +514,7 @@ void AstroCalcChart::setupAxes(const double jd, const int periods, const QString
 		font.setBold(false);
 		yAxisR->setTitleFont(font);
 	}
-	const QList<QtCharts::QAbstractSeries *> ser=series(); // currently shown series. These may be fewer than the series principally enabled in our map!
+	const QList<QAbstractSeries *> ser=series(); // currently shown series. These may be fewer than the series principally enabled in our map!
 
 	for (Series s: {AltVsTime, CurrentTime, TransitTime, SunElevation, CivilTwilight, NauticalTwilight, AstroTwilight, Moon, AzVsTime, MonthlyElevation,
 	     AngularSize1, Declination1, Distance1, Elongation1, HeliocentricDistance1, Magnitude1, PhaseAngle1, Phase1, RightAscension1, TransitAltitude1,
@@ -572,11 +575,11 @@ void AstroCalcChart::setYrangeR(Series series, qreal min, qreal max)
 	const double logYDiff=log10(yMaxR-yMinR);
 	const double s=pow(10., floor(logYDiff)-1.);
 
-	qreal rMin=floor(yMinR/s);
-	qreal rMax=ceil(yMaxR/s);
+	qreal rMin=floor(yMinR/s)*s;
+	qreal rMax=ceil(yMaxR/s)*s;
 
 	//qDebug() << "Setting yrangeR from" << min << "/" << max << "-->" << rMin*s << "/" << rMax*s;
-	yAxisR->setRange(rMin*s, rMax*s);
+	yAxisR->setRange(rMin, rMax);
 	if (rMax-rMin > 3*s)
 	{
 		yAxisR->setTickCount(6+1);
@@ -603,18 +606,24 @@ void AstroCalcChart::bufferYrange(Series series, double *min, double *max, bool
 		case Declination2:
 		case TransitAltitude1:
 		case TransitAltitude2:
+		{
 			*min=qMax(-90., *min-(strictMin ? 0. : 5.));
 			*max=qMin( 90., *max+5.);
 			break;
+		}
 		case AzVsTime:
+		{
 			*min=qMax(  0., *min);
 			*max=qMin(360., *max);
 			break;
+		}
 		case RightAscension1:
 		case RightAscension2:
+		{
 			*min=qMax( 0., *min);
 			*max=qMin(24., *max);
 			break;
+		}
 		case AngularSize1:
 		case AngularSize2:
 		case Distance1:
@@ -622,28 +631,36 @@ void AstroCalcChart::bufferYrange(Series series, double *min, double *max, bool
 		case HeliocentricDistance1:
 		case HeliocentricDistance2:
 		case pcDistanceAU:
+		{
 			*min=qMax( 0., *min);
 			*max*=1.05;
 			break;
+		}
 		case Elongation1:
 		case Elongation2:
 		case PhaseAngle1:
 		case PhaseAngle2:
 		case LunarElongation:
 		case pcDistanceDeg:
+		{
 			*min=qMax(  0., *min-0.05*range);
 			*max=qMin(180., *max+0.05*range);
 			break;
+		}
 		case Magnitude1:
 		case Magnitude2:
+		{
 			*min=*min-0.05*range;
 			*max=*max+0.05*range;
 			break;
+		}
 		case Phase1:
 		case Phase2:
+		{
 			*min=qMax(0., *min-0.05*range);
-			*max=qMin(1., *max+0.05*range);
+			*max=qMin(100., *max+0.05*range);
 			break;
+		}
 		default: // 8 other series which should not influence chart scaling
 			break;
 	}
