@@ -31,14 +31,13 @@
 #include <QTimer>
 #include <QRegularExpression>
 #include <QMutex>
-#include <QtCharts>
+#include <QtCharts/qchartview.h>
 
 #include "AstroCalcChart.hpp"
 #include "StelDialog.hpp"
 #include "StelCore.hpp"
 #include "Planet.hpp"
 #include "SolarSystem.hpp"
-#include "Nebula.hpp"
 #include "NebulaMgr.hpp"
 #include "StelPropertyMgr.hpp"
 #include "StarMgr.hpp"
@@ -60,6 +59,7 @@ struct Ephemeris
 	QString objDateStr;
 	float magnitude;
 	bool isComet;
+	PlanetP sso;
 };
 Q_DECLARE_METATYPE(Ephemeris)
 
@@ -98,6 +98,7 @@ public:
 	//! @enum HECPositionsColumns
 	enum HECPositionsColumns {
 		HECColumnName,          //! name of the planet
+		HECColumnSymbol,        //! symbol of the planet
 		HECColumnLatitude,      //! heliocentric ecliptical latitude
 		HECColumnLongitude,     //! heliocentric ecliptical longitude
 		HECColumnDistance,      //! distance
@@ -154,7 +155,8 @@ public:
 		GreatestElongation	= 2,
 		StationaryPoint		= 3,
 		OrbitalPoint		= 4,
-		Shadows			= 5
+		Shadows			= 5,
+		Quadrature		= 6
 	};
 
 	//! Defines the number and the order of the columns in the WUT tool
@@ -185,6 +187,20 @@ public:
 		LunarEclipseCount		//! total number of columns
 	};
 
+	//! Defines the number and the order of the columns in the lunar eclipse contact table
+	//! @enum LunarEclipseContactColumns
+	enum LunarEclipseContactColumns {
+		LunarEclipseContact,		//! circumstance of lunar eclipse
+		LunarEclipseContactDate,	//! date and time of circumstance
+		LunarEclipseContactAltitude,	//! altitude of the Moon
+		LunarEclipseContactAzimuth,	//! azimuth of the Moon
+		LunarEclipseContactLatitude,	//! latitude where the Moon appears in the zenith
+		LunarEclipseContactLongitude,	//! longitude where the Moon appears in the zenith
+		LunarEclipseContactPA,		//! position angle of shadow
+		LunarEclipseContactDistance,	//! angular distance between the Moon and shadow
+		LunarEclipseContactCount	//! total number of columns
+	};
+
 	//! Defines the number and the order of the columns in the global solar eclipse table
 	//! @enum SolarEclipseColumns
 	enum SolarEclipseColumns {
@@ -201,6 +217,19 @@ public:
 		SolarEclipseCount		//! total number of columns
 	};
 
+	//! Defines the number and the order of the columns in the global solar eclipse contact table
+	//! @enum SolarEclipseContactColumns
+	enum SolarEclipseContactColumns {
+		SolarEclipseContact,		//! circumstance of solar eclipse
+		SolarEclipseContactDate,	//! date and time of circumstance
+		SolarEclipseContactLatitude,	//! latitude at contact time
+		SolarEclipseContactLongitude,	//! longitude at contact time
+		SolarEclipseContactPathwidth,	//! pathwidth of total or annular solar eclipse
+		SolarEclipseContactDuration,	//! central duration of total or annular solar eclipse
+		SolarEclipseContactType,	//! type of solar eclipse		
+		SolarEclipseContactCount	//! total number of columns
+	};
+
 	//! Defines the number and the order of the columns in the local solar eclipse table
 	//! @enum SolarEclipseColumns
 	enum SolarEclipseLocalColumns {
@@ -233,14 +262,14 @@ public:
 	};
 
 	AstroCalcDialog(QObject* parent);
-	virtual ~AstroCalcDialog() Q_DECL_OVERRIDE;
+	~AstroCalcDialog() override;
 
 	static QVector<Ephemeris> EphemerisList;
 	static int DisplayedPositionIndex;
 
 
 public slots:
-	void retranslate() Q_DECL_OVERRIDE;
+	void retranslate() override;
 		
 signals:
 	//! This signal is emitted when the graph day changed.
@@ -248,7 +277,7 @@ signals:
 
 protected:
         //! Initialize the dialog widgets and connect the signals/slots.
-	virtual void createDialogContent() Q_DECL_OVERRIDE;
+	void createDialogContent() override;
         Ui_astroCalcDialogForm *ui;
 
 private slots:
@@ -258,10 +287,13 @@ private slots:
 	void selectCurrentCelestialPosition(const QModelIndex &modelIndex);
 
 	void currentHECPositions();
-	void drawHECGraph(QString selectedObject = "");
+	void drawHECGraph(const QString &selectedObject = "");
 	void saveHECPositions();
 	void selectCurrentHECPosition(const QModelIndex &modelIndex);
 	void markCurrentHECPosition(const QModelIndex &modelIndex);
+	void saveHECFlagMinorPlanets(bool b);
+	void saveHECFlagBrightComets(bool b);
+	void saveHECBrightCometMagnitudeLimit(double mag);
 
 	void saveCelestialPositionsMagnitudeLimit(double mag);
 	void saveCelestialPositionsHorizontalCoordinatesFlag(bool b);
@@ -274,6 +306,8 @@ private slots:
 	void saveEphemeris();	
 	void onChangedEphemerisPosition();
 	void reGenerateEphemeris();
+	void setDateTimeNow();
+	void saveIgnoreDateTestFlag(bool b);
 
 	//! Calculating the rises, transits and sets for selected celestial body and fill the list.
 	void generateRTS();
@@ -287,14 +321,21 @@ private slots:
 	void generateLunarEclipses();
 	void cleanupLunarEclipses();
 	void selectCurrentLunarEclipse(const QModelIndex &modelIndex);
+	void selectCurrentLunarEclipseDate(const QModelIndex &modelIndex);
+	void selectCurrentLunarEclipseContact(const QModelIndex &modelIndex);
 	void saveLunarEclipses();
+	void saveLunarEclipseCircumstances();
 
 	//! Calculating solar eclipses to fill the list.
 	//! Algorithm taken from calculating the rises, transits and sets.
 	void generateSolarEclipses();
 	void cleanupSolarEclipses();
 	void selectCurrentSolarEclipse(const QModelIndex &modelIndex);
+	void selectCurrentSolarEclipseDate(const QModelIndex &modelIndex);
+	void selectCurrentSolarEclipseContact(const QModelIndex &modelIndex);
 	void saveSolarEclipses();
+	void saveSolarEclipseCircumstances();
+	void saveSolarEclipseKML();
 
 	//! Calculating local solar eclipses to fill the list.
 	//! Algorithm taken from calculating the rises, transits and sets.
@@ -329,6 +370,7 @@ private slots:
 	void savePhenomenaCelestialGroup(int index);
 	void savePhenomenaOppositionFlag(bool b);
 	void savePhenomenaPerihelionAphelionFlag(bool b);
+	void savePhenomenaElongationsQuadraturesFlag(bool b);
 
 	//! Compute planetary data
 	void saveFirstCelestialBody(int index);
@@ -396,7 +438,7 @@ private slots:
 	void showExtraEphemerisDialog();
 	void showCustomStepsDialog();
 
-	void saveGraph(QtCharts::QChartView *graph);
+	void saveGraph(QChartView *graph);
 
 private:
 	class AstroCalcExtraEphemerisDialog* extraEphemerisDialog;
@@ -427,11 +469,16 @@ private:
 	QSettings* conf;
 	QTimer *currentTimeLine;
 	QHash<QString,int> wutCategories;
-	QPair<double, double> getLunarEclipseXY() const;
 	QList<HECPosition> hecObjects;
 
 	void saveTableAsCSV(const QString& fileName, QTreeWidget* tWidget, QStringList& headers);
+	void saveTableAsXLSX(const QString& fileName, QTreeWidget* tWidget, QStringList& headers, const QString& title, const QString& sheetName, const QString &note = "");
 	void saveTableAsBookmarks(const QString& fileName, QTreeWidget* tWidget);
+	QPair<QString, QString> askTableFilePath(const QString& caption, const QString& fileName);
+
+	void populateToolTips();
+	//! Get the list of selected dwarf and minor planets
+	QList<PlanetP> getSelectedMinorPlanets();
 
 	//! Update header names for celestial positions tables
 	void setCelestialPositionsHeaderNames();
@@ -447,8 +494,12 @@ private:
 	void setWUTHeaderNames(const bool magnitude = true, const bool separation = false);
 	//! update header names for lunar eclipse table
 	void setLunarEclipseHeaderNames();
+	//! update header names for lunar eclipse contact table
+	void setLunarEclipseContactsHeaderNames();
 	//! update header names for solar eclipse table
 	void setSolarEclipseHeaderNames();
+	//! update header names for solar eclipse contact table
+	void setSolarEclipseContactsHeaderNames();
 	//! update header names for local solar eclipse table
 	void setSolarEclipseLocalHeaderNames();
 	//! update header names for transit table
@@ -468,8 +519,30 @@ private:
 	void initListWUT(const bool magnitude = true, const bool separation = false);
 	//! Init header and list of lunar eclipse
 	void initListLunarEclipse();
+	//! Init header and list of lunar eclipse contact
+	void initListLunarEclipseContact();
 	//! Init header and list of solar eclipse
 	void initListSolarEclipse();
+	//! Init header and list of solar eclipse contact
+	void initListSolarEclipseContact();
+	//! Iteration to calculate minimum distance from Besselian elements
+	double getJDofMinimumDistance(double JD);
+	//! Iteration to calculate JD of solar eclipse contacts
+	double getJDofContact(double JD, bool beginning, bool penumbral, bool external, bool outerContact);
+	//! Iteration to calculate contact times of solar eclipse
+	double getDeltaTimeofContact(double JD, bool beginning, bool penumbra, bool external, bool outerContact);
+	//! Geographic coordinates where solar eclipse begins/ends at sunrise/sunset
+	QPair<double, double> getRiseSetLineCoordinates(bool first, double x, double y, double d, double L, double mu);
+	//! Geographic coordinates where maximum solar eclipse occurs at sunrise/sunset
+	QPair<double, double> getMaximumEclipseAtRiseSet(bool first, double JD);
+	//! Geographic coordinates of shadow outline
+	QPair<double, double> getShadowOutlineCoordinates(double angle, double x, double y, double d, double L, double tf,double mu);
+	//! Geographic coordinates of northern and southern limit of shadow
+	QPair<double, double> getNSLimitofShadow(double JD, bool northernLimit, bool penumbra);
+	//! Geographic coordinates of extreme northern and southern limits of shadow
+	QPair<double, double> getExtremeNSLimitofShadow(double JD, bool northernLimit, bool penumbra, bool begin);
+	//! Geographic coordinates of extreme contact
+	QPair<double, double> getContactCoordinates(double x, double y, double d, double mu);
 	//! Init header and list of local solar eclipse
 	void initListSolarEclipseLocal();
 	//! Init header and list of transit
@@ -498,61 +571,80 @@ private:
 	void adjustWUTColumns();
 	void adjustPhenomenaColumns();
 
+	void enableEphemerisButtons(bool enable);
+	void enableRTSButtons(bool enable);
+	void enablePhenomenaButtons(bool enable);
+	void enableSolarEclipsesButtons(bool enable);
+	void enableSolarEclipsesCircumstancesButtons(bool enable);
+	void enableSolarEclipsesLocalButtons(bool enable);
+	void enableLunarEclipsesButtons(bool enable);
+	void enableLunarEclipsesCircumstancesButtons(bool enable);
+	void enableTransitsButtons(bool enable);
+
 	void enableCustomEphemerisTimeStepButton();
 	double getCustomTimeStep();
 	void reGenerateEphemeris(bool withSelection);
 
+	//! Finding and selecting an object by its name in specific JD
+	void goToObject(const QString &name, const double JD);
+
 	//! Format RA/Dec or Az/Alt coordinates into nice strings.
 	//! @arg horizontal coord are horizontal (alt-azimuthal). Use degrees/degrees. Else use Hours/degrees.
 	//! @arg southAzimuth (relevant only for horizontal=true) count azimuth from south.
 	//! @arg decimalDegrees use decimal format, not DMS/HMS
 	//! @return QPair(lngStr, latStr) formatted output strings
-	static QPair<QString, QString> getStringCoordinates(const Vec3d coord, const bool horizontal, const bool southAzimuth, const bool decimalDegrees);
-	void fillWUTTable(QString objectName, QString designation, float magnitude, Vec4d RTSTime, double maxElevation,
-			  double angularSize, QString constellation, QString otype, bool decimalDegrees = false);
-	void fillCelestialPositionTable(QString objectName, QString RA, QString Dec, double magnitude,
-					QString angularSize, QString angularSizeToolTip, QString extraData,
-					QString extraDataToolTip, QString transitTime, QString maxElevation,
-					QString sElongation, QString objectType);
-	void fillHECPositionTable(QString objectName, QString latitude, QString longitude, double distance);
+	static QPair<QString, QString> getStringCoordinates(const Vec3d &coord, const bool horizontal, const bool southAzimuth, const bool decimalDegrees);
+	void fillWUTTable(const QString &objectName, const QString &designation, float magnitude, const Vec4d &RTSTime, double maxElevation,
+			  double angularSize, const QString &constellation, const QString &otype, bool decimalDegrees = false);
+	void fillCelestialPositionTable(const QString &objectName, const QString &RA, const QString &Dec, double magnitude,
+					const QString &angularSize, const QString &angularSizeToolTip, const QString &extraData,
+					const QString &extraDataToolTip, const QString &transitTime, const QString &maxElevation,
+					QString &sElongation, const QString &objectType);
+	void fillHECPositionTable(const QString &objectName, const QChar objectSymbol, const QString &latitude, const QString &longitude, const double distance);
 
 	//! Calculation conjunctions and oppositions.
 	//! @note Ported from KStars, should be improved, because this feature calculates
 	//! angular separation ("conjunction" defined as equality of right ascension
 	//! of two bodies), and current solution is not accurate and slow.
-	//! @note modes: 0 - conjuction, 1 - opposition, 2 - greatest elongation
+	//! @note modes: 0 - conjunction, 1 - opposition, 2 - greatest elongation
 	QMap<double, double> findClosestApproach(PlanetP& object1, StelObjectP& object2, const double startJD, const double stopJD, const double maxSeparation, const int mode);
-	// TODO: Doc?
+	//! Finding the angular distance between two celestial bodies at some Julian date
 	double findDistance(double JD, PlanetP object1, StelObjectP object2, int mode);
-	// TODO: Doc?
-	double findInitialStep(double startJD, double stopJD, QStringList objects);
-	// TODO: Doc?
+	//! Finding the initial time steps for interactions
+	double findInitialStep(double startJD, double stopJD, QStringList &objects);
+	//! Finding the celestial event
 	bool findPrecise(QPair<double, double>* out, PlanetP object1, StelObjectP object2, double JD, double step, int prevSign, int mode);
-	// TODO: Doc?
+	//! Wrapper for filling the table of phenomena between planet and star
 	void fillPhenomenaTable(const QMap<double, double> list, const PlanetP object1, const StelObjectP object2, int mode);
-	// TODO: Doc?
+	//! Wrapper for filling the table of phenomena between planet and deep-sky object
 	void fillPhenomenaTable(const QMap<double, double> list, const PlanetP object1, const NebulaP object2);
-	//! @note modes: 0 - conjuction, 1 - opposition, 2 - greatest elongation
+	//! Wrapper for filling the table of phenomena between two planets
+	//! @note modes: 0 - conjunction, 1 - opposition, 2 - greatest elongation
 	void fillPhenomenaTable(const QMap<double, double> list, const PlanetP object1, const PlanetP object2, int mode);
-	void fillPhenomenaTableVis(QString phenomenType, double JD, QString firstObjectName, float firstObjectMagnitude,
-				   QString secondObjectName, float secondObjectMagnitude, QString separation, QString elevation,
-				   QString elongation, QString angularDistance, QString elongTooltip="", QString angDistTooltip="");
-	//! Calculation greatest elongations
+	//! Filling the table of phenomena
+	void fillPhenomenaTableVis(const QString &phenomenType, double JD, const QString &firstObjectName, float firstObjectMagnitude,
+				   const QString &secondObjectName, float secondObjectMagnitude, const QString &separation, const QString &elevation,
+				   QString &elongation, const QString &angularDistance, const QString &elongTooltip="", const QString &angDistTooltip="");
+	//! Calculation of greatest elongations
 	QMap<double, double> findGreatestElongationApproach(PlanetP& object1, StelObjectP& object2, double startJD, double stopJD);
 	bool findPreciseGreatestElongation(QPair<double, double>* out, PlanetP object1, StelObjectP object2, double JD, double stopJD, double step);
-	//! Calculation stationary points
+	//! Calculation of quadratures
+	QMap<double, double> findQuadratureApproach(PlanetP& object1, StelObjectP& object2, double startJD, double stopJD);
+	bool findPreciseQuadrature(QPair<double, double>* out, PlanetP object1, StelObjectP object2, double JD, double stopJD, double step);
+	//! Calculation of stationary points
 	QMap<double, double> findStationaryPointApproach(PlanetP& object1, double startJD, double stopJD);
 	bool findPreciseStationaryPoint(QPair<double, double>* out, PlanetP object, double JD, double stopJD, double step, bool retrograde);
 	double findRightAscension(double JD, PlanetP object);
-	//! Calculation perihelion and aphelion points
+	//! Calculation of perihelion and aphelion points
 	QMap<double, double> findOrbitalPointApproach(PlanetP& object1, double startJD, double stopJD);
 	bool findPreciseOrbitalPoint(QPair<double, double>* out, PlanetP object1, double JD, double stopJD, double step, bool minimal);
-	inline double findHeliocentricDistance(double JD, PlanetP object1) const {return object1->getHeliocentricEclipticPos(JD+core->computeDeltaT(JD)/86400.).length();}
+	inline double findHeliocentricDistance(double JD, PlanetP object1) const {return object1->getHeliocentricEclipticPos(JD+core->computeDeltaT(JD)/86400.).norm();}
+	bool isSecondObjectRight(double JD, PlanetP object1, StelObjectP object2);
 
 	// Signal that a plot has to be redone
 	bool plotAltVsTime, plotAltVsTimeSun, plotAltVsTimeMoon, plotAltVsTimePositive, plotMonthlyElevation, plotMonthlyElevationPositive, plotDistanceGraph, plotLunarElongationGraph, plotAziVsTime;
 	int altVsTimePositiveLimit, monthlyElevationPositiveLimit, graphsDuration, graphsStep;
-	QStringList ephemerisHeader, phenomenaHeader, positionsHeader, hecPositionsHeader, wutHeader, rtsHeader, lunareclipseHeader, solareclipseHeader, solareclipselocalHeader, transitHeader;
+	QStringList ephemerisHeader, phenomenaHeader, positionsHeader, hecPositionsHeader, wutHeader, rtsHeader, lunareclipseHeader, lunareclipsecontactsHeader, solareclipseHeader, solareclipsecontactsHeader, solareclipselocalHeader, transitHeader;
 	static double brightLimit;
 	static const QString dash, delimiter;
 
@@ -562,6 +654,8 @@ private:
 
 	void enableAngularLimits(bool enable);
 
+	QString getSelectedObjectNameI18n(StelObjectP selectedObject);
+
 	//! Memorize day for detecting rollover to next/prev one
 	int oldGraphJD;
 
@@ -598,6 +692,7 @@ private:
 		PHCMoonsFirstBody           = 25,
 		PHCBrightCarbonStars        = 26,
 		PHCBrightBariumStars        = 27,
+		PHCSunPlanetsTheirMoons     = 28,
 		PHCNone	// stop gapper for syntax reasons
 	};
 
@@ -648,7 +743,7 @@ private:
 	};
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class ACCelPosTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -658,7 +753,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -703,7 +798,7 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class AHECPosTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -713,7 +808,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -732,7 +827,7 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class ACEphemTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -742,7 +837,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -765,7 +860,7 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class ACRTSTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -775,7 +870,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -798,7 +893,7 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class ACLunarEclipseTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -808,7 +903,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -827,7 +922,31 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Besselian elements for lunar eclipse
+class LunarEclipseBessel
+{
+public:
+	LunarEclipseBessel(double &besX, double &besY, double &besL1, double &besL2, double &besL3, double &latDeg, double &lngDeg);
+};
+
+//! Iteration to compute contact times of lunar eclipse
+class LunarEclipseIteration
+{
+public:
+	LunarEclipseIteration(double &JD, double &positionAngle, double &axisDistance, bool beforeMaximum, int eclipseType);
+};
+
+//! Derived from QTreeWidgetItem class, but currently nothing else.
+class ACLunarEclipseContactsTreeWidgetItem : public QTreeWidgetItem
+{
+public:
+	ACLunarEclipseContactsTreeWidgetItem(QTreeWidget* parent)
+		: QTreeWidgetItem(parent)
+	{
+	}
+};
+
+//! Derived from QTreeWidgetItem class with customized sort
 class ACSolarEclipseTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -837,11 +956,11 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
-		if (column == AstroCalcDialog::SolarEclipseDate || column == AstroCalcDialog::SolarEclipseLatitude || column == AstroCalcDialog::SolarEclipseLongitude || column == AstroCalcDialog::SolarEclipsePathwidth || column == AstroCalcDialog::SolarEclipseAltitude)
+		if (column == AstroCalcDialog::SolarEclipseDate || column == AstroCalcDialog::SolarEclipseLatitude || column == AstroCalcDialog::SolarEclipseLongitude || column == AstroCalcDialog::SolarEclipsePathwidth || column == AstroCalcDialog::SolarEclipseAltitude || column == AstroCalcDialog::SolarEclipseDuration)
 		{
 			return data(column, Qt::UserRole).toFloat() < other.data(column, Qt::UserRole).toFloat();
 		}
@@ -856,7 +975,40 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
+class ACSolarEclipseContactsTreeWidgetItem : public QTreeWidgetItem
+{
+public:
+	ACSolarEclipseContactsTreeWidgetItem(QTreeWidget* parent)
+		: QTreeWidgetItem(parent)
+	{
+	}
+
+private:
+	bool operator < (const QTreeWidgetItem &other) const override
+	{
+		int column = treeWidget()->sortColumn();
+
+		if (column == AstroCalcDialog::SolarEclipseContactDate)
+		{
+			return data(column, Qt::UserRole).toFloat() < other.data(column, Qt::UserRole).toFloat();
+		}
+		else
+		{
+			return text(column).toLower() < other.text(column).toLower();
+		}
+	}
+};
+
+// Class to compute parameters from Besselian elements
+class BesselParameters
+{
+public:
+	BesselParameters(double &xdot, double &ydot, double &ddot, double &mudot,
+	double &ldot, double &etadot, double &bdot, double &cdot, bool penumbra);
+};
+
+//! Derived from QTreeWidgetItem class with customized sort
 class ACSolarEclipseLocalTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -866,7 +1018,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -881,7 +1033,7 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class ACTransitTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -914,7 +1066,7 @@ public:
 	double &besDec, double &besTf1, double &besTf2, double &besL1, double &besL2, double &besMu);
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class ACPhenTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -924,7 +1076,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
@@ -947,7 +1099,7 @@ private:
 	}
 };
 
-// Reimplements the QTreeWidgetItem class to fix the sorting bug
+//! Derived from QTreeWidgetItem class with customized sort
 class WUTTreeWidgetItem : public QTreeWidgetItem
 {
 public:
@@ -957,7 +1109,7 @@ public:
 	}
 
 private:
-	bool operator < (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+	bool operator < (const QTreeWidgetItem &other) const override
 	{
 		int column = treeWidget()->sortColumn();
 
