@@ -32,15 +32,17 @@ class AstroCalcExtraEphemerisDialog : public StelDialog
 
 public:
 	AstroCalcExtraEphemerisDialog();
-	virtual ~AstroCalcExtraEphemerisDialog();
+	virtual ~AstroCalcExtraEphemerisDialog() Q_DECL_OVERRIDE;
 
 public slots:
-	void retranslate();
-	void setVisible(bool);
+	virtual void retranslate() Q_DECL_OVERRIDE;
+
+private slots:
+	void setOptionStatus();
 
 protected:
 	//! Initialize the dialog widgets and connect the signals/slots.
-	virtual void createDialogContent();
+	virtual void createDialogContent() Q_DECL_OVERRIDE;
 	Ui_astroCalcExtraEphemerisDialogForm *ui;
 };
 
