@@ -47,21 +47,21 @@
 #include "StelApp.hpp"
 #include "StelFileMgr.hpp"
 #include "StelGui.hpp"
-#include "StelGuiItems.hpp"
-#include "StelLocaleMgr.hpp"
 #include "StelLogger.hpp"
 #include "StelStyle.hpp"
 #include "StelActionMgr.hpp"
 #include "StelMovementMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelJsonParser.hpp"
+#include "StelTranslator.hpp"
+#include "ContributorsList.hpp"
 
 HelpDialog::HelpDialog(QObject* parent)
 	: StelDialog("Help", parent)
 	, message("")
 	, updateState(CompleteNoUpdates)
-	, networkManager(Q_NULLPTR)
-	, downloadReply(Q_NULLPTR)
+	, networkManager(nullptr)
+	, downloadReply(nullptr)
 {
 	ui = new Ui_helpDialogForm;	
 }
@@ -69,7 +69,7 @@ HelpDialog::HelpDialog(QObject* parent)
 HelpDialog::~HelpDialog()
 {
 	delete ui;
-	ui = Q_NULLPTR;
+	ui = nullptr;
 }
 
 void HelpDialog::retranslate()
@@ -79,11 +79,13 @@ void HelpDialog::retranslate()
 		ui->retranslateUi(dialog);
 		updateHelpText();
 		updateAboutText();
+		updateTabBarListWidgetWidth();
 	}
 }
 
-void HelpDialog::styleChanged()
+void HelpDialog::styleChanged(const QString &style)
 {
+	StelDialog::styleChanged(style);
 	if (dialog)
 	{
 		updateHelpText();
@@ -97,8 +99,8 @@ void HelpDialog::createDialogContent()
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	ui->stackedWidget->setCurrentIndex(0);
 	ui->stackListWidget->setCurrentRow(0);
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
 	// Kinetic scrolling
 	kineticScrollingList << ui->helpBrowser << ui->aboutBrowser << ui->logBrowser;
@@ -122,10 +124,15 @@ void HelpDialog::createDialogContent()
 	updateAboutText();
 
 	// Log page	
-	ui->logPathLabel->setText(QString("%1/log.txt:").arg(StelFileMgr::getUserDir()));
+	ui->logPathLabel->setText(QString("%1:").arg(StelLogger::getLogFileName()));
 	connect(ui->stackedWidget, SIGNAL(currentChanged(int)), this, SLOT(updateLog(int)));
 	connect(ui->refreshButton, SIGNAL(clicked()), this, SLOT(refreshLog()));
 
+	// Config page
+	ui->configPathLabel->setText(QString("%1:").arg(StelApp::getInstance().getSettings()->fileName()));
+	connect(ui->stackedWidget, SIGNAL(currentChanged(int)), this, SLOT(updateConfig(int)));
+	connect(ui->refreshConfigButton, SIGNAL(clicked()), this, SLOT(refreshConfig()));
+
 	// Set up download manager for checker of updates
 	networkManager = StelApp::getInstance().getNetworkAccessManager();
 	updateState = CompleteNoUpdates;
@@ -133,6 +140,12 @@ void HelpDialog::createDialogContent()
 	connect(this, SIGNAL(checkUpdatesComplete(void)), this, SLOT(updateAboutText()));
 
 	connect(ui->stackListWidget, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this, SLOT(changePage(QListWidgetItem *, QListWidgetItem*)));
+	updateTabBarListWidgetWidth();
+
+	connect((dynamic_cast<StelGui*>(StelApp::getInstance().getGui())), &StelGui::htmlStyleChanged, this, [=](const QString &style){
+		ui->helpBrowser->document()->setDefaultStyleSheet(style);
+		ui->aboutBrowser->document()->setDefaultStyleSheet(style);
+	});
 }
 
 void HelpDialog::setKeyButtonState(bool state)
@@ -142,7 +155,12 @@ void HelpDialog::setKeyButtonState(bool state)
 
 void HelpDialog::checkUpdates()
 {
+#if (QT_VERSION<QT_VERSION_CHECK(6,0,0))
+	// In Qt6 this is no longer available. Here we have to assume we are connected and test the reply.
+	// There is QNetworkInformation in Qt6.1, but it may give wrong results under certain circumstances.
+	// https://doc.qt.io/qt-6/qnetworkinformation.html
 	if (networkManager->networkAccessible()==QNetworkAccessManager::Accessible)
+#endif
 	{
 		if (updateState==HelpDialog::Updating)
 		{
@@ -155,7 +173,9 @@ void HelpDialog::checkUpdates()
 		QNetworkRequest request;
 		request.setUrl(API);
 		request.setRawHeader("User-Agent", StelUtils::getUserAgentString().toUtf8());
-		request.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+#if (QT_VERSION<QT_VERSION_CHECK(6,0,0))
+		request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
+#endif
 		downloadReply = networkManager->get(request);
 
 		updateState = HelpDialog::Updating;
@@ -164,7 +184,7 @@ void HelpDialog::checkUpdates()
 
 void HelpDialog::downloadComplete(QNetworkReply *reply)
 {
-	if (reply == Q_NULLPTR)
+	if (reply == nullptr)
 		return;
 
 	disconnect(networkManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadComplete(QNetworkReply*)));
@@ -173,11 +193,11 @@ void HelpDialog::downloadComplete(QNetworkReply *reply)
 	{
 		qWarning() << "Error: While trying to access"
 			   << reply->url().toString()
-			   << "the following error occured:"
+			   << "the following error occurred:"
 			   << reply->errorString();
 
 		reply->deleteLater();
-		downloadReply = Q_NULLPTR;
+		downloadReply = nullptr;
 		updateState = HelpDialog::DownloadError;
 		message = q_("Cannot check updates...");
 		return;
@@ -199,11 +219,13 @@ void HelpDialog::downloadComplete(QNetworkReply *reply)
 
 	QString latestVersion = map["name"].toString();
 	latestVersion.replace("v","", Qt::CaseInsensitive);
+	QStringList v = latestVersion.split(".");
+	v.append("0"); // the latest number (PATCH) is always 0 for releases
 
 	QString appVersion = StelUtils::getApplicationVersion();
-	QStringList c = appVersion.split(".");	
+	QStringList c = appVersion.split(".");
 	int r = StelUtils::compareVersions(latestVersion, appVersion);
-	if (r==-1 || c.count()>3 || c.last().contains("-"))
+	if (r==-1 || c.count()>v.count() || c.last().contains("-"))
 		message = q_("Looks like you are using the development version of Stellarium.");
 	else if (r==0)
 		message = q_("This is latest stable version of Stellarium.");
@@ -211,7 +233,7 @@ void HelpDialog::downloadComplete(QNetworkReply *reply)
 		message = QString("%1 <a href='%2'>%3</a>").arg(q_("This version of Stellarium is outdated!"), map["html_url"].toString(), q_("Download new version."));
 
 	reply->deleteLater();
-	downloadReply = Q_NULLPTR;
+	downloadReply = nullptr;
 
 	emit checkUpdatesComplete();
 }
@@ -229,6 +251,12 @@ void HelpDialog::updateLog(int)
 		refreshLog();
 }
 
+void HelpDialog::updateConfig(int)
+{
+	if (ui->stackedWidget->currentWidget() == ui->pageConfig)
+		refreshConfig();
+}
+
 void HelpDialog::refreshLog() const
 {
 	ui->logBrowser->setPlainText(StelLogger::getLog());
@@ -236,6 +264,17 @@ void HelpDialog::refreshLog() const
 	sb->setValue(sb->maximum());
 }
 
+void HelpDialog::refreshConfig() const
+{
+	QFile config(StelApp::getInstance().getSettings()->fileName());
+	if(config.open(QIODevice::ReadOnly))
+	{
+		ui->configBrowser->setPlainText(config.readAll());
+		ui->configBrowser->setFont(QFont("Courier New"));
+		config.close();
+	}
+}
+
 void HelpDialog::updateHelpText(void) const
 {
 	QString htmlText = "<html><head><title>";
@@ -261,7 +300,7 @@ void HelpDialog::updateHelpText(void) const
 	htmlText += "<tr><td><b>" + hotkeyTextWrapper("Ctrl+Up") + "/" + hotkeyTextWrapper("Ctrl+Down") + "</b></td></tr>\n";
 	// time dragging/scrolling
 	QString delimiter = "";
-	#ifdef Q_OS_MAC
+	#ifdef Q_OS_MACOS
 	// TRANSLATORS: The char mean "and"
 	delimiter = QString(" %1 ").arg(q_("&"));
 	#endif
@@ -270,11 +309,19 @@ void HelpDialog::updateHelpText(void) const
 	htmlText += "<tr><td>" + q_("Time scrolling: minutes").toHtmlEscaped() + "</td><td><b>" +
 			QKeySequence(Qt::CTRL).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
 	htmlText += "<tr><td>" + q_("Time scrolling: hours").toHtmlEscaped() + "</td><td><b>" +
+	#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+			QKeySequence(Qt::CTRL | Qt::SHIFT).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
+	htmlText += "<tr><td>" + q_("Time scrolling: days").toHtmlEscaped() + "</td><td><b>" +
+			QKeySequence(Qt::CTRL | Qt::ALT).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
+	htmlText += "<tr><td>" + q_("Time scrolling: years").toHtmlEscaped() + "</td><td><b>" +
+			QKeySequence(Qt::CTRL | Qt::ALT | Qt::SHIFT).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
+	#else
 			QKeySequence(Qt::CTRL + Qt::SHIFT).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
 	htmlText += "<tr><td>" + q_("Time scrolling: days").toHtmlEscaped() + "</td><td><b>" +
 			QKeySequence(Qt::CTRL + Qt::ALT).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
 	htmlText += "<tr><td>" + q_("Time scrolling: years").toHtmlEscaped() + "</td><td><b>" +
 			QKeySequence(Qt::CTRL + Qt::ALT + Qt::SHIFT).toString(QKeySequence::NativeText) + delimiter + q_("mouse wheel").toHtmlEscaped() + "</b></td></tr>";
+	#endif
 
 	// select object
 	htmlText += "<tr><td>" + q_("Select object").toHtmlEscaped() + "</td>";
@@ -282,11 +329,11 @@ void HelpDialog::updateHelpText(void) const
 	// clear selection
 	htmlText += "<tr><td>";
 	htmlText += q_("Clear selection").toHtmlEscaped() + "</td>";
-#ifdef Q_OS_MAC
+	#ifdef Q_OS_MACOS
 	htmlText += "<td><b>" + QKeySequence(Qt::CTRL).toString(QKeySequence::NativeText) + delimiter + q_("& left click").toHtmlEscaped() + "</b></td></tr>\n";
-#else
+	#else
 	htmlText += "<td><b>" + q_("Right click").toHtmlEscaped() + "</b></td></tr>\n";
-#endif
+	#endif
 	// add custom marker
 	htmlText += "<tr><td>" + q_("Add custom marker").toHtmlEscaped() + "</td>";
 	htmlText += "<td><b>" + QKeySequence(Qt::SHIFT).toString(QKeySequence::NativeText) + delimiter + q_("left click").toHtmlEscaped() + "</b></td></tr>\n";
@@ -295,7 +342,11 @@ void HelpDialog::updateHelpText(void) const
 	htmlText += "<td><b>" + QKeySequence(Qt::SHIFT).toString(QKeySequence::NativeText) + delimiter + q_("right click").toHtmlEscaped() + "</b></td></tr>\n";
 	// delete all custom markers
 	htmlText += "<tr><td>" + q_("Delete all custom markers").toHtmlEscaped() + "</td>";
+	#if (QT_VERSION>=QT_VERSION_CHECK(6,0,0))
+	htmlText += "<td><b>" + QKeySequence(Qt::SHIFT | Qt::ALT).toString(QKeySequence::NativeText) + delimiter + q_("right click").toHtmlEscaped() + "</b></td></tr>\n";
+	#else
 	htmlText += "<td><b>" + QKeySequence(Qt::SHIFT + Qt::ALT).toString(QKeySequence::NativeText) + delimiter + q_("right click").toHtmlEscaped() + "</b></td></tr>\n";
+	#endif
 
 	htmlText += "</table>\n<p>" +
 			q_("Below are listed only the actions with assigned keys. Further actions may be available via the \"%1\" button.")
@@ -305,6 +356,7 @@ void HelpDialog::updateHelpText(void) const
 	// Append all StelAction shortcuts.
 	StelActionMgr* actionMgr = StelApp::getInstance().getStelActionManager();
 	typedef QPair<QString, QString> KeyDescription;
+	QString keydelimiter = QString("</b> %1 <b>").arg(q_("or"));
 	QVector<KeyDescription> groups;
 	const QStringList groupList = actionMgr->getGroupList();
 	for (const auto &group : groupList)
@@ -319,11 +371,11 @@ void HelpDialog::updateHelpText(void) const
 		const QList<StelAction *>actionList = actionMgr->getActionList(group.second);
 		for (auto* action : actionList)
 		{
-			if (action->getShortcut().isEmpty())
-				continue;
 			QString text = action->getText();
-			QString key =  action->getShortcut().toString(QKeySequence::NativeText);
-			descriptions.append(KeyDescription(text, key));
+			QStringList keys = { action->getShortcut().toString(QKeySequence::NativeText), action->getAltShortcut().toString(QKeySequence::NativeText)};
+			keys.removeAll(QString("")); // remove empty shortcuts
+			if (keys.count()>0)
+				descriptions.append(KeyDescription(text, keys.join(keydelimiter)));
 		}
 		std::sort(descriptions.begin(), descriptions.end());
 		if (descriptions.count()>0)
@@ -333,7 +385,7 @@ void HelpDialog::updateHelpText(void) const
 			for (const auto& desc : descriptions)
 			{
 				htmlText += "<tr><td>" + desc.first.toHtmlEscaped() + "</td>";
-				htmlText += "<td><b>" + desc.second.toHtmlEscaped() + "</b></td></tr>\n";
+				htmlText += "<td><b>" + desc.second + "</b></td></tr>\n";
 			}
 		}
 		if (group.second=="TUI") // Special case: TUI
@@ -346,16 +398,16 @@ void HelpDialog::updateHelpText(void) const
 	}
 
 	htmlText += "<tr><td colspan='2'>&nbsp;</td></tr>";
-	htmlText += "<tr><td colspan='2'><b><u>" + q_("Special local keys") +	":</u></b></td></tr>\n";
+	htmlText += "<tr><td colspan='2'><b><u>" + q_("Special local keys") + ":</u></b></td></tr>\n";
 	htmlText += "<tr><td colspan='2'>" + q_("All these hotkeys are locally available to run when specific window or tab is opened.") + "</td></tr>";
-	htmlText += "<tr><td colspan='2'><b>" + q_("Script console") +	":</b></td></tr>\n";
+	htmlText += "<tr><td colspan='2'><b><em>" + q_("Script console") + ":</em></b></td></tr>\n";
 	htmlText += "<tr><td>" + q_("Load script from file") + "</td>";
 	htmlText += "<td><b>" + hotkeyTextWrapper("Ctrl+Shift+O") + "</b></td></tr>\n";
 	htmlText += "<tr><td>" + q_("Save script to file") + "</td>";
 	htmlText += "<td><b>" + hotkeyTextWrapper("Ctrl+Shift+S") + "</b></td></tr>\n";
 	htmlText += "<tr><td>" + q_("Run script") + "</td>";
 	htmlText += "<td><b>" + hotkeyTextWrapper("Ctrl+Return") + "</b></td></tr>\n";
-	htmlText += "<tr><td colspan='2'><b>" + q_("Astronomical calculations") +	":</b></td></tr>\n";
+	htmlText += "<tr><td colspan='2'><b><em>" + q_("Astronomical calculations") + ":</em></b></td></tr>\n";
 	htmlText += "<tr><td>" + q_("Update positions") + "</td>";
 	QString shiftF10 = hotkeyTextWrapper("Shift+F10");
 	htmlText += "<td><b>" + shiftF10 + "</b></td></tr>\n";
@@ -366,6 +418,12 @@ void HelpDialog::updateHelpText(void) const
 	htmlText += "<td><b>" + shiftF10 + "</b></td></tr>\n";
 	htmlText += "<tr><td>" + q_("Calculate phenomena") + "</td>";
 	htmlText += "<td><b>" + shiftF10 + "</b></td></tr>\n";
+	htmlText += "<tr><td>" + q_("Calculate solar eclipses") + "</td>";
+	htmlText += "<td><b>" + shiftF10 + "</b></td></tr>\n";
+	htmlText += "<tr><td>" + q_("Calculate lunar eclipses") + "</td>";
+	htmlText += "<td><b>" + shiftF10 + "</b></td></tr>\n";
+	htmlText += "<tr><td>" + q_("Calculate transits") + "</td>";
+	htmlText += "<td><b>" + shiftF10 + "</b></td></tr>\n";
 
 	htmlText += "</table>";
 
@@ -428,42 +486,37 @@ QString HelpDialog::hotkeyTextWrapper(const QString hotkey) const
 
 void HelpDialog::updateAboutText(void) const
 {
-    QStringList contributors({
-		     "Vladislav Bataron", "Barry Gerdes", "Peter Walser", "Michal Sojka",
-		     "Nick Fedoseev", "Clement Sommelet", "Ivan Marti-Vidal", "Nicolas Martignoni",
-		     "Oscar Roig Felius", "M.S. Adityan", "Tomasz Buchert", "Adam Majer",
-		     "Roland Bosa", "Łukasz 'sil2100' Zemczak", "Gábor Péterffy",
-		     "Mircea Lite", "Alexey Dokuchaev", "William Formyduval", "Daniel De Mickey",
-		     "François Scholder", "Anton Samoylov", "Mykyta Sytyi", "Shantanu Agarwal",
-		     "Teemu Nätkinniemi", "Kutaibaa Akraa", "J.L.Canales", "Leonid Froenchenko",
-		     "Peter Mousley", "Greg Alexander", "Yuri Chornoivan", "Daniel Michalik",
-		     "Hleb Valoshka", "Matthias Drochner", "Kenan Dervišević", "Alex Gamper",
-		     "Volker Hören", "Max Digruber", "Dan Smale", "Victor Reijs",
-		     "Tanmoy Saha", "Oleg Ginzburg", "Peter Hickey", "Bernd Kreuss",
-		     "Alexander Miller", "Eleni Maria Stea", "Kirill Snezhko",
-		     "Simon Parzer", "Peter Neubauer", "Andrei Borza", "Allan Johnson",
-		     "Felix Zeltner", "Paolo Cancedda", "Ross Mitchell", "David Baucum",
-		     "Maciej Serylak", "Adriano Steffler", "Sibi Antony", "Tony Furr",
-		     "misibacsi", "Pavel Klimenko", "Rumen G. Bogdanovski", "Colin Gaudion",
-		     "Annette S. Lee", "Vancho Stojkoski", "Robert S. Fuller", "Giuseppe Putzolu",
-		     "henrysky", "Nick Kanel", "Petr Kubánek", "Matwey V. Kornilov",
-		     "Alessandro Siniscalchi", "Ruslan Kabatsayev", "Pawel Stolowski",
-		     "Antoine Jacoutot", "Sebastian Jennen", "Matt Hughes", "Sun Shuwei",
-		     "Alexey Sokolov", "Paul Krizak", "ChrUnger", "Minmin Gong", "Andy Kirkham",
-		     "Michael Dickens",  "Patrick (zero0cool0)", "Martín Bernardi", "Sebastian Garcia",
-		     "Wolfgang Laun", "Alexandros Kosiaris", "Alexander Duytschaever", "Jocelyn Girod",
-		     "Atque", "Worachate Boonplod"});
-	contributors.sort();
+	QStringList allContributors = StelContributors::contributorsList;
+	allContributors.sort();
+	allContributors.removeDuplicates();
+
+	typedef QPair<QString, int> donator;
+	QVector<donator> financialContributors = {
+		// Individuals
+		{ "Laurence Holt", 1000 }, { "John Bellora", 570 }, { "Jeff Moe", 512 }, { "Vernon Hermsen", 324 },
+		{ "Marla Pinaire", 410 }, { "Satish Mallesh", 260 }, { "Vlad Magdalin", 250  }, { "Philippe Renoux", 250 },
+		{ "Fito Martin", 250 }, { "SuEllen Shepard", 250 },
+		// Organizations
+		{ "Astronomie-Werkstatt \"Sterne ohne Grenzen\"", 670 }, { "BairesDev", 3500 }, { "Triplebyte", 280 }
+	};
+	std::sort(financialContributors.begin(), financialContributors.end(), [](donator i, donator j){ return i.second > j.second; });
+	QStringList bestFinancialContributors;
+	for (auto fc = financialContributors.begin(); fc != financialContributors.end(); ++fc)
+	{
+		bestFinancialContributors << fc->first;
+	}
 
 	// Regexp to replace {text} with an HTML link.
 	static const QRegularExpression a_rx("[{]([^{]*)[}]");
 
 	// populate About tab
 	QString newHtml = "<h1>" + StelUtils::getApplicationName() + "</h1>";
-	// Note: this legal notice is not suitable for translation
-	newHtml += QString("<h3>%1</h3>").arg(STELLARIUM_COPYRIGHT);
+	newHtml += QString("<p><strong>%1 %2").arg(q_("Version"), StelUtils::getApplicationVersion());
+	newHtml += QString("<br />%1 %2</strong></p>").arg(q_("Based on Qt"), QT_VERSION_STR);
 	if (!message.isEmpty())
 		newHtml += "<p><strong>" + message + "</strong></p>";
+	// Note: this legal notice is not suitable for translation
+	newHtml += QString("<h3>%1</h3>").arg(STELLARIUM_COPYRIGHT);
 	// newHtml += "<p><em>Version 0.15 is dedicated in memory of our team member Barry Gerdes.</em></p>";
 	newHtml += "<p>This program is free software; you can redistribute it and/or ";
 	newHtml += "modify it under the terms of the GNU General Public License ";
@@ -486,7 +539,11 @@ void HelpDialog::updateAboutText(void) const
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Guillaume Chéreau")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Georg Zotti")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Alexander V. Wolf")).toHtmlEscaped() + "</li>";
-	newHtml += "<li>" + q_("Sky cultures researcher: %1").arg(QString("Susanne M. Hoffmann")).toHtmlEscaped() + "</li></ul>";
+	newHtml += "<li>" + q_("Developer: %1").arg(QString("Ruslan Kabatsayev")).toHtmlEscaped() + "</li>";
+	newHtml += "<li>" + q_("Developer: %1").arg(QString("Worachate Boonplod")).toHtmlEscaped() + "</li>";
+	newHtml += "<li>" + q_("Sky cultures researcher: %1").arg(QString("Susanne M. Hoffmann")).toHtmlEscaped() + "</li>";
+	newHtml += "<li>" + q_("Continuous Integration: %1").arg(QString("Hans Lambermont")).toHtmlEscaped() + "</li>";
+	newHtml += "<li>" + q_("Tester: %1").arg(QString("Khalid AlAjaji")).toHtmlEscaped() + "</li></ul>";
 	newHtml += "<h3>" + q_("Former Developers").toHtmlEscaped() + "</h3>";
 	newHtml += "<p>"  + q_("Several people have made significant contributions, but are no longer active. Their work has made a big difference to the project:").toHtmlEscaped() + "</p><ul>";
 	newHtml += "<li>" + q_("Graphic/other designer: %1").arg(QString("Johan Meuris")).toHtmlEscaped() + "</li>";
@@ -503,10 +560,12 @@ void HelpDialog::updateAboutText(void) const
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Marcos Cardinot")).toHtmlEscaped() + "</li>";	
 	newHtml += "<li>" + q_("OSX Developer: %1").arg(QString("Nigel Kerr")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("OSX Developer: %1").arg(QString("Diego Marcos")).toHtmlEscaped() + "</li></ul>";
-	newHtml += "<li>" + q_("Continuous Integration: %1").arg(QString("Hans Lambermont")).toHtmlEscaped() + "</li>";
-	newHtml += "<li>" + q_("Tester: %1").arg(QString("Khalid AlAjaji")).toHtmlEscaped() + "</li></ul>";
 	newHtml += "<h3>" + q_("Contributors").toHtmlEscaped() + "</h3>";
-	newHtml += "<p>"  + q_("Several people have made contributions to the project and their work has made Stellarium better (sorted alphabetically): %1.").arg(contributors.join(", ")).toHtmlEscaped() + "</p>";
+	newHtml += "<p>"  + q_("Many individuals have made contributions to the project and their work has made Stellarium better. Alphabetically sorted list of all contributors: %1.").arg(allContributors.join(", ")).toHtmlEscaped() + "</p>";
+	newHtml += "<h3>" + q_("Financial support").toHtmlEscaped() + "</h3>";
+	newHtml += "<p>"  + q_("Many individuals and organizations are supporting the development of Stellarium by donations, and the most generous financial contributors (with donations of $250 or more) are %1.").arg(bestFinancialContributors.join(", ")).toHtmlEscaped();
+	// TRANSLATORS: The text between braces is the text of an HTML link.
+	newHtml += " " + q_("The full list of financial contributors you may see on our {Open Collective page}.").toHtmlEscaped().replace(a_rx, "<a href=\"https://opencollective.com/stellarium\">\\1</a>") + "</p>";
 	newHtml += "<h3>" + q_("Acknowledgment").toHtmlEscaped() + "</h3>";
 	newHtml += "<p>"  + q_("If the Stellarium planetarium was helpful for your research work, the following acknowledgment would be appreciated:").toHtmlEscaped() + "</p>";
 	newHtml += "<p><em>"  + q_("This research has made use of the Stellarium planetarium") + "</em></p>";
@@ -529,3 +588,31 @@ void HelpDialog::changePage(QListWidgetItem *current, QListWidgetItem *previous)
 		current = previous;
 	ui->stackedWidget->setCurrentIndex(ui->stackListWidget->row(current));
 }
+
+void HelpDialog::updateTabBarListWidgetWidth()
+{
+	ui->stackListWidget->setWrapping(false);
+	// Update list item sizes after translation
+	ui->stackListWidget->adjustSize();
+	QAbstractItemModel* model = ui->stackListWidget->model();
+	if (!model)
+		return;
+
+	// stackListWidget->font() does not work properly!
+	// It has a incorrect fontSize in the first loading, which produces the bug#995107.
+	QFont font;
+	font.setPixelSize(14);
+	font.setWeight(QFont::Bold);
+	QFontMetrics fontMetrics(font);
+	int iconSize = ui->stackListWidget->iconSize().width();
+	int width = 0;
+	for (int row = 0; row < model->rowCount(); row++)
+	{
+		int textWidth = fontMetrics.boundingRect(ui->stackListWidget->item(row)->text()).width();
+		width += iconSize > textWidth ? iconSize : textWidth; // use the wider one
+		width += 24; // margin - 12px left and 12px right
+	}
+	// Hack to force the window to be resized...
+	ui->stackListWidget->setMinimumWidth(width);
+	ui->stackListWidget->updateGeometry();
+}
