@@ -19,8 +19,12 @@
 */
 
 #include "Dialog.hpp"
+#include "StelModuleMgr.hpp"
+#include "LandscapeMgr.hpp"
 #include "LocationDialog.hpp"
 #include "StelLocationMgr.hpp"
+#include "StelMovementMgr.hpp"
+#include "StelObjectMgr.hpp"
 #include "ui_locationDialogGui.h"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
@@ -28,9 +32,7 @@
 #include "StelModuleMgr.hpp"
 #include "SolarSystem.hpp"
 #include "StelFileMgr.hpp"
-#include "StelLocaleMgr.hpp"
 #include "StelGui.hpp"
-#include "StelGuiItems.hpp"
 #include "StelSkyCultureMgr.hpp"
 
 #include <QSettings>
@@ -44,9 +46,9 @@
 LocationDialog::LocationDialog(QObject* parent)
 	: StelDialog("Location", parent)
 	, isEditingNew(false)
-	, allModel(Q_NULLPTR)
-	, pickedModel(Q_NULLPTR)
-	, proxyModel(Q_NULLPTR)
+	, allModel(nullptr)
+	, pickedModel(nullptr)
+	, proxyModel(nullptr)
 #ifdef ENABLE_GPS
 	, gpsCount(0)
 #endif
@@ -71,8 +73,9 @@ void LocationDialog::retranslate()
 	}
 }
 
-void LocationDialog::styleChanged()
+void LocationDialog::styleChanged(const QString &style)
 {
+	StelDialog::styleChanged(style);
 	// Make the map red if needed
 	if (dialog)
 		setMapForLocation(StelApp::getInstance().getCore()->getCurrentLocation());
@@ -84,11 +87,6 @@ void LocationDialog::createDialogContent()
 	// We try to directly connect to the observer slots as much as we can
 	ui->setupUi(dialog);
 
-	//enable resizability
-	ui->mapLabel->setMinimumSize(0,0);
-	ui->mapLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
-	ui->mapLabel->setScaledContents(false);
-
 	StelApp *app = &StelApp::getInstance();
 	connect(app, SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	connect(app, SIGNAL(flagShowDecimalDegreesChanged(bool)), this, SLOT(setDisplayFormatForSpins(bool)));
@@ -133,14 +131,18 @@ void LocationDialog::createDialogContent()
 		this, SLOT(setLocationFromList(const QModelIndex&)));
 
 	// Connect all the QT signals
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
-	connect(ui->mapLabel, SIGNAL(positionChanged(double, double)), this, SLOT(setLocationFromMap(double, double)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->mapWidget, SIGNAL(positionChanged(double, double, const QColor&)), this, SLOT(setLocationFromMap(double, double, const QColor&)), Qt::UniqueConnection);
 
 	connect(ui->addLocationToListPushButton, SIGNAL(clicked()), this, SLOT(addCurrentLocationToList()));
 	connect(ui->deleteLocationFromListPushButton, SIGNAL(clicked()), this, SLOT(deleteCurrentLocationFromList()));
 	connect(ui->resetListPushButton, SIGNAL(clicked()), this, SLOT(resetLocationList()));
+#if (QT_VERSION>=QT_VERSION_CHECK(5,14,0))
+	connect(ui->regionNameComboBox, SIGNAL(textActivated(const QString &)), this, SLOT(filterSitesByRegion()));
+#else
 	connect(ui->regionNameComboBox, SIGNAL(activated(const QString &)), this, SLOT(filterSitesByRegion()));
+#endif
 
 	StelCore* core = StelApp::getInstance().getCore();
 	const StelLocation& currentLocation = core->getCurrentLocation();
@@ -167,8 +169,12 @@ void LocationDialog::createDialogContent()
 	}
 
 #ifdef ENABLE_GPS
+#ifdef Q_OS_WIN
+	ui->gpsToolButton->setText(q_("Get location from GPS or system service"));
+#else
+	ui->gpsToolButton->setText(q_("Get location from GPS"));
+#endif
 	connect(ui->gpsToolButton, SIGNAL(toggled(bool)), this, SLOT(gpsEnableQueryLocation(bool)));
-	ui->gpsToolButton->setStyleSheet(QString("QToolButton{ background: gray; }")); // ? Missing default style?
 	connect(locMgr, SIGNAL(gpsQueryFinished(bool)), this, SLOT(gpsReturn(bool)));
 #else
 	ui->gpsToolButton->setEnabled(false);
@@ -176,7 +182,6 @@ void LocationDialog::createDialogContent()
 #endif
 	connect(ui->useIpQueryCheckBox, SIGNAL(clicked(bool)), this, SLOT(ipQueryLocation(bool)));
 	connect(ui->useAsDefaultLocationCheckBox, SIGNAL(clicked(bool)), this, SLOT(setDefaultLocation(bool)));
-	connect(ui->pushButtonReturnToDefault, SIGNAL(clicked()), core, SLOT(returnToDefaultLocation()));
 	connect(ui->pushButtonReturnToDefault, SIGNAL(clicked()), this, SLOT(resetLocationList()));
 	connectBoolProperty(ui->dstCheckBox, "StelCore.flagUseDST");
 	connectBoolProperty(ui->useCustomTimeZoneCheckBox, "StelCore.flagUseCTZ");
@@ -184,12 +189,27 @@ void LocationDialog::createDialogContent()
 	ui->timeZoneNameComboBox->setEnabled(core->getUseCustomTimeZone());
 	connect(ui->useCustomTimeZoneCheckBox, SIGNAL(clicked(bool)), this, SLOT(updateTimeZoneControls(bool)));
 	connect(core, SIGNAL(currentTimeZoneChanged(QString)), this, SLOT(setTimezone(QString)));
+	connectBoolProperty(ui->autoEnableEnvironmentCheckBox, "LandscapeMgr.flagEnvironmentAutoEnabling");
+	connectBoolProperty(ui->autoChangeLandscapesCheckBox,  "LandscapeMgr.flagLandscapeAutoSelection");
 
 	connectEditSignals();
 
 	populateTooltips();
 
-	connect(core, SIGNAL(locationChanged(StelLocation)), this, SLOT(updateFromProgram(StelLocation)));
+	// In case this dialog is called up before going to an "observer", we need to update a few UI elements:
+	updateFromProgram(core->getCurrentLocation());
+	// This connection only updates the dialog with new coordinates, not the landscape
+	connect(core, &StelCore::targetLocationChanged, this, [=](const StelLocation &loc, const QString &id){ updateFromProgram(loc); Q_UNUSED(id); }); // Fill with actually selected location!
+
+	connect(ui->pushButtonReturnToDefault, &QPushButton::clicked, this, [=]{
+		static StelMovementMgr *mMgr=GETSTELMODULE(StelMovementMgr);
+		static LandscapeMgr *lMgr=GETSTELMODULE(LandscapeMgr);
+		mMgr->setFlagTracking(false);      // break orientation lock
+		this->setLocationUIvisible(true);  // restore UI
+		core->returnToDefaultLocation();
+		mMgr->resetInitViewPos();
+		lMgr->setCurrentLandscapeID(lMgr->getDefaultLandscapeID(), 1.);
+	});
 
 	ui->citySearchLineEdit->setFocus();
 }
@@ -209,14 +229,6 @@ void LocationDialog::setDisplayFormatForSpins(bool flagDecimalDegrees)
 	ui->latitudeSpinBox->setDisplayFormat(format);
 }
 
-void LocationDialog::handleDialogSizeChanged(QSizeF size)
-{
-	StelDialog::handleDialogSizeChanged(size);
-	StelLocation loc = locationFromFields();
-	//resizePixmap();
-	//ui->mapLabel->setCursorPos(loc.longitude, loc.latitude);
-}
-
 void LocationDialog::reloadLocations()
 {
 	allModel->setStringList(StelApp::getInstance().getLocationMgr().getAllMap().keys());
@@ -225,22 +237,30 @@ void LocationDialog::reloadLocations()
 void LocationDialog::populateTooltips()
 {
 	ui->resetListPushButton->setToolTip(q_("Reset location list to show all known locations"));
+#ifdef Q_OS_WIN
+	ui->gpsToolButton->setToolTip(QString("<p>%1</p>").arg(q_("Toggle fetching location from GPS or system location service. (Does not change time zone!) When satisfied, toggle off to let other programs access the GPS device.")));
+#else
 	ui->gpsToolButton->setToolTip(QString("<p>%1</p>").arg(q_("Toggle fetching GPS location. (Does not change time zone!) When satisfied, toggle off to let other programs access the GPS device.")));
+#endif
 }
 
 // Update the widget to make sure it is synchrone if the location is changed programmatically
-void LocationDialog::updateFromProgram(const StelLocation& currentLocation)
+void LocationDialog::updateFromProgram(const StelLocation& newLocation)
 {
 	if (!dialog)
 		return;
 
+	if (newLocation.name.contains("->")) // avoid extra updates
+		return;
+
+	populateRegionList(newLocation.planetName);
 	StelCore* stelCore = StelApp::getInstance().getCore();
 
 	isEditingNew = false;
 
 	// Check that the use as default check box needs to be updated
 	// Move to setFieldsFromLocation()? --BM?
-	const bool b = currentLocation.getID() == stelCore->getDefaultLocationID();
+	const bool b = newLocation.getID() == stelCore->getDefaultLocationID();
 	QSettings* conf = StelApp::getInstance().getSettings();
 	if (conf->value("init_location/location", "auto").toString() != ("auto"))
 	{
@@ -248,12 +268,10 @@ void LocationDialog::updateFromProgram(const StelLocation& currentLocation)
 		ui->pushButtonReturnToDefault->setEnabled(!b);
 	}
 
-	const QString& key1 = currentLocation.getID();
-	const QString& key2 = locationFromFields().getID();
-	if (key1!=key2)
-	{
-		setFieldsFromLocation(currentLocation);
-	}
+	if (newLocation.role!='o')
+		GETSTELMODULE(StelMovementMgr)->setFlagTracking(false);
+	setFieldsFromLocation(newLocation);
+	setLocationUIvisible(newLocation.role!='o'); // hide various detail settings when changing to an "observer"
 }
 
 void LocationDialog::disconnectEditSignals()
@@ -261,9 +279,9 @@ void LocationDialog::disconnectEditSignals()
 	disconnect(ui->longitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setLocationFromCoords()));
 	disconnect(ui->latitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setLocationFromCoords()));
 	disconnect(ui->altitudeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(setLocationFromCoords(int)));
-	disconnect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(moveToAnotherPlanet(const QString&)));	
-	disconnect(ui->regionNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(reportEdit()));
-	disconnect(ui->timeZoneNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(saveTimeZone()));
+	disconnect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const int)), this, SLOT(moveToAnotherPlanet()));
+	disconnect(ui->regionNameComboBox, SIGNAL(currentIndexChanged(const int)), this, SLOT(reportEdit()));
+	disconnect(ui->timeZoneNameComboBox, SIGNAL(currentIndexChanged(const int)), this, SLOT(saveTimeZone()));
 	disconnect(ui->cityNameLineEdit, SIGNAL(textEdited(const QString&)), this, SLOT(reportEdit()));
 }
 
@@ -272,12 +290,33 @@ void LocationDialog::connectEditSignals()
 	connect(ui->longitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setLocationFromCoords()));
 	connect(ui->latitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setLocationFromCoords()));
 	connect(ui->altitudeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(setLocationFromCoords(int)));
-	connect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(moveToAnotherPlanet(const QString&)));
-	connect(ui->regionNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(reportEdit()));
-	connect(ui->timeZoneNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(saveTimeZone()));
+	connect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const int)), this, SLOT(moveToAnotherPlanet()));
+	connect(ui->regionNameComboBox, SIGNAL(currentIndexChanged(const int)), this, SLOT(reportEdit()));
+	connect(ui->timeZoneNameComboBox, SIGNAL(currentIndexChanged(const int)), this, SLOT(saveTimeZone()));
 	connect(ui->cityNameLineEdit, SIGNAL(textEdited(const QString&)), this, SLOT(reportEdit()));
 }
 
+void LocationDialog::setLocationUIvisible(bool visible)
+{
+	ui->frame_coordinates->setVisible(visible);
+	ui->regionNameComboBox->setVisible(visible);
+	ui->labelRegion->setVisible(visible);
+	ui->cityNameLineEdit->setVisible(visible);
+	ui->labelName->setVisible(visible);
+	ui->frame_citylist->setVisible(visible);
+	ui->mapWidget->setMarkerVisible(visible);
+	if(visible)
+	{
+		connect(ui->mapWidget, SIGNAL(positionChanged(double, double, const QColor&)), this, SLOT(setLocationFromMap(double, double, const QColor&)), Qt::UniqueConnection);
+	}
+	else
+	{
+		disconnect(ui->mapWidget, SIGNAL(positionChanged(double, double, const QColor&)), this, SLOT(setLocationFromMap(double, double, const QColor&)));
+	}
+	ui->addLocationToListPushButton->setVisible(visible);
+	ui->deleteLocationFromListPushButton->setVisible(visible);
+}
+
 void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 {
 	StelCore *core = StelApp::getInstance().getCore();
@@ -290,12 +329,12 @@ void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 		customTimeZone=core->getCurrentTimeZone();
 
 	ui->cityNameLineEdit->setText(loc.name);
-	ui->longitudeSpinBox->setDegrees(loc.longitude);
-	ui->latitudeSpinBox->setDegrees(loc.latitude);
+	ui->longitudeSpinBox->setDegrees(loc.getLongitude(true));
+	ui->latitudeSpinBox->setDegrees(loc.getLatitude(true));
 	ui->altitudeSpinBox->setValue(loc.altitude);
 
 	int idx = ui->planetNameComboBox->findData(loc.planetName, Qt::UserRole, Qt::MatchCaseSensitive);
-	if (idx==-1)
+	if (idx<0)
 	{
 		// Use Earth as default
 		idx = ui->planetNameComboBox->findData(QVariant("Earth"), Qt::UserRole, Qt::MatchCaseSensitive);
@@ -303,7 +342,7 @@ void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 	ui->planetNameComboBox->setCurrentIndex(idx);
 
 	idx = ui->regionNameComboBox->findData(loc.region, Qt::UserRole, Qt::MatchCaseSensitive);
-	if (idx==-1)
+	if (idx<0)
 	{
 		if (ui->planetNameComboBox->currentData(Qt::UserRole).toString()=="Earth")
 		{
@@ -341,7 +380,6 @@ void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 	core->setCurrentTimeZone(tz);
 
 	setMapForLocation(loc);
-	ui->mapLabel->setCursorPos(loc.longitude, loc.latitude);
 
 	ui->deleteLocationFromListPushButton->setEnabled(StelApp::getInstance().getLocationMgr().canDeleteUserLocation(loc.getID()));
 
@@ -350,7 +388,7 @@ void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 	StelModule* ls = StelApp::getInstance().getModule("LandscapeMgr");
 	if (ls->property("flagEnvironmentAutoEnable").toBool())
 	{
-		if (loc.planetName != StelApp::getInstance().getCore()->getCurrentLocation().planetName)
+		if (loc.planetName != core->getCurrentLocation().planetName)
 		{
 			QSettings* conf = StelApp::getInstance().getSettings();
 			ls->setProperty("atmosphereDisplayed", p->hasAtmosphere() && conf->value("landscape/flag_atmosphere", true).toBool());
@@ -366,38 +404,35 @@ void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 void LocationDialog::setMapForLocation(const StelLocation& loc)
 {
 	// Avoids useless processing
-	if (lastPlanet==loc.planetName)
-		return;
-
-	QPixmap pixmap;
-	// Try to set the proper planet map image
-	if (loc.planetName=="Earth")
+	if (lastPlanet!=loc.planetName)
 	{
-		// Special case for earth, we don't want to see the clouds
-		pixmap = QPixmap(":/graphicGui/miscWorldMap.png");
-	}
-	else
-	{
-		SolarSystem* ssm = GETSTELMODULE(SolarSystem);
-		PlanetP p = ssm->searchByEnglishName(loc.planetName);
-		if (p)
+		QPixmap pixmap;
+		// Try to set the proper planet map image
+		if (loc.planetName=="Earth")
 		{
-			QString path = StelFileMgr::findFile("textures/"+p->getTextMapName());
-			if (path.isEmpty())
-			{
-				qWarning() << "ERROR - could not find planet map for " << loc.planetName;
-				return;
-			}
-			pixmap = QPixmap(path);
+			// Special case for earth, we don't want to see the clouds
+			pixmap = QPixmap(":/graphicGui/miscWorldMap.jpg");
 		}
+		else
+		{
+			SolarSystem* ssm = GETSTELMODULE(SolarSystem);
+			PlanetP p = ssm->searchByEnglishName(loc.planetName);
+			if (p)
+			{
+				QString path = StelFileMgr::findFile("textures/"+p->getTextMapName());
+				if (path.isEmpty())
+				{
+					qWarning() << "ERROR - could not find planet map for " << loc.planetName;
+					return;
+				}
+				pixmap = QPixmap(path);
+			}
+		}
+		ui->mapWidget->setMap(pixmap);
+		// For caching
+		lastPlanet = loc.planetName;
 	}
-	StelCore * core = StelApp::getInstance().getCore();
-	pixmap.setDevicePixelRatio(core->getCurrentStelProjectorParams().devicePixelsPerPixel);
-	ui->mapLabel->setPixmap(pixmap);
-	ui->mapLabel->resizePixmap();
-	ui->mapLabel->setCursorPos(loc.longitude, loc.latitude);
-	// For caching
-	lastPlanet = loc.planetName;
+	ui->mapWidget->setMarkerPos(loc.getLongitude(), loc.getLatitude());
 }
 
 void LocationDialog::populatePlanetList()
@@ -439,7 +474,7 @@ void LocationDialog::populateRegionList(const QString& planet)
 	regionCombo->clear();
 	//For each region, display the localized name and store the original as user
 	//data. Unfortunately, there's no other way to do this than with a loop.
-	for (const auto& name : qAsConst(regionNames))
+	for (const auto& name : std::as_const(regionNames))
 		regionCombo->addItem(q_(name), name);
 
 	regionCombo->addItem(QChar(0x2014), "");
@@ -458,7 +493,7 @@ void LocationDialog::populateTimeZonesList()
 	// Return a list of all the known time zone names (from Qt)
 	QStringList tzNames;
 	auto tzList = QTimeZone::availableTimeZoneIds(); // System dependent set of IANA timezone names.
-	for (const auto& tz : qAsConst(tzList))
+	for (const auto& tz : std::as_const(tzList))
 	{
 		tzNames.append(tz);
 		// Activate this to get a list of known TZ names...
@@ -466,6 +501,49 @@ void LocationDialog::populateTimeZonesList()
 	}
 	tzNames.sort();
 
+	// Special sort for UTC+XX:YY time zones: we want them
+	// to go from the most negative to the most positive.
+	static const QRegularExpression utcRegEx("^UTC([+-])(\\d\\d):(\\d\\d)$");
+	std::vector<int> utcOffsets;
+	for(int n = 0; n < tzNames.size();)
+	{
+		const auto match = utcRegEx.match(tzNames[n]);
+		if(match.lastCapturedIndex() != 3)
+		{
+			++n;
+			continue;
+		}
+		tzNames.removeAt(n);
+		const int sign = match.captured(1)=="-" ? -1 : 1;
+		const int hour      = match.captured(2).toInt();
+		const int minute    = match.captured(3).toInt();
+		// Encode with a shift by ±1 to distinguish UTC±00:00
+		utcOffsets.push_back(sign * (100 * hour + minute + 1));
+	}
+	std::sort(utcOffsets.begin(), utcOffsets.end());
+	for(const auto offset : utcOffsets)
+	{
+		const auto hm = std::abs(offset) - 1;
+		const auto hour   = hm / 100;
+		const auto minute = hm % 100;
+		tzNames.push_back(QString("UTC%1%2:%3").arg(offset > 0 ? "+" : "-")
+											   .arg(hour  , 2, 10, QChar('0'))
+											   .arg(minute, 2, 10, QChar('0')));
+	}
+
+	if(!utcOffsets.empty())
+	{
+		// If we have UTC offsets, the Etc/GMT±x time zones are not useful. In
+		// addition, they'd also need re-sorting, so let's just remove them.
+		for(int n = 0; n < tzNames.size();)
+		{
+			if(tzNames[n].startsWith("Etc/GMT"))
+				tzNames.removeAt(n);
+			else
+				++n;
+		}
+	}
+
 	//Save the current selection to be restored later
 	tzCombo->blockSignals(true);
 	int index = tzCombo->currentIndex();
@@ -482,11 +560,9 @@ void LocationDialog::populateTimeZonesList()
 	tzCombo->addItem(q_("System default"), "system_default");
 	//Restore the selection
 	index = tzCombo->findData(selectedTzId, Qt::UserRole, Qt::MatchCaseSensitive);
-	// TODO: Handle notfound!?
-	if (index==-1)
-	{
+	if (index==-1) // the TZ is not found
 		index=tzCombo->count()-1; // should point to system_default.
-	}
+
 	Q_ASSERT(index!=-1);
 	tzCombo->setCurrentIndex(index);
 	tzCombo->blockSignals(false);
@@ -505,8 +581,8 @@ StelLocation LocationDialog::locationFromFields() const
 	else
 		loc.planetName = ui->planetNameComboBox->itemData(index).toString();
 	loc.name = ui->cityNameLineEdit->text().trimmed(); // avoid locations with leading whitespace
-	loc.latitude = qBound(-90.0, ui->latitudeSpinBox->valueDegrees(), 90.0);
-	loc.longitude = ui->longitudeSpinBox->valueDegrees();
+	loc.setLatitude(qBound(-90.0, ui->latitudeSpinBox->valueDegrees(), 90.0));
+	loc.setLongitude(ui->longitudeSpinBox->valueDegrees());
 	loc.altitude = ui->altitudeSpinBox->value();
 	index = ui->regionNameComboBox->currentIndex();
 	if (index < 0)
@@ -541,17 +617,22 @@ void LocationDialog::setLocationFromList(const QModelIndex& index)
 	// This calls indirectly updateFromProgram()
 }
 
-void LocationDialog::setLocationFromMap(double longitude, double latitude)
+void LocationDialog::setLocationFromMap(double longitude, double latitude, const QColor &color)
 {
 	StelCore *core = StelApp::getInstance().getCore();
 	if (core->getUseCustomTimeZone())
 		customTimeZone=core->getCurrentTimeZone();
 	reportEdit();
 	StelLocation loc = locationFromFields();
-	loc.latitude = latitude;
-	loc.longitude = longitude;
+	loc.setLatitude(latitude);
+	loc.setLongitude(longitude);
+	loc.name= QString("%1, %2").arg(loc.getLatitude()).arg(loc.getLongitude()); // Force a preliminary name
 	setFieldsFromLocation(loc);
-	core->moveObserverTo(loc, 0.);
+	if (loc.planetName=="Earth")
+		core->moveObserverTo(loc, 0., 1., GETSTELMODULE(LandscapeMgr)->getFlagLandscapeAutoSelection() ? QString("ZeroColor(%1)").arg(Vec3f(color).toStr()) : QString());
+	else
+		core->moveObserverTo(loc, 0., 1., loc.planetName); // Loads a default landscape for the planet.
+
 	// Only for locations on Earth: set zone to LMST.
 	// TODO: Find a way to lookup (lon,lat)->country->timezone.
 
@@ -569,27 +650,28 @@ void LocationDialog::setLocationFromMap(double longitude, double latitude)
 }
 
 // Called when the planet name is changed by hand
-void LocationDialog::moveToAnotherPlanet(const QString&)
+void LocationDialog::moveToAnotherPlanet()
 {
 	reportEdit();
 	StelLocation loc = locationFromFields();
 	StelCore* stelCore = StelApp::getInstance().getCore();
-	StelModule* lMgr = StelApp::getInstance().getModule("LandscapeMgr");
+	LandscapeMgr *lMgr = GETSTELMODULE(LandscapeMgr);
 	populateRegionList(loc.planetName);
 	if (loc.planetName != stelCore->getCurrentLocation().planetName)
 	{
 		setFieldsFromLocation(loc);
-		if (lMgr->property("flagLandscapeAutoSelection").toBool())
+		if (lMgr->getFlagLandscapeAutoSelection())
 		{
-			// If we have a landscape for selected planet then set it, otherwise use default landscape
+			// If we have a landscape for selected planet then set it, otherwise use zero landscape
 			// Details: https://bugs.launchpad.net/stellarium/+bug/1173254
-			if (lMgr->property("allLandscapeNames").toStringList().indexOf(loc.planetName)>0)
-				lMgr->setProperty("currentLandscapeName", loc.planetName);
+			if (lMgr->getAllLandscapeNames().contains(loc.planetName))
+				lMgr->setCurrentLandscapeName(loc.planetName); // TODO: Why not setCurrentLandscapeID?
 			else
-				lMgr->setProperty("currentLandscapeID", lMgr->property("defaultLandscapeID"));
+				//lMgr->setProperty("currentLandscapeID", lMgr->property("defaultLandscapeID"));
+				lMgr->setCurrentLandscapeID("zero"); // harmonize with LandscapeMgr::onTargetLocationChanged()
 		}
 
-		// GZ populate site list with sites only from that planet, or full list for Earth (faster than removing the ~50 non-Earth positions...).
+		// populate site list with sites only from that planet, or full list for Earth (faster than removing the ~50 non-Earth positions...).
 		StelLocationMgr &locMgr=StelApp::getInstance().getLocationMgr();
 		if (loc.planetName == "Earth")
 		{
@@ -608,9 +690,41 @@ void LocationDialog::moveToAnotherPlanet(const QString&)
 		proxyModel->sort(0, Qt::AscendingOrder);
 		ui->citySearchLineEdit->setText(""); // https://wiki.qt.io/Technical_FAQ#Why_does_the_memory_keep_increasing_when_repeatedly_pasting_text_and_calling_clear.28.29_in_a_QLineEdit.3F
 		ui->citySearchLineEdit->setFocus();
-		stelCore->moveObserverTo(loc, 0., 0.);
+
+		// If we change to an Observer "planet", auto-select and focus on the observed object.
+		StelObjectMgr *soMgr=GETSTELMODULE(StelObjectMgr);
+		SolarSystem *ss=GETSTELMODULE(SolarSystem);
+		PlanetP planet=nullptr;
+		if (ss)
+			planet=GETSTELMODULE(SolarSystem)->searchByEnglishName(loc.planetName);
+		if (planet && planet->getPlanetType()==Planet::isObserver)
+		{
+			setLocationUIvisible(false);
+
+			loc.role=QChar('o'); // Mark this ad-hoc location as "observer".
+			if (soMgr)
+			{
+				soMgr->findAndSelect(planet->getParent()->getEnglishName());
+				GETSTELMODULE(StelMovementMgr)->setFlagTracking(true);
+			}
+		}
+		else
+		{
+			GETSTELMODULE(StelMovementMgr)->setFlagTracking(false);
+			setLocationUIvisible(true);
+			GETSTELMODULE(StelMovementMgr)->resetInitViewPos();
+			// Get rid of selection if we are standing on it...
+			if (soMgr)
+			{
+				const QList<StelObjectP>& selection=soMgr->getSelectedObject();
+				if (!selection.isEmpty() && selection[0]->getEnglishName()==loc.planetName)
+						soMgr->unSelect();
+			}
+		}
+
+		stelCore->moveObserverTo(loc, 0., 0., loc.planetName);
 	}
-	// Planet transition time also set to null to prevent uglyness when
+	// Planet transition time also set to null to prevent ugliness when
 	// "use landscape location" is enabled for that planet's landscape. --BM
 	// NOTE: I think it also makes sense in the other cases. --BM
 }
@@ -620,9 +734,9 @@ void LocationDialog::setLocationFromCoords(int i)
 	Q_UNUSED(i)
 	reportEdit();
 	StelLocation loc = locationFromFields();
-	StelApp::getInstance().getCore()->moveObserverTo(loc, 0.);
+	StelApp::getInstance().getCore()->moveObserverTo(loc, 0.); // No landscape update: This may be used for finetuning within a landscape
 	//Update the position of the map pointer
-	ui->mapLabel->setCursorPos(loc.longitude, loc.latitude);
+	ui->mapWidget->setMarkerPos(loc.getLongitude(), loc.getLatitude());
 }
 
 void LocationDialog::saveTimeZone()
@@ -718,10 +832,7 @@ void LocationDialog::setDefaultLocation(bool state)
 	{
 		StelCore* core = StelApp::getInstance().getCore();
 		QString currentLocationId = core->getCurrentLocation().getID();
-		core->setDefaultLocationID(currentLocationId);
-
-		// Why this code even exists? After the previous code, this should always
-		// be true, except if setting the default location somehow fails. --BM
+		core->setDefaultLocationID(currentLocationId); // May fail for invalid locations. Therefore test:
 		bool isDefault = (currentLocationId == core->getDefaultLocationID());
 		disconnectEditSignals();
 		updateDefaultLocationControls(isDefault);
@@ -822,7 +933,6 @@ void LocationDialog::gpsReturn(bool success)
 		StelCore* core = StelApp::getInstance().getCore();
 
 		gpsCount++;
-		ui->gpsToolButton->setText(QString("%1 %2").arg(q_("GPS location fix")).arg(gpsCount));
 		ui->useAsDefaultLocationCheckBox->setChecked(false);
 		ui->pushButtonReturnToDefault->setEnabled(true);
 		//ui->useCustomTimeZoneCheckBox->setChecked(true); // done by updateTimeZoneControls(true) below.
@@ -833,15 +943,17 @@ void LocationDialog::gpsReturn(bool success)
 		setFieldsFromLocation(loc);
 		if (loc.altitude==0) // give feedback of fix quality.
 		{
+			ui->gpsToolButton->setText(QString("%1 %2").arg(q_("2D location fix")).arg(gpsCount));
 			ui->gpsToolButton->setStyleSheet(QString("QToolButton{ background: yellow; }"));
 		}
 		else
 		{
+			ui->gpsToolButton->setText(QString("%1 %2").arg(q_("3D location fix")).arg(gpsCount));
 			ui->gpsToolButton->setStyleSheet(QString("QToolButton{ background: green; }"));
 		}
 		QSettings* conf = StelApp::getInstance().getSettings();
 		conf->setValue("init_location/location", loc.getID());
-		conf->setValue("init_location/last_location", QString("%1, %2, %3").arg(loc.latitude).arg(loc.longitude).arg(loc.altitude));
+		conf->setValue("init_location/last_location", QString("%1, %2, %3").arg(loc.getLatitude()).arg(loc.getLongitude()).arg(loc.altitude));
 	}
 	else
 	{
@@ -857,8 +969,12 @@ void LocationDialog::gpsReturn(bool success)
 void LocationDialog::resetGPSbuttonLabel()
 {
 	ui->gpsToolButton->setChecked(false);
+#ifdef Q_OS_WIN
+	ui->gpsToolButton->setText(q_("Get location from GPS or system service"));
+#else
 	ui->gpsToolButton->setText(q_("Get location from GPS"));
-	ui->gpsToolButton->setStyleSheet(QString("QToolButton{ background: gray; }"));
+#endif
+	ui->gpsToolButton->setStyleSheet("");
 }
 #endif
 
@@ -868,11 +984,26 @@ void LocationDialog::resetLocationList()
 	//reset search before setting model, prevents unnecessary search in full list
 	ui->citySearchLineEdit->setText(""); // https://wiki.qt.io/Technical_FAQ#Why_does_the_memory_keep_increasing_when_repeatedly_pasting_text_and_calling_clear.28.29_in_a_QLineEdit.3F
 	ui->citySearchLineEdit->setFocus();
-	proxyModel->setSourceModel(allModel);
+
+	// populate site list with sites only from that planet, or full list for Earth (faster than removing the ~50 non-Earth positions...).
+	StelLocationMgr &locMgr=StelApp::getInstance().getLocationMgr();
+	StelLocation loc = locationFromFields();
+	if (loc.planetName == "Earth")
+	{
+		proxyModel->setSourceModel(allModel);
+	}
+	else
+	{
+		LocationMap results = locMgr.pickLocationsNearby(loc.planetName, 0.0f, 0.0f, 180.0f);
+		pickedModel->setStringList(results.keys());
+		proxyModel->setSourceModel(pickedModel);
+		ui->regionNameComboBox->setCurrentIndex(ui->regionNameComboBox->findData("", Qt::UserRole, Qt::MatchCaseSensitive));
+	}
+
 	proxyModel->sort(0, Qt::AscendingOrder);
 }
 
-// called when user clicks in the country combobox and selects a country. The locations in the list are updated to select only sites in that country.
+// called when user clicks in the region combobox and selects a region. The locations in the list are updated to select only sites in that region.
 void LocationDialog::filterSitesByRegion()
 {
 	QString region=ui->regionNameComboBox->currentData(Qt::UserRole).toString();
