@@ -34,18 +34,16 @@ class LocationDialog : public StelDialog
 	Q_OBJECT
 public:
 	LocationDialog(QObject* parent);
-	virtual ~LocationDialog() Q_DECL_OVERRIDE;
-	//! Notify that the application style changed
-	virtual void styleChanged() Q_DECL_OVERRIDE;
+	~LocationDialog() override;
 
 public slots:
-	virtual void retranslate() Q_DECL_OVERRIDE;
-	//! In addition to StelDialog's inherited solution, puts the arrow on the right spot in the map.
-	virtual void handleDialogSizeChanged(QSizeF size) Q_DECL_OVERRIDE;
+	//! Apply application style change
+	void styleChanged(const QString &style) override;
+	void retranslate() override;
 
 protected:
 	//! Initialize the dialog widgets and connect the signals/slots
-	virtual void createDialogContent() Q_DECL_OVERRIDE;
+	void createDialogContent() override;
 	Ui_locationDialogForm* ui;
 
 private:
@@ -61,6 +59,9 @@ private:
 	
 	void disconnectEditSignals();
 	void connectEditSignals();
+
+	//! show or hide UI elements to edit location (Hide if on observer planet!)
+	void setLocationUIvisible(bool visible);
 	
 	//! Update the map for the given location.
 	void setMapForLocation(const StelLocation& loc);
@@ -101,17 +102,19 @@ private slots:
 	
 	//! Update the widget to make sure it is synchrone if the location is changed programmatically
 	//! This function should be called repeatidly with e.g. a timer
-	void updateFromProgram(const StelLocation& location);
+	void updateFromProgram(const StelLocation& newLocation);
 	
 	//! Called when the map is clicked.
-	//! create new list for places nearby and feed into location list box.
-	void setLocationFromMap(double longitude, double latitude);
+	//! Creates new list for places nearby and feed into location list box.
+	//! Sets lolcation to the clicked location
+	//! Also signals (for locations on Earth only) to LandscapeMgr to load zero landscape with just the color of the clicked point.
+	void setLocationFromMap(double longitude, double latitude, const QColor &color);
 	
 	//! Called when the user activates an item from the locations list.
 	void setLocationFromList(const QModelIndex& index);
 	
 	//! Called when the planet is manually changed.
-	void moveToAnotherPlanet(const QString& text);
+	void moveToAnotherPlanet();
 
 	//! Called when latitude/longitude/altitude is modified
 	//! The int argument is required by the Altitude spinbox signal connection, but unused.
