@@ -167,9 +167,9 @@ QString SearchDialog::extSearchText = "";
 
 SearchDialog::SearchDialog(QObject* parent)
 	: StelDialog("Search", parent)
-	, simbadReply(Q_NULLPTR)
-	, listModel(Q_NULLPTR)
-	, proxyModel(Q_NULLPTR)
+	, simbadReply(nullptr)
+	, listModel(nullptr)
+	, proxyModel(nullptr)
 	, flagHasSelectedText(false)
 	, shiftPressed(false)
 {
@@ -183,6 +183,7 @@ SearchDialog::SearchDialog(QObject* parent)
 	conf = StelApp::getInstance().getSettings();
 	enableSimbadSearch(conf->value("search/flag_search_online", true).toBool());
 	useStartOfWords = conf->value("search/flag_start_words", false).toBool();
+	useLengthSorting = conf->value("search/flag_sorting_length", false).toBool();
 	useLockPosition = conf->value("search/flag_lock_position", true).toBool();
 	useFOVCenterMarker = conf->value("search/flag_fov_center_marker", true).toBool();
 	fovCenterMarkerState = GETSTELMODULE(SpecialMarkersMgr)->getFlagFOVCenterMarker();
@@ -210,7 +211,7 @@ SearchDialog::~SearchDialog()
 	if (simbadReply)
 	{
 		simbadReply->deleteLater();
-		simbadReply = Q_NULLPTR;
+		simbadReply = nullptr;
 	}
 }
 
@@ -231,7 +232,7 @@ void SearchDialog::retranslate()
 
 void SearchDialog::setCurrentCoordinateSystemKey(QString key)
 {
-	const QMetaEnum& en = metaObject()->enumerator(metaObject()->indexOfEnumerator("CoordinateSystem"));
+	const QMetaEnum& en = SearchDialog::metaObject()->enumerator(SearchDialog::metaObject()->indexOfEnumerator("CoordinateSystem"));
 	CoordinateSystem coordSystem = static_cast<CoordinateSystem>(en.keyToValue(key.toLatin1().data()));
 	if (coordSystem<0)
 	{
@@ -360,8 +361,8 @@ void SearchDialog::createDialogContent()
 	ui->setupUi(dialog);
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	connect(&StelApp::getInstance(), SIGNAL(flagShowDecimalDegreesChanged(bool)), this, SLOT(populateCoordinateAxis()));
-	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
-	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
+	connect(ui->titleBar, &TitleBar::closeClicked, this, &StelDialog::close);
+	connect(ui->titleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 	connect(ui->lineEditSearchSkyObject, SIGNAL(textChanged(const QString&)), this, SLOT(onSearchTextChanged(const QString&)));
 	connect(ui->simbadCooQueryButton, SIGNAL(clicked()), this, SLOT(lookupCoordinates()));
 	connect(GETSTELMODULE(StelObjectMgr), SIGNAL(selectedObjectChanged(StelModule::StelModuleSelectAction)), this, SLOT(clearSimbadText(StelModule::StelModuleSelectAction)));
@@ -391,6 +392,7 @@ void SearchDialog::createDialogContent()
 	connect(ui->coordinateSystemComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(setCoordinateSystem(int)));
 	connect(ui->AxisXSpinBox, SIGNAL(valueChanged()), this, SLOT(manualPositionChanged()));
 	connect(ui->AxisYSpinBox, SIGNAL(valueChanged()), this, SLOT(manualPositionChanged()));
+	connect(ui->goPushButton, SIGNAL(clicked(bool)), this, SLOT(manualPositionChanged()));
 	
 	connect(ui->alphaPushButton, SIGNAL(clicked(bool)), this, SLOT(greekLetterClicked()));
 	connect(ui->betaPushButton, SIGNAL(clicked(bool)), this, SLOT(greekLetterClicked()));
@@ -435,6 +437,8 @@ void SearchDialog::createDialogContent()
 
 	connect(ui->checkBoxUseStartOfWords, SIGNAL(clicked(bool)), this, SLOT(enableStartOfWordsAutofill(bool)));
 	ui->checkBoxUseStartOfWords->setChecked(useStartOfWords);
+	connect(ui->checkBoxUseSortingByLength, SIGNAL(clicked(bool)), this, SLOT(enableSortingByLength(bool)));
+	ui->checkBoxUseSortingByLength->setChecked(useLengthSorting);
 
 	connect(ui->checkBoxFOVCenterMarker, SIGNAL(clicked(bool)), this, SLOT(enableFOVCenterMarker(bool)));
 	ui->checkBoxFOVCenterMarker->setChecked(useFOVCenterMarker);
@@ -460,12 +464,7 @@ void SearchDialog::createDialogContent()
 	connect(ui->tabWidget, SIGNAL(currentChanged(int)), this, SLOT(changeTab(int)));
 	connect(this, SIGNAL(visibleChanged(bool)), this, SLOT(refreshFocus(bool)));
 	connect(StelApp::getInstance().getCore(), SIGNAL(updateSearchLists()), this, SLOT(updateListTab()));
-	connect(GETSTELMODULE(NomenclatureMgr), SIGNAL(nomenclatureDisplayedChanged(bool)), this, SLOT(updateListTab()));
-
-	QString style = "QLabel { color: rgb(238, 238, 238); }";
-	ui->simbadStatusLabel->setStyleSheet(style);
-	ui->labelGreekLetterTitle->setStyleSheet(style);
-	ui->simbadCooStatusLabel->setStyleSheet(style);
+	connect(GETSTELMODULE(NomenclatureMgr), SIGNAL(flagShowNomenclatureChanged(bool)), this, SLOT(updateListTab()));
 
 	// Get data from previous session
 	loadRecentSearches();
@@ -594,7 +593,7 @@ void SearchDialog::recentSearchSizeEditingFinished()
 	// Update max size in dialog and user data
 	int maxSize = ui->recentSearchSizeSpinBox->value();
 	setRecentSearchSize(maxSize);
-	maxSize = recentObjectSearchesData.maxSize; // Might not be the same
+	// maxSize = recentObjectSearchesData.maxSize; // Might not be the same. BUT USELESS call, dead store!
 
 	// Save maxSize to user's data
 	saveRecentSearches();
@@ -617,12 +616,11 @@ void SearchDialog::recentSearchClearDataClicked()
 
 void SearchDialog::setRecentSearchClearDataPushButton()
 {
-	// Enable clear button if recent list is greater than 0
-	bool toEnable = recentObjectSearchesData.recentList.size() > 0;
+	// Enable clear button if recent list is not empty
+	bool toEnable = !recentObjectSearchesData.recentList.isEmpty();
 	ui->recentSearchClearDataPushButton->setEnabled(toEnable);
 	// Tool tip depends on recent list size
-	QString toolTipText;
-	toolTipText = toEnable ? q_("Clear search history: delete all search objects data") : q_("Clear search history: no data to delete");
+	QString toolTipText = toEnable ? q_("Clear search history: delete all search objects data") : q_("Clear search history: no data to delete");
 	ui->recentSearchClearDataPushButton->setToolTip(toolTipText);
 }
 
@@ -635,6 +633,15 @@ void SearchDialog::enableStartOfWordsAutofill(bool enable)
 	onSearchTextChanged(ui->lineEditSearchSkyObject->text());
 }
 
+void SearchDialog::enableSortingByLength(bool enable)
+{
+	useLengthSorting = enable;
+	conf->setValue("search/flag_sorting_length", useLengthSorting);
+
+	// Update search result on "Object" tab
+	onSearchTextChanged(ui->lineEditSearchSkyObject->text());
+}
+
 void SearchDialog::enableLockPosition(bool enable)
 {
 	useLockPosition = enable;
@@ -778,7 +785,7 @@ void SearchDialog::onSearchTextChanged(const QString& text)
 		{
 			disconnect(simbadReply, SIGNAL(statusChanged()), this, SLOT(onSimbadStatusChanged()));
 			delete simbadReply;
-			simbadReply=Q_NULLPTR;
+			simbadReply=nullptr;
 		}
 		simbadResults.clear();
 	}
@@ -815,12 +822,12 @@ void SearchDialog::onSearchTextChanged(const QString& text)
 
 		QString greekText = substituteGreek(trimmedText);
 
-		int trimmedTextMaxNbItem = 13;
+		int trimmedTextMaxNbItem = 50;
 		int greekTextMaxMbItem = 0;
 
 		if(greekText != trimmedText)
 		{
-			trimmedTextMaxNbItem = 8;
+			trimmedTextMaxNbItem = 50;
 			greekTextMaxMbItem = 18;
 
 			// Get recent matches
@@ -837,7 +844,7 @@ void SearchDialog::onSearchTextChanged(const QString& text)
 		}
 		else
 		{
-			trimmedTextMaxNbItem = 13;
+			trimmedTextMaxNbItem = 50;
 
 			// Get recent matches
 			recentMatches = listMatchingRecentObjects(trimmedText, trimmedTextMaxNbItem, useStartOfWords);
@@ -911,7 +918,7 @@ void SearchDialog::adjustMatchesResult(QStringList &allMatches, QStringList& rec
 	stringLengthCompare comparator;
 	std::sort(matches.begin(), matches.end(), comparator);
 
-	// Adjust recent matches to prefered max size
+	// Adjust recent matches to preferred max size
 	recentMatches = recentMatches.mid(0, recentObjectSearchesData.maxSize);
 
 	// Find total size of both matches
@@ -1054,6 +1061,13 @@ QStringList SearchDialog::listMatchingRecentObjects(const QString& objPrefix, in
 		if (result.size() >= maxNbItem)
 			break;
 	}
+
+	if (useLengthSorting)
+	{
+		stringLengthCompare comparator;
+		std::sort(result.begin(), result.end(), comparator);
+	}
+
 	return result;
 }
 
@@ -1121,7 +1135,7 @@ void SearchDialog::onSimbadStatusChanged()
 	{
 		disconnect(simbadReply, SIGNAL(statusChanged()), this, SLOT(onSimbadStatusChanged()));
 		delete simbadReply;
-		simbadReply=Q_NULLPTR;
+		simbadReply=nullptr;
 
 		// Update push button enabled state
 		setPushButtonGotoSearch();
@@ -1257,13 +1271,12 @@ void SearchDialog::gotoObject(const QModelIndex &modelIndex)
 void SearchDialog::gotoObjectWithType(const QModelIndex &modelIndex)
 {
 	QString objType, objClass = ui->objectTypeComboBox->currentData(Qt::UserRole).toString();
-	QStringList list;
 	if (objClass.contains(":"))
 	{
 		#if (QT_VERSION>=QT_VERSION_CHECK(5, 14, 0))
-		list = objClass.split(":", Qt::SkipEmptyParts);
+		QStringList list = objClass.split(":", Qt::SkipEmptyParts);
 		#else
-		list = objClass.split(":", QString::SkipEmptyParts);
+		QStringList list = objClass.split(":", QString::SkipEmptyParts);
 		#endif
 		objType = list.at(0);
 	}
@@ -1275,11 +1288,13 @@ void SearchDialog::gotoObjectWithType(const QModelIndex &modelIndex)
 	objType.replace("Nomenclature","NomenclatureItem");
 	// plug-ins
 	objType.replace("Supernovae","Supernova");
+	objType.replace("Satellites","Satellite");
 	objType.replace("Novae","Nova");
 	objType.replace("Exoplanets","Exoplanet");
 	objType.replace("Pulsars","Pulsar");
 	objType.replace("Quasars","Quasar");
 	objType.replace("MeteorShowers","MeteorShower");
+	objType.replace("MissingStars","MissingStar");
 
 	gotoObject(modelIndex.model()->data(modelIndex, Qt::DisplayRole).toString(), objType);
 }
@@ -1483,7 +1498,7 @@ void SearchDialog::pasteAndGo()
 	// https://wiki.qt.io/Technical_FAQ#Why_does_the_memory_keep_increasing_when_repeatedly_pasting_text_and_calling_clear.28.29_in_a_QLineEdit.3F
 	ui->lineEditSearchSkyObject->setText(""); // clear current text
 	ui->lineEditSearchSkyObject->paste(); // paste text from clipboard
-	gotoObject(); // go to first finded object
+	gotoObject(); // go to first found object
 }
 
 void SearchDialog::setVisible(bool v)
