@@ -81,20 +81,20 @@ public:
 	friend class ViewDialog;
 	
 	StelGui();
-	virtual ~StelGui() Q_DECL_OVERRIDE;
+	~StelGui() override;
 
 	///////////////////////////////////////////////////////////////////////////
 	// Methods defined in the StelModule class
 	//! Initialize the StelGui object.
-	virtual void init(QGraphicsWidget* topLevelGraphicsWidget) Q_DECL_OVERRIDE;
+	void init(QGraphicsWidget* topLevelGraphicsWidget) override;
 	void update();
 
 	StelStyle getStelStyle() const {return currentStelStyle;}
 	
 	///////////////////////////////////////////////////////////////////////////
 	// Methods specific to the StelGui class
-	//! Load a Qt style sheet to define the widgets style
-	void loadStyle(const QString& fileName);
+	// ! Load a Qt style sheet to define the widgets style
+	//void loadStyle(const QString& fileName);
 	
 	//! Get the button bar at the bottom of the screen
 	BottomStelBar* getButtonBar() const;
@@ -114,18 +114,18 @@ public:
 #endif
 
 	//! Used to force a refreshing of the GUI elements such as the button bars.
-	virtual void forceRefreshGui() Q_DECL_OVERRIDE;
+	void forceRefreshGui() override;
 	
-	virtual void setVisible(bool b) Q_DECL_OVERRIDE;
+	void setVisible(bool b) override;
 
-	virtual bool getVisible() const Q_DECL_OVERRIDE;
+	bool getVisible() const override;
 
-	virtual bool getAstroCalcVisible() const;
+	bool getAstroCalcVisible() const;
 
-	virtual bool isCurrentlyUsed() const Q_DECL_OVERRIDE;
+	bool isCurrentlyUsed() const override;
 	
-	virtual void setInfoTextFilters(const StelObject::InfoStringGroup& aflags) Q_DECL_OVERRIDE;
-	virtual const StelObject::InfoStringGroup& getInfoTextFilters() const Q_DECL_OVERRIDE;
+	void setInfoTextFilters(const StelObject::InfoStringGroup& aflags) override;
+	const StelObject::InfoStringGroup& getInfoTextFilters() const override;
 
 public slots:
 	//! Set the state of the flag of usage background for GUI buttons
@@ -212,8 +212,10 @@ public slots:
 	void decreaseScriptSpeed();
 	void setRealScriptSpeed();
 	void stopScript();
+	#ifndef ENABLE_SCRIPT_QML
 	void pauseScript();
 	void resumeScript();
+	#endif
 #endif
 
 	void displayAllInfo();
@@ -294,6 +296,8 @@ signals:
 	void flagShowCardinalButtonChanged(bool b);
 	void flagShowCompassButtonChanged(bool b);
 	void infoStringChanged();
+	void guiStyleChanged(const QString &style);
+	void htmlStyleChanged(const QString &style);
 
 private slots:
 	void reloadStyle();
@@ -302,12 +306,13 @@ private slots:
 	void scriptStopped();
 #endif
 	//! Load color scheme from the given ini file and section name
-	virtual void setStelStyle(const QString& section) Q_DECL_OVERRIDE;
+	void setStelStyle(const QString& style) override Q_DECL_FINAL;
 	void quit();	
 	void updateI18n();
 	void copySelectedObjectInfo(void);
 
 private:
+	void updateStelStyle();
 	//! convenience method to find an action in the StelActionMgr.
 	StelAction* getAction(const QString& actionName) const;
 
@@ -344,7 +349,7 @@ private:
 	ScriptConsole* scriptConsole;
 #endif
 	AstroCalcDialog* astroCalcDialog;
-    ObsListDialog* obsListDialog;
+	ObsListDialog* obsListDialog;
 
 	bool flagShowFlipButtons;
 	StelButton* flipVert;
@@ -421,7 +426,7 @@ public:
 	virtual void setInfoTextFilters(const StelObject::InfoStringGroup& aflags) {dummyInfoTextFilter=aflags;}
 	virtual const StelObject::InfoStringGroup& getInfoTextFilters() const {return dummyInfoTextFilter;}
 	virtual QProgressBar* addProgressBar() {return new QProgressBar;}
-	virtual QAction* addGuiActions(const QString& actionName, const QString& text, const QString& shortCut, const QString& helpGroup, bool checkable=true, bool autoRepeat=false) {return Q_NULLPTR;}
+	virtual QAction* addGuiActions(const QString& actionName, const QString& text, const QString& shortCut, const QString& helpGroup, bool checkable=true, bool autoRepeat=false) {return nullptr;}
 	virtual void forceRefreshGui() {;}
 	virtual void setVisible(bool b) {visible=b;}
 	virtual bool getVisible() const {return visible;}
