@@ -19,7 +19,6 @@
 
 #include "StelApp.hpp"
 #include "StelCore.hpp"
-#include "StelProjector.hpp"
 
 #include "StelUtils.hpp"
 #include "SolarSystem.hpp"
@@ -43,6 +42,7 @@
 #include <QGraphicsLineItem>
 #include <QRectF>
 #include <QDebug>
+#include <QScreen>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsTextItem>
 #include <QTimeLine>
@@ -55,39 +55,39 @@
 #include <QSettings>
 #include <QGuiApplication>
 
-// Inspired by text-use-opengl-buffer branch: work around font problems in GUI buttons.
-// May be useful in other broken OpenGL font situations. RasPi necessity as of 2016-03-26. Mesa 13 (2016-11) has finally fixed this on RasPi(VC4).
-QPixmap getTextPixmap(const QString& str, QFont font)
-{
-	// Render the text str into a QPixmap.
-	QRect strRect = QFontMetrics(font).boundingRect(str);
-	int w = strRect.width()+1+static_cast<int>(0.02f*static_cast<float>(strRect.width()));
-	int h = strRect.height();
-
-	QPixmap strPixmap(w, h);
-	strPixmap.fill(Qt::transparent);
-	QPainter painter(&strPixmap);
-	font.setStyleStrategy(QFont::NoAntialias); // else: font problems on RasPi20160326
-	painter.setFont(font);
-	//painter.setRenderHints(QPainter::TextAntialiasing);
-	painter.setPen(Qt::white);
-	painter.drawText(-strRect.x(), -strRect.y(), str);
-	return strPixmap;
-}
-
 void StelButton::initCtor(const QPixmap& apixOn,
-                          const QPixmap& apixOff,
-                          const QPixmap& apixNoChange,
-                          const QPixmap& apixHover,
-			  StelAction* anAction,
-			  StelAction* otherAction,
-			  bool noBackground,
-                          bool isTristate)
+						  const QPixmap& apixOff,
+						  const QPixmap& apixNoChange,
+						  const QPixmap& apixHover,
+						  StelAction* anAction,
+						  StelAction* otherAction,
+						  bool noBackground,
+						  bool isTristate)
 {
 	pixOn = apixOn;
 	pixOff = apixOff;
 	pixHover = apixHover;
 	pixNoChange = apixNoChange;
+
+	if(!pixmapsScale)
+	{
+		pixmapsScale = StelApp::getInstance().getSettings()->value("gui/pixmaps_scale", GUI_INPUT_PIXMAPS_SCALE).toDouble();
+	}
+	if(pixmapsScale != GUI_INPUT_PIXMAPS_SCALE)
+	{
+		const auto scale = pixmapsScale/GUI_INPUT_PIXMAPS_SCALE;
+		pixOn = pixOn.scaled(pixOn.size()*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+		pixOff = pixOff.scaled(pixOff.size()*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+		if(!pixHover.isNull())
+			pixHover = pixHover.scaled(pixHover.size()*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+		if(!pixNoChange.isNull())
+			pixNoChange = pixNoChange.scaled(pixNoChange.size()*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+	}
+	pixOn.setDevicePixelRatio(pixmapsScale);
+	pixOff.setDevicePixelRatio(pixmapsScale);
+	pixHover.setDevicePixelRatio(pixmapsScale);
+	pixNoChange.setDevicePixelRatio(pixmapsScale);
+
 	noBckground = noBackground;
 	isTristate_ = isTristate;
 	opacity = 1.;
@@ -109,13 +109,12 @@ void StelButton::initCtor(const QPixmap& apixOn,
 	setAcceptHoverEvents(true);
 	timeLine = new QTimeLine(250, this);
 	timeLine->setEasingCurve(QEasingCurve(QEasingCurve::OutCurve));
-	connect(timeLine, SIGNAL(valueChanged(qreal)),
-	        this, SLOT(animValueChanged(qreal)));
+	connect(timeLine, SIGNAL(valueChanged(qreal)), this, SLOT(animValueChanged(qreal)));
 	connect(&StelMainView::getInstance(), SIGNAL(updateIconsRequested()), this, SLOT(updateIcon()));  // Not sure if this is ever called?
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
 	connect(gui, SIGNAL(flagUseButtonsBackgroundChanged(bool)), this, SLOT(updateIcon()));
 
-	if (action!=Q_NULLPTR)
+	if (action!=nullptr)
 	{
 		if (action->isCheckable())
 		{
@@ -128,7 +127,7 @@ void StelButton::initCtor(const QPixmap& apixOn,
 			QObject::connect(this, SIGNAL(triggered()), action, SLOT(trigger()));
 		}
 	}
-	if (secondAction!=Q_NULLPTR)
+	if (secondAction!=nullptr)
 	{
 			QObject::connect(this, SIGNAL(triggeredRight()), secondAction, SLOT(trigger()));
 	}
@@ -138,43 +137,47 @@ void StelButton::initCtor(const QPixmap& apixOn,
 }
 
 StelButton::StelButton(QGraphicsItem* parent,
-		       const QPixmap& pixOn,
-		       const QPixmap& pixOff,
-		       const QPixmap& pixHover,
-		       StelAction *action,
-		       bool noBackground,
-		       StelAction *otherAction) :
-	QGraphicsPixmapItem(pixOff, parent)
+					   const QPixmap& pixOn,
+					   const QPixmap& pixOff,
+					   const QPixmap& pixHover,
+					   StelAction *action,
+					   bool noBackground,
+					   StelAction *otherAction)
+	: QGraphicsPixmapItem(pixOff, parent)
 {
 	initCtor(pixOn, pixOff, QPixmap(), pixHover, action, otherAction, noBackground, false);
 }
 
 StelButton::StelButton(QGraphicsItem* parent,
-		       const QPixmap& pixOn,
-		       const QPixmap& pixOff,
-		       const QPixmap& pixNoChange,
-		       const QPixmap& pixHover,
-		       const QString& actionId,
-		       bool noBackground,
-		       bool isTristate) :
-	QGraphicsPixmapItem(pixOff, parent)
+					   const QPixmap& pixOn,
+					   const QPixmap& pixOff,
+					   const QPixmap& pixNoChange,
+					   const QPixmap& pixHover,
+					   const QString& actionId,
+					   bool noBackground,
+					   bool isTristate)
+	: QGraphicsPixmapItem(pixOff, parent)
 {
 	StelAction *action = StelApp::getInstance().getStelActionManager()->findAction(actionId);
-	initCtor(pixOn, pixOff, pixNoChange, pixHover, action, Q_NULLPTR, noBackground, isTristate);
+	if (!actionId.isEmpty() && !action)
+		qWarning() << "Couldn't find action" << actionId;
+	initCtor(pixOn, pixOff, pixNoChange, pixHover, action, nullptr, noBackground, isTristate);
 }
 
 StelButton::StelButton(QGraphicsItem* parent,
-		       const QPixmap& pixOn,
-		       const QPixmap& pixOff,
-		       const QPixmap& pixHover,
-		       const QString& actionId,
-		       bool noBackground,
-		       const QString &otherActionId)
-	:QGraphicsPixmapItem(pixOff, parent)
+					   const QPixmap& pixOn,
+					   const QPixmap& pixOff,
+					   const QPixmap& pixHover,
+					   const QString& actionId,
+					   bool noBackground,
+					   const QString &otherActionId)
+	: QGraphicsPixmapItem(pixOff, parent)
 {
 	StelAction *action = StelApp::getInstance().getStelActionManager()->findAction(actionId);
-	StelAction *otherAction=Q_NULLPTR;
-	if (otherActionId.length()>0)
+	if (!actionId.isEmpty() && !action)
+		qWarning() << "Couldn't find action" << actionId;
+	StelAction *otherAction=nullptr;
+	if (!otherActionId.isEmpty())
 		otherAction = StelApp::getInstance().getStelActionManager()->findAction(otherActionId);
 
 	initCtor(pixOn, pixOff, QPixmap(), pixHover, action, otherAction, noBackground, false);
@@ -240,7 +243,7 @@ void StelButton::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
 {
 	if (event->button()==Qt::LeftButton)
 	{
-		if (action!=Q_NULLPTR && !action->isCheckable())
+		if (action!=nullptr && !action->isCheckable())
 			setChecked(toggleChecked(checked));
 
 		if (flagChangeFocus) // true if button is on bottom bar
@@ -268,6 +271,7 @@ void StelButton::updateIcon()
 	if (opacity < 0.)
 		opacity = 0;
 	QPixmap pix(pixOn.size());
+	pix.setDevicePixelRatio(pixmapsScale);
 	pix.fill(QColor(0,0,0,0));
 	QPainter painter(&pix);
 	painter.setOpacity(opacity);
@@ -285,6 +289,7 @@ void StelButton::updateIcon()
 		painter.drawPixmap(0, 0, pixHover);
 	}
 	setPixmap(pix);
+	scaledCurrentPixmap = {};
 }
 
 void StelButton::animValueChanged(qreal value)
@@ -305,25 +310,60 @@ void StelButton::setBackgroundPixmap(const QPixmap &newBackground)
 	updateIcon();
 }
 
+QRectF StelButton::boundingRect() const
+{
+	return QRectF(0,0, getButtonPixmapWidth(), getButtonPixmapHeight());
+}
+
+void StelButton::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
+{
+	/* QPixmap::scaled has much better quality than that scaling via QPainter::drawPixmap, so let's
+	 * have our scaled copy of the pixmap.
+	 * NOTE: we cache this copy for two reasons:
+	 * 1. Performance
+	 * 2. Work around a Qt problem (I think it's a bug): when rendering multiple StelButton items
+	 *    in sequence, only the first one gets the necessary texture parameters set, particularly
+	 *    GL_TEXTURE_MIN_FILTER. On deletion of QPixmap the texture is deleted, and its Id gets
+	 *    assigned to the next QPixmap. Apparently, the Id gets cached somewhere in Qt internals, and
+	 *    becomes similar to a dangling pointer, informing Qt as if the necessary setup has already
+	 *    been done. The result is that after the first button all others in the same panel are black
+	 *    rectangles.
+	 *    Our keeping QPixmap alive instead of deleting it on return from this function prevents this.
+	 */
+	const double ratio = QOpenGLContext::currentContext()->screen()->devicePixelRatio();
+	if(scaledCurrentPixmap.isNull() || ratio != scaledCurrentPixmap.devicePixelRatioF())
+	{
+		const auto scale = ratio / pixmapsScale;
+		scaledCurrentPixmap = pixmap().scaled(pixOn.size()*scale, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+		scaledCurrentPixmap.setDevicePixelRatio(ratio);
+	}
+	// Align the pixmap to pixel grid, otherwise we'll get artifacts at some scaling factors.
+	const auto transform = painter->combinedTransform();
+	const auto shift = QPointF(-std::fmod(transform.dx(), 1.),
+							   -std::fmod(transform.dy(), 1.));
+	painter->drawPixmap(shift/ratio, scaledCurrentPixmap);
+}
+
 LeftStelBar::LeftStelBar(QGraphicsItem* parent)
 	: QGraphicsItem(parent)
-	, hideTimeLine(Q_NULLPTR)
-	, helpLabelPixmap(Q_NULLPTR)
+	, hideTimeLine(nullptr)
 {
 	// Create the help label
 	helpLabel = new QGraphicsSimpleTextItem("", this);
 	helpLabel->setBrush(QBrush(QColor::fromRgbF(1,1,1,1)));
-	if (qApp->property("text_texture")==true) // CLI option -t given?
-		helpLabelPixmap=new QGraphicsPixmapItem(this);
+
+	setFontSizeFromApp(StelApp::getInstance().getScreenFontSize());
+	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSizeFromApp(int)));
+	connect(&StelApp::getInstance(), SIGNAL(fontChanged(QFont)), this, SLOT(setFont(QFont)));
 }
 
 LeftStelBar::~LeftStelBar()
 {
-	if (helpLabelPixmap) { delete helpLabelPixmap; helpLabelPixmap=Q_NULLPTR; }
 }
 
 void LeftStelBar::addButton(StelButton* button)
 {
+	prepareGeometryChange();
 	double posY = 0;
 	if (QGraphicsItem::childItems().size()!=0)
 	{
@@ -332,7 +372,7 @@ void LeftStelBar::addButton(StelButton* button)
 	}
 	button->setParentItem(this);
 	button->setFocusOnSky(false);
-	button->prepareGeometryChange(); // could possibly be removed when qt 4.6 become stable
+	//button->prepareGeometryChange(); // could possibly be removed when qt 4.6 become stable
 	button->setPos(0., qRound(posY+10.5));
 
 	connect(button, SIGNAL(hoverChanged(bool)), this, SLOT(buttonHoverChanged(bool)));
@@ -353,7 +393,7 @@ QRectF LeftStelBar::boundingRectNoHelpLabel() const
 	QRectF childRect;
 	for (auto* child : QGraphicsItem::childItems())
 	{
-		if ((child==helpLabel) || (child==helpLabelPixmap))
+		if (child==helpLabel)
 			continue;
 		QPointF childPos = child->pos();
 		QTransform matrix = child->transform() * QTransform().translate(childPos.x(), childPos.y());
@@ -382,21 +422,12 @@ void LeftStelBar::buttonHoverChanged(bool b)
 				tip += "  [" + shortcut + "]";
 			}
 			helpLabel->setText(tip);
-			helpLabel->setPos(qRound(boundingRectNoHelpLabel().width()+15.5),qRound(button->pos().y()+button->pixmap().size().height()/2-8));
-			if (qApp->property("text_texture")==true)
-			{
-				helpLabel->setVisible(false);
-				helpLabelPixmap->setPixmap(getTextPixmap(tip, helpLabel->font()));
-				helpLabelPixmap->setPos(helpLabel->pos());
-				helpLabelPixmap->setVisible(true);
-			}
+			helpLabel->setPos(qRound(boundingRectNoHelpLabel().width()+15.5),qRound(button->pos().y()+button->getButtonPixmapHeight()/2-8));
 		}
 	}
 	else
 	{
 		helpLabel->setText("");
-		if (qApp->property("text_texture")==true)
-			helpLabelPixmap->setVisible(false);
 	}
 	// Update the screen as soon as possible.
 	StelMainView::getInstance().thereWasAnEvent();
@@ -408,35 +439,57 @@ void LeftStelBar::setColor(const QColor& c)
 	helpLabel->setBrush(c);
 }
 
+//! connect from StelApp to resize fonts on the fly.
+void LeftStelBar::setFontSizeFromApp(int size)
+{
+	// Font size was developed based on base font size 13, i.e. 12
+	int screenFontSize = size-1;
+	QFont font=QGuiApplication::font();
+	font.setPixelSize(screenFontSize);
+	helpLabel->setFont(font);
+	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+	if (gui)
+	{
+		// to avoid crash
+		SkyGui* skyGui=gui->getSkyGui();
+		if (skyGui)
+			skyGui->updateBarsPos();
+	}
+}
+
+//! connect from StelApp to resize fonts on the fly.
+void LeftStelBar::setFont(QFont font)
+{
+	font.setPixelSize(StelApp::getInstance().getScreenFontSize()-1);
+	helpLabel->setFont(font);
+	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+	if (gui)
+	{
+		// to avoid crash
+		SkyGui* skyGui=gui->getSkyGui();
+		if (skyGui)
+			skyGui->updateBarsPos();
+	}
+}
+
+
 BottomStelBar::BottomStelBar(QGraphicsItem* parent,
                              const QPixmap& pixLeft,
                              const QPixmap& pixRight,
                              const QPixmap& pixMiddle,
                              const QPixmap& pixSingle) :
 	QGraphicsItem(parent),
-	locationPixmap(Q_NULLPTR),
-	datetimePixmap(Q_NULLPTR),
-	fovPixmap(Q_NULLPTR),
-	fpsPixmap(Q_NULLPTR),
+	gap(2),
 	pixBackgroundLeft(pixLeft),
 	pixBackgroundRight(pixRight),
 	pixBackgroundMiddle(pixMiddle),
-	pixBackgroundSingle(pixSingle),
-	helpLabelPixmap(Q_NULLPTR)
+	pixBackgroundSingle(pixSingle)
 {
 	// The text is dummy just for testing
 	datetime = new QGraphicsSimpleTextItem("2008-02-06  17:33", this);
 	location = new QGraphicsSimpleTextItem("Munich, Earth, 500m", this);
 	fov = new QGraphicsSimpleTextItem("FOV 43.45", this);
 	fps = new QGraphicsSimpleTextItem("43.2 FPS", this);
-	if (qApp->property("text_texture")==true) // CLI option -t given?
-	{
-		datetimePixmap=new QGraphicsPixmapItem(this);
-		locationPixmap=new QGraphicsPixmapItem(this);
-		fovPixmap=new QGraphicsPixmapItem(this);
-		fpsPixmap=new QGraphicsPixmapItem(this);
-		helpLabelPixmap=new QGraphicsPixmapItem(this);
-	}
 
 	// Create the help label
 	helpLabel = new QGraphicsSimpleTextItem("", this);
@@ -445,8 +498,9 @@ BottomStelBar::BottomStelBar(QGraphicsItem* parent,
 	setColor(QColor::fromRgbF(1,1,1,1));
 
 	setFontSizeFromApp(StelApp::getInstance().getScreenFontSize());
-	connect(&StelApp::getInstance(), SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSizeFromApp(int)));
+	connect(&StelApp::getInstance(), &StelApp::screenFontSizeChanged, this, [=](int fontsize){setFontSizeFromApp(fontsize); setFontSizeFromApp(fontsize);}); // We must call that twice to force all geom. updates
 	connect(&StelApp::getInstance(), SIGNAL(fontChanged(QFont)), this, SLOT(setFont(QFont)));
+	connect(StelApp::getInstance().getCore(), &StelCore::flagUseTopocentricCoordinatesChanged, this, [=](bool){updateText(false, true);});
 
 	QSettings* confSettings = StelApp::getInstance().getSettings();
 	setFlagShowTime(confSettings->value("gui/flag_show_datetime", true).toBool());
@@ -461,21 +515,25 @@ BottomStelBar::BottomStelBar(QGraphicsItem* parent,
 //! connect from StelApp to resize fonts on the fly.
 void BottomStelBar::setFontSizeFromApp(int size)
 {
-	// Font size was developed based on base font size 13, i.e. 12
-	int screenFontSize = size-1;
+	prepareGeometryChange();
 	QFont font=QGuiApplication::font();
-	font.setPixelSize(screenFontSize);
+	// Font size was developed based on base font size 13, i.e. 12
+	font.setPixelSize(size-1);
 	datetime->setFont(font);
 	location->setFont(font);
 	fov->setFont(font);
 	fps->setFont(font);
+	helpLabel->setFont(font);
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
 	if (gui)
 	{
 		// to avoid crash
 		SkyGui* skyGui=gui->getSkyGui();
 		if (skyGui)
+		{
 			skyGui->updateBarsPos();
+			updateButtonsGroups(); // Make sure bounding boxes are readjusted.
+		}
 	}
 }
 
@@ -502,24 +560,20 @@ BottomStelBar::~BottomStelBar()
 	// Remove currently hidden buttons which are not deleted by a parent element
 	for (auto& group : buttonGroups)
 	{
-		for (auto* b : qAsConst(group.elems))
+		for (auto* b : std::as_const(group.elems))
 		{
-			if (b->parentItem()==Q_NULLPTR)
+			if (b->parentItem()==nullptr)
 			{
 				delete b;
-				b=Q_NULLPTR;
+				b=nullptr;
 			}
 		}
 	}
-	if (datetimePixmap) { delete datetimePixmap; datetimePixmap=Q_NULLPTR; }
-	if (locationPixmap) { delete locationPixmap; locationPixmap=Q_NULLPTR; }
-	if (fovPixmap) { delete fovPixmap; fovPixmap=Q_NULLPTR; }
-	if (fpsPixmap) { delete fpsPixmap; fpsPixmap=Q_NULLPTR; }
-	if (helpLabelPixmap) { delete helpLabelPixmap; helpLabelPixmap=Q_NULLPTR; }
 }
 
 void BottomStelBar::addButton(StelButton* button, const QString& groupName, const QString& beforeActionName)
 {
+	prepareGeometryChange();
 	QList<StelButton*>& g = buttonGroups[groupName].elems;
 	bool done = false;
 	for (int i=0; i<g.size(); ++i)
@@ -546,11 +600,11 @@ void BottomStelBar::addButton(StelButton* button, const QString& groupName, cons
 StelButton* BottomStelBar::hideButton(const QString& actionName)
 {
 	QString gName;
-	StelButton* bToRemove = Q_NULLPTR;
+	StelButton* bToRemove = nullptr;
 	for (auto iter = buttonGroups.begin(); iter != buttonGroups.end(); ++iter)
 	{
 		int i=0;
-		for (auto* b : qAsConst(iter.value().elems))
+		for (auto* b : std::as_const(iter.value().elems))
 		{
 			if (b->action && b->action->objectName()==actionName)
 			{
@@ -562,15 +616,15 @@ StelButton* BottomStelBar::hideButton(const QString& actionName)
 			++i;
 		}
 	}
-	if (bToRemove == Q_NULLPTR)
-		return Q_NULLPTR;
+	if (bToRemove == nullptr)
+		return nullptr;
 	if (buttonGroups[gName].elems.size() == 0)
 	{
 		buttonGroups.remove(gName);
 	}
 	// Cannot really delete because some part of the GUI depend on the presence of some buttons
 	// so just make invisible
-	bToRemove->setParentItem(Q_NULLPTR);
+	bToRemove->setParentItem(nullptr);
 	bToRemove->setVisible(false);
 	updateButtonsGroups();
 	emit sizeChanged();
@@ -606,21 +660,21 @@ void BottomStelBar::setGroupBackground(const QString& groupName,
 
 QRectF BottomStelBar::getButtonsBoundingRect() const
 {
-	// Re-use original Qt code, just remove the help label
 	QRectF childRect;
 	bool hasBtn = false;
 	for (auto* child : QGraphicsItem::childItems())
 	{
-		if (qgraphicsitem_cast<StelButton*>(child)==Q_NULLPTR)
+		if (qgraphicsitem_cast<StelButton*>(child)==nullptr)
 			continue;
 		hasBtn = true;
 		QPointF childPos = child->pos();
+		//qDebug() << "childPos" << childPos;
 		QTransform matrix = child->transform() * QTransform().translate(childPos.x(), childPos.y());
 		childRect |= matrix.mapRect(child->boundingRect() | child->childrenBoundingRect());
 	}
 
 	if (hasBtn)
-		return QRectF(0, 0, childRect.width()-1, childRect.height()-1);
+		return QRectF(0, 0, childRect.width(), childRect.height());
 	else
 		return QRectF();
 }
@@ -628,7 +682,8 @@ QRectF BottomStelBar::getButtonsBoundingRect() const
 void BottomStelBar::updateButtonsGroups()
 {
 	double x = 0;
-	double y = datetime->boundingRect().height() + 3;
+	QFontMetrics statusFM(datetime->font());
+	const double y = statusFM.lineSpacing()+gap; // Take natural font geometry into account
 	for (auto& group : buttonGroups)
 	{
 		QList<StelButton*>& buttons = group.elems;
@@ -644,14 +699,14 @@ void BottomStelBar::updateButtonsGroups()
 			{
 				if (buttons.size() == 1)
 				{
-					if (group.pixBackgroundSingle == Q_NULLPTR)
+					if (group.pixBackgroundSingle == nullptr)
 						b->setBackgroundPixmap(pixBackgroundSingle);
 					else
 						b->setBackgroundPixmap(*group.pixBackgroundSingle);
 				}
 				else
 				{
-					if (group.pixBackgroundLeft == Q_NULLPTR)
+					if (group.pixBackgroundLeft == nullptr)
 						b->setBackgroundPixmap(pixBackgroundLeft);
 					else
 						b->setBackgroundPixmap(*group.pixBackgroundLeft);
@@ -661,19 +716,19 @@ void BottomStelBar::updateButtonsGroups()
 			{
 				if (buttons.size() != 1)
 				{
-					if (group.pixBackgroundSingle == Q_NULLPTR)
+					if (group.pixBackgroundSingle == nullptr)
 						b->setBackgroundPixmap(pixBackgroundSingle);
 					else
 						b->setBackgroundPixmap(*group.pixBackgroundSingle);
 				}
-				if (group.pixBackgroundRight == Q_NULLPTR)
+				if (group.pixBackgroundRight == nullptr)
 					b->setBackgroundPixmap(pixBackgroundRight);
 				else
 					b->setBackgroundPixmap(*group.pixBackgroundRight);
 			}
 			else
 			{
-				if (group.pixBackgroundMiddle == Q_NULLPTR)
+				if (group.pixBackgroundMiddle == nullptr)
 					b->setBackgroundPixmap(pixBackgroundMiddle);
 				else
 					b->setBackgroundPixmap(*group.pixBackgroundMiddle);
@@ -691,13 +746,13 @@ void BottomStelBar::updateButtonsGroups()
 
 // create text elements and tooltips in bottom toolbar.
 // Make sure to avoid any change if not necessary to avoid triggering useless redraw
-void BottomStelBar::updateText(bool updatePos)
+// This is also called when button groups have been updated.
+void BottomStelBar::updateText(bool updatePos, bool updateTopocentric)
 {
 	StelCore* core = StelApp::getInstance().getCore();
 	const double jd = core->getJD();
 	const double deltaT = core->getDeltaT();
 	const double sigma = StelUtils::getDeltaTStandardError(jd);
-	QString sigmaInfo = "";
 	QString validRangeMarker = "";
 	core->getCurrentDeltaTAlgorithmValidRangeDescription(jd, &validRangeMarker);
 
@@ -775,10 +830,11 @@ void BottomStelBar::updateText(bool updatePos)
 
 	if (core->getCurrentDeltaTAlgorithm()!=StelCore::WithoutCorrection)
 	{
+		QString sigmaInfo("");
 		if (sigma>0)
 			sigmaInfo = QString("; %1(%2T) = %3s").arg(QChar(0x03c3)).arg(QChar(0x0394)).arg(sigma, 3, 'f', 1);
 
-		QString deltaTInfo = "";
+		QString deltaTInfo;
 		if (qAbs(deltaT)>60.)
 			deltaTInfo = QString("%1 (%2s)%3").arg(StelUtils::hoursToHmsStr(deltaT/3600.)).arg(deltaT, 5, 'f', 2).arg(validRangeMarker);
 		else
@@ -794,37 +850,28 @@ void BottomStelBar::updateText(bool updatePos)
 	else
 		datetime->setToolTip(QString("<p style='white-space:pre'>%1<br>%2<br>%3</p>").arg(newDateAppx, currTZ, timeRateInfo));
 
-	if (qApp->property("text_texture")==true) // CLI option -t given?
-	{
-		datetime->setVisible(false); // hide normal thingy.
-		datetimePixmap->setPixmap(getTextPixmap(newDateInfo, datetime->font()));
-	}
-
 	// build location tooltip
-	QString newLocation = "";
+	QString newLocation("");
 	if (getFlagShowLocation())
 	{
 		const StelLocation* loc = &core->getCurrentLocation();
-		if(loc->name.isEmpty())
-			newLocation = planetNameI18n +", "+StelUtils::decDegToDmsStr(loc->latitude)+", "+StelUtils::decDegToDmsStr(loc->longitude);
+		if (core->getCurrentPlanet()->getPlanetType()==Planet::isObserver)
+			newLocation = planetNameI18n;
+		else if(loc->name.isEmpty())
+			newLocation = planetNameI18n +", "+StelUtils::decDegToDmsStr(loc->getLatitude())+", "+StelUtils::decDegToDmsStr(loc->getLongitude());
+		else if (loc->name.contains("->")) // a spaceship
+			newLocation = QString("%1 [%2 %3]").arg(planetNameI18n, q_("flight"), loc->name);
 		else
-		{
-			if (loc->name.contains("->")) // a spaceship
-				newLocation = QString("%1 [%2 %3]").arg(planetNameI18n, q_("flight"), loc->name);
-			else
-			{
-				//TRANSLATORS: Unit of measure for distance - meter
-				newLocation = planetNameI18n +", "+q_(loc->name) + ", "+ QString("%1 %2").arg(loc->altitude).arg(qc_("m", "distance"));
-			}
-		}
+			//TRANSLATORS: Unit of measure for distance - meter
+			newLocation = planetNameI18n +", "+q_(loc->name) + ", "+ QString("%1 %2").arg(loc->altitude).arg(qc_("m", "distance"));
 	}
-	// TODO: When topocentric switch is toggled, this must be redrawn!
-	if (location->text()!=newLocation)
+	// When topocentric switch is toggled, this must be redrawn!
+	if (location->text()!=newLocation || updateTopocentric)
 	{
 		updatePos = true;
 		location->setText(newLocation);
-		double lat = static_cast<double>(core->getCurrentLocation().latitude);
-		double lon = static_cast<double>(core->getCurrentLocation().longitude);
+		double lat = static_cast<double>(core->getCurrentLocation().getLatitude());
+		double lon = static_cast<double>(core->getCurrentLocation().getLongitude());
 		QString latStr, lonStr, pm;
 		if (lat >= 0)
 			pm = "N";
@@ -858,44 +905,29 @@ void BottomStelBar::updateText(bool updatePos)
 				weather = QString("%1: %2 %3; %4: %5 °C").arg(q_("Atmospheric pressure"), QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.atmospherePressure").toDouble(), 'f', 2), qc_("mbar", "pressure unit"), q_("temperature"), QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.atmosphereTemperature").toDouble(), 'f', 1));
 				location->setToolTip(QString("<p style='white-space:pre'>%1 %2; %3<br>%4</p>").arg(latStr, lonStr, rho, weather));
 			}
+			else if (core->getCurrentPlanet()->getPlanetType()==Planet::isObserver)
+				newLocation = planetNameI18n;
 			else
 				location->setToolTip(QString("%1 %2; %3").arg(latStr, lonStr, rho));
 		}
-
-		if (qApp->property("text_texture")==true) // CLI option -t given?
-		{
-			locationPixmap->setPixmap(getTextPixmap(newLocation, location->font()));
-			location->setVisible(false);
-		}
 	}
 
-	QString str;
-
 	// build fov tooltip
-	QTextStream wos(&str);
 	// TRANSLATORS: Field of view. Please use abbreviation.
-	QString fovstr = QString("%1 ").arg(qc_("FOV", "abbreviation"));
+	QString fovdms = StelUtils::decDegToDmsStr(core->getMovementMgr()->getCurrentFov());
+	QString fovText;
 	if (getFlagFovDms())
-	{
-		wos << fovstr << StelUtils::decDegToDmsStr(core->getMovementMgr()->getCurrentFov());
-	}
+		fovText=QString("%1 %2").arg(qc_("FOV", "abbreviation"), fovdms);
 	else
-	{
-		wos << fovstr << qSetRealNumberPrecision(3) << core->getMovementMgr()->getCurrentFov() << QChar(0x00B0);
-	}
+		fovText=QString("%1 %2%3").arg(qc_("FOV", "abbreviation"), QString::number(core->getMovementMgr()->getCurrentFov(), 'g', 3), QChar(0x00B0));
 
-	if (fov->text()!=str)
+	if (fov->text()!=fovText)
 	{
 		updatePos = true;
 		if (getFlagShowFov())
 		{
-			fov->setText(str);
-			fov->setToolTip(q_("Field of view"));
-			if (qApp->property("text_texture")==true) // CLI option -t given?
-			{
-				fovPixmap->setPixmap(getTextPixmap(str, fov->font()));
-				fov->setVisible(false);
-			}
+			fov->setText(fovText);
+			fov->setToolTip(QString("%1: %2").arg(q_("Field of view"), fovdms));
 		}
 		else
 		{
@@ -904,25 +936,16 @@ void BottomStelBar::updateText(bool updatePos)
 		}
 	}
 
-	str="";
-
 	// build fps tooltip
-	QTextStream wos2(&str);
 	// TRANSLATORS: Frames per second. Please use abbreviation.
-	QString fpsstr = QString(" %1").arg(qc_("FPS", "abbreviation"));
-	wos2 << qSetRealNumberPrecision(3) << StelApp::getInstance().getFps() << fpsstr;
-	if (fps->text()!=str)
+	QString fpsText = QString("%1 %2").arg(QString::number(StelApp::getInstance().getFps(), 'g', 3), qc_("FPS", "abbreviation"));;
+	if (fps->text()!=fpsText)
 	{
 		updatePos = true;
 		if (getFlagShowFps())
 		{
-			fps->setText(str);
+			fps->setText(fpsText);
 			fps->setToolTip(q_("Frames per second"));
-			if (qApp->property("text_texture")==true) // CLI option -t given?
-			{
-				fpsPixmap->setPixmap(getTextPixmap(str, fps->font()));
-				fps->setVisible(false);
-			}
 		}
 		else
 		{
@@ -933,30 +956,23 @@ void BottomStelBar::updateText(bool updatePos)
 
 	if (updatePos)
 	{
-		QFontMetrics fpsMetrics(fps->font());
-		int fpsShift = fpsMetrics.boundingRect(fpsstr).width() + 50;
-
-		QFontMetrics fovMetrics(fov->font());
-		int fovShift = fpsShift + fovMetrics.boundingRect(fovstr).width() + 80;
-		if (getFlagFovDms())
-			fovShift += 25;
+		// The location string starts at left, dateTime ends at right. FoV and FPS come ahead of dateTime.
+		// In case the strings are wider than available button space, they are now pushed to the right.
+		QFontMetrics fontMetrics(location->font());
+		int fpsShift     = qMax(fontMetrics.boundingRect(fps->text()+"MMM").width(), fontMetrics.boundingRect(qc_("FPS", "abbreviation")+"MM.M MMM").width());
+		int fovShift     = fontMetrics.boundingRect(fov->text()+"MMM").width() + fpsShift;
+		int locationWidth= fontMetrics.boundingRect(location->text() + "MMM").width();
+		location->setPos(0, 0);
 
 		QRectF rectCh = getButtonsBoundingRect();
-		location->setPos(0, 0);		
-		int dtp = static_cast<int>(rectCh.right()-datetime->boundingRect().width())-5;
-		if ((dtp%2) == 1) dtp--; // make even pixel
-		datetime->setPos(dtp,0);
+		int dateTimePos = static_cast<int>(rectCh.right()-datetime->boundingRect().width())-5;
+		if ((dateTimePos%2) == 1) dateTimePos--; // make even pixel
+
+		const int rightPush=qMax(0, locationWidth-(dateTimePos-fovShift));
+		datetime->setPos(dateTimePos+rightPush, 0);
 		fov->setPos(datetime->x()-fovShift, 0);
 		fps->setPos(datetime->x()-fpsShift, 0);
-		if (qApp->property("text_texture")==true) // CLI option -t given?
-		{
-			locationPixmap->setPos(0,0);
-			int dtp = static_cast<int>(rectCh.right()-datetimePixmap->boundingRect().width())-5;
-			if ((dtp%2) == 1) dtp--; // make even pixel
-			datetimePixmap->setPos(dtp,0);
-			fovPixmap->setPos(datetime->x()-fovShift, 0);
-			fpsPixmap->setPos(datetime->x()-fpsShift, 0);
-		}
+		//emit sizeChanged(); // This causes max fps!
 	}
 }
 
@@ -969,8 +985,8 @@ QRectF BottomStelBar::boundingRect() const
 {
 	if (QGraphicsItem::childItems().size()==0)
 		return QRectF();
-	const QRectF& r = childrenBoundingRect();
-	return QRectF(0, 0, r.width()-1, r.height()-1);
+	const QRectF& r = childrenBoundingRect(); // BBX of status text (Location/FoV/FPS/Time) and buttons
+	return QRectF(0, 0, r.width(), r.height());
 }
 
 QRectF BottomStelBar::boundingRectNoHelpLabel() const
@@ -979,7 +995,7 @@ QRectF BottomStelBar::boundingRectNoHelpLabel() const
 	QRectF childRect;
 	for (const auto* child : QGraphicsItem::childItems())
 	{
-		if ((child==helpLabel) || (child==helpLabelPixmap))
+		if (child==helpLabel)
 			continue;
 		QPointF childPos = child->pos();
 		QTransform matrix = child->transform() * QTransform().translate(childPos.x(), childPos.y());
@@ -988,7 +1004,7 @@ QRectF BottomStelBar::boundingRectNoHelpLabel() const
 	return childRect;
 }
 
-// Set the pen for all the sub elements
+// Set the brush for all the sub elements
 void BottomStelBar::setColor(const QColor& c)
 {
 	datetime->setBrush(c);
@@ -1019,21 +1035,12 @@ void BottomStelBar::buttonHoverChanged(bool b)
 			}
 			helpLabel->setText(tip);
 			//helpLabel->setPos(button->pos().x()+button->pixmap().size().width()/2,-27);
-			helpLabel->setPos(20,-27);
-			if (qApp->property("text_texture")==true)
-			{
-				helpLabel->setVisible(false);
-				helpLabelPixmap->setPixmap(getTextPixmap(tip, helpLabel->font()));
-				helpLabelPixmap->setPos(helpLabel->pos());
-				helpLabelPixmap->setVisible(true);
-			}
+			helpLabel->setPos(20,-10-location->font().pixelSize()); // Set help text XY position. Y adjusted for font size!
 		}
 	}
 	else
 	{
 		helpLabel->setText("");
-		if (qApp->property("text_texture")==true)
-			helpLabelPixmap->setVisible(false);
 	}
 	// Update the screen as soon as possible.
 	StelMainView::getInstance().thereWasAnEvent();
@@ -1041,29 +1048,29 @@ void BottomStelBar::buttonHoverChanged(bool b)
 
 StelBarsPath::StelBarsPath(QGraphicsItem* parent) : QGraphicsPathItem(parent), roundSize(6)
 {
-	QPen aPen(QColor::fromRgbF(0.7,0.7,0.7,0.5));
-	aPen.setWidthF(1.);
 	setBrush(QBrush(QColor::fromRgbF(0.22, 0.22, 0.23, 0.2)));
+	QPen aPen(QColor::fromRgbF(0.7,0.7,0.7,0.5));
+	// aPen.setWidthF(1.); // 1=default!
 	setPen(aPen);
 }
 
-void StelBarsPath::updatePath(BottomStelBar* bot, LeftStelBar* lef)
+void StelBarsPath::updatePath(BottomStelBar* bottom, LeftStelBar* left)
 {
-	QPainterPath newPath;
-	QPointF p = lef->pos();
-	QRectF r = lef->boundingRectNoHelpLabel();
-	QPointF p2 = bot->pos();
-	QRectF r2 = bot->boundingRectNoHelpLabel();
+	const QPointF l = left->pos() + QPointF(-0.5,0.5);   // pos() is the top-left point in the parent's coordinate system.
+	const QRectF lB = left->boundingRectNoHelpLabel();
+	const QPointF b = bottom->pos() + QPointF(-0.5,0.5);
+	const QRectF bB = bottom->boundingRectNoHelpLabel();
 
-	newPath.moveTo(p.x()-roundSize, p.y()-roundSize);
-	newPath.lineTo(p.x()+r.width(),p.y()-roundSize);
-	newPath.arcTo(p.x()+r.width()-roundSize, p.y()-roundSize, 2.*roundSize, 2.*roundSize, 90, -90);
-	newPath.lineTo(p.x()+r.width()+roundSize, p2.y()-roundSize);
-	newPath.lineTo(p2.x()+r2.width(),p2.y()-roundSize);
-	newPath.arcTo(p2.x()+r2.width()-roundSize, p2.y()-roundSize, 2.*roundSize, 2.*roundSize, 90, -90);
-	newPath.lineTo(p2.x()+r2.width()+roundSize, p2.y()+r2.height()+roundSize);
-	newPath.lineTo(p.x()-roundSize, p2.y()+r2.height()+roundSize);
-	setPath(newPath);
+	QPainterPath path(QPointF(l.x()-roundSize, l.y()-roundSize));                                 // top left point
+	//path.lineTo(l.x()+lB.width()-roundSize,l.y()-roundSize);                                    // top edge. Not needed because the arc connects anyhow!
+	path.arcTo(l.x()+lB.width()-roundSize, l.y()-roundSize, 2.*roundSize, 2.*roundSize, 90, -90); // top-right curve of left bar
+	path.lineTo(l.x()+lB.width()+roundSize, b.y()-roundSize);                                     // vertical to inside sharp edge
+	//path.lineTo(b.x()+bB.width(),b.y()-roundSize);                                              // Top edge of bottom bar. Not needed because the arc connects anyhow!
+	path.arcTo(b.x()+bB.width()-roundSize, b.y()-roundSize, 2.*roundSize, 2.*roundSize, 90, -90); // top right curved edge of bottom bar (just connects.)
+	path.lineTo(b.x()+bB.width()+roundSize, b.y()+bB.height()+roundSize);
+	path.lineTo(l.x()-roundSize, b.y()+bB.height()+roundSize);                                    // bottom line (outside screen area!)
+	path.closeSubpath();                                                                          // vertical line up left outside screen
+	setPath(path);
 }
 
 void StelBarsPath::setBackgroundOpacity(double opacity)
@@ -1096,7 +1103,7 @@ void StelProgressBarMgr::addProgressBar(const StelProgressController* p)
 	pb->setMinimum(p->getMin());
 	pb->setMaximum(p->getMax());
 	pb->setFormat(p->getFormat());
-	if (gui!=Q_NULLPTR)
+	if (gui!=nullptr)
 		pb->setStyleSheet(gui->getStelStyle().qtStyleSheet);
 	QGraphicsProxyWidget* pbProxy = new QGraphicsProxyWidget();
 	pbProxy->setWidget(pb);
@@ -1142,7 +1149,7 @@ QRectF CornerButtons::boundingRect() const
 	if (QGraphicsItem::childItems().size()==0)
 		return QRectF();
 	const QRectF& r = childrenBoundingRect();
-	return QRectF(0, 0, r.width()-1, r.height()-1);
+	return QRectF(0, 0, r.width(), r.height());
 }
 
 void CornerButtons::setOpacity(double opacity)
@@ -1155,7 +1162,7 @@ void CornerButtons::setOpacity(double opacity)
 	for (auto* child : QGraphicsItem::childItems())
 	{
 		StelButton* sb = qgraphicsitem_cast<StelButton*>(child);
-		Q_ASSERT(sb!=Q_NULLPTR);
+		Q_ASSERT(sb!=nullptr);
 		sb->setOpacity(opacity);
 	}
 }
