@@ -32,16 +32,13 @@
 
 #include <QDebug>
 
-#ifndef USE_QUICKVIEW
-	#include <QApplication>
-	#include <QMessageBox>
-	#include <QStyleFactory>
-#else
-	#include <QGuiApplication>
-#endif
+#include <QApplication>
+#include <QMessageBox>
+#include <QStyleFactory>
 #include <QCoreApplication>
 #include <QDir>
 #include <QFile>
+#include <QScreen>
 #include <QFileInfo>
 #include <QFontDatabase>
 #include <QGuiApplication>
@@ -53,6 +50,11 @@
 #include <QNetworkDiskCache>
 #include <QThread>
 
+#ifdef Q_OS_MACOS
+#include <QEvent>
+#include <QFileOpenEvent>
+#endif
+
 #include <clocale>
 
 #ifdef Q_OS_WIN
@@ -102,6 +104,30 @@ public:
 	}
 };
 
+class StelApplication : public QApplication
+{
+public:
+	StelApplication(int &argc, char **argv)
+		: QApplication(argc, argv)
+	{
+	}
+
+	#ifdef Q_OS_MACOS
+	bool event(QEvent *event) override
+	{
+		if (event->type() == QEvent::FileOpen)
+		{
+			QFileOpenEvent *openEvent = static_cast<QFileOpenEvent *>(event);
+			QString script = openEvent->file();
+			if (script.endsWith(".ssc"))
+				qApp->setProperty("onetime_startup_script", script);
+		}
+
+		return QApplication::event(event);
+	}
+	#endif
+};
+
 
 //! Copies the default configuration file.
 //! This function copies the default_cfg.ini file to config.ini (or other
@@ -156,22 +182,21 @@ int main(int argc, char **argv)
 	}
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
-	// Seed the PRNG. Later Qt versions use qApp->randomGenerator
-	qsrand(QDateTime::currentMSecsSinceEpoch());
-#endif
 	QCoreApplication::setApplicationName("stellarium");
-	QCoreApplication::setApplicationVersion(StelUtils::getApplicationVersion());
+	QCoreApplication::setApplicationVersion(StelUtils::getApplicationPublicVersion());
 	QCoreApplication::setOrganizationDomain("stellarium.org");
 	QCoreApplication::setOrganizationName("stellarium");
 
+	QCoreApplication::setAttribute(Qt::AA_CompressHighFrequencyEvents);
 	// Support high DPI pixmaps and fonts
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 	QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+#endif
 	if (argList.contains("--scale-gui")) // Variable QT_SCALE_FACTOR should be defined before app will be created!
 		qputenv("QT_SCALE_FACTOR", CLIProcessor::argsGetOptionWithArg(argList, "", "--scale-gui", "").toString().toLatin1());
 
-	#if defined(Q_OS_MAC)
+	#if defined(Q_OS_MACOS)
 	QFileInfo appInfo(QString::fromUtf8(argv[0]));
 	QDir appDir(appInfo.absolutePath());
 	appDir.cdUp();
@@ -181,15 +206,22 @@ int main(int argc, char **argv)
 	QCoreApplication::addLibraryPath(appInfo.absolutePath());
 	#endif	
 
-	QGuiApplication::setDesktopSettingsAware(false);
+	StelApplication::setDesktopSettingsAware(false);
 
-#ifndef USE_QUICKVIEW
-	QApplication::setStyle(QStyleFactory::create("Fusion"));
+	// This must be run before QGuiApplication, otherwise it'll have no effect.
+	CLIProcessor::parseCLIArgsPreQApp(argList);
+
+	StelApplication::setStyle(QStyleFactory::create("Fusion"));
 	// The QApplication MUST be created before the StelFileMgr is initialized.
-	QApplication app(argc, argv);
-#else
-	QGuiApplication::setDesktopSettingsAware(false);
-	QGuiApplication app(argc, argv);
+	StelApplication app(argc, argv);
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	// Follow vague hint from https://stackoverflow.com/questions/70152818/no-space-between-letters-in-text
+	// For some absurd reason, Qt6 needs some initialisation kick so that the font engine starts working.
+	// Else all characters are squashed together.
+	QSize absurdInitBugSize=QFontMetrics(qApp->font()).size(Qt::TextSingleLine, "A really absurd bug!");
+	Q_ASSERT(absurdInitBugSize.width()>0);
+	Q_UNUSED(absurdInitBugSize)
 #endif
 
 	// QApplication sets current locale, but
@@ -207,7 +239,7 @@ int main(int argc, char **argv)
 
 	// add contents of STEL_OPTS environment variable.
 	QString envStelOpts(qgetenv("STEL_OPTS").constData());
-	if (envStelOpts.length()>0)
+	if (!envStelOpts.isEmpty())
 	{
 		argList+= envStelOpts.split(" ");
 		argStr += " " + envStelOpts;
@@ -220,24 +252,37 @@ int main(int argc, char **argv)
 	CLIProcessor::parseCLIArgsPreConfig(argList);
 
 	// Start logging.
-	StelLogger::init(StelFileMgr::getUserDir()+"/log.txt");
+	QString logName("log.txt");
+	try
+	{
+		logName = CLIProcessor::argsGetOptionWithArg(argList, "-l", "--log-file", "log.txt").toString();
+		// Strip external paths!
+		QFileInfo fi(logName);
+		logName=fi.fileName();
+	}
+	catch (std::runtime_error& e)
+	{
+		qWarning() << "WARNING: while processing --log-file option: " << e.what() << ". Using \"log.txt\"";
+		logName = "log.txt";
+	}
+	StelLogger::init(StelFileMgr::getUserDir()+"/"+logName);
 	StelLogger::writeLog(argStr);
 
 	// OK we start the full program.
 	// Print the console splash and get on with loading the program
-	QString versionLine = QString("This is %1 - %2").arg(StelUtils::getApplicationName(), STELLARIUM_URL);
+	QString versionLine = QString("This is %1 (v%2) - %3").arg(StelUtils::getApplicationName(), StelUtils::getApplicationVersion(), STELLARIUM_URL);
 	QString copyrightLine = STELLARIUM_COPYRIGHT;
 	int maxLength = qMax(versionLine.size(), copyrightLine.size());
 	qDebug() << qPrintable(QString(" %1").arg(QString().fill('-', maxLength+2)));
 	qDebug() << qPrintable(QString("[ %1 ]").arg(versionLine.leftJustified(maxLength, ' ')));
 	qDebug() << qPrintable(QString("[ %1 ]").arg(copyrightLine.leftJustified(maxLength, ' ')));
 	qDebug() << qPrintable(QString(" %1").arg(QString().fill('-', maxLength+2)));
-	qDebug() << "Writing log file to:" << QDir::toNativeSeparators(StelLogger::getLogFileName());
+	qDebug().noquote() << "Writing log file to:" << QDir::toNativeSeparators(StelLogger::getLogFileName());
 	qDebug() << "File search paths:";
 	int n=0;
 	for (const auto& i : StelFileMgr::getSearchPaths())
 	{
-		qDebug() << " " << n << ". " << QDir::toNativeSeparators(i);
+		qDebug().noquote().nospace() << " [" << n << "]: " << QDir::toNativeSeparators(i);
 		++n;
 	}
 
@@ -249,7 +294,7 @@ int main(int argc, char **argv)
 	}
 	catch (std::runtime_error& e)
 	{
-		qWarning() << "WARNING: while looking for --config-file option: " << e.what() << ". Using \"config.ini\"";
+		qWarning().noquote() << "WARNING: while looking for --config-file option:" << e.what() << ". Using \"config.ini\"";
 		configName = "config.ini";
 	}
 
@@ -275,7 +320,7 @@ int main(int argc, char **argv)
 		if (!restoreDefaultConfigFile)
 		{
 			QString version = confSettings->value("main/version", "0.0.0").toString();
-			if (version!=QString(PACKAGE_VERSION))
+			if (version!=QString(STELLARIUM_PUBLIC_VERSION))
 			{
 				QTextStream istr(&version);
 				char tmp;
@@ -286,7 +331,7 @@ int main(int argc, char **argv)
 				if (v1==0 && v2<6)
 				{
 					// The config file is too old to try an import
-					qDebug() << "The current config file is from a version too old for parameters to be imported ("
+					qDebug().noquote() << "The current config file is from a version too old for parameters to be imported ("
 							 << (version.isEmpty() ? "<0.6.0" : version) << ").\n"
 							 << "It will be replaced by the default config file.";
 					restoreDefaultConfigFile = true;
@@ -294,7 +339,7 @@ int main(int argc, char **argv)
 				else
 				{
 					qDebug() << "Attempting to use an existing older config file.";
-					confSettings->setValue("main/version", QString(PACKAGE_VERSION)); // Upgrade version of config.ini
+					confSettings->setValue("main/version", QString(STELLARIUM_PUBLIC_VERSION)); // Upgrade version of config.ini
 					clearCache();
 					qDebug() << "Cleared cache and updated config.ini...";
 				}
@@ -313,19 +358,21 @@ int main(int argc, char **argv)
 			QFile(configFileFullPath).rename(backupFile);
 			copyDefaultConfigFile(configFileFullPath);
 			confSettings = new QSettings(configFileFullPath, StelIniFormat);
-			qWarning() << "Resetting defaults config file. Previous config file was backed up in " << QDir::toNativeSeparators(backupFile);
+			qWarning().noquote() << "Resetting defaults config file. Previous config file was backed up in" << QDir::toNativeSeparators(backupFile);
 			clearCache();
 		}
 	}
 	else
 	{
-		qDebug() << "Config file " << QDir::toNativeSeparators(configFileFullPath) << " does not exist. Copying the default file.";
+		qDebug().noquote() << "Config file" << QDir::toNativeSeparators(configFileFullPath) << "does not exist. Copying the default file.";
 		copyDefaultConfigFile(configFileFullPath);
 		confSettings = new QSettings(configFileFullPath, StelIniFormat);
 	}
 
 	Q_ASSERT(confSettings);
-	qDebug() << "Config file is: " << QDir::toNativeSeparators(configFileFullPath);
+	qDebug().noquote() << "Config file:" << QDir::toNativeSeparators(configFileFullPath);
+
+	QSurfaceFormat::setDefaultFormat(StelMainView::getDesiredGLFormat(confSettings));
 
 	#ifdef ENABLE_SCRIPTING
 	QString outputFile = StelFileMgr::getUserDir()+"/output.txt";
@@ -337,10 +384,16 @@ int main(int argc, char **argv)
 	// Override config file values from CLI.
 	CLIProcessor::parseCLIArgsPostConfig(argList, confSettings);
 
-	// Add the DejaVu font that we use everywhere in the program
-	const QString& fName = StelFileMgr::findFile("data/DejaVuSans.ttf");
-	if (!fName.isEmpty())
-		QFontDatabase::addApplicationFont(fName);
+	StelFileMgr::setObsListDir(confSettings->value("main/observinglists_dir", StelFileMgr::getUserDir()).toString());
+
+	// Add the Noto & DejaVu fonts that we use everywhere in the program
+	const QStringList customFonts = { "NotoSans-Regular.ttf", "NotoSansMono-Regular.ttf", "NotoSansSC-Regular.otf", "DejaVuSans.ttf", "DejaVuSansMono.ttf" };
+	for (auto &font: std::as_const(customFonts))
+	{
+		QString customFont = StelFileMgr::findFile(QString("data/%1").arg(font));
+		if (!customFont.isEmpty())
+			QFontDatabase::addApplicationFont(customFont);
+	}
 	
 	QString fileFont = confSettings->value("gui/base_font_file", "").toString();
 	if (!fileFont.isEmpty())
@@ -349,21 +402,13 @@ int main(int argc, char **argv)
 		if (!afName.isEmpty() && !afName.contains("file not found"))
 			QFontDatabase::addApplicationFont(afName);
 		else
-			qWarning() << "ERROR while loading custom font " << QDir::toNativeSeparators(fileFont);
+			qWarning().noquote() << "ERROR while loading custom font:" << QDir::toNativeSeparators(fileFont);
 	}
 
 	// Set the default application font and font size.
 	// Note that style sheet will possibly override this setting.
-#ifdef Q_OS_WIN
-	// Let's try avoid ugly font rendering on Windows.
-	// Details: https://sourceforge.net/p/stellarium/discussion/278769/thread/810a1e5c/
-	QString baseFont = confSettings->value("gui/base_font_name", "Verdana").toString();
+	QString baseFont = confSettings->value("gui/base_font_name", "Noto Sans").toString();
 	QFont tmpFont(baseFont);
-	tmpFont.setStyleHint(QFont::AnyStyle, QFont::OpenGLCompatible);
-#else
-	QString baseFont = confSettings->value("gui/base_font_name", "DejaVu Sans").toString();
-	QFont tmpFont(baseFont);
-#endif
 	tmpFont.setPixelSize(confSettings->value("gui/gui_font_size", 13).toInt());
 	QGuiApplication::setFont(tmpFont);
 
@@ -375,6 +420,42 @@ int main(int argc, char **argv)
 	app.installTranslator(&trans);
 
 	StelMainView mainWin(confSettings);
+
+	int screen = confSettings->value("video/screen_number", 0).toInt();
+	if (screen < 0 || screen >= qApp->screens().count())
+	{
+		qWarning().noquote() << "WARNING: screen" << screen << "not found";
+		screen = 0;
+	}
+	const auto qscreen = qApp->screens().at(screen);
+	const QRect screenGeom = qscreen->geometry();
+	const auto pixelRatio = qscreen->devicePixelRatio();
+
+	const auto virtSize = QSize(confSettings->value("video/screen_w", screenGeom.width()).toInt(),
+								confSettings->value("video/screen_h", screenGeom.height()).toInt());
+	const auto size = QSize(std::lround(virtSize.width()/pixelRatio),
+							std::lround(virtSize.height()/pixelRatio));
+	mainWin.resize(size);
+
+	const bool fullscreen = confSettings->value("video/fullscreen", true).toBool();
+	if (fullscreen)
+	{
+		// The "+1" below is to work around Linux/Gnome problem with mouse focus.
+		mainWin.move(screenGeom.x()+1, screenGeom.y()+1);
+		// The fullscreen window appears on screen where is the majority of
+		// the normal window. Therefore we crop the normal window to the
+		// screen area to ensure that the majority is not on another screen.
+		mainWin.setGeometry(mainWin.geometry() & screenGeom);
+		mainWin.setFullScreen(true);
+	}
+	else
+	{
+		const int x = confSettings->value("video/screen_x", 0).toInt();
+		const int y = confSettings->value("video/screen_y", 0).toInt();
+		mainWin.move(screenGeom.x() + x/pixelRatio,
+			     screenGeom.y() + y/pixelRatio);
+	}
+
 	mainWin.show();
 	SplashScreen::finish(&mainWin);
 	app.exec();
