@@ -23,8 +23,12 @@
 #include <QObject>
 #include <QVariant>
 #include <QStringList>
-#include "StelObject.hpp"
+#include "V3d.hpp"
+#ifdef ENABLE_SCRIPT_QML
+#include <QJSEngine>
+#endif
 #include "StelCore.hpp"
+#include "VecMath.hpp"
 
 class QScriptEngine;
 
@@ -44,8 +48,45 @@ public:
 	StelMainScriptAPI(QObject *parent = Q_NULLPTR);
 	~StelMainScriptAPI() Q_DECL_OVERRIDE;
 
+#ifdef ENABLE_SCRIPT_QML
+	void setEngine(QJSEngine *eng){m_engine=eng;}
+#endif
+
 // These functions will be available in scripts
 public slots:
+
+	//! Create a Vec3d object. This is very important for many functions, but can only be created indirectly.
+	//! Either use this function or use an intermediary V3d object like
+	//! @code
+	//! var myV3d=new V3d(vec);
+	//! var myVec3d=myV3d.toVec3d();
+	//! @endcode
+	static Vec3d vec3d(const double x, const double y, const double z);
+
+	//! Create a Vec3f object. This is very important for many functions, but can only be created indirectly.
+	//! Either use this function or use an intermediary V3f object like
+	//! @code
+	//! var myV3f=new V3f(vec);
+	//! var myVec3f=myV3f.toVec3f();
+	//! @endcode
+	static Vec3f vec3f(const float x, const float y, const float z);
+
+#ifdef ENABLE_SCRIPT_QML
+	//! @returns Color object from a color hexstring or even color name definition.
+	//! @code
+	//! var crimson=core.color("Crimson");
+	//! var red=core.color("#ff0000");
+	//! @endcode
+	//! almost an alias for vec3f(cstr)
+	static Color color(const QString &cstr);
+#endif
+
+	//! Returns true if the script is running on the older, Qt5-based QtScript JavaScript engine.
+	//! Note that it is possible to build Stellarium on Qt5.14 and later also with the newer scripting engine.
+	//! Use this to make code paths work with all versions of Stellarium.
+	//! @todo Should we rename this method?
+	static bool useQtScript();
+
 	//! Set the current date as Julian Day number
 	//! @param JD the Julian Day number
 	static void setJDay(double JD);
@@ -218,6 +259,7 @@ public slots:
 	//! - phase-angle : phase angle of object in radians (for Solar system objects only!)
 	//! - phase-angle-dms : phase angle of object in DMS (for Solar system objects only!)
 	//! - phase-angle-deg : phase angle of object in decimal degrees (for Solar system objects only!)
+	//! - is-waning : whether phase angle is increasing, signifying the waning phase (for Solar system objects only!)
 	//! - elongation : elongation of object in radians (for Solar system objects only!)
 	//! - elongation-dms : elongation of object in DMS (for Solar system objects only!)
 	//! - elongation-deg : elongation of object in decimal degrees (for Solar system objects only!)
@@ -340,7 +382,7 @@ public slots:
 	//! @param lon the galactic longitude
 	//! @param dec the galactic latitude
 	//! @param duration the duration of the movement in seconds
-	static void moveToGalLongLat(const QString& lon, const QString& lat, float duration);
+	static void moveToGalLongLat(const QString& lon, const QString& lat, float duration=1.);
 
 	//! Set the observer location
 	//! @param longitude the longitude in degrees. E is +ve.
@@ -404,6 +446,21 @@ public slots:
 	//! Return an array of all timezone names valid for setTimezone(tzName)
 	static QStringList getAllTimezoneNames();
 
+	//! Coordinate conversion: geographic (WGS84)-->UTM
+	//! @arg longitude geographic longitude from Greenwich, degrees
+	//! @arg latitude geographic latitude from equator, degrees
+	//! @arg zone UTM zone [1...60]. If 0, compute best-fit zone.
+	//! @return {{E[m], N[m], zone, gamma[deg], k}}
+	//! The returned zone contains the input or, if input was 0 (or missing), the most appropriate zone. North or South is not returned but is trivially fround from latitude.
+	static QList<double> geo2utm(const double longitude, const double latitude, const int zone=0);
+	//! Coordinate conversion: UTM->geographic (WGS84)
+	//! @arg easting (metres). False Easting of Zone meridian = 500000
+	//! @arg northing (metres). For southern latitudes, equator = 10000000
+	//! @arg zone UTM zone (longitudinal) [1...60].
+	//! @arg north true for N, false for S latitude zones.
+	//! @return {{longitude[deg], latitude[deg], refLong[deg], gamma[deg], k}}
+	static QList<double> utm2geo(const double easting, const double northing, const int zone, const bool north);
+
 	//! Save a screenshot.
 	//! @param prefix the prefix for the file name to use
 	//! @param dir the path of the directory to save the screenshot in.  If
@@ -418,6 +475,17 @@ public slots:
 	//! @param b if true, show the GUI, if false, hide the GUI.
 	static void setGuiVisible(bool b);
 
+	//! Show or hide the selection pointers/markers
+	//! @param b if true, show the pointer/marker around selected objects, if false, hide the pointer/marker.
+	static void setSelectedObjectMarkerVisible(bool b);
+
+	//! Use a custom CSS for the GUI. This is a very advanced feature, designing CSS is an art.
+	//! To use properly, place a private copy of normalStyle.css into your user data directory and edit style, but leave structure as-is.
+	//! @param cssStyle The file name without ".css"
+	//! The special name "default" can be used to reset everything to defaults.
+	//! @attention Stellarium's normalStyle.css evolves. We cannot give any guarantee that a modified CSS will work with another version of Stellarium.
+	static void setGuiStyle(const QString& cssStyle);
+
 	//! Set the minimum frames per second.  Usually this minimum will
 	//! be switched to after there are no user events for some seconds
 	//! to save power.  However, if can be useful to set this to a high
@@ -473,6 +541,10 @@ public slots:
 	//! - ProjectionMiller
 	void setProjectionMode(const QString& id);
 
+	//! Set size of current window. This will never exceed the current screen dimensions.
+	//! @return the actually gained size(width, height).
+	static Vec2d setWindowSize(int width, int height);
+
 	//! Get the status of the disk viewport
 	//! @return true if the disk view port is currently enabled
 	static bool getDiskViewport();
@@ -497,7 +569,7 @@ public slots:
 
 	//! Find out the current sky culture
 	//! @return the ID of the current sky culture (i.e. the name of the directory in
-	//! which the curret sky cultures files are found, e.g. "western")
+	//! which the current sky cultures files are found, e.g. "western")
 	static QString getSkyCulture();
 
 	//! Set the current sky culture
@@ -721,7 +793,7 @@ public slots:
 	//! Set the alpha value of a video when visible.
 	//! @param id the identifier used when loadVideo() was called
 	//! @param alpha the new alpha value to set.
-	//! @bug With Qt5/V0.13+, @param alpha does not work properly, only @param alpha=0 makes it invisible.
+	//! @bug With Qt5, @param alpha does not work properly, only @param alpha=0 makes it invisible.
 	void setVideoAlpha(const QString& id, float alpha);
 
 	//! Resize the video widget to the specified width, height.
@@ -951,6 +1023,11 @@ signals:
 	void requestSetDiskViewport(bool b);
 	void requestExit();
 	void requestSetHomePosition();
+
+private:
+#ifdef ENABLE_SCRIPT_QML
+	QJSEngine *m_engine;
+#endif
 };
 
 #endif // STELMAINSCRIPTAPI_HPP
