@@ -29,22 +29,35 @@
 #include <QPair>
 #include <QSet>
 
-#include "StelMainScriptAPI.hpp"
-
+#ifdef ENABLE_SCRIPT_QML
+#include <QMutex>
+#include <QJSValue>
+#include "V3d.hpp"
+class QJSEngine;
+#else
 class StelScriptEngineAgent;
 class QScriptEngine;
+#endif
+
+#include "StelMainScriptAPI.hpp"
 
 #ifdef ENABLE_SCRIPT_CONSOLE
 class ScriptConsole;
 #endif
 
 //! Manage scripting in Stellarium
+//! Notes on migration from QtScript to QJSEngine
+//! - The old engine had isEvaluating(). We must use a mutex for the same idea.
+//! - There is no script.pause() function. We can only stop a running script.
 class StelScriptMgr : public QObject
 {
 	Q_OBJECT
 
 	Q_PROPERTY(QString runningScriptId READ runningScriptId NOTIFY runningScriptIdChanged)
-		
+	// CAVEAT: Do not convert this class to a StelModule: The Qt properties (esp. the following 2) should not be available in the StelProperty system (and the object should not be scriptable)!
+	Q_PROPERTY(bool flagAllowExternalScreenshotDir READ getFlagAllowExternalScreenshotDir WRITE setFlagAllowExternalScreenshotDir NOTIFY flagAllowExternalScreenshotDirChanged)
+	Q_PROPERTY(bool flagAllowWriteAbsolutePaths READ getFlagAllowWriteAbsolutePaths WRITE setFlagAllowWriteAbsolutePaths NOTIFY flagAllowWriteAbsolutePathsChanged)
+
 #ifdef ENABLE_SCRIPT_CONSOLE
 friend class ScriptConsole;
 #endif
@@ -57,7 +70,11 @@ public:
 
 	//! Find out if a script is running
 	//! @return true if a script is running, else false
+	#ifdef ENABLE_SCRIPT_QML
+	bool scriptIsRunning();
+	#else
 	bool scriptIsRunning() const;
+	#endif
 	//! Get the ID (usually filename) of the currently running script
 	//! @return Empty string if no script is running, else the 
 	//! ID of the script which is running.
@@ -80,13 +97,17 @@ public:
 	void addObject(QObject *obj);
 
 	//! Define JS classes Vec3f, Vec3d
+	#ifdef ENABLE_SCRIPT_QML
+	static void defVecClasses(QJSEngine *engine);
+	#else
 	static void defVecClasses(QScriptEngine *engine);
+	#endif
 
 	//! Permit access to StelScriptMainAPI's methods
-	const QMetaObject * getMetaOfStelMainScriptAPI(){ return mainAPI->metaObject(); }
+	const QMetaObject * getMetaOfStelMainScriptAPI() const { return mainAPI->metaObject(); }
 
 	//! Accessor to QEventLoop
-	QEventLoop* getWaitEventLoop(){ return waitEventLoop; }
+	QEventLoop* getWaitEventLoop() const { return waitEventLoop; }
 
 public slots:
 	//! Returns a HTML description of the specified script.
@@ -204,7 +225,7 @@ public slots:
 	
 	//! Get the rate at which the script is running as a multiple of the normal
 	//! execution rate.
-	double getScriptRate();
+	double getScriptRate() const;
 
 	//! cause the emission of the scriptDebug signal. This is so that functions in
 	//! StelMainScriptAPI can explicitly send information to the ScriptConsole
@@ -224,11 +245,23 @@ public slots:
 	void saveOutputAs(const QString &filename);
 
 	//! Pause a running script.
+	//! @note This method only works with the Qt5-based scripting engine.
 	void pauseScript();
 
 	//! Resume a paused script.
+	//! @note This method only works with the Qt5-based scripting engine.
 	void resumeScript();
 
+	//! Ensure that users must actively enable storing screenshots to directories configured in scripts.
+	//! If this is false, a directory dir given in StelMainScriptAPI::screenshot(prefix, invert, dir, ...) is ignored.
+	bool getFlagAllowExternalScreenshotDir() const {return flagAllowExternalScreenshotDir;}
+	void setFlagAllowExternalScreenshotDir(bool flag);
+
+	//! Ensure that users must actively enable writing to absolute paths configured in scripts.
+	//! If this is false, the output file is just stored to the user data directory
+	bool getFlagAllowWriteAbsolutePaths() const {return flagAllowWriteAbsolutePaths;}
+	void setFlagAllowWriteAbsolutePaths(bool flag);
+
 private slots:
 	//! Called at the end of the running threa
 	void scriptEnded();
@@ -245,11 +278,15 @@ signals:
 	void scriptDebug(const QString&);
 	//! Notification of a script event - output line.
 	void scriptOutput(const QString&);
+	//! Notification that screenshots to script-defined directories are allowed
+	void flagAllowExternalScreenshotDirChanged(bool flag);
+	//! Notification that flag to allow scripts to write to absolute paths changed
+	void flagAllowWriteAbsolutePathsChanged(bool flag);
 
 private:
-	// Utility functions for preprocessor
-	QMap<QString, QString> mappify(const QStringList& args, bool lowerKey=false);
-	bool strToBool(const QString& str);
+	// Utility functions for preprocessor. DEAD CODE!
+	//QMap<QString, QString> mappify(const QStringList& args, bool lowerKey=false);
+	static bool strToBool(const QString& str);
 	// The recursive preprocessing workhorse.
 	void expand(const QString fileName, const QString &input, QString &output, const QString &scriptDir, int &errLoc);
 
@@ -264,8 +301,16 @@ private:
 	//! @return the text following the id and : on a comment line near the top of 
 	//! the script file (i.e. before there is a non-comment line).
 	QString getHeaderSingleLineCommentText(const QString& s, const QString& id, const QString& notFoundText="");
+
+#ifdef ENABLE_SCRIPT_QML
+	QJSEngine *engine;
+	QMutex mutex; // we need to lock this while a script is running.
+	QJSValue result;
+#else
 	QScriptEngine* engine;
-	
+	//Script engine agent
+	StelScriptEngineAgent *agent;
+#endif
 	//! The thread in which scripts are run
 	StelMainScriptAPI *mainAPI;
 
@@ -274,8 +319,6 @@ private:
 	
 	QString scriptFileName;
 	
-	//Script engine agent
-	StelScriptEngineAgent *agent;
 
 	// Map line numbers of output to <path>:<line>
 	int outline;
@@ -284,6 +327,13 @@ private:
 
 	// Registry for include files
 	QSet<QString> includeSet;
+
+	//! Ensure that users must actively allow storing screenshots to directories configured in scripts.
+	//! If this is false, a directory dir given in StelMainScriptAPI::screenshot(prefix, invert, dir, ...) is ignored.
+	bool flagAllowExternalScreenshotDir;
+	//! Ensure that users must actively allow storing output data to absolute paths.
+	//! If this is false, the output file is stored to the user data directory.
+	bool flagAllowWriteAbsolutePaths;
 };
 
 #endif // STELSCRIPTMGR_HPP
